@@ -74,12 +74,12 @@ module.exports = {
         // disallow a duplicate case label.
         'no-duplicate-case': 2,
 
-        // disallow the use of empty character classes in regular expressions
-        'no-empty-character-class': 2,
-
         // disallow empty statements
         'no-empty': 0,
 
+        // disallow the use of empty character classes in regular expressions
+        'no-empty-character-class': 2,
+
         // disallow assigning to the exception in a catch block
         'no-ex-assign': 2,
 
@@ -110,6 +110,9 @@ module.exports = {
         // disallow the use of object properties of the global object (Math and JSON) as functions
         'no-obj-calls': 2,
 
+        // disallow use of Object.prototypes builtins directly
+        'no-prototype-builtins': 2,
+
         // disallow multiple spaces in a regular expression literal
         'no-regex-spaces': 2,
 
@@ -122,6 +125,9 @@ module.exports = {
         // disallow unreachable statements after a return, throw, continue, or break statement
         'no-unreachable': 2,
 
+        // disallow control flow statements in finally blocks
+        'no-unsafe-finally': 2,
+
         // disallow comparisons with the value NaN
         'use-isnan': 2,
 
@@ -139,9 +145,12 @@ module.exports = {
         //
         // http://eslint.org/docs/rules/index.html#best-practices
 
-        // Enforces getter/setter pairs in objects
+        // enforces getter/setter pairs in objects
         'accessor-pairs': 2,
 
+        // enforces return statements in callbacks of array's methods
+        'array-callback-return': 0,
+
         // treat var statements as if they were block scoped
         'block-scoped-var': 2,
 
@@ -184,8 +193,8 @@ module.exports = {
         // disallow else after a return in an if
         'no-else-return': 0,
 
-        // disallow use of labels for anything other then loops and switches
-        'no-empty-label': 2,
+        // disallow empty functions
+        'no-empty-function': 0,
 
         // disallow use of empty destructuring patterns
         'no-empty-pattern': 2,
@@ -202,6 +211,9 @@ module.exports = {
         // disallow unnecessary function binding
         'no-extra-bind': 2,
 
+        // disallow unnecessary labels
+        'no-extra-label': 2,
+
         // disallow fallthrough of case statements
         'no-fallthrough': 2,
 
@@ -211,6 +223,9 @@ module.exports = {
         // disallow the type conversions with shorter notations
         'no-implicit-coercion': 0,
 
+        // disallow var and named functions in global scope
+        'no-implicit-globals': 2,
+
         // disallow use of eval()-like methods
         'no-implied-eval': 2,
 
@@ -241,28 +256,25 @@ module.exports = {
         // disallow reassignments of native objects
         'no-native-reassign': 2,
 
+        // disallow use of new operator when not part of the assignment or comparison
+        'no-new': 2,
+
         // disallow use of new operator for Function object
         'no-new-func': 2,
 
-        // disallows creating new instances of String,Number, and Boolean
+        // disallows creating new instances of String, Number, and Boolean
         'no-new-wrappers': 2,
 
-        // disallow use of new operator when not part of the assignment or comparison
-        'no-new': 2,
+        // disallow use of (old style) octal literals
+        'no-octal': 2,
 
         // disallow use of octal escape sequences in string literals, such as
         // var foo = 'Copyright \251';
         'no-octal-escape': 2,
 
-        // disallow use of (old style) octal literals
-        'no-octal': 2,
-
         // disallow reassignment of function parameters
         'no-param-reassign': 0,
 
-        // disallow use of process.env
-        'no-process-env': 2,
-
         // disallow usage of __proto__ property
         'no-proto': 2,
 
@@ -275,6 +287,9 @@ module.exports = {
         // disallow use of `javascript:` urls.
         'no-script-url': 2,
 
+        // disallow self assignment
+        'no-self-assign': 2,
+
         // disallow comparisons where both sides are exactly the same
         'no-self-compare': 2,
 
@@ -282,17 +297,26 @@ module.exports = {
         'no-sequences': 2,
 
         // restrict what can be thrown as an exception
-        'no-throw-literal': 0,
+        'no-throw-literal': 2,
+
+        // disallow unmodified conditions of loops
+        'no-unmodified-loop-condition': 0, // disabled temporarily: https://github.com/eslint/eslint/issues/6280
 
         // disallow usage of expressions in statement position
         'no-unused-expressions': 2,
 
+        // disallow unused labels
+        'no-unused-labels': 2,
+
         // disallow unnecessary .call() and .apply()
         'no-useless-call': 2,
 
         // disallow unnecessary concatenation of literals or template literals
         'no-useless-concat': 2,
 
+        // disallow unnecessary escape characters
+        'no-useless-escape': 2,
+
         // disallow use of void operator
         'no-void': 2,
 
@@ -312,7 +336,7 @@ module.exports = {
         'wrap-iife': [2, 'outside'],
 
         // require or disallow Yoda conditions
-        'yoda': [2, 'never'],
+        'yoda': 0,
 
         // STRICT MODE ========================================================
         //
@@ -341,18 +365,21 @@ module.exports = {
         // disallow labels that share a name with a variable
         'no-label-var': 2,
 
-        // disallow shadowing of names such as arguments
-        'no-shadow-restricted-names': 2,
+        // disallow specific global variables
+        'no-restricted-globals': 2,
 
         // disallow declaration of variables already declared in the outer scope
         'no-shadow': 0,
 
-        // disallow use of undefined when initializing variables
-        'no-undef-init': 2,
+        // disallow shadowing of names such as arguments
+        'no-shadow-restricted-names': 2,
 
         // disallow use of undeclared variables unless mentioned in a 'globals'
         'no-undef': 2,
 
+        // disallow use of undefined when initializing variables
+        'no-undef-init': 2,
+
         // disallow use of undefined variable
         'no-undefined': 0,
 
@@ -401,6 +428,9 @@ module.exports = {
         // enforces use of function declarations or expressions
         'func-style': 0,
 
+        // disallow specified identifiers
+        'id-blacklist': 2,
+
         // this option enforces minimum and maximum identifier lengths (variable names, property names etc.)
         'id-length': 0,
 
@@ -416,6 +446,9 @@ module.exports = {
         // enforces spacing between keys and values in object literal properties
         'key-spacing': [2, { beforeColon: false, afterColon: true, mode: 'minimum' }],
 
+        // enforces spacing between keys and values in object literal properties
+        'keyword-spacing': 2,
+
         // disallow mixed 'LF' and 'CRLF' as linebreaks
         'linebreak-style': [2, 'unix'],
 
@@ -437,6 +470,9 @@ module.exports = {
         // specify the maximum number of statement allowed in a function
         'max-statements': 0,
 
+        // enforce a maximum number of statements allowed per line
+        'max-statements-per-line': 0,
+
         // require a capital letter for constructors
         'new-cap': [2, { capIsNew: true, newIsCap: true, properties: true, capIsNewExceptions: ['$.Deferred', 'Baton'] }],
 
@@ -446,6 +482,12 @@ module.exports = {
         // allow/disallow an empty newline after var statement
         'newline-after-var': 0,
 
+        // require an empty line before return statements
+        'newline-before-return': 0,
+
+        // require a newline after each call in a method chain
+        'newline-per-chained-call': 0,
+
         // disallow use of the Array constructor
         'no-array-constructor': 2,
 
@@ -497,12 +539,21 @@ module.exports = {
         // disallow the use of Boolean literals in conditional expressions
         'no-unneeded-ternary': [2, { defaultAssignment: true }],
 
+        // disallow whitespace before properties
+        'no-whitespace-before-property': 2,
+
         // require or disallow padding inside curly braces
         'object-curly-spacing': [2, 'always', { objectsInObjects: true, arraysInObjects: true }],
 
+        // enforce placing object properties on separate lines
+        'object-property-newline': 0,
+
         // allow just one var statement per function
         'one-var': 0,
 
+        // require or disallow an newline around variable declarations
+        'one-var-declaration-per-line': 0,
+
         // require assignment operator shorthand where possible or prohibit it entirely
         'operator-assignment': 1,
 
@@ -521,42 +572,36 @@ module.exports = {
         // Require JSDoc comment
         'require-jsdoc': 0,
 
-        // enforce spacing before and after semicolons
-        'semi-spacing': [2, { before: false, after: true }],
-
         // require or disallow use of semicolons instead of ASI
         'semi': [2, 'always'],
 
+        // enforce spacing before and after semicolons
+        'semi-spacing': [2, { before: false, after: true }],
+
         // sort variables within the same declaration block
         'sort-vars': 0,
 
-        // require a space after certain keywords
-        'space-after-keywords': 2,
-
         // require or disallow space before blocks
         'space-before-blocks': 2,
 
         // require or disallow space before function opening parenthesis
         'space-before-function-paren': [2, { anonymous: 'always', named: 'never' }],
 
-        // require a space before certain keywords
-        'space-before-keywords': [2, 'always'],
-
         // require or disallow spaces inside parentheses
         'space-in-parens': [2, 'never'],
 
         // require spaces around operators
         'space-infix-ops': 2,
 
-        // require a space after return, throw, and case
-        'space-return-throw-case': 2,
-
         // Require or disallow spaces before/after unary operators
         'space-unary-ops': 2,
 
         // require or disallow a space immediately following the // or /* in a comment
         'spaced-comment': 0,
 
+        // require or disallow the Unicode Byte Order Mark (BOM)
+        'unicode-bom': [2, "never"],
+
         // require regex literals to be wrapped in parentheses
         'wrap-regex': 0
     }
