@@ -12,15 +12,26 @@
  */
 
 define('io.ox/office/baseframework/app/basecontroller', [
+
+    'io.ox/core/capabilities',
+
+    'io.ox/office/tk/config',
     'io.ox/office/tk/utils',
+
     'io.ox/office/tk/keycodes',
     'io.ox/office/tk/dialogs',
+
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/tk/utils/shareutils',
+    'io.ox/office/tk/utils/domconsole',
+
     'io.ox/office/tk/object/baseobject',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
+
     'io.ox/office/baseframework/app/appobjectmixin'
-], function (Utils, KeyCodes, Dialogs, DriveUtils, BaseObject, TriggerObject, TimerMixin, AppObjectMixin) {
+
+], function (Capabilities, Config, Utils, KeyCodes, Dialogs, DriveUtils, ShareUtils, DOMConsole, BaseObject, TriggerObject, TimerMixin, AppObjectMixin) {
 
     'use strict';
 
@@ -115,54 +126,56 @@ define('io.ox/office/baseframework/app/basecontroller', [
      */
     function BaseController(app, docModel, docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // all registered controller items, mapped by item key
-            items = {},
+        // all registered controller items, mapped by item key
+        var items = {};
 
-            // dummy item, used e.g. for undefined parent items
-            dummyItem = null,
+        // dummy item, used e.g. for undefined parent items
+        var dummyItem = null;
 
-            // the delay time for the debounced BaseController.update() method
-            // Bug 30479: must NOT be 0, to be able give some space for deferred
-            // focus handling in form controls, for example in text fields which
-            // want to commit their value before the controller will reset it.
-            updateDelay = Utils.getIntegerOption(initOptions, 'updateDelay', 50, 50),
+        // the delay time for the debounced BaseController.update() method
+        // Bug 30479: must NOT be 0, to be able give some space for deferred
+        // focus handling in form controls, for example in text fields which
+        // want to commit their value before the controller will reset it.
+        var updateDelay = Utils.getIntegerOption(initOptions, 'updateDelay', 50, 50);
 
-            // cached item states, mapped by item keys
-            stateCache = {},
+        // cached item states, mapped by item keys
+        var stateCache = {};
 
-            // cached states of all controller items as notified the last time
-            notifiedStateCache = {},
+        var controllerUpdatePromise = $.when();
 
-            // number of item setters currently running (recursion counter)
-            runningSetters = 0,
+        // cached states of all controller items as notified the last time
+        var notifiedStateCache = {};
 
-            // shortcut definitions for 'keydown', mapped by key code (for performance)
-            keyShortcuts = {},
+        // number of item setters currently running (recursion counter)
+        var runningSetters = 0;
 
-            // shortcut definitions for 'keypress', mapped by char code (for performance)
-            charShortcuts = {};
+        // shortcut definitions for 'keydown', mapped by key code (for performance)
+        var keyShortcuts = {};
+
+        // shortcut definitions for 'keypress', mapped by char code (for performance)
+        var charShortcuts = {};
 
         // class Item ---------------------------------------------------------
 
         var Item = BaseObject.extend({ constructor: function (key, definition) {
 
-            var // parent items whose values/states are needed to resolve the own value/state
-                parentKeys = Utils.getOption(definition, 'parent'),
-                // handler for enabled state (default to function that returns true)
-                enableHandler = Utils.getFunctionOption(definition, 'enable', _.constant(true)),
-                // handler for value getter (default to identity to forward first parent value)
-                getHandler = Utils.getFunctionOption(definition, 'get', _.identity),
-                // handler for value setter
-                setHandler = Utils.getFunctionOption(definition, 'set'),
-                // whether an asynchronous setter is cancelable
-                cancelable = Utils.getBooleanOption(definition, 'cancel', false),
-                // behavior for returning browser focus to application
-                itemPreserveFocus = Utils.getBooleanOption(definition, 'preserveFocus', false),
-                // custom focus target node or callback handler
-                itemFocusTarget = Utils.getOption(definition, 'focusTarget');
+            // parent items whose values/states are needed to resolve the own value/state
+            var parentKeys = Utils.getOption(definition, 'parent');
+            // handler for enabled state (default to function that returns true)
+            var enableHandler = Utils.getFunctionOption(definition, 'enable', _.constant(true));
+            // handler for value getter (default to identity to forward first parent value)
+            var getHandler = Utils.getFunctionOption(definition, 'get', _.identity);
+            // handler for value setter
+            var setHandler = Utils.getFunctionOption(definition, 'set');
+            // whether an asynchronous setter is cancelable
+            var cancelable = Utils.getBooleanOption(definition, 'cancel', false);
+            // behavior for returning browser focus to application
+            var itemPreserveFocus = Utils.getBooleanOption(definition, 'preserveFocus', false);
+            // custom focus target node or callback handler
+            var itemFocusTarget = Utils.getOption(definition, 'focusTarget');
 
             BaseObject.call(this);
 
@@ -320,7 +333,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
                     // execute the set handler
                     runningSetters += 1;
                     if (_.isFunction(setHandler)) {
-                        promise = setHandler.call(this, value);
+                        promise = setHandler.call(this, value, options);
                     }
 
                     // convert result of the setter callback to a promise
@@ -354,12 +367,12 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 }
 
                 // post-processing after the setter is finished
-                Utils.logSelenium('time=' + _.now(), 'key=' + key, 'state=' + promise.state());
+                Utils.logSelenium(key, promise.state());
                 if (pending) {
                     this.waitForAny(promise, function () {
                         docView.leaveBusy();
                         finalize();
-                        Utils.logSelenium('time=' + _.now(), 'key=' + key, 'state=' + promise.state());
+                        Utils.logSelenium(key, promise.state());
                     });
                 } else {
                     finalize();
@@ -714,6 +727,9 @@ define('io.ox/office/baseframework/app/basecontroller', [
             // clear the entire cache state on every call of the update() method
             function invalidateStates() {
                 stateCache = {};
+                if (controllerUpdatePromise.state() !== 'pending') {
+                    controllerUpdatePromise = $.Deferred();
+                }
             }
 
             // after a delay, collect all item states, and notify change listeners
@@ -754,6 +770,8 @@ define('io.ox/office/baseframework/app/basecontroller', [
                         self.trigger('change:items', changedStates);
                     });
                 }
+
+                controllerUpdatePromise.resolve();
             }
 
             return self.createDebouncedMethod(invalidateStates, updateStates, { delay: updateDelay, infoString: 'BaseController: update' });
@@ -893,6 +911,10 @@ define('io.ox/office/baseframework/app/basecontroller', [
             return this;
         };
 
+        this.getControllerUpdatePromise = function () {
+            return controllerUpdatePromise;
+        };
+
         // initialization -----------------------------------------------------
 
         // dummy item singleton, used e.g. for undefined parent items
@@ -917,6 +939,16 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 enable: function () { return !app.isStandalone(); }
             },
 
+            'app/share': {
+                parent: ['app/imported', 'app/bundled'],
+                enable: function () { return DriveUtils.isShareable(app.getFileDescriptor()); }
+            },
+
+            // all supported operation systems have a file system where user can save in, but not on IOS
+            'system/filesystem': {
+                enable: function () { return !Utils.IOS; }
+            },
+
             // download the document: enabled in read-only mode, disabled during import
             'document/download': {
                 parent: ['app/imported', 'system/filesystem'],
@@ -930,22 +962,57 @@ define('io.ox/office/baseframework/app/basecontroller', [
                 shortcut: { keyCode: 'P', ctrlOrMeta: true }
             },
 
-            // compose new mail with this document's content being the mail-body's content:
-            // enabled in read-only mode, disabled during import, disabled in stand-alone-mode
+            // compose new mail with this document as attachment
             'document/sendmail': {
                 parent: ['app/imported', 'app/bundled'],
-                enable: function () { return !DriveUtils.isGuest(); },
+                enable: function () { return (Capabilities.has('webmail') && !DriveUtils.isGuest()); },
                 set: function () { return app.sendMail(); }
             },
+
+            // compose new mail with this document's content being the mail-body's content:
+            // enabled in read-only mode, disabled during import, disabled in stand-alone-mode
             'document/sendmail/inline-html': {
                 parent: 'document/sendmail',
                 enable: function () { return app.canSendMail(); },
                 set: function (config) { return app.sendMail(config); }
             },
 
-            // all supported operation systems have a file system where user can save in, but not on IOS
-            'system/filesystem': {
-                enable: function () { return !Utils.IOS; }
+            'document/sendmail/pdf-attachment': {
+                parent: 'document/sendmail',
+                //enable: function () { return app.canSendMail(); },
+                set: function (config) { return app.sendMail(config); }
+            },
+
+            'document/sendmail/menu': {
+                parent: 'app/share',
+                enable: function () { return (Capabilities.has('webmail') && !DriveUtils.isGuest()); }
+            },
+
+            'document/share': {
+                parent: 'app/share'
+            },
+
+            'document/share/getlink': {
+                parent: 'document/share',
+                set: function () { return ShareUtils.shareLink(app.getFileDescriptor());  }
+            },
+
+            'document/share/inviteuser': {
+                parent: 'document/share',
+                set: function () { return ShareUtils.inviteUser(app.getFileDescriptor()); }
+            },
+
+            // debug mode
+
+            'debug/enabled': {
+                parent: 'app/valid',
+                enable: function () { return Config.DEBUG; }
+            },
+
+            'debug/console': {
+                parent: 'debug/enabled',
+                get: function () { return DOMConsole.isVisible(); },
+                set: function (state) { DOMConsole.toggle(state); }
             }
         });
 
@@ -953,6 +1020,7 @@ define('io.ox/office/baseframework/app/basecontroller', [
         this.waitForImportSuccess(function () {
             initializeKeyHandler();
             this.listenTo(docView, 'refresh:layout', function () { self.update(); });
+            this.listenTo(DOMConsole, 'change:state', function () { self.update(); });
             this.update();
         }, this);
 
