@@ -5,6 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
+ *
  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
@@ -18,118 +19,115 @@ define('io.ox/office/baseframework/app/extensionregistry', [
 
     'use strict';
 
-    var // which file formats are editable (maps format identifier to booleans)
-        EDITABLE_FILE_FORMATS = {
-            ooxml: true,
-            odf: Config.getFlag('odfsupport', true)
-        },
+    // which file formats are editable (maps format identifier to booleans)
+    var EDITABLE_FILE_FORMATS = {
+        ooxml: true,
+        odf: Config.getFlag('odfsupport', true)
+    };
 
-        // the extension suffix for files with an internal error
-        INTERNAL_ERROR_SUFFIX = '_ox',
+    // the extension suffix for files with an internal error
+    var INTERNAL_ERROR_SUFFIX = '_ox';
 
-        // file extension configuration
-        FILE_EXTENSION_CONFIGURATION = {
+    // file extension configuration
+    var FILE_EXTENSION_CONFIGURATION = {
 
-            text: {
-                module: 'io.ox/office/text',
-                requires: 'text',
-                editable: !_.browser.Android || Utils.supportedChromeVersionOnAndroidForText(),
-                extensions: {
-                    docx: { format: 'ooxml' },
-                    docm: { format: 'ooxml', macros: true },
-                    dotx: { format: 'ooxml', template: true },
-                    dotm: { format: 'ooxml', template: true, macros: true },
-                    odt:  { format: 'odf', macros: true },
-                    ott:  { format: 'odf', template: true, macros: true },
-                    doc:  { format: 'ooxml', macros: true, convert: true },
-                    dot:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
-                    rtf:  { format: 'ooxml', convert: true }
-                }
-            },
-
-            spreadsheet: {
-                module: 'io.ox/office/spreadsheet',
-                requires: 'spreadsheet',
-                editable: true,
-                extensions: {
-                    xlsx: { format: 'ooxml' },
-                    xlsm: { format: 'ooxml', macros: true },
-                    xltx: { format: 'ooxml', template: true },
-                    xltm: { format: 'ooxml', template: true, macros: true },
-                    xlam: { macros: true }, // add-in
-                    xls:  { format: 'ooxml', macros: true, convert: true },
-                    xlt:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
-                    xla:  { macros: true }, // add-in
-                    xlsb: { format: 'ooxml', macros: true, convert: true },
-                    ods:  { format: 'odf', macros: true }, //spreadsheet
-                    ots:  { format: 'odf', template: true, macros: true } //spreadsheet
-                }
-            },
-
-            presentation: {
-                module: 'io.ox/office/presentation',
-                requires: 'presentation',
-                editable: !_.browser.Android || Utils.supportedChromeVersionOnAndroidForText(),
-                extensions: {
-                    pptx: { format: 'ooxml' },
-                    pptm: { format: 'ooxml', macros: true },
-                    potx: { format: 'ooxml', template: true },
-                    potm: { format: 'ooxml', template: true, macros: true },
-                    ppsx: {}, // slide show
-                    ppsm: { macros: true }, // slide show
-                    ppam: { macros: true }, // add-in
-                    odp:  { format: 'odf', macros: true },
-                    otp:  { format: 'odf', template: true, macros: true },
-                    ppt:  { format: 'ooxml', macros: true, convert: true },
-                    pot:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
-                    pps:  { format: 'ooxml', macros: true, convert: true }, // slide show
-                    ppa:  { format: 'ooxml', macros: true, convert: true } // add-in
-                }
-            },
-
-            preview: {
-                extensions: {
-                    pdf:  {},
-                    odg:  { format: 'odf', macros: true }, // drawing
-                    otg:  { format: 'odf', template: true, macros: true }, // drawing
-                    odi:  { format: 'odf' }, // image
-                    oti:  { format: 'odf', template: true }, // image
-                    odc:  { format: 'odf' }, // chart
-                    otc:  { format: 'odf', template: true }, // chart
-                    odf:  { format: 'odf' }, // formula
-                    otf:  { format: 'odf', template: true }, // formula
-                    odm:  { format: 'odf' } // global text document
-                }
+        text: {
+            module: 'io.ox/office/text',
+            requires: 'text',
+            editable: !_.browser.Android || Utils.supportedChromeVersionOnAndroidForText(),
+            extensions: {
+                docx: { format: 'ooxml' },
+                docm: { format: 'ooxml', macros: true },
+                dotx: { format: 'ooxml', template: true },
+                dotm: { format: 'ooxml', template: true, macros: true },
+                odt:  { format: 'odf', macros: true },
+                ott:  { format: 'odf', template: true, macros: true },
+                doc:  { format: 'ooxml', macros: true, convert: true },
+                dot:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
+                rtf:  { format: 'ooxml', convert: true }
             }
         },
 
-        // extension to template extension map
-        EXT_TO_TEMPLATE_EXT_MAP = {
-            docx: 'dotx',
-            docm: 'dotx',
-            dotm: 'dotx',
-            xlsx: 'xltx',
-            xlsm: 'xltx',
-            xltm: 'xltx',
-            pptx: 'potx',
-            pptm: 'potx',
-            potm: 'potx',
-            odt: 'ott',
-            ods: 'ots',
-            odp: 'otp'
+        spreadsheet: {
+            module: 'io.ox/office/spreadsheet',
+            requires: 'spreadsheet',
+            editable: true,
+            extensions: {
+                xlsx: { format: 'ooxml' },
+                xlsm: { format: 'ooxml', macros: true },
+                xltx: { format: 'ooxml', template: true },
+                xltm: { format: 'ooxml', template: true, macros: true },
+                xlam: { macros: true }, // add-in
+                xls:  { format: 'ooxml', macros: true, convert: true },
+                xlt:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
+                xla:  { macros: true }, // add-in
+                xlsb: { format: 'ooxml', macros: true, convert: true },
+                ods:  { format: 'odf', macros: true }, //spreadsheet
+                ots:  { format: 'odf', template: true, macros: true } //spreadsheet
+            }
         },
 
-        // all application configurations, mapped by application identifier
-        applicationMap = {},
+        presentation: {
+            module: 'io.ox/office/presentation',
+            requires: 'presentation',
+            editable: !_.browser.Android || Utils.supportedChromeVersionOnAndroidForText(),
+            extensions: {
+                pptx: { format: 'ooxml' },
+                pptm: { format: 'ooxml', macros: true },
+                potx: { format: 'ooxml', template: true },
+                potm: { format: 'ooxml', template: true, macros: true },
+                ppsx: {}, // slide show
+                ppsm: { macros: true }, // slide show
+                ppam: { macros: true }, // add-in
+                odp:  { format: 'odf', macros: true },
+                otp:  { format: 'odf', template: true, macros: true },
+                ppt:  { format: 'ooxml', macros: true, convert: true },
+                pot:  { format: 'ooxml', template: true, templateLocked: true, macros: true, convert: true },
+                pps:  { format: 'ooxml', macros: true, convert: true }, // slide show
+                ppa:  { format: 'ooxml', macros: true, convert: true } // add-in
+            }
+        },
 
-        // all configurations, mapped by lower-case extension
-        fileExtensionMap = {},
+        preview: {
+            extensions: {
+                pdf:  {},
+                odg:  { format: 'odf', macros: true }, // drawing
+                otg:  { format: 'odf', template: true, macros: true }, // drawing
+                odi:  { format: 'odf' }, // image
+                oti:  { format: 'odf', template: true }, // image
+                odc:  { format: 'odf' }, // chart
+                otc:  { format: 'odf', template: true }, // chart
+                odf:  { format: 'odf' }, // formula
+                otf:  { format: 'odf', template: true }, // formula
+                odm:  { format: 'odf' } // global text document
+            }
+        }
+    };
 
-        // all editable file ending in a comma separated String
-        editableFileExtensions = null,
+    // extension to template extension map
+    var EXT_TO_TEMPLATE_EXT_MAP = {
+        docx: 'dotx',
+        docm: 'dotx',
+        dotm: 'dotx',
+        xlsx: 'xltx',
+        xlsm: 'xltx',
+        xltm: 'xltx',
+        pptx: 'potx',
+        pptm: 'potx',
+        potm: 'potx',
+        odt: 'ott',
+        ods: 'ots',
+        odp: 'otp'
+    };
 
-        // whether OX Preview is available at all
-        previewAvailable = Capabilities.has('document_preview');
+    // all application configurations, mapped by application identifier
+    var applicationMap = {};
+
+    // all configurations, mapped by lower-case extension
+    var fileExtensionMap = {};
+
+    // whether OX Preview is available at all
+    var previewAvailable = Capabilities.has('document_preview');
 
     // static class ExtensionRegistry =========================================
 
@@ -155,35 +153,6 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return Utils.getBooleanOption(applicationMap[editModule], 'editable', false);
     };
 
-    /**
-     * Returns the lower-case extension of the passed file name.
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @returns {String}
-     *  The lower-case extension of the passed file name.
-     */
-    ExtensionRegistry.getExtension = function (fileName) {
-        var index = String(fileName || '').lastIndexOf('.');
-        return (index >= 0) ? fileName.substring(index + 1).toLowerCase() : '';
-    };
-
-    /**
-     * Returns the base name of the passed file name, without file extension.
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @returns {String}
-     *  The base name of the passed file name. Character case will be
-     *  preserved.
-     */
-    ExtensionRegistry.getBaseName = function (fileName) {
-        var index = String(fileName || '').lastIndexOf('.');
-        return (index > 0) ? fileName.substring(0, index) : index;
-    };
-
     /**
      * Returns the configuration settings of the file extension contained by
      * the passed file name.
@@ -201,12 +170,12 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      */
     ExtensionRegistry.getExtensionSettings = function (fileName, editModule) {
 
-        var // the lower-case extension of the passed file name
-            extension = ExtensionRegistry.getExtension(fileName),
-            // the extension settings object
-            extensionSettings = (extension in fileExtensionMap) ? fileExtensionMap[extension] : null,
-            // the module name of the edit application for the extension
-            module = Utils.getStringOption(extensionSettings, 'module');
+        // the lower-case extension of the passed file name
+        var extension = Utils.getFileExtension(fileName);
+        // the extension settings object
+        var extensionSettings = (extension in fileExtensionMap) ? fileExtensionMap[extension] : null;
+        // the module name of the edit application for the extension
+        var module = Utils.getStringOption(extensionSettings, 'module');
 
         // passed module name must match if specified
         return (_.isString(editModule) && (editModule !== module)) ? null : extensionSettings;
@@ -233,9 +202,9 @@ define('io.ox/office/baseframework/app/extensionregistry', [
     };
 
     /**
-     * Returns all extensions that can be viewed with OX Preview as array.
+     * Returns all extensions that can be viewed with OX Preview, as array.
      *
-     * @returns {Array}
+     * @returns {Array<String>}
      *  All extensions supported by OX Preview.
      */
     ExtensionRegistry.getViewableExtensions = function () {
@@ -248,6 +217,22 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return extensions;
     };
 
+    /**
+     * Returns an array containing all file extensions that can be edited.
+     *
+     * @returns {Array<String>}
+     *  An array containing all file extensions that can be edited.
+     */
+    ExtensionRegistry.getEditableExtensions = function () {
+        var extensions = [];
+        _.each(fileExtensionMap, function (settings, extension) {
+            if (settings.editable) {
+                extensions.push(extension);
+            }
+        });
+        return extensions;
+    };
+
     /**
      * Returns whether the file with the passed name is viewable by the OX
      * Preview application.
@@ -270,18 +255,14 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      * @param {String} fileName
      *  The file name (case-insensitive).
      *
-     * @returns {String}
+     * @returns {String|Null}
      *  The module name of the edit application that is able to modify the file
-     *  with the passed file name; or null, if the file is not
-     *  editable.
+     *  with the passed file name; or null, if no edit module exists for the
+     *  file extension.
      */
     ExtensionRegistry.getEditModule = function (fileName) {
         var extensionSettings = ExtensionRegistry.getExtensionSettings(fileName);
-        if (extensionSettings && extensionSettings.editable) {
-            return Utils.getStringOption(extensionSettings, 'module', '');
-        } else {
-            return null;
-        }
+        return Utils.getStringOption(extensionSettings, 'module', null);
     };
 
     /**
@@ -372,48 +353,6 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         return Utils.getStringOption(extensionSettings, 'format', '');
     };
 
-    /**
-     * Returns whether the file with the passed name is a file that will be
-     * edited in the OfficeOpenXML file format (either natively, or by
-     * conversion from a file format not supported natively).
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @param {String} [editModule]
-     *  If specified, must match the module name of the edit application
-     *  registered for the extension of the passed file name. If omitted, the
-     *  edit application module name for the extension will be ignored.
-     *
-     * @returns {Boolean}
-     *  Whether the specified file will be edited in the OfficeOpenXML file
-     *  format.
-     */
-    ExtensionRegistry.isOfficeOpenXML = function (fileName, editModule) {
-        return ExtensionRegistry.getFileFormat(fileName, editModule) === 'ooxml';
-    };
-
-    /**
-     * Returns whether the file with the passed name is a file that will be
-     * edited in the OpenDocument file format (either natively, or by
-     * conversion from a file format not supported natively).
-     *
-     * @param {String} fileName
-     *  The file name (case-insensitive).
-     *
-     * @param {String} [editModule]
-     *  If specified, must match the module name of the edit application
-     *  registered for the extension of the passed file name. If omitted, the
-     *  edit application module name for the extension will be ignored.
-     *
-     * @returns {Boolean}
-     *  Whether the specified file will be edited in the OpenDocument file
-     *  format.
-     */
-    ExtensionRegistry.isOpenDocument = function (fileName, editModule) {
-        return ExtensionRegistry.getFileFormat(fileName, editModule) === 'odf';
-    };
-
     /**
      * Returns whether the file with the passed name is a template file.
      *
@@ -484,7 +423,7 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  extension suffix.
      */
     ExtensionRegistry.isError = function (fileName) {
-        var extension = ExtensionRegistry.getExtension(fileName);
+        var extension = Utils.getFileExtension(fileName);
         return extension.indexOf(INTERNAL_ERROR_SUFFIX, extension.length - INTERNAL_ERROR_SUFFIX.length) >= 0;
     };
 
@@ -514,34 +453,24 @@ define('io.ox/office/baseframework/app/extensionregistry', [
      *  be written to a template format.
      */
     ExtensionRegistry.getTemplateExtensionForFileName = function (fileName) {
-        var extension = ExtensionRegistry.getExtension(fileName);
+        var extension = Utils.getFileExtension(fileName);
         extension = EXT_TO_TEMPLATE_EXT_MAP[extension];
         return _.isString(extension) ? extension : null;
     };
 
-    /**
-     * @returns {String}
-     *  comma separated file extensions
-     */
-    ExtensionRegistry.getEditableTypes = function () {
-        return editableFileExtensions;
-    };
-
     // static initialization ==================================================
 
-    var editableList = [];
-
     // process the configuration of all modules
     _.each(FILE_EXTENSION_CONFIGURATION, function (moduleConfiguration, documentType) {
 
-        var // the capability required to edit the file
-            editable = Utils.getBooleanOption(moduleConfiguration, 'editable', false),
-            // the capability required to edit the file
-            requires = Utils.getStringOption(moduleConfiguration, 'requires', null),
-            // the module name of the edit application
-            module = Utils.getStringOption(moduleConfiguration, 'module', null),
-            // whether the edit module is available at all
-            editAvailable = editable && _.isString(requires) && Capabilities.has(requires) && _.isString(module);
+        // the capability required to edit the file
+        var editable = Utils.getBooleanOption(moduleConfiguration, 'editable', false);
+        // the capability required to edit the file
+        var requires = Utils.getStringOption(moduleConfiguration, 'requires', null);
+        // the module name of the edit application
+        var module = Utils.getStringOption(moduleConfiguration, 'module', null);
+        // whether the edit module is available at all
+        var editAvailable = editable && _.isString(requires) && Capabilities.has(requires) && _.isString(module);
 
         // application configuration antry
         applicationMap[documentType] = { editable: editAvailable };
@@ -549,10 +478,10 @@ define('io.ox/office/baseframework/app/extensionregistry', [
         // process all extensions registered for the module
         _.each(moduleConfiguration.extensions, function (extensionSettings, extension) {
 
-            var // the file format of files with the current extension
-                format = Utils.getStringOption(extensionSettings, 'format', ''),
-                // whether the file extension is supported natively
-                native = !Utils.getBooleanOption(extensionSettings, 'convert', false);
+            // the file format of files with the current extension
+            var format = Utils.getStringOption(extensionSettings, 'format', '');
+            // whether the file extension is supported natively
+            var native = !Utils.getBooleanOption(extensionSettings, 'convert', false);
 
             if (extension in fileExtensionMap) {
                 Utils.warn('ExtensionRegistry(): extension "' + extension + '" already registered');
@@ -572,18 +501,12 @@ define('io.ox/office/baseframework/app/extensionregistry', [
             // initialize all properties of the current extension with internal error
             // suffix (native only) - these files are not viewable in OX Preview
             if (native) {
-                fileExtensionMap[extension + INTERNAL_ERROR_SUFFIX] = _.chain(fileExtensionMap[extension]).clone().extend({ viewable: false }).value();
-            }
-
-            if (fileExtension.editable) {
-                editableList.push('.' + extension);
-                if (native) { editableList.push('.' + extension + INTERNAL_ERROR_SUFFIX); }
+                fileExtension = _.extend({}, fileExtension, { viewable: false });
+                fileExtensionMap[extension + INTERNAL_ERROR_SUFFIX] = fileExtension;
             }
         });
     });
 
-    editableFileExtensions = editableList.join(',');
-
     // exports ================================================================
 
     return ExtensionRegistry;
