@@ -19,14 +19,14 @@ define('io.ox/office/baseframework/app/guidedtour', [
 
     'use strict';
 
-    var // debug mode: whether to show all tours repeatedly
-        DEBUG_SHOW_TOURS = Config.getDebugUrlFlag('office:show-tours'),
+    // debug mode: whether to show all tours repeatedly
+    var DEBUG_SHOW_TOURS = Config.getDebugUrlFlag('office:show-tours');
 
-        // the RequireJS paths of all registered application tours
-        appTourRegistry = {},
+    // the RequireJS paths of all registered application tours
+    var appTourRegistry = {};
 
-        // whether a tour is currently running, for fail-safety
-        isTourRunning = false;
+    // whether a tour is currently running, for fail-safety
+    var isTourRunning = false;
 
     // class StepMixin ========================================================
 
@@ -536,7 +536,7 @@ define('io.ox/office/baseframework/app/guidedtour', [
      */
     GuidedTour.registerAppTour = function (appType, requirePath) {
         appTourRegistry[appType] = requirePath;
-        Wizard.registry.add({ id: appType }, function () { GuidedTour.run(requirePath); });
+        Wizard.registry.add({ id: 'default/' + appType }, function () { GuidedTour.run(requirePath); });
     };
 
     /**
@@ -588,17 +588,6 @@ define('io.ox/office/baseframework/app/guidedtour', [
         return requirePath ? GuidedTour.run(requirePath, options) : $.Deferred().reject();
     };
 
-    // static initialization ==================================================
-
-    // Dynamically create the method app.getTour() for all new application instances that
-    // have a registered welcome tour (see static method GuidedTour.registerAppTour()
-    // above for more details). This will add the 'Guided tour for this app' menu entry
-    // in the drop-down menu of the top bar.
-    ox.on('app:init', function (app) {
-        var appType = app.getName(), requirePath = appTourRegistry[appType];
-        if (requirePath) { app.getTour = _.constant({ id: appType, path: requirePath }); }
-    });
-
     // exports ================================================================
 
     return GuidedTour;
