@@ -36,7 +36,6 @@ define('io.ox/office/baseframework/utils/clienterror', [
     ClientError.ERROR_WHILE_MODIFYING_DOCUMENT = { error: 'ERROR_WHILE_MODIFYING_DOCUMENT', errorClass: ErrorCode.ERRORCLASS_ERROR };
     ClientError.ERROR_WHILE_LOADING_DOCUMENT = { error: 'ERROR_WHILE_LOADING_DOCUMENT', errorClass: ErrorCode.ERRORCLASS_ERROR };
     ClientError.ERROR_SIRI_NOT_SUPPORTED = { error: 'ERROR_SIRI_NOT_SUPPORTED', errorClass: ErrorCode.ERRORCLASS_ERROR };
-    ClientError.ERROR_CLIPBOARD_TIMEOUT = { error: 'ERROR_CLIPBOARD_TIMEOUT', errorClass: ErrorCode.ERRORCLASS_ERROR };
     ClientError.ERROR_ANDROID_IME_NOT_SUPPORTED_KEYBOARD = { error: 'ERROR_ANDROID_IME_NOT_SUPPORTED_KEYBOARD', errorClass: ErrorCode.ERRORCLASS_ERROR };
     ClientError.ERROR_LOAD_DOC_FAILED_SERVER_TOO_BUSY = { error: 'ERROR_LOAD_DOC_FAILED_SERVER_TOO_BUSY', errorClass: ErrorCode.ERRORCLASS_ERROR };
     ClientError.ERROR_BAD_SERVER_COMPONENT_DETECTED = { error: 'ERROR_BAD_SERVER_COMPONENT_DETECTED', errorClass: ErrorCode.ERRORCLASS_ERROR };
@@ -55,6 +54,7 @@ define('io.ox/office/baseframework/utils/clienterror', [
     ClientError.WARNING_DOC_IS_LOCKED = { error: 'WARNING_DOC_IS_LOCKED', errorClass: ErrorCode.ERRORCLASS_WARNING };
     ClientError.WARNING_SYNC_AFTER_OFFLINE = { error: 'WARNING_SYNC_AFTER_OFFLINE', errorClass: ErrorCode.ERRORCLASS_WARNING };
     ClientError.WARNING_SYNC_FOR_VIEWER = { error: 'WARNING_SYNC_FOR_VIEWER', errorClass: ErrorCode.ERRORCLASS_WARNING };
+    ClientError.WARNING_RESCUE_DOC_CANNOT_BE_CHANGED = { error: 'WARNING_RESCUE_DOC_CANNOT_BE_CHANGED', errorClass: ErrorCode.ERRORCLASS_WARNING };
 
     // exports ================================================================
 
