@@ -46,7 +46,10 @@ define('io.ox/office/baseframework/utils/errorcode', [
             errorContext = null,
 
             // optional error context data
-            errorContextData = null;
+            errorContextData = null,
+
+            // optional error value
+            errorValue = null;
 
         // public methods -----------------------------------------------------
 
@@ -131,6 +134,19 @@ define('io.ox/office/baseframework/utils/errorcode', [
             return errorContext;
         };
 
+        /**
+         * Provides an optional error value which describes in more
+         * detail what caused the error. E.g. the illegal character
+         * that resulted in a failed rename operation.
+         *
+         * @return {String}
+         *  The error value. Can be an empty string if no error
+         *  value was set.
+         */
+        this.getErrorValue = function () {
+            return errorValue;
+        };
+
         /**
          * Provides the textual representation of the error code object.
          *
@@ -201,6 +217,7 @@ define('io.ox/office/baseframework/utils/errorcode', [
             result.error[ErrorCode.PROPERTY_ERRORCLASS] = errorClass;
             result.error[ErrorCode.PROPERTY_ERRORSOURCE] = errorSource;
             result.error[ErrorCode.PROPERTY_ERRORCONTEXTDATA] = errorContextData;
+            result.error[ErrorCode.PROPERTY_ERRORVALUE] = errorValue;
             return result;
         };
 
@@ -214,6 +231,7 @@ define('io.ox/office/baseframework/utils/errorcode', [
                 codeAsStringConstant = Utils.getStringOption(resultData.error, ErrorCode.PROPERTY_ERRORCODEASSTRING, 'NO_ERROR');
                 errorClass = Utils.getNumberOption(resultData.error, ErrorCode.PROPERTY_ERRORCLASS, ErrorCode.ERRORCLASS_NO_ERROR);
                 errorContextData = Utils.getObjectOption(resultData.error, ErrorCode.PROPERTY_ERRORCONTEXTDATA, {});
+                errorValue = Utils.getStringOption(resultData.error, ErrorCode.PROPERTY_ERRORVALUE, '');
             } else if (_.isObject(resultData) && !_.isString(Utils.getStringOption(resultData, ErrorCode.PROPERTY_OX_ERRORID, null))) {
                 // we also support to provide a error object directly - detect and ignore plain error data from backend
                 description = Utils.getStringOption(resultData, ErrorCode.PROPERTY_ERRORDESCRIPTION, '');
@@ -221,6 +239,7 @@ define('io.ox/office/baseframework/utils/errorcode', [
                 errorClass = Utils.getNumberOption(resultData, ErrorCode.PROPERTY_ERRORCLASS, ErrorCode.ERRORCLASS_NO_ERROR);
                 errorSource = Utils.getNumberOption(resultData, ErrorCode.PROPERTY_ERRORSOURCE, ErrorCode.ERRORSOURCE_CLIENT);
                 errorContextData = Utils.getObjectOption(resultData, ErrorCode.PROPERTY_ERRORCONTEXTDATA, {});
+                errorValue = Utils.getStringOption(resultData, ErrorCode.PROPERTY_ERRORVALUE, '');
             }
         }
 
@@ -283,6 +302,7 @@ define('io.ox/office/baseframework/utils/errorcode', [
     ErrorCode.PROPERTY_ERRORCLASS = 'errorClass';
     ErrorCode.PROPERTY_ERRORSOURCE = 'errorSource';
     ErrorCode.PROPERTY_ERRORCONTEXTDATA = 'errorContextData';
+    ErrorCode.PROPERTY_ERRORVALUE = 'errorValue';
 
     // normal error data sent by plain backend including RT
     ErrorCode.PROPERTY_OX_ERRORID = 'error_id';
