@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH
+  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Carsten Driesner <carsten.driesner@open-xchange.com>
  */
@@ -18,7 +18,13 @@ define('io.ox/office/baseframework/utils/errorcontextdata', function () {
     // static class ErrorContextData ==========================================
 
     var ErrorContextData = {
-        MAX_DOCSIZE_ALLOWED: 'MAX_DOCSIZE_ALLOWED'
+        MAX_DOCSIZE_ALLOWED: 'MAX_DOCSIZE_ALLOWED',
+        RESTORED_FILENAME: 'restoredFileName',
+        RESTORED_FILEID:   'restoredFileId',
+        RESTORED_FOLDERID: 'restoredFolderId',
+        RESTORED_PATHNAME: 'restoredPathName',
+        RESTORED_ERRORCODE: 'restoredErrorCode',
+        ORIGINAL_FILEID:   'originalFileId'
     };
 
     // static methods ---------------------------------------------------------
