@@ -45,7 +45,6 @@ define('io.ox/office/baseframework/utils/errormessages', [
             ERROR_WHILE_MODIFYING_DOCUMENT: gt('An unrecoverable error occurred while modifying the document.'),
             ERROR_WHILE_LOADING_DOCUMENT: gt('An unrecoverable error occurred while loading the document.'),
             ERROR_SIRI_NOT_SUPPORTED: gt('Siri is not supported as input method. Please do not use to input text.'),
-            ERROR_CLIPBOARD_TIMEOUT: gt('The server detected a sychronization problem with your client. Please reload the doument.'),
             ERROR_ANDROID_IME_NOT_SUPPORTED_KEYBOARD: gt('Document editing is not supported with your current soft/virtual keyboard settings. Please disable automatic correction, gesture typing and suggestions.'),
             ERROR_LOAD_DOC_FAILED_SERVER_TOO_BUSY: gt('The document could not be loaded. The server is currently too busy. Please try again later.'),
             ERROR_BAD_SERVER_COMPONENT_DETECTED: gt('A server component is not working. Please contact the server administrator.'),
@@ -61,7 +60,8 @@ define('io.ox/office/baseframework/utils/errormessages', [
             WARNING_CONNECTION_INSTABLE: gt('The server does not answer our action requests. Maybe the connection is unstable or the server side has problems.'),
             WARNING_NO_PERMISSION_FOR_DOC: gt('You do not have permissions to change this document.'),
             WARNING_SYNC_AFTER_OFFLINE: gt('Connection to server was lost. Please wait, trying to synchronize to enable edit mode.'),
-            WARNING_SYNC_FOR_VIEWER:  gt('Connection to server was lost. Enable client to acquire edit rights.')
+            WARNING_SYNC_FOR_VIEWER:  gt('Connection to server was lost. Enable client to acquire edit rights.'),
+            WARNING_RESCUE_DOC_CANNOT_BE_CHANGED: gt('The document cannot be changed, because the format is not editable. To create an editable document, please use "save as" or copy the complete content into the clipboard and paste it into a new document.')
         },
 
         // server-side mapping error code to error messages, including error context for general errors
@@ -110,7 +110,7 @@ define('io.ox/office/baseframework/utils/errormessages', [
             HANGUP_CALCENGINE_NOT_RESPONDING_ERROR: gt('The server detected a synchronization problem with all clients of this document. Please reload the document.'),
             HANGUP_INVALID_OSN_DETECTED_ERROR: gt('Your document changed on the server. Please reload the document.'),
             RENAMEDOCUMENT_FAILED_ERROR: gt('Renaming the document failed.'),
-            RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR: gt('Renaming the document failed. The file name contains invalid characters.'),
+            RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR: gt('Renaming the document failed. The file name contains invalid characters'),
             RENAMEDOCUMENT_NOT_SUPPORTED_ERROR: gt('Renaming the document failed. The storage containing the file does not support renaming a file.'),
             RENAMEDOCUMENT_SAVE_IN_PROGRESS_WARNING: gt('Please wait. The document will be renamed and must be reloaded.'),
             LOADDOCUMENT_FAILED_ERROR: gt('An error occurred while loading the document.'),
@@ -124,17 +124,18 @@ define('io.ox/office/baseframework/utils/errormessages', [
             LOADDOCUMENT_STRICT_OOXML_NOT_SUPPORTED_ERROR: gt('This document could not be loaded, because it was created with a version of Microsoft Office prior to Office 2007.'),
             LOADDOCUMENT_FEATURE_NOT_SUPPORTED_ERROR: gt('The document could not be loaded, because it contains an unsupported feature.'),
             LOADDOCUMENT_FEATURE_NOT_SUPPORTED_FRAME_ATTACHED_TO_FRAME_ERROR: gt('The document could not be loaded, because it contains grouped text frames.'),
-            LOADDOCUMENT_FILE_HAS_CHANGED_ERROR: gt('The document failed to load because someone has changed the original document. Please try again later.'),
             'GENERAL_PERMISSION_READ_MISSING_ERROR.LOAD': gt('The document could not be read, because you do not have read permissions.'),
             'GENERAL_FILE_NOT_FOUND_ERROR.LOAD': gt('The document cannot be found. Please check, if the document has been removed.'),
             'GENERAL_MEMORY_TOO_LOW_ERROR.LOAD': gt('The document could not be loaded. The server is currently too busy. Please try again later.'),
             'GENERAL_FILE_CORRUPT_ERROR.LOAD': gt('The document could not be loaded. The document is corrupt.'),
             'GENERAL_SYSTEM_BUSY_ERROR.LOAD': gt('The document could not be loaded. The server is currently too busy. Please try again later.'),
+            'GENERAL_UNKNOWN_ERROR.LOAD': gt('The document could not be loaded. An unknown error occurred. Please try again later.'),
             GENERAL_PERMISSION_CREATE_MISSING_ERROR: gt('Could not create document due to missing folder permissions.'),
             GENERAL_BACKGROUNDSAVE_IN_PROGRESS_ERROR: gt('The system is currently busy to store the document. Please try again later.'),
             BACKUPFILE_WONT_WRITE_WARNING: gt('You do not have sufficient permissions to write the backup file.'),
             GENERAL_UNKNOWN_ERROR: gt('An unknown error occurred.'),
             GENERAL_SERVER_COMPONENT_NOT_WORKING_ERROR: gt('A server component is not working. Please contact the server administrator.'),
+            GENERAL_SESSION_COMPONENT_NOT_WORKING_ERROR: gt('There is a configuation problem on the server. Please contact the server administrator.'),
             BACKUPDOCUMENT_SERVICE_NOT_AVAILABLE: gt('Your changes could not be written to the original document. To save your work, please copy the complete content into the clipboard and paste it into a new document.'),
             BACKUPDOCUMENT_BASEDOCSTREAM_NOT_FOUND: gt('Your changes could not be written to the original document. To save your work, please copy the complete content into the clipboard and paste it into a new document.'),
             BACKUPDOCUMENT_CLIENTACTIONS_MALFORMED: gt('Your changes could not be written to the original document. To save your work, please copy the complete content into the clipboard and paste it into a new document.'),
@@ -200,6 +201,8 @@ define('io.ox/office/baseframework/utils/errormessages', [
             errorClass = _.isObject(errorCode) ? errorCode.getErrorClass() : ErrorCode.ERRORCLASS_ERROR,
             // error context data
             errorContextData = _.isObject(errorCode) ? errorCode.getContextData() : {},
+            // error value
+            errorValue = _.isObject(errorCode) ? errorCode.getErrorValue() : null,
             // a flexible key to map error code/context to error message
             keyToMap = null,
             // context dependent data
@@ -283,6 +286,22 @@ define('io.ox/office/baseframework/utils/errormessages', [
                         messageData.message = gt('Your changes could not be written to the original document. A new document was stored but some of your latest changes could not be saved. To save all of your last changes, please copy the complete content into the clipboard and paste it into a new document.');
                     }
                     break;
+                case 'RENAMEDOCUMENT_VALIDATION_FAILED_CHARACTERS_ERROR':
+                    // use the optional error value to provide the illegal character to the user
+                    if (_.isString(errorValue) && (errorValue.length > 0)) {
+                        messageData.message = messageData.message.concat(': "').concat(errorValue).concat('"');
+                    } else {
+                        messageData.message = messageData.message.concat('.');
+                    }
+                    break;
+                case 'LOADDOCUMENT_FILE_HAS_CHANGED_ERROR':
+                    // use the optional error value to provide the editors user name
+                    if (_.isString(errorValue) && (errorValue.length > 0)) {
+                        messageData.message = gt('The document cannot be loaded, because an older version of the document is currently in use by "%1$s”. Please contact "%1$s" or try again later.', gt.noI18n(errorValue));
+                    } else {
+                        messageData.message = gt('The document cannot be loaded, because an older version of the document is currently in use by someone. Please try again later.');
+                    }
+                    break;
             }
         }
 
@@ -359,13 +378,13 @@ define('io.ox/office/baseframework/utils/errormessages', [
             //use the cause error for extented message with errorcode & fileid
             var causeError = Utils.getOption(options, 'causeError', errorCode);
             if (_.isObject(causeError)) {
-                messageData.extendedMessage = 'Error&nbsp;code:&nbsp;' + causeError.getCodeAsConstant() + '. ';
+                messageData.extendedMessage = 'Error\xa0code:\xa0' + causeError.getCodeAsConstant() + '. ';
                 var originalFileId = String(Utils.getOption(options, ErrorContextData.ORIGINAL_FILEID, ''));
                 if (originalFileId) {
                     if (originalFileId.length > 30) {
                         originalFileId = '...' + originalFileId.substring(originalFileId.length - 27, originalFileId.length);
                     }
-                    messageData.extendedMessage += ' File&nbsp;id:&nbsp;' + originalFileId;
+                    messageData.extendedMessage += ' File\xa0id:\xa0' + originalFileId;
                 }
             }
         }
