@@ -100,9 +100,11 @@ define('io.ox/office/baseframework/view/baselabels', [
      *
      * @constant
      */
-    BaseLabels.SEND_AS_MAIL_LABEL              = gt('Send as mail');
-    BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL    = gt('Attach document to mail');
-    BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL  = gt('Send content as mail');
+    BaseLabels.SEND_AS_MAIL_LABEL             = gt('Send as mail');
+    BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL   = gt('Attach document to mail');
+  //BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL    = gt('Attach document as PDF');
+    BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL    = gt('Attach as PDF to mail');
+    BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL = gt('Send content as mail');
 
     /**
      * Standard icon for a 'Send document as mail' button.
@@ -181,7 +183,7 @@ define('io.ox/office/baseframework/view/baselabels', [
      *
      * @constant
      */
-    BaseLabels.QUIT_BUTTON_OPTIONS = { icon: 'fa-times', tooltip: gt('Close document') };
+    BaseLabels.QUIT_BUTTON_OPTIONS = { icon: 'fa-times', tooltip: gt('Close document'), classes: 'always-visible' };
 
     /**
      * Standard options for the 'Zoom out' button.
