@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -22,10 +22,9 @@ define('io.ox/office/baseframework/view/baseview', [
     'io.ox/office/baseframework/utils/errormessages',
     'io.ox/office/baseframework/app/appobjectmixin',
     'io.ox/office/baseframework/view/viewobjectmixin',
-    'io.ox/office/baseframework/view/pane',
     'gettext!io.ox/office/baseframework/main',
     'less!io.ox/office/baseframework/view/basestyle'
-], function (Notifications, Utils, KeyCodes, Forms, TriggerObject, TimerMixin, Dialogs, ErrorMessages, AppObjectMixin, ViewObjectMixin, Pane, gt) {
+], function (Notifications, Utils, KeyCodes, Forms, TriggerObject, TimerMixin, Dialogs, ErrorMessages, AppObjectMixin, ViewObjectMixin, gt) {
 
     'use strict';
 
@@ -231,7 +230,7 @@ define('io.ox/office/baseframework/view/baseview', [
         function refreshPaneLayout() {
 
             // do nothing if the window is hidden (but refresh if import runs (fast loading))
-            if (!self.isVisible()) {
+            if (!self.isVisible() || app.isInQuit()) {
                 return;
             }
 
@@ -280,9 +279,6 @@ define('io.ox/office/baseframework/view/baseview', [
          */
         function showNotification(yellOptions) {
 
-            var // the notification DOM element
-                yellNode = null;
-
             if (yellOptions.type === 'error') {
                 // Bug 28554: no auto-close for error messages
                 yellOptions.duration = -1;
@@ -293,44 +289,46 @@ define('io.ox/office/baseframework/view/baseview', [
             }
 
             // create and show the notification DOM node
-            yellNode = Notifications.yell(yellOptions);
+            var yellNode = Notifications.yell(yellOptions).addClass('io-ox-office-alert');
 
             // wait for deferred initialization of the DOM node
             self.listenTo(yellNode, 'notification:appear', function () {
 
-                var // the message node as target for additional contents
-                    messageNode = yellNode.find('.message'),
-                    // options for a static hyperlink shown below the message text
-                    linkOptions = Utils.getObjectOption(yellOptions, 'hyperlink'),
-                    // the URL for the static hyperlink
-                    linkUrl = Utils.getStringOption(linkOptions, 'url'),
-                    // the display text for the static hyperlink
-                    linkLabel = Utils.getStringOption(linkOptions, 'label'),
-                    // options for an action link shown below the message text
-                    actionOptions = Utils.getObjectOption(yellOptions, 'action'),
-                    // the key of the controller item for an action link
-                    actionKey = Utils.getStringOption(actionOptions, 'itemKey'),
-                    // extendedMessage for better support
-                    extendedMessage = Utils.getStringOption(yellOptions, 'extendedMessage');
+                // the message node as target for additional contents
+                var messageNode = yellNode.find('.message');
 
-                // append a static URL to the alert
+                // options for a static hyperlink shown below the message text
+                var linkOptions = Utils.getObjectOption(yellOptions, 'hyperlink', null);
+                // the URL of the static hyperlink
+                var linkUrl = Utils.getStringOption(linkOptions, 'url', null);
+                // the display text for the static hyperlink
+                var linkLabel = Utils.getStringOption(linkOptions, 'label', null);
+
+                // append the mark-up for a static hyperlink to the alert message
                 if (linkUrl) {
-                    messageNode.append('<div><a href="' + linkUrl + '" target="_blank" tabindex="0">' + (linkLabel || _.noI18n(linkUrl)) + '</a></div>');
+                    linkLabel = linkLabel ? Utils.escapeHTML(linkLabel) : _.noI18n(linkUrl);
+                    messageNode.append('<div><a href="' + linkUrl + '" target="_blank" tabindex="0">' + linkLabel + '</a></div>');
                 }
 
+                // extended message text for better support
+                var extendedMessage = Utils.getStringOption(yellOptions, 'extendedMessage');
                 if (extendedMessage) {
-                    messageNode.append($('<div class="extendedMessage"><span>' +  _.noI18n(extendedMessage) + '</span></div>'));
+                    messageNode.append($('<div class="small-text"><span>' + Utils.escapeHTML(extendedMessage) + '</span></div>'));
                 }
 
+                // options for an action link shown below the message text
+                var actionOptions = Utils.getObjectOption(yellOptions, 'action');
+                // the key of the controller item for an action link
+                var actionKey = Utils.getStringOption(actionOptions, 'itemKey');
                 // do not insert an action link, if the controller item is missing or disabled
                 if (!actionKey || !app.getController().isItemEnabled(actionKey)) { return; }
 
-                var // the icon class for the link
-                    actionIcon = Utils.getStringOption(actionOptions, 'icon'),
-                    // the label text for the link
-                    actionLabel = Utils.getStringOption(actionOptions, 'label'),
-                    // the anchor element to be inserted into the alert node
-                    anchorNode = $('<a href="#">');
+                // the icon class for the link
+                var actionIcon = Utils.getStringOption(actionOptions, 'icon');
+                // the label text for the link
+                var actionLabel = Utils.getStringOption(actionOptions, 'label');
+                // the anchor element to be inserted into the alert node
+                var anchorNode = $('<a href="#">');
 
                 // insert the icon and label to the anchor node
                 if (actionIcon) { anchorNode.append(Forms.createIconMarkup(actionIcon)); }
@@ -378,10 +376,10 @@ define('io.ox/office/baseframework/view/baseview', [
         function windowShowHandler() {
 
             // do not show the window contents if view is still hidden explicitly
-            if (!self.isVisible()) { return; }
+            if (!self.isVisible() || app.isInQuit()) { return; }
 
             // bug 29348: show pending notification also, if tempNode is empty
-            if (pendingYellOptions && self.isImportFinished() && self.isVisible()) {
+            if (pendingYellOptions && self.isImportFinished()) {
                 showNotification(pendingYellOptions);
             }
 
@@ -397,7 +395,7 @@ define('io.ox/office/baseframework/view/baseview', [
                 self.executeDelayed(function () {
                     refreshPaneLayout();
                     app.getController().update();
-                    self.grabFocus();
+                    self.grabFocus({ afterImport: true });
                 }, undefined, 'BaseView: windowShowHandler');
             }
         }
@@ -469,7 +467,6 @@ define('io.ox/office/baseframework/view/baseview', [
 
             // wait for the callback, immediately refresh all view panes to reduce flicker effects
             return $.when(result).always(function () {
-                app.setRootAttribute('data-doc-loaded', true);
                 silentRefreshPaneLayout();
                 self.leaveBusy();
             });
@@ -515,7 +512,7 @@ define('io.ox/office/baseframework/view/baseview', [
          *  A reference to this instance.
          */
         this.grabFocus = function (options) {
-            if (this.isVisible()) {
+            if (!app.isInQuit() && this.isVisible()) {
                 var dialogNode = Dialogs.getActiveModalDialogNode();
                 if (dialogNode.length > 0) {
                     Forms.grabFocus(dialogNode);
@@ -629,28 +626,22 @@ define('io.ox/office/baseframework/view/baseview', [
             this.leaveBusy();
 
             // enter busy state, and extend the blocker element
-            appWindow.busy(null, null, function () {
+            appWindow.busy(null, null, function (blockerNode, headerNode, footerNode) {
 
-                var // the initialization handler
-                    initHandler = Utils.getFunctionOption(options, 'initHandler'),
-                    // the cancel handler
-                    cancelHandler = Utils.getFunctionOption(options, 'cancelHandler'),
-                    // the delay time before the blocker element becomes visible
-                    delay = Utils.getIntegerOption(options, 'delay', 500, 0),
-                    // the label text for the warning alert for long-running actions
-                    warningLabel = Utils.getStringOption(options, 'warningLabel', ''),
-                    // the delay time before the warning alert box becomes visible
-                    warningDelay = Utils.getIntegerOption(options, 'warningDelay', 3000, 0),
-                    // the DOM element containing the warning alert box, or the single cancel button
-                    warningNode = $('<div>').hide(),
-                    // the window blocker element (bound to 'this')
-                    blockerNode = this,
-                    // the header container node
-                    headerNode = blockerNode.find('.header').empty(),
-                    // the footer container node
-                    footerNode = blockerNode.find('.footer').empty(),
-                    // the cancel button element
-                    cancelButton = null;
+                // the initialization handler
+                var initHandler = Utils.getFunctionOption(options, 'initHandler');
+                // the cancel handler
+                var cancelHandler = Utils.getFunctionOption(options, 'cancelHandler');
+                // the delay time before the blocker element becomes visible
+                var delay = Utils.getIntegerOption(options, 'delay', 500, 0);
+                // the label text for the warning alert for long-running actions
+                var warningLabel = Utils.getStringOption(options, 'warningLabel', '');
+                // the delay time before the warning alert box becomes visible
+                var warningDelay = Utils.getIntegerOption(options, 'warningDelay', 3000, 0);
+                // the DOM element containing the warning alert box, or the single cancel button
+                var warningNode = $('<div>').hide();
+                // the cancel button element
+                var cancelButton = null;
 
                 // focus handler that prevents focusing document contents during busy mode
                 function changeFocusHandler(event, focusNode) {
@@ -675,9 +666,6 @@ define('io.ox/office/baseframework/view/baseview', [
                     self.stopListeningTo(appWindow, 'idle', unregisterListeners);
                 }
 
-                // special marker for custom CSS formatting
-                blockerNode.addClass('io-ox-office-blocker');
-
                 // bug 38770: grab focus to prevent modifications of document
                 blockerNode.attr('tabindex', 1).focus();
                 invalidateTabIndexes();
@@ -692,16 +680,6 @@ define('io.ox/office/baseframework/view/baseview', [
                 // unregister all event handlers when leaving busy mode
                 self.listenTo(appWindow, 'idle', unregisterListeners);
 
-                // add file name to header area
-                if (Utils.getBooleanOption(options, 'showFileName', false)) {
-                    headerNode.append($('<div>').addClass('filename clear-title').text(_.noI18n(app.getFullFileName())));
-                }
-
-                // on IE, remove stripes (they are displayed too nervous and flickering)
-                if (_.browser.IE) {
-                    blockerNode.find('.progress-striped').removeClass('progress-striped');
-                }
-
                 // execute initialization handler
                 if (_.isFunction(initHandler)) {
                     initHandler.call(self, headerNode, footerNode, blockerNode);
@@ -710,10 +688,8 @@ define('io.ox/office/baseframework/view/baseview', [
                 // append the container node for the warning alert box and/or cancel button
                 footerNode.append(warningNode);
 
-                // show blocker immediately, or fade it in after a delay
-                if (Utils.getBooleanOption(options, 'immediate', false)) {
-                    blockerNode.css('opacity', '');
-                } else {
+                // fade in blocker node after a delay
+                if (!Utils.getBooleanOption(options, 'immediate', false)) {
                     blockerNode.css('opacity', 0);
                     blockerFadeTimer = self.repeatDelayed(function (index) {
                         blockerNode.css('opacity', (index + 1) / 10);
@@ -748,7 +724,7 @@ define('io.ox/office/baseframework/view/baseview', [
                         }
                     }, warningDelay);
                 }
-            });
+            }, options);
 
             return this;
         };
@@ -760,7 +736,7 @@ define('io.ox/office/baseframework/view/baseview', [
          *  Whether this application is currently in busy state.
          */
         this.isBusy = function () {
-            return !!appWindow.nodes.blocker && appWindow.nodes.blocker.is(':visible');
+            return appWindow.isBusy();
         };
 
         /**
@@ -1010,6 +986,16 @@ define('io.ox/office/baseframework/view/baseview', [
             return contentRootNode;
         };
 
+        /**
+         * Returns the container node for application contents
+         *
+         * @returns {jQuery}
+         *  The DOM root node for application contents
+         */
+        this.getAppContentNode = function () {
+            return appContentNode;
+        };
+
         /**
          * Returns the current margins between the fixed application pane and
          * the embedded application container node.
