@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH
+  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -583,7 +583,7 @@ define('io.ox/office/baseframework/view/component', [
 
                 // bug 37236: update enabled state of all new groups, e.g. when initializing
                 // a view component lazily (e.g. directly before showing a pop-up menu)
-                app.onImportSuccess(updateAllGroupsDebounced);
+                this.waitForImportSuccess(updateAllGroupsDebounced);
             }
 
             // bind group visibility to controller item
