@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH
+  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -50,6 +50,8 @@ define('io.ox/office/baseframework/view/control/compoundsplitbutton', [
         Button.call(this, initOptions);
         CompoundMenuMixin.call(this, docView, Utils.extendOptions(initOptions, { button: menuButton }));
 
+        this.getNode().addClass('compund-split-group');
+
         // initialization -----------------------------------------------------
 
         Forms.setToolTip(menuButton, {
