@@ -37,6 +37,8 @@ define('io.ox/office/baseframework/view/control/userpicture', [
      *  Additionally, the following options are supported:
      *  @param {Number} [initOptions.size=48]
      *      The size of the picture element, in pixels.
+     *  @param {Boolean} [immediatedelete=false]
+     *      Whether an existing background image shall be deleted synchronously.
      */
     function UserPicture(userData, initOptions) {
 
@@ -46,6 +48,10 @@ define('io.ox/office/baseframework/view/control/userpicture', [
             // size of the photo bitmap (double on retina displays)
             bitmapSize = nodeSize * (Utils.RETINA ? 2 : 1),
 
+            // whether an existing background image shall be deleted synchronously (this is important
+            // for the change track user picture, because there is only one change trage badge).
+            immediateDelete = Utils.getBooleanOption(initOptions, 'immediatedelete', false),
+
             // the element containing the photo (as CSS background)
             pictureNode = $('<div class="photo-container" style="min-width:' + nodeSize + 'px;height:' + nodeSize + 'px;background-size:' + nodeSize + 'px;">');
 
@@ -66,6 +72,8 @@ define('io.ox/office/baseframework/view/control/userpicture', [
                 // display name of the user
                 userName = _.noI18n(Utils.getStringOption(currentData, 'userName', ''));
 
+            if (immediateDelete) { pictureNode.css('background-image', ''); } // avoid flickering by deferred exchange of old picture in CT badge
+
             ContactsAPI.pictureHalo(pictureNode, _.isNumber(userId) ? { internal_userid: userId } : {}, { width: bitmapSize, height: bitmapSize, scaleType: 'cover' });
             Forms.setToolTip(pictureNode, { tooltip: userName });
         }
