@@ -466,6 +466,16 @@ define('io.ox/office/baseframework/view/pane', [
             return this;
         };
 
+        /**
+         * Get the size of this view pane.
+         *
+         * @returns {nodeSize}
+         *  The last cached size of the root node.
+         */
+        this.getSize = function () {
+            return nodeSize;
+        };
+
         /**
          * Adds the passed view component into this view pane.
          *
