@@ -506,6 +506,9 @@ define('io.ox/office/baseframework/view/popup/compoundmenu', [
         // update OK/Cancel buttons after showing the menu
         this.on('popup:show popup:idle', function () {
             self.updateFooter();
+            if (cancelButton) {
+                Forms.enableBSButton(cancelButton, true);
+            }
         });
 
         // create the header and footer sections
