@@ -327,6 +327,9 @@ define('io.ox/office/baseframework/view/popup/contextmenu', [
             this.handleChangedControllerItems(controllerChangeHandler);
         }
 
+        // fix for Bug 46769
+        self.on('popup:hide', function () { docView.grabFocus(); });
+
         // destroy all class members on destruction
         this.registerDestructor(function () {
             docView = sourceNode = initOptions = self = null;
