@@ -41,13 +41,13 @@ define('io.ox/office/baseframework/view/toolpane', [
      *  Optional parameters. Supports all options supported by the base class
      *  Pane.
      */
-    function ToolPane(docView, initOptions) {
+    var ToolPane = Pane.extend({ constructor: function (docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // area nodes, mapped by type identifier
-            areaNodes = {};
+        // area nodes, mapped by type identifier
+        var areaNodes = {};
 
         // base constructor ---------------------------------------------------
 
@@ -60,10 +60,10 @@ define('io.ox/office/baseframework/view/toolpane', [
          */
         function componentInserter(component, options) {
 
-            var // the target area passed in the options
-                targetArea = Utils.getStringOption(options, 'targetArea', 'center'),
-                // special position of component
-                specialPosition = Utils.getOption(options, 'insertBefore', false);
+            // the target area passed in the options
+            var targetArea = Utils.getStringOption(options, 'targetArea', 'center');
+            // special position of component
+            var specialPosition = Utils.getOption(options, 'insertBefore', false);
 
             // insert the component root node (fall-back to center area)
             if (!(targetArea in areaNodes)) { targetArea = 'center'; }
@@ -114,10 +114,10 @@ define('io.ox/office/baseframework/view/toolpane', [
          */
         this.getAreaSizes = function () {
 
-            var // the name of the size property for the area nodes
-                sizeProp = this.isVerticalPosition() ? 'width' : 'height',
-                // the resulting sizes
-                areaSizes = { total: Utils.getFloorNodeSize(self.getNode())[sizeProp] };
+            // the name of the size property for the area nodes
+            var sizeProp = this.isVerticalPosition() ? 'width' : 'height';
+            // the resulting sizes
+            var areaSizes = { total: Utils.getFloorNodeSize(self.getNode())[sizeProp] };
 
             _.each(areaNodes, function (areaNode, areaType) {
                 areaSizes[areaType] = {
@@ -138,10 +138,10 @@ define('io.ox/office/baseframework/view/toolpane', [
          */
         this.updateAreaSizes = function () {
 
-            var // the name of the size property for the area nodes
-                sizeProp = this.isVerticalPosition() ? 'width' : 'height',
-                // the current sizes of the area nodes
-                areaSizes = this.getAreaSizes();
+            // the name of the size property for the area nodes
+            var sizeProp = this.isVerticalPosition() ? 'width' : 'height';
+            // the current sizes of the area nodes
+            var areaSizes = this.getAreaSizes();
 
             // do not let leading and trailing areas overlap (trailing pane wins over leading over center)
             areaSizes.trailing.area = Math.min(areaSizes.trailing.content, areaSizes.total);
@@ -158,12 +158,28 @@ define('io.ox/office/baseframework/view/toolpane', [
 
         // initialization -----------------------------------------------------
 
-        // add CSS marker class for special formatting
-        this.getNode().addClass('tool-pane');
+        // initialization of the DOM root node of this tool pane
+        (function (rootNode) {
 
-        this.getNode().on('touchmove', function (event) {
-            event.preventDefault();
-        });
+            // add CSS marker class for special formatting; initially hide all contents
+            rootNode.addClass('tool-pane hidden-contents');
+
+            // removes the CSS marker class that hides the pane contents during import
+            function showPaneContents() {
+                self.executeDelayed(function () {
+                    rootNode.removeClass('hidden-contents');
+                }, 1500);
+            }
+
+            // show pane contents after import, and during import in preview state
+            this.waitForImport(showPaneContents);
+            docView.getApp().once('docs:state:preview', showPaneContents);
+
+            // prevent unwanted scrolling on iOS
+            rootNode.on('touchmove', function (event) {
+                event.preventDefault();
+            });
+        }.call(this, this.getNode()));
 
         // create component area nodes
         ['leading', 'center', 'trailing'].forEach(function (areaType) {
@@ -183,11 +199,10 @@ define('io.ox/office/baseframework/view/toolpane', [
             self = docView = initOptions = areaNodes = null;
         });
 
-    } // class ToolPane
+    } }); // class ToolPane
 
     // exports ================================================================
 
-    // derive this class from class Pane
-    return Pane.extend({ constructor: ToolPane });
+    return ToolPane;
 
 });
