@@ -13,10 +13,11 @@
 
 define('io.ox/office/drawinglayer/model/drawingcollection', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/simplemap',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
     'io.ox/office/drawinglayer/model/drawingmodel'
-], function (Utils, TriggerObject, TimerMixin, DrawingModel) {
+], function (Utils, SimpleMap, TriggerObject, TimerMixin, DrawingModel) {
 
     'use strict';
 
@@ -43,7 +44,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
      *          The JQuery event object.
      *      (2) {DrawingModel} drawingModel
      *          The drawing model that caused the change event.
-     *      (3) {Number[]} position
+     *      (3) {Array<Number>} position
      *          The current position of the drawing object.
      *      (4) {String} type
      *          The exact type of the change event. The possible values are
@@ -87,37 +88,39 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
      *      of the drawing model according to the document position, and
      *      returns whether registration of the drawing model at the passed
      *      position was successful.
-     *  @param {Function} [initOptions.clientSetAttributesHandler]
-     *      A function that will be called every time the formatting attributes
-     *      of a drawing model contained in this collection will be changed by
-     *      using its DrawingModel.setAttributes() method. Receives the drawing
-     *      model instance.
+     *  @param {Function} initOptions.clientUnregisterModelHandler
+     *      A function that receives a drawing model that has just been removed
+     *      from this collection, and the old document position of the drawing
+     *      model. The function has to perform client-side deregistration of
+     *      the drawing model according to the document position, and returns
+     *      whether deregistration of the drawing model at the passed position
+     *      was successful.
      */
     function DrawingCollection(docModel, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the client factory function for drawing model instances
-            clientCreateModelHandler = Utils.getFunctionOption(initOptions, 'clientCreateModelHandler', $.noop),
+        // the client factory function for drawing model instances
+        var clientCreateModelHandler = Utils.getFunctionOption(initOptions, 'clientCreateModelHandler', _.constant(null));
 
-            // the client resolves document positions to models
-            clientResolveModelHandler = Utils.getFunctionOption(initOptions, 'clientResolveModelHandler', $.noop),
+        // the client resolves document positions to models
+        var clientResolveModelHandler = Utils.getFunctionOption(initOptions, 'clientResolveModelHandler', _.constant(null));
 
-            // the client resolves models to document positions
-            clientResolvePositionHandler = Utils.getFunctionOption(initOptions, 'clientResolvePositionHandler', $.noop),
+        // the client resolves models to document positions
+        var clientResolvePositionHandler = Utils.getFunctionOption(initOptions, 'clientResolvePositionHandler', _.constant(null));
 
-            // the client has to register new drawing models
-            clientRegisterModelHandler = Utils.getFunctionOption(initOptions, 'clientRegisterModelHandler', $.noop),
+        // the client has to register new drawing models
+        var clientRegisterModelHandler = Utils.getFunctionOption(initOptions, 'clientRegisterModelHandler', _.constant(false));
 
-            // the client can hook into the setAttributes operation and can update other attributes
-            clientSetAttributesHandler = Utils.getFunctionOption(initOptions, 'clientSetAttributesHandler'),
+        // the client has to register new drawing models
+        var clientUnregisterModelHandler = Utils.getFunctionOption(initOptions, 'clientUnregisterModelHandler', _.constant(false));
 
-            // all drawing models, mapped by internal unique identifier
-            drawingModels = {},
+        // all drawing models, mapped by internal unique identifier
+        var drawingModelMap = new SimpleMap();
 
-            // cached number of drawing models in this collection (faster than counting map properties)
-            modelCount = 0;
+        // cached number of drawing models in this collection (faster than counting map properties)
+        var modelCount = 0;
 
         // base constructors --------------------------------------------------
 
@@ -130,16 +133,16 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * Returns the drawing model at the specified document position
          * contained in this drawing collection.
          *
-         * @param {Number[]} position
+         * @param {Array<Number>} position
          *  The document position of the drawing model.
          */
         function getModel(position) {
 
-            var // let client resolve the drawing model
-                model = clientResolveModelHandler.call(self, position);
+            // let client resolve the drawing model
+            var model = clientResolveModelHandler.call(self, position);
 
             // check that the model is part of this collection
-            if (model && !(model.getUid() in drawingModels)) {
+            if (model && !drawingModelMap.has(model.getUid())) {
                 Utils.warn('DrawingCollection.getModel() - unknown drawing model');
                 return null;
             }
@@ -151,7 +154,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * Tries to find the drawing collection embedded in a drawing object
          * inside this collection.
          *
-         * @param {Number[]} position
+         * @param {Array<Number>} position
          *  The document position of the drawing model.
          *
          * @returns {Object|Null}
@@ -159,7 +162,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          *  - {DrawingCollection} collection
          *      The drawing collection of a drawing object inside this
          *      collection.
-         *  - {Number[]} position
+         *  - {Array<Number>} position
          *      The remaining document position relative to the drawing
          *      collection.
          * If no drawing object with an own embedded collection has been found,
@@ -167,10 +170,10 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          */
         function findEmbeddedCollection(position) {
 
-            var // an existing drawing model
-                model = null,
-                // the collection embedded in the drawing model
-                collection = null;
+            // an existing drawing model
+            var model = null;
+            // the collection embedded in the drawing model
+            var collection = null;
 
             for (var length = 1; length < position.length; length += 1) {
                 if ((model = getModel(position.slice(0, length)))) {
@@ -203,18 +206,17 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          */
         this.getModelCount = function (options) {
 
-            var // whether to search deeply in embedded collections
-                deep = Utils.getBooleanOption(options, 'deep', false),
-                // whether to restrict to a specific type
-                type = Utils.getStringOption(options, 'type'),
-                // the resulting model count
-                count = 0;
+            // whether to search deeply in embedded collections
+            var deep = Utils.getBooleanOption(options, 'deep', false);
+            // whether to restrict to a specific type
+            var type = Utils.getStringOption(options, 'type');
 
             // fast access of model count without deep option and type filtering
             if (!deep && !type) { return modelCount; }
 
             // count all models according to options
-            _.each(drawingModels, function (model) {
+            var count = 0;
+            drawingModelMap.forEach(function (model) {
 
                 // type filtering
                 if (!type || (type === model.getType())) { count += 1; }
@@ -223,14 +225,13 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
                 var collection = deep ? model.getCollection() : null;
                 if (collection) { count += collection.getModelCount(options); }
             });
-
             return count;
         };
 
         /**
          * Tries to find the drawing model at the passed document position.
          *
-         * @param {Number[]} position
+         * @param {Array<Number>} position
          *  The document position of the drawing model. May specify a position
          *  inside another drawing object.
          *
@@ -250,25 +251,18 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          */
         this.findModel = function (position, options) {
 
-            var // whether to search deeply in embedded collections
-                deep = Utils.getBooleanOption(options, 'deep', false),
-                // whether to restrict to a specific type
-                type = Utils.getStringOption(options, 'type'),
-                // embedded collection addressed by the passed position
-                embedInfo = null,
-                // the drawing model
-                model = null;
+            // whether to search deeply in embedded collections
+            var deep = Utils.getBooleanOption(options, 'deep', false);
+            // embedded collection addressed by the passed position
+            var embedInfo = deep ? findEmbeddedCollection(position) : null;
 
             // existing drawing object with embedded collection: search drawing model there
-            if (deep && (embedInfo = findEmbeddedCollection(position))) {
-                return embedInfo.collection.findModel(embedInfo.position, options);
-            }
+            if (embedInfo) { return embedInfo.collection.findModel(embedInfo.position, options); }
 
-            // find the drawing model at the specified position directly
-            model = getModel(position);
-
-            // check the type of the drawing model if specified
-            return (model && (!_.isString(type) || (type === model.getType()))) ? model : null;
+            // find the drawing model at the specified position directly (check the drawing type if specified)
+            var type = Utils.getStringOption(options, 'type', null);
+            var model = getModel(position);
+            return (model && (!type || (type === model.getType()))) ? model : null;
         };
 
         /**
@@ -285,58 +279,25 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          *      embedded drawing object. Otherwise, the passed drawing object
          *      must be contained directly in this collection.
          *
-         * @returns {Number[]|Null}
+         * @returns {Array<Number>|Null}
          *  The position of the drawing object, if it is contained in this
          *  collection; otherwise null.
          */
         this.getModelPosition = function (model/*, options*/) {
 
-            var // whether to support embedded drawing models
-                /*deep = Utils.getBooleanOption(options, 'deep', false),*/
-                // position of the drawing model
-                position = null;
+            // whether to support embedded drawing models
+// TODO            var deep = Utils.getBooleanOption(options, 'deep', false);
 
             // TODO: support for deep option
-            position = clientResolvePositionHandler.call(self, model);
+            var position = clientResolvePositionHandler.call(self, model);
             return position;
         };
 
-        /**
-         * Invokes the passed iterator function for all drawing models in this
-         * collection, in no specific order.
-         *
-         * @param {Function} iterator
-         *  The iterator function called for all drawing models. Receives the
-         *  current drawing model as first parameter. If the iterator returns
-         *  the Utils.BREAK object, the iteration process will be stopped
-         *  immediately.
-         *
-         * @param {Object} [options]
-         *  Optional parameters:
-         *  @param {Object} [options.context]
-         *      If specified, the iterator will be called with this context
-         *      (the symbol 'this' will be bound to the context inside the
-         *      iterator function).
-         *
-         * @returns {Utils.BREAK|Undefined}
-         *  A reference to the Utils.BREAK object, if the iterator has returned
-         *  Utils.BREAK to stop the iteration process, otherwise undefined.
-         */
-        this.iterateModels = function (iterator, options) {
-
-            var // the calling context for the iterator function
-                context = Utils.getOption(options, 'context');
-
-            return _.any(drawingModels, function (model) {
-                return iterator.call(context, model) === Utils.BREAK;
-            }) ? Utils.BREAK : undefined;
-        };
-
         /**
          * Stores the passed model of a new drawing object into this drawing
          * collection.
          *
-         * @param {Number[]} position
+         * @param {Array<Number>} position
          *  The document position of the new drawing model. May specify a
          *  position inside another drawing object (if the array without the
          *  last element points to an existing drawing object). If that drawing
@@ -354,16 +315,12 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          */
         this.insertModelInstance = function (position, model) {
 
-            var // embedded collection addressed by the passed position
-                embedInfo = findEmbeddedCollection(position);
-
             // existing drawing object with embedded collection found: create new drawing model there
-            if (embedInfo) {
-                return embedInfo.collection.insertModelInstance(embedInfo.position, model);
-            }
+            var embedInfo = findEmbeddedCollection(position);
+            if (embedInfo) { return embedInfo.collection.insertModelInstance(embedInfo.position, model); }
 
             // store the new drawing model
-            drawingModels[model.getUid()] = model;
+            drawingModelMap.insert(model.getUid(), model);
             modelCount += 1;
 
             // register the new drawing model at the client application
@@ -374,11 +331,6 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
 
             // listen to attribute changes of the drawing model
             model.on('change:attributes', function (event, newAttributes, oldAttributes) {
-                // call the client hook to preprocess the formatting attributes
-                if (_.isFunction(clientSetAttributesHandler)) {
-                    clientSetAttributesHandler.call(this, model);
-                    newAttributes = model.getMergedAttributes();
-                }
                 self.trigger('change:drawing', model, self.getModelPosition(model), 'attributes', newAttributes, oldAttributes);
             });
 
@@ -394,7 +346,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * Creates and stores the model of a new drawing object based on the
          * passed settings.
          *
-         * @param {Number[]} position
+         * @param {Array<Number>} position
          *  The document position of the new drawing model. May specify a
          *  position inside another drawing object (if the array without the
          *  last element points to an existing drawing object). If that drawing
@@ -414,18 +366,12 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          */
         this.insertModel = function (position, type, attributes) {
 
-            var // embedded collection addressed by the passed position
-                embedInfo = findEmbeddedCollection(position),
-                // the drawing model constructed by the factory function
-                model = null;
-
             // existing drawing object with embedded collection found: create new drawing model there
-            if (embedInfo) {
-                return embedInfo.collection.insertModel(embedInfo.position, type, attributes);
-            }
+            var embedInfo = findEmbeddedCollection(position);
+            if (embedInfo) { return embedInfo.collection.insertModel(embedInfo.position, type, attributes); }
 
             // create and store the new drawing model
-            model = clientCreateModelHandler.call(this, type, attributes);
+            var model = clientCreateModelHandler.call(this, type, attributes);
             return (model instanceof DrawingModel) && this.insertModelInstance(position, model);
         };
 
@@ -433,7 +379,7 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          * Removes the model of a drawing object located at the passed document
          * position.
          *
-         * @param {Number[]} position
+         * @param {Array<Number>} position
          *  The document position of the drawing model. May specify a position
          *  inside another drawing object (if the array without the last
          *  element points to an existing drawing object).
@@ -443,24 +389,22 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
          */
         this.deleteModel = function (position) {
 
-            var // embedded collection addressed by the passed position
-                embedInfo = findEmbeddedCollection(position),
-                // the drawing model
-                model = null;
-
             // existing drawing object with embedded collection found: create new drawing model there
-            if (embedInfo) {
-                return embedInfo.collection.deleteModel(embedInfo.position);
-            }
+            var embedInfo = findEmbeddedCollection(position);
+            if (embedInfo) { return embedInfo.collection.deleteModel(embedInfo.position); }
 
             // find the drawing model at the specified position
-            if (!(model = this.findModel(position))) { return false; }
+            var model = this.findModel(position);
+            if (!model) { return false; }
 
             // notify all listeners
             this.trigger('delete:drawing', model, position);
 
+            // unregister the new drawing model at the client application
+            if (!clientUnregisterModelHandler.call(this, model, position)) { return false; }
+
             // remove and destroy the drawing model
-            delete drawingModels[model.getUid()];
+            drawingModelMap.remove(model.getUid());
             model.destroy();
             modelCount -= 1;
 
@@ -471,8 +415,10 @@ define('io.ox/office/drawinglayer/model/drawingcollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            _.invoke(drawingModels, 'destroy');
-            drawingModels = null;
+            drawingModelMap.forEach(function (model) { model.destroy(); });
+            self = docModel = drawingModelMap = null;
+            clientCreateModelHandler = clientResolveModelHandler = clientResolvePositionHandler = null;
+            clientRegisterModelHandler = clientUnregisterModelHandler = null;
         });
 
     } // class DrawingCollection
