@@ -91,9 +91,19 @@ define('io.ox/office/drawinglayer/model/drawingmodel', [
          *  Whether this drawing model is in visible state.
          */
         this.isVisible = function () {
-            return !this.getMergedAttributes().drawing.hidden;
+            return !this.getMergedAttributeSet(true).drawing.hidden;
         };
 
+        /**
+         * Returns the collection of child drawing objects contained in this
+         * drawing object model. Intended to be overwritten by sub classes that
+         * represent drawing models with an internal child drawing collection
+         * (e.g. group objects).
+         *
+         * @returns {DrawingCollection|Null}
+         *  The child drawing collection contained in this instance; or null,
+         *  if the drawing object does not contain a child collection.
+         */
         this.getCollection = function () {
             return null;
         };
