@@ -205,11 +205,6 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          */
         paddingBottom: { def: 125 },
 
-        /**
-         * Whether the size of the shape shall be adapted to the text content.
-         */
-        autoResizeHeight: { def: false },
-
         /**
          * Specifies the vertical alignment of text inside of a text body. Possible
          * values: 'bottom', 'centered', 'distributed', 'justified' or 'top'.
@@ -236,7 +231,32 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          * Specifies if the text is allowed to flow out of the bounding box or if it cut.
          * Possible values are 'overflow', 'clip' or 'ellipsis'.
          */
-        vertOverflow: { def: 'overflow' }
+        vertOverflow: { def: 'overflow' },
+
+        /**
+         * Whether the size of the shape shall be adapted to the text content.
+         */
+        autoResizeHeight: { def: false },
+
+        /**
+         * Whether the fontsize of the text content shall be adapted to the shape height.
+         */
+        autoResizeText: { def: false },
+
+        /**
+         *  0 - 1
+         */
+        fontScale:      { def: 1 },
+
+        /**
+         *  0 - 1
+         */
+        lineReduction:  { def: 0 },
+
+        /**
+         * disables autoResizeHeight & autoResizeText
+         */
+        noAutoResize:   { def: false }
     };
 
     // definitions for geometry attributes --------------------------------
@@ -250,13 +270,13 @@ define('io.ox/office/drawinglayer/model/drawingstylecollection', [
          */
         presetShape: { def: 'rect' },
 
-        avList: { def: [] },
+        avList: { def: {} },
 
         gdList: { def: [] },
 
         pathList: { def: [] },
 
-        textRect: { def: [] }
+        textRect: { def: {} }
     };
 
     // definitions for common chart attributes --------------------------------
