@@ -14,9 +14,8 @@
 define('io.ox/office/drawinglayer/view/chartformatter', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/object/baseobject',
-    'io.ox/office/drawinglayer/view/chartstyleutil',
     'gettext!io.ox/office/drawinglayer/main'
-], function (Utils, BaseObject, ChartStyleUtil, gt) {
+], function (Utils, BaseObject, gt) {
 
     'use strict';
 
@@ -33,6 +32,12 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
 
         // private methods ----------------------------------------------------
 
+        function isAnyDateTime(format, value) {
+            if (format && format.isAnyDateTime() && !isNaN(value)) {
+                return true;
+            }
+        }
+
         function newInfoHolder(type, label) {
             return {
                 max: Number.NEGATIVE_INFINITY,
@@ -40,18 +45,18 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
                 type: type,
                 label: label,
                 unclean: false,
-                exp: 0,
-                labelLength: 0
+                exp: 0
             };
         }
 
         function handleData(info, source, dataPoint, nullAsZero) {
-            var realNr = source.result;
+
+            var realNr = source.value;
             var display = source.display;
             var format = source.format;
 
             if (format && !info.format) {
-                if (format.isAnyDateTime()) {
+                if (isAnyDateTime(format, realNr)) {
                     info.date = format;
                 }
                 info.format = format;
@@ -71,14 +76,14 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
             } else if (info.format) {
                 info.max = Math.max(info.max, realNr);
                 res = realNr;
-                label = docModel.getNumberFormatter().formatValue(realNr, info.format);
+                label = docModel.getNumberFormatter().formatValue(info.format, realNr);
             } else {
                 info.max = Math.max(info.max, realNr);
                 res = realNr;
                 label = docModel.getNumberFormatter().formatStandardNumber(realNr, 12);
             }
 
-            dataPoint[info.label] = Utils.escapeHTML(label);
+            dataPoint[info.label] = sanitize(label);
             dataPoint[info.type] = res;
         }
 
@@ -103,17 +108,22 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
 
         function handleLabelLength(info, dataPoint) {
             var label = dataPoint[info.label];
-            if (label) {
-                info.labelLength = Math.max(info.labelLength, label.length);
+            if (label && label.length > 30) {
+                dataPoint[info.label] = label.substring(0, 27) + '...';
             }
         }
 
+        function sanitize(text) {
+            return Utils.parseAndSanitizeHTML(text).text();
+        }
+
         // public methods -----------------------------------------------------
 
         this.format = function () {
             var data = chartModel.getModelData();
-            var attrs = chartModel.getMergedAttributes();
+            var attrs = chartModel.getMergedAttributeSet(true);
             var chartType = attrs.chart.type;
+            var stacking = attrs.chart.stacking;
             var xyChart = chartModel.isXYType() || chartType.indexOf('area') === 0;
             var nullAsZero = chartType.indexOf('pie') === -1 && chartType.indexOf('donut') === -1;
             var dateChart = false;
@@ -149,7 +159,7 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
                         //first of first
                         if (attrs.chart.stacking === 'clustered' || attrs.chart.stacking === 'standard') {
                             var format = dataPoint.nameSource ? dataPoint.nameSource.format : null;
-                            if (format && format.isAnyDateTime()) {
+                            if (isAnyDateTime(format, dataPoint.nameSource.value)) {
                                 dateChart = true;
                             }
                         }
@@ -166,16 +176,18 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
 
                     //ugly part against double formatting!!!
                     if (dataPoint.nameSource) {
-                        dataPoint[x.label] = Utils.escapeHTML(dataPoint.nameSource.display);
+                        dataPoint[x.label] = sanitize(dataPoint.nameSource.display);
                     } else {
-                        dataPoint[x.label] = Utils.escapeHTML(String(dataPoint[x.type]));
+                        dataPoint[x.label] = sanitize(String(dataPoint[x.type]));
                     }
 
+                    if (dataPoint.label) { dataPoint.legendLabel = dataPoint.label; }
+
                     handleLabelLength(x, dataPoint);
                     handleLabelLength(y, dataPoint);
 
                     if (dataPoint.sizeSource) {
-                        dataPoint.z = Math.abs(dataPoint.sizeSource.result);
+                        dataPoint.z = Math.abs(dataPoint.sizeSource.value);
 
                         //fix for funny bug in canvasjs
                         dataPoint.markerBorderColor = 'transparent';
@@ -184,7 +196,7 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
                     } else {
                         dataPoint.z = null;
                     }
-                    dataPoint.legendText = dataPoint.label;
+                    dataPoint.legendText = dataPoint.legendLabel;
                 });
 
                 dataSeries.toolTipContent = '{label}: {name}';
@@ -226,7 +238,7 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
             });
 
             data.data = data.series.slice(0);
-            var mustReverse = attrs.chart.type.indexOf('bar') === 0 && (attrs.chart.stacking === 'clustered' || attrs.chart.stacking === 'standard');
+            var mustReverse = chartType.indexOf('bar') === 0 && (stacking === 'clustered' || stacking === 'standard');
             if (mustReverse) {
                 data.data.reverse();
             }
@@ -237,8 +249,14 @@ define('io.ox/office/drawinglayer/view/chartformatter', [
 
             var dataSeries = data.series[seriesIndex];
 
+            if (!dataSeries) {
+                //workaround for Bug 46928
+                Utils.warn('no dataSeries found for ' + seriesIndex + ' title: ' + titles + ' names: ' + names);
+                return;
+            }
+
             // build series title
-            dataSeries.nameHolder = titles[0];
+            if (titles) { dataSeries.nameHolder = titles[0]; }
             if (!seriesIndex) {
                 if (dataSeries.nameHolder) {
                     chartModel.setMainName(dataSeries.nameHolder.display);
