@@ -40,24 +40,23 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
         }
 
         function getAccentColorSetName(accent) {
-            return gt.format(
-                //#. predefined formatting style for chart objects: single accent color from the current color scheme
-                //#. Example result: "Accent 1", "Accent 2"
-                //#. %1$d is the index of the accent color
-                //#, c-format
-                gt.pgettext('chart-format', 'Accent %1$d'),
-                _.noI18n(accent)
-            );
+            //#. predefined formatting style for chart objects: single accent color from the current color scheme
+            //#. Example result: "Accent 1", "Accent 2"
+            //#. %1$d is the index of the accent color
+            //#, c-format
+            return gt.pgettext('chart-format', 'Accent %1$d', _.noI18n(accent));
         }
 
         COLORSET.push({
-            name: /*#. predefined formatting style for chart objects: black/gray/white only */ gt.pgettext('chart-format', 'Grayscale'),
+            //#. predefined formatting style for chart objects: black/gray/white only
+            name: gt.pgettext('chart-format', 'Grayscale'),
             colors: [{ type: 'rgb', value: '555555' }, { type: 'rgb', value: '9E9E9E' }, { type: 'rgb', value: '727272' }, { type: 'rgb', value: '464646' }, { type: 'rgb', value: '838383' }, { type: 'rgb', value: 'C1C1C1' }],
             type: 'group'
         });
 
         COLORSET.push({
-            name: /*#. predefined formatting style for chart objects: all accent colors from the current color scheme */ gt.pgettext('chart-format', 'Accents'),
+             //#. predefined formatting style for chart objects: all accent colors from the current color scheme
+            name: gt.pgettext('chart-format', 'Accents'),
             colors: allAccents,
             type: 'group'
         });
@@ -102,11 +101,11 @@ define('io.ox/office/drawinglayer/view/chartstyleutil', [
     };
 
     function getCorrectLineColor(docModel, chartModel) {
-        var attrs = chartModel.getMergedAttributes();
+        var attrs = chartModel.getMergedAttributeSet(true);
         var bg = attrs.fill.color;
         if (Color.parseJSON(bg).isAuto()) {
             chartModel.updateBackgroundColor();
-            attrs = chartModel.getMergedAttributes();
+            attrs = chartModel.getMergedAttributeSet(true);
             bg = attrs.fill.color;
         }
         var colorDesc = docModel.resolveColor(Color.parseJSON(bg), 'line');
