@@ -48,8 +48,7 @@ define('io.ox/office/drawinglayer/view/control/chartlegendpicker', [
             .createOptionButton('top',      { section: 'pos', label: /*#. chart legend at top of border of the chart */ gt.pgettext('chart-legend', 'Top') })
             .createOptionButton('bottom',   { section: 'pos', label: /*#. chart legend at bottom border of the chart */ gt.pgettext('chart-legend', 'Bottom') })
             .createOptionButton('left',     { section: 'pos', label: /*#. chart legend at left border of the chart */ gt.pgettext('chart-legend', 'Left') })
-            .createOptionButton('right',    { section: 'pos', label: /*#. chart legend at right border of the chart */ gt.pgettext('chart-legend', 'Right') })
-            .createOptionButton('topRight', { section: 'pos', label: /*#. chart legend at top-right corner of the chart */ gt.pgettext('chart-legend', 'Top right') });
+            .createOptionButton('right',    { section: 'pos', label: /*#. chart legend at right border of the chart */ gt.pgettext('chart-legend', 'Right') });
 
     } // class ChartLegendPicker
 
