@@ -16,11 +16,12 @@ define('io.ox/office/drawinglayer/view/drawingcontrols', [
     'io.ox/office/drawinglayer/view/control/chartcolorsetpicker',
     'io.ox/office/drawinglayer/view/control/chartstylesetpicker',
     'io.ox/office/drawinglayer/view/control/chartlegendpicker',
+    'io.ox/office/drawinglayer/view/control/shapetypepicker',
     'io.ox/office/baseframework/view/control/compoundsplitbutton',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/tk/controls',
     'gettext!io.ox/office/drawinglayer/main'
-], function (ChartTypePicker, ChartColorSetPicker, ChartStyleSetPicker, ChartLegendPicker, CompoundSplitButton, DrawingLabels, Controls, gt) {
+], function (ChartTypePicker, ChartColorSetPicker, ChartStyleSetPicker, ChartLegendPicker, ShapeTypePicker, CompoundSplitButton, DrawingLabels, Controls, gt) {
 
     'use strict';
 
@@ -34,10 +35,11 @@ define('io.ox/office/drawinglayer/view/drawingcontrols', [
         ChartTypePicker: ChartTypePicker,
         ChartColorSetPicker: ChartColorSetPicker,
         ChartStyleSetPicker: ChartStyleSetPicker,
-        ChartLegendPicker: ChartLegendPicker
+        ChartLegendPicker: ChartLegendPicker,
+        ShapeTypePicker: ShapeTypePicker
     };
 
-    DrawingControls.ImagePicker = CompoundSplitButton.extend({ constructor: function (docView) {
+    DrawingControls.ImagePicker = CompoundSplitButton.extend({ constructor: function (docView, itemKey) {
 
         // base constructor ---------------------------------------------------
 
@@ -52,15 +54,14 @@ define('io.ox/office/drawinglayer/view/drawingcontrols', [
             value: 'drive'
         });
 
-        var dialogTypeGroup =   new Controls.RadioGroup();
+        itemKey = itemKey || 'image/insert/dialog';
 
-        dialogTypeGroup.createOptionButton('local',  { label: /*#. Contextmenu item label for insert image from the local file system. */ gt('Local file') });
+        this.addGroup(itemKey, new Controls.Button({ value: 'local', label: /*#. Label for insert image from the local file system. */ gt('Local file') }));
 
-        dialogTypeGroup.createOptionButton('drive',  { label: /*#. Contextmenu item label for insert image from drive. Please do not translate the productname 'Drive' */ gt('From Drive') });
+        this.addGroup(itemKey, new Controls.Button({ value: 'drive', label: /*#. Label for insert image from drive. Please do not translate the productname 'Drive' */ gt('From Drive') }));
 
-        dialogTypeGroup.createOptionButton('url',   { label:  /*#. Contextmenu item label for insert image from an url. */ gt('From URL') });
+        this.addGroup(itemKey, new Controls.Button({ value: 'url', label:  /*#. Label for insert image from an url. */ gt('From URL') }));
 
-        this.addGroup('image/insert/dialog', dialogTypeGroup);
     } });
 
     // exports ================================================================
