@@ -121,7 +121,35 @@ define('io.ox/office/drawinglayer/view/drawinglabels', [
      */
     DrawingLabels.INSERT_DRAWING_TOOLTIP = gt.pgettext('drawing', 'Insert an image');
 
-    // constants for controls -------------------------------------------------
+    /**
+     * Standard options for the 'Group drawing' label.
+     *
+     * @constant
+     */
+    DrawingLabels.GROUP_DRAWING_LABEL = /*#. group the selected drawings */ gt.pgettext('drawing', 'Group');
+
+    /**
+     * Standard options for the 'Group drawing' tooltip.
+     *
+     * @constant
+     */
+    DrawingLabels.GROUP_DRAWING_TOOLTIP = gt.pgettext('drawing', 'Group the selected drawings');
+
+    /**
+     * Standard options for the 'Ungroup drawing' label.
+     *
+     * @constant
+     */
+    DrawingLabels.UNGROUP_DRAWING_LABEL = /*#. ungroup the selected drawing(s) */ gt.pgettext('drawing', 'Ungroup');
+
+    /**
+     * Standard options for the 'Ungroup drawing' tooltip.
+     *
+     * @constant
+     */
+    DrawingLabels.UNGROUP_DRAWING_TOOLTIP = gt.pgettext('drawing', 'Ungroup the selected drawings');
+
+// constants for controls -------------------------------------------------
 
     /**
      * Standard options for the 'Delete drawing' button.
@@ -162,6 +190,7 @@ define('io.ox/office/drawinglayer/view/drawinglabels', [
         icon: DrawingLabels.getDrawingTypeIcon('textframe'),
         label: DrawingLabels.INSERT_TEXTFRAME_OPTIONS.label,
         tooltip: DrawingLabels.INSERT_TEXTFRAME_OPTIONS.tooltip,
+        toggle: true,
         smallerVersion: {
             css: { width: 35 },
             hideLabel: true
