@@ -226,8 +226,8 @@ define('io.ox/office/drawinglayer/view/imageutil', [
      */
     Image.hasFileImageExtension = function (file) {
 
-        var ext = (_.isString(file)) ? file.split('.').pop().toLowerCase() : '';
-        return IMAGE_EXTENSIONS.hasOwnProperty(ext);
+        var ext = _.isString(file) ? file.split('.').pop().toLowerCase() : '';
+        return ext in IMAGE_EXTENSIONS;
     };
 
     /**
@@ -296,7 +296,7 @@ define('io.ox/office/drawinglayer/view/imageutil', [
     Image.getMimeTypeFromImageUri = function (uri) {
         var fileName = Image.getFileNameFromImageUri(uri),
             ext = fileName ? fileName.split('.').pop().toLowerCase() : '';
-        return IMAGE_EXTENSIONS.hasOwnProperty(ext) ? IMAGE_EXTENSIONS[ext] : '';
+        return IMAGE_EXTENSIONS[ext] || '';
     };
 
     /**
@@ -559,7 +559,7 @@ define('io.ox/office/drawinglayer/view/imageutil', [
         // Bug 43868: ios auto correction should be of for input fields
         // TODO: use Forms.createInputMarkup() to create inputs here, it alrady has this fix
         if (Utils.IOS) {
-            urlInput.attr({ autocorrect : 'off', autocapitalize : 'none' });
+            urlInput.attr({ autocorrect: 'off', autocapitalize: 'none' });
         }
 
         // create the dialog
