@@ -12,10 +12,10 @@
  */
 
 define('io.ox/office/editframework/app/editcontroller', [
-    'io.ox/office/tk/utils',
+    'io.ox/core/capabilities',
     'io.ox/office/baseframework/app/basecontroller',
     'io.ox/office/editframework/utils/editconfig'
-], function (Utils, BaseController, Config) {
+], function (Capabilities, BaseController, Config) {
 
     'use strict';
 
@@ -44,8 +44,8 @@ define('io.ox/office/editframework/app/editcontroller', [
      */
     function EditController(app, docModel, docView, initOptions) {
 
-        var // self reference
-            self = this;
+        // self reference
+        var self = this;
 
         // base constructor ---------------------------------------------------
 
@@ -99,9 +99,19 @@ define('io.ox/office/editframework/app/editcontroller', [
 
             // document
 
+            // parent iten that is enabled if the edited document is based on OOXML file format
+            'document/ooxml': {
+                enable: function () { return app.isOOXML(); }
+            },
+
             'document/acquireedit': {
                 parent: 'app/valid',
-                enable: function () { return app.isAcquireEditRightsEnabled(); },
+                enable: function () { return app.isAcquireEditRightsEnabled(); }
+            },
+
+            'document/acquireeditOrPending': {
+                parent: 'app/valid',
+                enable: function () { return app.isAcquireEditRightsEnabledPendingUpdates(); },
                 set: function () { app.acquireEditRights(); }
             },
 
@@ -162,6 +172,13 @@ define('io.ox/office/editframework/app/editcontroller', [
                 set: function (type) { return docView.showSaveAsDialog(type); }
             },
 
+            'document/exportaspdf/dialog': {
+              //parent: 'document/saveas/dialog',
+                parent: 'app/valid',
+                enable: function () { return Capabilities.has('document_preview'); },
+                set: function (type) { return docView.showSaveAsDialog(type); }
+            },
+
             'document/autosave': {
                 parent: 'app/valid',
                 get: function () { return app.isAutoSaveEnabled(); },
@@ -185,7 +202,14 @@ define('io.ox/office/editframework/app/editcontroller', [
             'document/search/text': {
                 parent: 'document/search',
                 get: function (settings) { return settings.query; },
-                set: function (text) { return docView.executeSearchOperation('search:start', { query: text }); }
+                set: function (text, evt) {
+                    // workaround for Bug 46401: 'custom' sourceType is triggered on blur on the textfield
+                    if (evt && evt.changeEvent && evt.changeEvent.sourceType === 'custom') {
+                        return docView.changeSearchSettings({ query: text });
+                    } else {
+                        return docView.executeSearchOperation('search:start', { query: text });
+                    }
+                }
             },
 
             'document/search/regexp': {
@@ -235,13 +259,6 @@ define('io.ox/office/editframework/app/editcontroller', [
             'document/replace/all': {
                 parent: 'document/replace',
                 set: function () { return docView.executeSearchOperation('replace:all'); }
-            },
-
-            // debug mode
-
-            'debug/enabled': {
-                parent: 'app/valid',
-                enable: function () { return Config.DEBUG; }
             }
         });
 
