@@ -5,7 +5,7 @@
  * or copyright law is prohibited.
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
@@ -19,9 +19,9 @@ define('io.ox/office/editframework/app/fileactions', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/io',
     'io.ox/office/baseframework/app/extensionregistry',
-    'io.ox/office/editframework/utils/editconfig',
+    'io.ox/office/baseframework/app/applicationlauncher',
     'gettext!io.ox/office/editframework/actions'
-], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, Config, gt) {
+], function (ext, links, DriveUtils, Utils, IO, ExtensionRegistry, ApplicationLauncher, gt) {
 
     'use strict';
 
@@ -56,17 +56,24 @@ define('io.ox/office/editframework/app/fileactions', [
      * @param {String} actionId
      *  The identifier of the action to be disabled.
      */
-    function disableActionForInvalidFiles(actionId) {
-        new links.Action(actionId, {
+    function disableActionForInvalidFiles(actionId, capabilities) {
+        var opt = {
             id: 'disable_action',
             index: 'first',
             requires: function (data) {
-                if (ExtensionRegistry.isError(data.baton.data.filename)) {
+                var fileName = data.baton.data.filename;
+                if (fileName && ExtensionRegistry.isError(fileName)) {
                     data.stopPropagation();
                     return false;
                 }
             }
-        });
+        };
+        if (capabilities) {
+            //workaround for Bug 47678
+            opt.capabilities = capabilities;
+        }
+
+        new links.Action(actionId, opt);
     }
 
     /**
@@ -86,6 +93,30 @@ define('io.ox/office/editframework/app/fileactions', [
         return false;
     }
 
+    function getRunningApp(fileDesc, moduleName) {
+        if (!fileDesc.filename || !ExtensionRegistry.isEditable(fileDesc.filename, moduleName)) { return null; }
+        var app = ApplicationLauncher.getRunningApp(moduleName, fileDesc);
+        return (app && app.isImportSucceeded()) ? app : null;
+    }
+
+    function overwriteExtPointForRunningApp(ref, moduleName, id, index, action) {
+        new links.Action(ref, {
+            id: moduleName + '/' + id,
+            index: index,
+            requires: function (e) {
+                var filename = e.context.filename;
+                return $.when(!!filename && ExtensionRegistry.isEditable(filename, moduleName));
+            },
+            filter: function (file) {
+                return !!getRunningApp(file, moduleName);
+            },
+            action: function (baton) {
+                var runningApp = getRunningApp(baton.data, moduleName);
+                if (runningApp) { action.call(this, runningApp); }
+            }
+        });
+    }
+
     // static class FileActions ===============================================
 
     var FileActions = {};
@@ -137,15 +168,22 @@ define('io.ox/office/editframework/app/fileactions', [
                     //it is important to call getData before of "can" or "is" calls
                     //DriveUtils does this already, but in this situation we dont have the id of the folder yet
                     return e.baton.app.folder.getData().then(function (data) {
-                        return DriveUtils.getCreateState(data.id).then(function (create) {
-                            if (create) {
-                                return DriveUtils.getTrashState(data.id).then(function (state) {
-                                    return !state;
-                                });
-                            } else {
-                                return false;
-                            }
-                        });
+                        if (_.isObject(data) && _.isString(data.id)) {
+                            return DriveUtils.getCreateState(data.id).then(function (create) {
+                                if (create) {
+                                    return DriveUtils.getTrashState(data.id).then(function (state) {
+                                        return !state;
+                                    });
+                                } else {
+                                    return false;
+                                }
+                            });
+                        } else {
+                            // Bug 46390
+                            // In case we cannot retrieve any data from the folder
+                            // we cannot support the edit mode.
+                            return false;
+                        }
                     });
                 },
                 action: function (baton) {
@@ -157,7 +195,8 @@ define('io.ox/office/editframework/app/fileactions', [
         var editAction = function (baton) {
             var promise = DriveUtils.getFile(baton.data);
             promise.done(function (data) {
-                if (ExtensionRegistry.isNative(data.filename)) {
+                var fileName = data.filename;
+                if (fileName && ExtensionRegistry.isNative(fileName)) {
                     launchApplication({ action: 'load', file: data });
                 } else {
                     launchApplication({ action: 'convert', templateFile: data, preserveFileName: true });
@@ -179,16 +218,15 @@ define('io.ox/office/editframework/app/fileactions', [
         new links.Action(ACTION_POINT + '-edit', {
             requires: function (e) {
                 var filename = e.context.filename;
-                if (hasWritePermissions(e) && ExtensionRegistry.isEditable(filename, MODULE_NAME) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isNative(filename, MODULE_NAME)) {
+                if (filename && hasWritePermissions(e) && ExtensionRegistry.isEditable(filename, MODULE_NAME) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isNative(filename, MODULE_NAME)) {
                     // prefetch application source code
                     IO.prefetchModuleSource(MODULE_NAME);
                     return isEditableFolder(e.baton);
-                } else {
-                    return $.when(false);
                 }
+                return $.when(false);
             },
             filter: function (obj) {
-                return ExtensionRegistry.isEditable(obj.filename, MODULE_NAME);
+                return !!obj.filename && ExtensionRegistry.isEditable(obj.filename, MODULE_NAME);
             },
             action: editAction
         });
@@ -204,11 +242,10 @@ define('io.ox/office/editframework/app/fileactions', [
                 }
 
                 var filename = e.context.filename;
-                if (e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && ExtensionRegistry.isTemplate(filename, MODULE_NAME)) {
+                if (filename && e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && ExtensionRegistry.isTemplate(filename, MODULE_NAME)) {
                     return isEditableFolder(e.baton);
-                } else {
-                    return $.when(false);
                 }
+                return $.when(false);
             },
             filter: function (obj) {
                 return ExtensionRegistry.isTemplate(obj.filename, MODULE_NAME);
@@ -221,16 +258,16 @@ define('io.ox/office/editframework/app/fileactions', [
             id: MODULE_NAME,
             //requires is not called for 'io.ox/files/actions/default' so we must use filter function!
             filter: function (obj) {
-                if (ExtensionRegistry.isTemplate(obj.filename, MODULE_NAME)) {
-                    return true;
-                } else if (DriveUtils.canWrite(obj.folder_id) && ExtensionRegistry.isNative(obj.filename) && ExtensionRegistry.isEditable(obj.filename, MODULE_NAME)) {
-                    return true;
-                } else {
-                    return false;
-                }
+                var filename = obj.filename;
+                if (!filename || DriveUtils.isTrash(obj.folder_id)) { return false; }
+
+                if (ExtensionRegistry.isTemplate(filename, MODULE_NAME)) { return true; }
+
+                return DriveUtils.canModify(obj) && ExtensionRegistry.isNative(filename) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
             },
             action: function (baton) {
-                if (ExtensionRegistry.isTemplate(baton.data.filename, MODULE_NAME)) {
+                var filename = baton.data.filename;
+                if (filename && ExtensionRegistry.isTemplate(filename, MODULE_NAME)) {
                     templAction(baton);
                 } else {
                     editAction(baton);
@@ -247,10 +284,11 @@ define('io.ox/office/editframework/app/fileactions', [
                 new links.Action(ACTION_POINT + ref, {
                     requires: requires,
                     filter: function (obj) {
-                        return ExtensionRegistry.isEditable(obj.filename, MODULE_NAME);
+                        return obj.filename && ExtensionRegistry.isEditable(obj.filename, MODULE_NAME);
                     },
                     action: function (baton) {
-                        var convert = ExtensionRegistry.isConvertible(baton.data.filename);
+                        var filename = baton.data.filename;
+                        var convert = filename && ExtensionRegistry.isConvertible(filename);
                         launchApplication({ action: convert ? 'convert' : 'new', target_folder_id: baton.data.folder_id, templateFile: baton.data, preserveFileName: convert });
                     }
                 });
@@ -259,16 +297,14 @@ define('io.ox/office/editframework/app/fileactions', [
             var isExtraEditAsNew = function (e) {
                 // workaround for Guest/anonymous
                 // guest -> no my files -> no edit-as-new button!
-                if (DriveUtils.isGuest()) {
-                    return false;
-                }
                 var filename = e.context.filename;
-                return (e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME));
+                if (!filename || DriveUtils.isGuest()) { return false; }
+                return e.collection.has('one', 'read') && !ExtensionRegistry.isError(filename) && !ExtensionRegistry.isTemplate(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME);
             };
 
             var isNormalEditAsNew = function (e) {
                 var filename = e.context.filename;
-                return (hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME));
+                return !!filename && hasWritePermissions(e) && ExtensionRegistry.isNative(filename, MODULE_NAME);
             };
 
             editAsNew('-edit-asnew', function (e) {
@@ -288,17 +324,17 @@ define('io.ox/office/editframework/app/fileactions', [
             new links.Action(ACTION_POINT + '-edit-template', {
                 requires: function (e) {
                     var filename = e.context.filename;
-                    if (hasWritePermissions(e) && !ExtensionRegistry.isError(filename) && ExtensionRegistry.isTemplate(filename, MODULE_NAME) && !ExtensionRegistry.isTemplateLocked(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME)) {
+                    if (filename && hasWritePermissions(e) && !ExtensionRegistry.isError(filename) && ExtensionRegistry.isTemplate(filename, MODULE_NAME) && !ExtensionRegistry.isTemplateLocked(filename, MODULE_NAME) && ExtensionRegistry.isEditable(filename, MODULE_NAME)) {
                         return isEditableFolder(e.baton);
-                    } else {
-                        return $.when(false);
                     }
+                    return $.when(false);
                 },
                 filter: function (obj) {
-                    return ExtensionRegistry.isEditable(obj.filename, MODULE_NAME);
+                    return obj.filename && ExtensionRegistry.isEditable(obj.filename, MODULE_NAME);
                 },
                 action: function (baton) {
-                    if (ExtensionRegistry.isNative(baton.data.filename)) {
+                    var filename = baton.data.filename;
+                    if (filename && ExtensionRegistry.isNative(filename)) {
                         launchApplication({ action: 'load', file: baton.data });
                     } else {
                         launchApplication({ action: 'convert', target_folder_id: baton.data.folder_id, templateFile: baton.data, preserveFileName: true });
@@ -351,13 +387,19 @@ define('io.ox/office/editframework/app/fileactions', [
         extend('-editasnew',       gt('Edit as new'),          'lo',   'lo',         'first',  '-edit-asnew',     'edit');
         extend('-editasnewhi',     gt('Edit as new'),          'hi',   'lo',         150,      '-edit-asnew-hi',  'edit');
 
+        if (!Utils.IOS) {
+            overwriteExtPointForRunningApp('io.ox/files/actions/download', MODULE_NAME, '/download', 50, function (app) {
+                app.download();
+            });
+        }
+
     };
 
     // static initialization ==================================================
 
     if (!DriveUtils.isGuest()) {
         //isguest check is a workaround for Bug 40480
-        disableActionForInvalidFiles('io.ox/files/actions/add-to-portal');
+        disableActionForInvalidFiles('io.ox/files/actions/add-to-portal', 'portal');
         disableActionForInvalidFiles('io.ox/files/actions/publish');
     }
 
