@@ -69,8 +69,10 @@ define('io.ox/office/editframework/app/mailactions', [
             capabilities: 'infostore',
             requires: function (e) {
 
+                // Fix for 46557: e.context can be an object or array dependent on the context
+                // Show operations for attachments or show all attachments in a list with operations
                 var // whether the "edit" link should be shown for the attachment
-                    isEditable = e.collection.has('one') && ExtensionRegistry.isEditable(e.context.filename, MODULE_NAME);
+                    isEditable = e.collection.has('one') && ((_.isArray(e.context)) ? ExtensionRegistry.isEditable(e.context[0].filename, MODULE_NAME) : ExtensionRegistry.isEditable(e.context.filename, MODULE_NAME));
 
                 // prefetch application source code
                 if (isEditable) { IO.prefetchModuleSource(MODULE_NAME); }
