@@ -16,14 +16,14 @@
 define('io.ox/office/editframework/app/rtconnection', [
     'io.ox/core/event',
     'io.ox/core/uuids',
+    'io.ox/core/tk/sessionrestore',
     'io.ox/realtime/groups',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/logger',
     'io.ox/office/tk/object/triggerobject',
     'io.ox/office/tk/object/timermixin',
-    'io.ox/office/editframework/utils/editconfig',
-    'io.ox/core/tk/sessionrestore'
-], function (Events, UUID, RTGroups, Utils, Logger, TriggerObject, TimerMixin, Config, SessionRestore) {
+    'io.ox/office/editframework/utils/editconfig'
+], function (Events, UUID, SessionRestore, RTGroups, Utils, Logger, TriggerObject, TimerMixin, Config) {
 
     'use strict';
 
@@ -34,7 +34,7 @@ define('io.ox/office/editframework/app/rtconnection', [
         REQUEST_EVENTS = 'addresource getdocument',
 
         // names of runtime push messages
-        PUSH_EVENTS = 'update flusherrorinfo hangup preparelosingeditrights declinedacquireeditrights acceptedacquireeditrights infomessage renameandreload',
+        PUSH_EVENTS = 'update flusherrorinfo hangup preparelosingeditrights declinedacquireeditrights acceptedacquireeditrights infomessage renameandreload alive',
 
         // repeated time to check for pending backend ACKs
         CHECK_PENDING_INTERVAL = 30000,
@@ -785,6 +785,20 @@ define('io.ox/office/editframework/app/rtconnection', [
             return send('sync', 'state', { osn: app.getModel().getOperationStateNumber() });
         };
 
+        /**
+         * Sends a "alive" answer to the server, which extends the time
+         * for client to make necessary changes until a "edit rights" switch will
+         * be forced due to time-out.
+         *
+         * @return {jQuery.Promise}
+         *  A promise that will be resolved when the ACK of the internal send
+         *  arrives.
+         */
+        this.alive = function () {
+            RTConnection.log('RTConnection.alive called');
+            return send('alive', 'state', { osn: app.getModel().getOperationStateNumber() });
+        };
+
         /**
          * Close the document at the connected RT object
          *
@@ -943,13 +957,6 @@ define('io.ox/office/editframework/app/rtconnection', [
     // extend statically with logging methods
     Logger.extend(RTConnection, { enable: RTConnection.debug, prefix: 'RT' });
 
-    // enable DOM console for RT debugging by default
-    if (RTConnection.debug && Config.getUrlFlag('office:debug-console', true)) {
-        require(['io.ox/office/tk/utils/domconsole']).done(function (DOMConsole) {
-            DOMConsole.enable();
-        });
-    }
-
     // enable logging for real-time core
     require(['io.ox/realtime/rt']).done(function (CoreRT) {
         CoreRT.debug = RTConnection.debug;
