@@ -66,6 +66,11 @@ define('io.ox/office/editframework/model/attributedmodel', [
      *      families supported by the style sheet container (as specified in
      *      the constructor of the respective container) do not need to be
      *      repeated here.
+     *  @param {Boolean} [initOptions.listenToStyles=true]
+     *      If set to false, this instance will not listen to change events of
+     *      the style sheet collection specified with the option 'styleFamily'.
+     *      This may be desired for performance reasons to reduce the number of
+     *      event listeners in collections with many instances of this class.
      *  @param {AttributedModel} [initOptions.parentModel]
      *      A parent model object (instance of AttributedModel) that supports
      *      all or a few of the attribute families supported by this instance.
@@ -107,11 +112,8 @@ define('io.ox/office/editframework/model/attributedmodel', [
             // the collection of style sheets for the style family
             styleCollection = null,
 
-            // all attribute families supported by instances of this class
-            supportedFamilies = null,
-
-            // the current auto style
-            autoStyleId = null,
+            // the names of all supported attribute families, as flag set
+            supportedFamilySet = null,
 
             // the (incomplete) explicit attributes of this model object
             explicitAttributeSet = {},
@@ -125,112 +127,40 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
         // private methods ----------------------------------------------------
 
-        /**
-         * Returns the current effective style sheet identifier, if style
-         * sheets are supported.
-         */
-        function getEffectiveStyleId() {
-            return styleCollection ? styleCollection.getEffectiveStyleId(Utils.getStringOption(explicitAttributeSet, 'styleId', ''), true) : null;
-        }
-
-        /**
-         * Adds or removes an attribute value in the specified attribute map.
-         *
-         * @param {Object} attributes
-         *  A map with formatting attributes to be updated.
-         *
-         * @param {String} name
-         *  The name of the formatting attribute to be changed.
-         *
-         * @param {Any} value
-         *  The new value of the formatting attribute. If set to null, the
-         *  attribute will be removed from the map.
-         *
-         * @param {Object} [definition]
-         *  The definition descriptor of the attribute, if available. Used to
-         *  check the new attribute value against the default value, if the
-         *  option 'autoClear' has been passed to the constructor.
-         */
-        function updateAttributeValue(attributes, name, value, definition) {
-
-            var // whether this attribute has changed
-                attrChanged = false;
-
-            if (_.isNull(value) || (autoClear && _.isObject(definition) && _.isEqual(value, definition.def))) {
-                if (name in attributes) {
-                    delete attributes[name];
-                    attrChanged = true;
-                }
-            } else {
-                if (!_.isEqual(attributes[name], value)) {
-                    attributes[name] = _.copy(value, true);
-                    attrChanged = true;
-                }
-            }
-
-            // delete child attributes according to current attribute value
-            if (attrChanged && autoClear && _.isObject(definition) && _.isArray(definition.childAttrs)) {
-                if (_.isNull(value)) { value = definition.def; }
-                _.each(definition.childAttrs, function (childAttr) {
-
-                    var // the expected value of the parent attribute
-                        expectedValue = childAttr.value,
-                        // whether the current value of the primary attribute matches the expected value
-                        valueMatches = _.isFunction(expectedValue) ? expectedValue.call(self, value) : _.isEqual(value, expectedValue);
-
-                    // delete secondary attribute if expected value does not match
-                    if (!valueMatches) { delete attributes[childAttr.name]; }
-                });
-            }
-
-            return attrChanged;
-        }
-
         /**
          * Recalculates the merged attribute set.
          */
         function calculateMergedAttributeSet(notify) {
 
-            var // remember the old merged attributes
-                oldMergedAttributeSet = mergedAttributeSet,
-                // the identifier of the style sheet
-                styleId = getEffectiveStyleId();
+            // remember the old merged attributes
+            var oldMergedAttributeSet = mergedAttributeSet;
 
-            // start with defaults and style sheet attributes
-            mergedAttributeSet = docModel.getDefaultAttributes(supportedFamilies);
+            // start with default attribute values of all supported families
+            mergedAttributeSet = docModel.getDefaultAttributeSet(supportedFamilySet);
 
             // add merged attributes of parent model object
             if (parentModel) {
-                docModel.extendAttributes(mergedAttributeSet, parentModel.getMergedAttributes());
-                _.chain(mergedAttributeSet).keys().difference(supportedFamilies).each(function (family) {
-                    delete mergedAttributeSet[family];
-                });
+                docModel.extendAttributes(mergedAttributeSet, parentModel.getMergedAttributeSet(true));
             }
 
-            // additional processing, if style sheet support is enabled
+            // add the style sheet attributes to resulting merged attribute set
+            var styleId = null;
             if (styleCollection) {
-
-                // set default auto-style identifier if existing
-                if (!autoStyleId && styleCollection.isAuto(styleId)) {
-                    autoStyleId = styleId;
-                }
-
-                // add auto style attributes to resulting merged attribute set
-                if (_.isString(autoStyleId)) {
-                    docModel.extendAttributes(mergedAttributeSet, styleCollection.getStyleAttributeSet(autoStyleId));
-                    styleId = mergedAttributeSet.styleId;
-                }
-
-                // add style sheet attributes to resulting merged attribute set
-                if (!autoStyleId || ('styleId' in explicitAttributeSet)) {
-                    docModel.extendAttributes(mergedAttributeSet, styleCollection.getStyleAttributeSet(explicitAttributeSet.styleId || ''));
-                    styleId = mergedAttributeSet.styleId;
-                }
+                styleId = explicitAttributeSet.styleId || '';
+                docModel.extendAttributes(mergedAttributeSet, styleCollection.getStyleAttributeSet(styleId));
+                styleId = mergedAttributeSet.styleId;
             }
 
-            // add the passed explicit attributes
+            // add the explicit attributes of this instance
             docModel.extendAttributes(mergedAttributeSet, explicitAttributeSet);
 
+            // delete all unsupported attribute families
+            _.each(mergedAttributeSet, function (attributes, family) {
+                if (!(family in supportedFamilySet)) {
+                    delete mergedAttributeSet[family];
+                }
+            });
+
             // restore the effective style sheet identifier
             if (styleCollection) {
                 mergedAttributeSet.styleId = styleId;
@@ -260,11 +190,8 @@ define('io.ox/office/editframework/model/attributedmodel', [
          */
         this.cloneFrom = function (sourceModel) {
 
-            // copy the auto style identifier of the source model
-            autoStyleId = sourceModel.getAutoStyleId();
-
             // deep copy of all explicit attributes
-            explicitAttributeSet = sourceModel.getExplicitAttributes();
+            explicitAttributeSet = sourceModel.getExplicitAttributeSet();
 
             // recalculate the merged attributes (without notifications)
             calculateMergedAttributeSet(false);
@@ -274,17 +201,6 @@ define('io.ox/office/editframework/model/attributedmodel', [
 
         // public methods -----------------------------------------------------
 
-        /**
-         * Returns whether this model object contains a reference to an auto
-         * style.
-         *
-         * @returns {Boolean}
-         *  Whether this model object contains a reference to an auto style.
-         */
-        this.hasAutoStyle = function () {
-            return _.isString(autoStyleId);
-        };
-
         /**
          * Returns whether this model object contains any explicit attributes,
          * or a reference to a style sheet.
@@ -297,29 +213,6 @@ define('io.ox/office/editframework/model/attributedmodel', [
             return !_.isEmpty(explicitAttributeSet);
         };
 
-        /**
-         * Returns whether this model object contains any explicit attributes,
-         * a reference to a style sheet, or a reference to an auto style.
-         *
-         * @returns {Boolean}
-         *  Whether this model object contains any explicit attributes, a
-         *  reference to a style sheet, or a reference to an auto style.
-         */
-        this.isFormatted = function () {
-            return this.hasAutoStyle() || this.hasExplicitAttributes();
-        };
-
-        /**
-         * Returns the identifier of the auto style referred by this model.
-         *
-         * @returns {String|Null}
-         *  The identifier of the auto style referred by this model, if
-         *  available; otherwise null.
-         */
-        this.getAutoStyleId = function () {
-            return autoStyleId;
-        };
-
         /**
          * Returns the explicit attribute set of this model object.
          *
@@ -335,41 +228,142 @@ define('io.ox/office/editframework/model/attributedmodel', [
          *  containing the style sheet reference in the 'styleId' property),
          *  containing values for all attributes that have been explicitly set.
          */
-        this.getExplicitAttributes = function (direct) {
+        this.getExplicitAttributeSet = this.getExplicitAttributes = function (direct) {
             return (direct === true) ? explicitAttributeSet : _.copy(explicitAttributeSet, true);
         };
 
         /**
          * Returns the merged attribute set of this model object.
          *
+         * @param {Boolean} [direct=false]
+         *  If set to true, the returned attribute set will be a reference to
+         *  the original map stored in this instance, which MUST NOT be
+         *  modified! By default, a deep clone of the attribute set will be
+         *  returned that can be freely modified.
+         *
          * @returns {Object}
          *  A complete attribute set (a map of attribute maps with name/value
          *  pairs, keyed by the attribute families, additionally containing the
          *  style sheet reference in the 'styleId' property), containing values
          *  for all known attributes, collected from the document default
          *  values, the style sheet currently referenced by this model object,
-         *  and the explicit attributes of this model object. For efficiency,
-         *  a reference to the cached attribute set will be returned. This
-         *  object MUST NOT be changed!
+         *  and the explicit attributes of this model object.
          */
-        this.getMergedAttributes = function () {
-            return mergedAttributeSet;
+        this.getMergedAttributeSet = function (direct) {
+            return (direct === true) ? mergedAttributeSet : _.copy(mergedAttributeSet, true);
         };
 
         /**
-         * Returns whether this attributed model contains the same auto style
-         * identifier and explicit attributes as the passed attributed model.
+         * Returns a reduced copy of the passed attribute set that contains
+         * only the attributes that are not equal to the attributes of this
+         * model instance (i.e. all attributes that will change this model if
+         * applied as a document operation).
+         *
+         * @param {Object} attributeSet
+         *  An (incomplete) attribute set to be reduced according to the
+         *  explicit attributes of this instance.
+         *
+         * @returns {Object}
+         *  A dep copy of the passed attribute set that will only contain the
+         *  attribute values that are not equal to the explicit attibute values
+         *  of this model instance (incluging missing explicit attributes); or
+         *  null values that will delete an existing explicit attribute.
+         */
+        this.getReducedAttributeSet = function (attributeSet) {
+
+            var reducedAttributeSet = {};
+
+            // copy all new attributes that change a value, or clear an existing value
+            _.each(attributeSet, function (newAttrs, family) {
+
+                // skip unsupported attribute families
+                if (!(family in supportedFamilySet)) { return; }
+
+                // the explicit attributes of the current family
+                var oldExplicitAttrs = explicitAttributeSet[family];
+                // the attribute values for comparison, according to 'autoClear' mode
+                var oldAttrValues = autoClear ? mergedAttributeSet[family] : oldExplicitAttrs;
+
+                // new attribute is null: clear existing attributes; otherwise copy attributes that will change the current values
+                _.each(newAttrs, function (value, name) {
+                    if (value === null) {
+                        if (oldExplicitAttrs && (name in oldExplicitAttrs)) {
+                            AttributeUtils.insertAttribute(reducedAttributeSet, family, name, null);
+                        }
+                    } else {
+                        if (!oldExplicitAttrs || !(name in oldExplicitAttrs) || !_.isEqual(value, oldAttrValues[name])) {
+                            AttributeUtils.insertAttribute(reducedAttributeSet, family, name, value);
+                        }
+                    }
+                });
+            });
+
+            return reducedAttributeSet;
+        };
+
+        /**
+         * Returns an attribute set that will restore the current state of the
+         * explicit attributes, after they have been changed according to the
+         * passed attribute set. Intended to be used to create undo operations.
+         *
+         * @param {Object} attributeSet
+         *  An (incomplete) attribute set to be merged over the current
+         *  explicit attributes of this instance.
+         *
+         * @returns {Object}
+         *  An attribute set that will restore the current explicit attributes
+         *  after they have been changed according to the passed attributes.
+         */
+        this.getUndoAttributeSet = function (attributeSet) {
+
+            var undoAttributeSet = {};
+
+            // restore all old attributes that will be changed or cleared
+            _.each(explicitAttributeSet, function (oldAttrs, family) {
+
+                // the new attributes of the current family (nothing to undo, if the family will not be changed)
+                var newAttrs = attributeSet[family];
+                if (!_.isObject(newAttrs)) { return; }
+
+                _.each(oldAttrs, function (value, name) {
+                    if ((name in newAttrs) && !_.isEqual(value, newAttrs[name])) {
+                        AttributeUtils.insertAttribute(undoAttributeSet, family, name, value);
+                    }
+                });
+            });
+
+            // clear all new attributes with the undo operation, that currently do not exist
+            _.each(attributeSet, function (newAttrs, family) {
+
+                // skip unsupported attribute families
+                if (!(family in supportedFamilySet)) { return; }
+
+                // the explicit attributes of the current family
+                var oldAttrs = explicitAttributeSet[family];
+
+                _.each(newAttrs, function (value, name) {
+                    if (!oldAttrs || !(name in oldAttrs)) {
+                        AttributeUtils.insertAttribute(undoAttributeSet, family, name, null);
+                    }
+                });
+            });
+
+            return undoAttributeSet;
+        };
+
+        /**
+         * Returns whether this attributed model contains the same explicit
+         * attributes as the passed attributed model.
          *
          * @param {AttributedModel} attribModel
          *  The other attributed model to be compared to this model.
          *
          * @returns {Boolean}
-         *  Whether both attributed models contain the same auto style
-         *  identifier and explicit formatting attributes.
+         *  Whether both attributed models contain the same explicit formatting
+         *  attributes.
          */
         this.hasEqualAttributes = function (attribModel) {
-            return (this === attribModel) ||
-                ((autoStyleId === attribModel.getAutoStyleId()) && _.isEqual(explicitAttributeSet, attribModel.getExplicitAttributes(true)));
+            return (this === attribModel) || _.isEqual(explicitAttributeSet, attribModel.getExplicitAttributeSet(true));
         };
 
         /**
@@ -407,10 +401,10 @@ define('io.ox/office/editframework/model/attributedmodel', [
          */
         this.setAttributes = function (attributeSet, options) {
 
-            var // whether to trigger the event
-                notify = Utils.getStringOption(options, 'notify', 'auto'),
-                // whether any explicit attribute or the style identifier has been changed
-                changed = false;
+            // whether to trigger the event
+            var notify = Utils.getStringOption(options, 'notify', 'auto');
+            // whether any explicit attribute or the style identifier has been changed
+            var changed = false;
 
             // set new style sheet or auto style
             if ('styleId' in attributeSet) {
@@ -421,8 +415,8 @@ define('io.ox/office/editframework/model/attributedmodel', [
                     return false;
                 }
 
-                var // the style sheet identifier from the passed attributes
-                    styleId = attributeSet.styleId;
+                // the style sheet identifier from the passed attributes
+                var styleId = attributeSet.styleId;
 
                 // remove explicit reference to default style sheet (missing style
                 // reference will automatically fall-back to the default style sheet)
@@ -430,53 +424,27 @@ define('io.ox/office/editframework/model/attributedmodel', [
                     styleId = null;
                 }
 
-                // special handling for auto styles
-                if (_.isString(styleId) && styleCollection.isAuto(styleId)) {
-
-                    // store the new auto style identifier in a special attribute
-                    if (autoStyleId !== styleId) {
-                        autoStyleId = styleId;
-                        changed = true;
-                    }
-
-                    // remove explicit reference to a style sheet (will be resolved via auto style)
-                    if ('styleId' in explicitAttributeSet) {
-                        delete explicitAttributeSet.styleId;
-                        changed = true;
-                    }
-
-                    // remove all explicit attributes supported by style sheets
-                    styleCollection.getSupportedFamilies().forEach(function (family) {
-                        if (family in explicitAttributeSet) {
-                            delete explicitAttributeSet[family];
-                            changed = true;
-                        }
-                    });
-
-                } else {
-
-                    // change the style sheet identifier in the internal map, update the resulting changed flag
-                    if (updateAttributeValue(explicitAttributeSet, 'styleId', styleId)) {
-                        changed = true;
-                    }
+                // change the style sheet identifier in the internal map, update the resulting changed flag
+                if (AttributeUtils.updateAttribute(explicitAttributeSet, 'styleId', styleId)) {
+                    changed = true;
                 }
             }
 
             // update the remaining explicit attributes of all supported attribute families
-            supportedFamilies.forEach(function (family) {
+            _.each(supportedFamilySet, function (flag, family) {
 
                 // check if new attributes exist in the passed attribute set
                 if (!_.isObject(attributeSet[family])) { return; }
 
-                var // attribute definitions of the current family
-                    definitions = docModel.getAttributeDefinitions(family),
-                    // target attribute map for the current family
-                    explicitAttributes = explicitAttributeSet[family] || (explicitAttributeSet[family] = {});
+                // attribute definitions of the current family
+                var definitions = docModel.getAttributeDefinitions(family);
+                // target attribute map for the current family
+                var explicitAttributes = explicitAttributeSet[family] || (explicitAttributeSet[family] = {});
 
                 // update the attribute map with the new attribute values
                 _.each(attributeSet[family], function (value, name) {
                     if (AttributeUtils.isRegisteredAttribute(definitions, name, options)) {
-                        if (updateAttributeValue(explicitAttributes, name, value, definitions[name])) {
+                        if (AttributeUtils.updateAttribute(explicitAttributes, name, value, autoClear ? definitions[name] : null)) {
                             changed = true;
                         }
                     }
@@ -515,9 +483,8 @@ define('io.ox/office/editframework/model/attributedmodel', [
         styleCollection = styleFamily ? docModel.getStyleCollection(styleFamily) : null;
 
         // get all supported attribute families
-        supportedFamilies = Utils.getTokenListOption(initOptions, 'families', []);
-        if (styleCollection) { supportedFamilies = supportedFamilies.concat(styleCollection.getSupportedFamilies()); }
-        supportedFamilies = _.unique(supportedFamilies);
+        supportedFamilySet = Utils.makeSet(Utils.getTokenListOption(initOptions, 'families', []));
+        if (styleCollection) { _.extend(supportedFamilySet, styleCollection.getSupportedFamilies()); }
 
         // set the attributes passed to the constructor (filters by supported attributes)
         this.setAttributes(_.isObject(initAttributes) ? initAttributes : {}, { notify: 'never' });
@@ -531,7 +498,7 @@ define('io.ox/office/editframework/model/attributedmodel', [
         }
 
         // listen to style sheet changes, update the merged attributes and notify own listeners
-        if (styleCollection) {
+        if (styleCollection && Utils.getBooleanOption(initOptions, 'listenToStyles', true)) {
             this.listenTo(styleCollection, 'triggered', function () {
                 calculateMergedAttributeSet(true);
             });
