@@ -13,13 +13,13 @@
 
 define('io.ox/office/editframework/model/modelattributesmixin', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/object/triggerobject',
+    'io.ox/office/tk/utils/simplemap',
     'io.ox/office/editframework/utils/color',
     'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/utils/attributeutils',
     'io.ox/office/editframework/model/fontcollection',
     'io.ox/office/editframework/model/themecollection'
-], function (Utils, TriggerObject, Color, Border, AttributeUtils, FontCollection, ThemeCollection) {
+], function (Utils, SimpleMap, Color, Border, AttributeUtils, FontCollection, ThemeCollection) {
 
     'use strict';
 
@@ -49,150 +49,52 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
      */
     function ModelAttributesMixin() {
 
-        var // self reference (the document model)
-            self = this,
+        // self reference (the document model)
+        var self = this;
 
-            // the collection of document fonts
-            fontCollection = new FontCollection(this),
+        // the collection of document fonts
+        var fontCollection = new FontCollection(this);
 
-            // the collection of document themes
-            themeCollection = new ThemeCollection(this),
+        // the collection of document themes
+        var themeCollection = new ThemeCollection(this);
 
-            // style collections mapped by attribute family
-            styleCollections = {},
+        // style sheet collections mapped by attribute family
+        var styleCollectionMap = new SimpleMap();
 
-            // attribute definitions registry (mapped by attribute family)
-            definitionsRegistry = {},
+        // auto-style collections mapped by attribute family
+        var autoStyleCollectionMap = new SimpleMap();
 
-            // default values for all supported attribute families
-            defaultAttributeSet = {};
+        // attribute definitions registry (mapped by attribute family)
+        var definitionsRegistryMap = new SimpleMap();
+
+        // default values for all supported attribute families
+        var defaultAttributeSet = {};
 
         // public methods -----------------------------------------------------
 
         /**
-         * Registers formatting attributes for a specific attribute family.
+         * Returns a specific global attribute of the document.
          *
-         * @param {String} family
-         *  The name of the attribute family the new formatting attributes are
-         *  associated with. The attribute family 'document' is reserved for
-         *  the definitions of global document attributes.
+         * @param {String} name
+         *  The name of the global document attribute.
          *
-         * @param {Object} definitions
-         *  The attribute definitions map. Contains attribute definition
-         *  objects for all attributes supported by the specified attribute
-         *  family, mapped by the names of the attributes. This method may be
-         *  called repeatedly for the same attribute family to add new
-         *  attributes, or to overwrite existing attribute definitions. Each
-         *  definition object contains the following properties:
-         *  - {Number|String|Boolean|RegExp|Object} definition.def
-         *      Specifies the default value of the attribute which will be used
-         *      if neither a style sheet nor an explicit value exists for the
-         *      attribute.
-         *  - {String} [definition.scope='any']
-         *      Specifies where the attribute can be used. If set to 'element',
-         *      the attribute can be set at explicitly only (not in style
-         *      sheets). If set to 'style', the attribute can be contained in
-         *      style sheets only. By default, the attribute can be set
-         *      explicitly as well as in style sheets.
-         *  - {Function} [definition.merge]
-         *      A function that will be called while merging attribute sets,
-         *      for example while collecting attributes from style sheets and
-         *      explicit attribute sets. Will be called to merge two existing
-         *      values of this attribute, where the second value has to
-         *      overwrite the first value in some way. Will be called in the
-         *      context of this instance. The function receives the 'old'
-         *      attribute value in the first parameter, and the 'new' attribute
-         *      value in the second parameter. By default, the new value wins
-         *      and the first value will be overwritten completely.
-         *  The attribute definitions may contain any other user-defined
-         *  properties.
-         *
-         * @returns {ModelAttributesMixin}
-         *  A reference to this instance.
+         * @returns {Any}
+         *  A deep copy of the specified global document attribute.
          */
-        this.registerAttributeDefinitions = function (family, definitions) {
-
-            var // get existing or create a new entry in the global registry
-                definitionsMap = definitionsRegistry[family] || (definitionsRegistry[family] = {}),
-                // the container for the default attribute values
-                defaultAttributes = defaultAttributeSet[family] || (defaultAttributeSet[family] = {});
-
-            // store definitions, and the default attribute values
-            _.each(definitions, function (definition, name) {
-                if (_.isNull(definition.def) || _.isUndefined(definition.def) || _.isFunction(definition.def)) {
-                    Utils.error('ModelAttributesMixin.registerAttributeDefinitions(): invalid attribute default value, family=' + family + ', name=' + name + ', value=', definition.def);
-                } else {
-                    definitionsMap[name] = _.clone(definition);
-                    defaultAttributes[name] = definition.def;
-                }
-            });
-
-            // reset all old settings for child attributes
-            _.each(definitionsMap, function (definition) { delete definition.childAttrs; });
-
-            // collect settings for child attributes
-            _.each(definitionsMap, function (definition, name) {
-                var parentName = Utils.getStringOption(definition.parent, 'name');
-                if (_.isString(parentName) && (parentName in definitionsMap)) {
-                    var parentDef = definitionsMap[parentName],
-                        childAttrs = parentDef.childAttrs || (parentDef.childAttrs = []);
-                    childAttrs.push({ name: name, value: definition.parent.value });
-                }
-            });
-
-            return this;
-        };
-
-        /**
-         * Returns the static definitions map of all attributes registered for
-         * the specified attribute family.
-         *
-         * @param {String} family
-         *  The attribute family whose attribute definitions will be returned.
-         *
-         * @returns {Object|Null}
-         *  A reference to the static attribute definitions map, or null if the
-         *  passed attribute family is invalid.
-         */
-        this.getAttributeDefinitions = function (family) {
-            return (family in definitionsRegistry) ? definitionsRegistry[family] : null;
+        this.getDocumentAttribute = function (name) {
+            return _.copy(defaultAttributeSet.document[name], true);
         };
 
         /**
          * Returns the global attributes of the document.
          *
-         * @param {Object}
+         * @returns {Object}
          *  A deep copy of the global document attributes.
          */
         this.getDocumentAttributes = function () {
             return _.copy(defaultAttributeSet.document, true);
         };
 
-        /**
-         * Returns the default attribute values of the specified attribute
-         * families.
-         *
-         * @param {String|Array<String>} families
-         *  A single attribute family, or an array of attribute families.
-         *
-         * @returns {Object}
-         *  The attribute set containing all default values of the specified
-         *  attribute families.
-         */
-        this.getDefaultAttributes = function (families) {
-
-            var // the attribute set containing all specified families
-                attributeSet = {};
-
-            _.getArray(families).forEach(function (family) {
-                if ((family in defaultAttributeSet) && (family !== 'document')) {
-                    attributeSet[family] = _.copy(defaultAttributeSet[family], true);
-                }
-            });
-
-            return attributeSet;
-        };
-
         /**
          * Changes the global document attributes, and/or the default values
          * for various other formatting attributes. These values override the
@@ -209,21 +111,21 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          */
         this.setDocumentAttributes = function (attributeSet) {
 
-            var // whether any document attribute has been changed
-                docChanged = false,
-                // whether any other default value has been changed
-                defChanged = false,
-                // copy of the old attribute defaults for change listeners
-                oldAttributeSet = _.copy(defaultAttributeSet, true),
-                // all changed attributes
-                changedAttributeSet = {};
+            // whether any document attribute has been changed
+            var docChanged = false;
+            // whether any other default value has been changed
+            var defChanged = false;
+            // copy of the old attribute defaults for change listeners
+            var oldAttributeSet = _.copy(defaultAttributeSet, true);
+            // all changed attributes
+            var changedAttributeSet = {};
 
             // update defaults of all attribute families
             _.each(attributeSet, function (attributes, family) {
                 if (_.isObject(attributes) && (family in defaultAttributeSet)) {
 
-                    var defAttributes = defaultAttributeSet[family],
-                        changedAttributes = changedAttributeSet[family] = {};
+                    var defAttributes = defaultAttributeSet[family];
+                    var changedAttributes = changedAttributeSet[family] = {};
 
                     _.each(attributes, function (value, name) {
                         if ((name in defAttributes) && !_.isNull(value) && !_.isUndefined(value) && !_.isEqual(defAttributes[name], value)) {
@@ -255,37 +157,218 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
             return this;
         };
 
+        /**
+         * Registers formatting attributes for a specific attribute family.
+         *
+         * @param {String} family
+         *  The name of the attribute family the new formatting attributes are
+         *  associated with. The attribute family 'document' is reserved for
+         *  the definitions of global document attributes.
+         *
+         * @param {Object} definitions
+         *  The attribute definitions map. Contains attribute definition
+         *  objects for all attributes supported by the specified attribute
+         *  family, mapped by the names of the attributes. This method may be
+         *  called repeatedly for the same attribute family to add new
+         *  attributes, or to overwrite existing attribute definitions. Each
+         *  definition object contains the following properties:
+         *  - {Number|String|Boolean|RegExp|Object} definition.def
+         *      REQUIRED! Specifies the default value of the attribute which
+         *      will be used if neither a style sheet nor an explicit value
+         *      exists for the attribute.
+         *  - {String} [definition.scope='any']
+         *      Specifies where the attribute can be used. If set to 'element',
+         *      the attribute can be set at explicitly only (not in style
+         *      sheets). If set to 'style', the attribute can be contained in
+         *      style sheets only. By default, the attribute can be set as an
+         *      explicit attribute, as well as in style sheets.
+         *  - {Function} [definition.merge]
+         *      A function that will be called while merging attribute sets,
+         *      for example while collecting attributes from style sheets and
+         *      explicit attribute sets. Will be called to merge two existing
+         *      values of this attribute, where the second value has to
+         *      overwrite the first value in some way. Will be called in the
+         *      context of this instance. The function receives the 'old'
+         *      attribute value in the first parameter, and the 'new' attribute
+         *      value in the second parameter. By default, the new value wins
+         *      and the first value will be overwritten completely.
+         *  - {Object} [definition.parent]
+         *      The descriptor of a parent attribute of the same family related
+         *      to this attribute. The attribute described by this definition
+         *      is considered to be unused or invalid, if the parent attribute
+         *      does not contain a specific value, or does not pass a truth
+         *      test. The 'parent' object must contain the properties 'name'
+         *      (the name of the parent attribute), and 'value' (the expected
+         *      value of the parent attribute, or a predicate callback function
+         *      receiving the value of the parent attribute, specifying whether
+         *      this attribute is considered to be valid).
+         *  The attribute definitions may contain any other user-defined
+         *  properties.
+         *
+         * @returns {ModelAttributesMixin}
+         *  A reference to this instance.
+         */
+        this.registerAttributeDefinitions = function (family, definitions) {
+
+            // get existing or create a new entry in the global registry
+            var definitionsMap = definitionsRegistryMap.getOrConstruct(family, Object);
+            // the container for the default attribute values
+            var defaultAttributes = defaultAttributeSet[family] || (defaultAttributeSet[family] = {});
+
+            // store definitions, and the default attribute values
+            _.each(definitions, function (definition, name) {
+                if (_.isNull(definition.def) || _.isUndefined(definition.def) || _.isFunction(definition.def)) {
+                    Utils.error('ModelAttributesMixin.registerAttributeDefinitions(): invalid attribute default value, family=' + family + ', name=' + name + ', value=', definition.def);
+                } else {
+                    definitionsMap[name] = _.clone(definition);
+                    defaultAttributes[name] = definition.def;
+                }
+            });
+
+            // reset all old settings for child attributes
+            _.each(definitionsMap, function (definition) { delete definition.childAttrs; });
+
+            // collect settings for child attributes
+            _.each(definitionsMap, function (definition, name) {
+                var parentName = Utils.getStringOption(definition.parent, 'name');
+                if (_.isString(parentName) && (parentName in definitionsMap)) {
+                    var parentDef = definitionsMap[parentName];
+                    var childAttrs = parentDef.childAttrs || (parentDef.childAttrs = []);
+                    childAttrs.push({ name: name, value: definition.parent.value });
+                }
+            });
+
+            return this;
+        };
+
+        /**
+         * Returns the static definitions map of all attributes registered for
+         * the specified attribute family.
+         *
+         * @param {String} family
+         *  The attribute family whose attribute definitions will be returned.
+         *
+         * @returns {Object|Null}
+         *  A reference to the static attribute definitions map, or null if the
+         *  passed attribute family is invalid.
+         */
+        this.getAttributeDefinitions = function (family) {
+            return definitionsRegistryMap.get(family, null);
+        };
+
+        /**
+         * Returns the default attribute values of a single attribute family.
+         *
+         * @param {String} family
+         *  The attribute family whose default attributes will be returned.
+         *
+         * @returns {Object|Null}
+         *  A simple map with the default attribute values of the specified
+         *  attribute family; or null, if the passed attribute family is not
+         *  supported by this document model.
+         */
+        this.getDefaultAttributes = function (family) {
+
+            // return a deep copy of the default attribute map
+            if ((family in defaultAttributeSet) && (family !== 'document')) {
+                return _.copy(defaultAttributeSet[family], true);
+            }
+
+            return null;
+        };
+
+        /**
+         * Returns an attribute set with the default values of all specified
+         * attribute families.
+         *
+         * @param {String|Array<String>|Object} families
+         *  A single attribute family, or an array of attribute families, or a
+         *  set object with attribute families as property keys.
+         *
+         * @returns {Object}
+         *  The complete attribute set containing all default values of the
+         *  specified attribute families.
+         */
+        this.getDefaultAttributeSet = function (families) {
+
+            // the resulting attribute set
+            var attributeSet = {};
+
+            // adds the attributes of a single family to the result object
+            function addAttributes(family) {
+                var attributes = self.getDefaultAttributes(family);
+                if (attributes) { attributeSet[family] = attributes; }
+            }
+
+            // process the input parameter according to its type
+            if (_.isString(families)) {
+                addAttributes(families);
+            } else if (_.isArray(families)) {
+                families.forEach(addAttributes);
+            } else if (_.isObject(families)) {
+                _.each(families, function (flag, family) { addAttributes(family); });
+            }
+
+            return attributeSet;
+        };
+
+        /**
+         * Builds a map with all supported formatting attributes of the
+         * specified attribute family, set to the null value.
+         *
+         * @param {String} family
+         *  The attribute family whose null attributes will be returned.
+         *
+         * @returns {Object}
+         *  A simple map with the attributes of the specified attribute family,
+         *  set to the null value; or null, if the passed attribute family is
+         *  not supported by this document model.
+         */
+        this.buildNullAttributes = function (family) {
+
+            // the attribute definitions of the current family
+            var definitions = this.getAttributeDefinitions(family);
+            if (!definitions) { return null; }
+
+            // create the attribute map filled with null values
+            var nullAttributes = {};
+            _.each(definitions, function (definition, name) {
+                if (!definition.special) { nullAttributes[name] = null; }
+            });
+            return nullAttributes;
+        };
+
         /**
          * Builds an attribute set containing all formatting attributes of the
          * specified attribute families, set to the null value.
          *
-         * @param {String|Array<String>} styleFamilies
-         *  The name of a single attribute family, or an array with names of
-         *  attribute families.
+         * @param {String|Array<String>|Object} families
+         *  A single attribute family, or an array of attribute families, or a
+         *  set object with attribute families as property keys.
          *
          * @returns {Object}
-         *  An attribute set with null values for all attributes registered for
+         *  The complete attribute set with null values for all attributes of
          *  the specified attribute families.
          */
-        this.buildNullAttributes = function (families) {
+        this.buildNullAttributeSet = function (families) {
 
-            var // the resulting attribute set
-                attributeSet = {};
+            // the resulting attribute set
+            var attributeSet = {};
 
-            _.getArray(families).forEach(function (family) {
+            // adds the null attributes of a single family to the result object
+            function addAttributes(family) {
+                var attributes = self.buildNullAttributes(family);
+                if (attributes) { attributeSet[family] = attributes; }
+            }
 
-                var // the attribute definitions of the current family
-                    definitions = self.getAttributeDefinitions(family),
-                    // attribute values of the current family
-                    attributes = attributeSet[family] = {};
-
-                // add null values for all registered attributes
-                _.each(definitions, function (definition, name) {
-                    if (!definition.special) {
-                        attributes[name] = null;
-                    }
-                });
-            });
+            // process the input parameter according to its type
+            if (_.isString(families)) {
+                addAttributes(families);
+            } else if (_.isArray(families)) {
+                families.forEach(addAttributes);
+            } else if (_.isObject(families)) {
+                _.each(families, function (flag, family) { addAttributes(family); });
+            }
 
             return attributeSet;
         };
@@ -381,30 +464,73 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
         };
 
         /**
-         * Adds a style collection to the document.
+         * Adds a style sheet collection to the document.
          *
          * @param {StyleCollection} styleCollection
-         *  The new style collection to be inserted into the document.
+         *  The new style sheet collection to be inserted into the document.
          *
          * @returns {ModelAttributesMixin}
          *  A reference to this instance.
          */
-        this.addStyleCollection = function (styleCollection) {
-            styleCollections[styleCollection.getStyleFamily()] = styleCollection;
+        this.addStyleCollection = function (collection) {
+
+            // prevent double registration
+            var styleFamily = collection.getStyleFamily();
+            if (styleCollectionMap.has(styleFamily)) {
+                throw new Error('style family "' + styleFamily + '" already registered');
+            }
+
+            styleCollectionMap.insert(styleFamily, collection);
             return this;
         };
 
         /**
-         * Returns the style collection for the specified attribute family.
+         * Returns the style sheet collection for the specified attribute
+         * family.
          *
-         * @param {String} family
-         *  The name of the attribute family.
+         * @param {String} styleFamily
+         *  The name of the style attribute family.
          *
          * @returns {StyleCollection|Null}
-         *  The specified style collection if existing, otherwise null.
+         *  The specified style sheet collection if existing, otherwise null.
          */
-        this.getStyleCollection = function (family) {
-            return (family in styleCollections) ? styleCollections[family] : null;
+        this.getStyleCollection = function (styleFamily) {
+            return styleCollectionMap.get(styleFamily, null);
+        };
+
+        /**
+         * Adds an auto-style collection to the document.
+         *
+         * @param {AutoStyleCollection} styleCollection
+         *  The new auto-style collection to be inserted into the document.
+         *
+         * @returns {ModelAttributesMixin}
+         *  A reference to this instance.
+         */
+        this.addAutoStyleCollection = function (collection) {
+
+            // prevent double registration
+            var styleFamily = collection.getStyleFamily();
+            if (autoStyleCollectionMap.has(styleFamily)) {
+                throw new Error('auto-style family "' + styleFamily + '" already registered');
+            }
+
+            autoStyleCollectionMap.insert(styleFamily, collection);
+            return this;
+        };
+
+        /**
+         * Returns the auto-style collection for the specified attribute
+         * family.
+         *
+         * @param {String} family
+         *  The name of the auto-style attribute family.
+         *
+         * @returns {AutoStyleCollection|Null}
+         *  The specified auto-style collection if existing, otherwise null.
+         */
+        this.getAutoStyleCollection = function (styleFamily) {
+            return autoStyleCollectionMap.get(styleFamily, null);
         };
 
         /**
@@ -428,13 +554,18 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
         };
 
         /**
-         * Returns the current theme from the document's theme collection.
+         * Returns a single theme from the document's theme collection.
+         *
+         * @param {String} [name]
+         *  The name of the theme to be returned. If omitted or not existing,
+         *  the 'current' theme will be returned.
          *
          * @returns {Theme}
-         *  The current theme from the document's theme collection.
+         *  The specified theme, or the current theme. If no theme has been
+         *  inserted, returns the built-in default theme.
          */
-        this.getTheme = function () {
-            return themeCollection.getTheme();
+        this.getTheme = function (name) {
+            return themeCollection.getTheme(name);
         };
 
         /**
@@ -536,10 +667,10 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
          */
         this.getCssTextColor = function (jsonTextColor, jsonFillColors) {
 
-            var // the text color, as instance of the class Color
-                textColor = _.isObject(jsonTextColor) ? Color.parseJSON(jsonTextColor) : new Color('auto'),
-                // all fill colors, as array of Color instances
-                fillColors = jsonFillColors.map(Color.parseJSON);
+            // the text color, as instance of the class Color
+            var textColor = _.isObject(jsonTextColor) ? Color.parseJSON(jsonTextColor) : new Color('auto');
+            // all fill colors, as array of Color instances
+            var fillColors = jsonFillColors.map(Color.parseJSON);
 
             // convert to CSS color string
             return this.resolveTextColor(textColor, fillColors).css;
@@ -653,8 +784,8 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
                 result += token;
             }
 
-            if (_.isBoolean(charAttributes.underline) && charAttributes.underline) { addToken('underline'); }
-            if (_.isString(charAttributes.strike) && (charAttributes.strike !== 'none')) { addToken('line-through'); }
+            if (charAttributes.underline === true) { addToken('underline'); }
+            if ((typeof charAttributes.strike === 'string') && (charAttributes.strike !== 'none')) { addToken('line-through'); }
 
             return result || 'none';
         };
@@ -665,10 +796,13 @@ define('io.ox/office/editframework/model/modelattributesmixin', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            _.invoke(styleCollections, 'destroy');
+            styleCollectionMap.forEach(function (styleCollection) { styleCollection.destroy(); });
+            autoStyleCollectionMap.forEach(function (autoStyleCollection) { autoStyleCollection.destroy(); });
             themeCollection.destroy();
             fontCollection.destroy();
-            fontCollection = themeCollection = styleCollections = null;
+            fontCollection = themeCollection = null;
+            styleCollectionMap = autoStyleCollectionMap = null;
+            definitionsRegistryMap = defaultAttributeSet = null;
         });
 
     } // class ModelAttributesMixin
