@@ -20,6 +20,29 @@ define('io.ox/office/editframework/model/undomanager', [
 
     'use strict';
 
+    // private global functions ===============================================
+
+    /**
+     * Helper function for the method UndoAction.appendOperations().
+     */
+    function insertOperations(array, operations, prepend) {
+
+        // no insertion without actual operations
+        if (!operations) { return array; }
+
+        // callback functions and operations cannot be mixed
+        if ((array.length > 0) && (_.isFunction(operations) !== _.isFunction(array[0]))) {
+            Utils.error('UndoAction.appendOperations(): callback function and operation objects cannot be mixed!');
+            return array;
+        }
+
+        // create a deep clone of the passed operations
+        if (!_.isFunction(operations)) { operations = _.copy(operations, true); }
+
+        // concatenate array according to the passed direction
+        return prepend ? [].concat(operations, array) : array.concat(operations);
+    }
+
     // class UndoAction =======================================================
 
     /**
@@ -28,59 +51,78 @@ define('io.ox/office/editframework/model/undomanager', [
      *
      * @constructor
      *
-     * @param {Object|Object[]|Function} [undoOperations]
+     * @param {Object|Array<Object>|Function} [undoOperations]
      *  One ore more operations that form a logical undo action. When the undo
      *  action is executed, the operations will be applied in the exact order
      *  as passed in this parameter; they will NOT be applied in reversed order
      *  as it would be the case if the operations have been added in multiple
      *  undo actions. The parameter may be a single operation object, an array
-     *  of operation objects, or omitted.
+     *  of operation objects, an arbitrary callback function, or omitted.
      *
-     * @param {Object|Object[]|Function} [redoOperations]
+     * @param {Object|Array<Object>|Function} [redoOperations]
      *  One ore more operations that form a logical redo action. When the redo
      *  action is executed, the operations will be applied in the exact order
      *  as passed in this parameter. The parameter may be a single operation
-     *  object, an array of operation objects, or omitted.
+     *  object, an array of operation objects, an arbitrary callback function,
+     *  or omitted.
+     *
+     * @param {Object} [undoSelectionState]
+     *  A descriptor of the initial selection state that will be stored in the
+     *  undo action. If specified, the selection state will be restored after
+     *  applying the undo operations of this undo action. See public methods
+     *  EditModel.getSelectionState() and EditModel.setSelectionState() for
+     *  details.
+     *
+     * @param {Object} [redoSelectionState]
+     *  A descriptor of the resulting selection state that will be stored in
+     *  the undo action. If specified, the selection state will be restored
+     *  after applying the redo operations of this undo action. See public
+     *  methods EditModel.getSelectionState() and EditModel.setSelectionState()
+     *  for details.
      */
-    function UndoAction(undoOperations, redoOperations) {
+    function UndoAction(undoOperations, redoOperations, undoSelectionState, redoSelectionState) {
+
         this.undoOperations = [];
         this.redoOperations = [];
+        this.undoSelectionState = undoSelectionState;
+        this.redoSelectionState = redoSelectionState;
+        this.options = null;
+
         this.appendOperations(undoOperations, redoOperations);
-    }
+
+    } // class UndoAction
+
+    // public methods ---------------------------------------------------------
 
     /**
-     * Appends the passed undo and redo operations/functions to the own operations
-     * arrays. Undo operations/functions will be inserted at the beginning of the undo
-     * operations array, and redo operations will be appended to the redo
-     * operations array.
+     * Appends the passed undo and redo operations to the own operation arrays.
+     * Undo operations will be inserted at the beginning of the undo operations
+     * array, and redo operations will be appended to the redo operations
+     * array.
+     *
+     * @param {Object|Array<Object>|Function} undoOperations
+     *  One ore more operations that form a logical undo action. See the
+     *  description of the constructor of this class for details.
+     *
+     * @param {Object|Array<Object>|Function} redoOperations
+     *  One ore more operations that form a logical redo action. See the
+     *  description of the constructor of this class for details.
      */
     UndoAction.prototype.appendOperations = function (undoOperations, redoOperations) {
 
-        // add the undo operations at the beginning of the array
-        if (_.isArray(undoOperations)) {
-            this.undoOperations = _.copy(undoOperations, true).concat(this.undoOperations);
-        } else if (_.isFunction(undoOperations)) {
-            this.undoOperations.unshift(undoOperations);
-        } else if (_.isObject(undoOperations)) {
-            this.undoOperations.unshift(_.copy(undoOperations, true));
-        }
+        // add the undo operations at the beginning of the array, accept an arbitrary callback as undo operation
+        this.undoOperations = insertOperations(this.undoOperations, undoOperations, true);
 
-        // add the redo operations at the end of the array
-        if (_.isArray(redoOperations)) {
-            this.redoOperations = this.redoOperations.concat(_.copy(redoOperations, true));
-        } else if (_.isFunction(redoOperations)) {
-            this.redoOperations.push(redoOperations);
-        } else if (_.isObject(redoOperations)) {
-            this.redoOperations.push(_.copy(redoOperations, true));
-        }
+        // add the redo operations at the end of the array, accept an arbitrary callback as redo operation
+        this.redoOperations = insertOperations(this.redoOperations, redoOperations, false);
     };
 
     // class UndoManager ======================================================
 
     /**
-     * The UndoManager mix-in class adds undo/redo functionality to the
-     * document model. Also the grouping and merging of undo/redo operations is
-     * a task of the undo manager.
+     * A collection of undo actions for a document model. Each undo action
+     * contains an arbitrary number of document operations to undo, and to redo
+     * a specific user action.
      *
      * Triggers the following events:
      * - 'undo:before': Before undo operations are about to be applied by the
@@ -108,13 +150,6 @@ define('io.ox/office/editframework/model/undomanager', [
      *
      * @param {Object} [initOptions]
      *  Optional parameters:
-     *  @param {Boolean} [initOptions.remoteUndo=false]
-     *      If set to true, the application does not manage its undo and redo
-     *      operations, but sends 'undo' and 'redo' requests to the server
-     *      which executes the actual undo or redo operations from its internal
-     *      undo/redo stack, and answers with all the operations to be applied
-     *      at the document model, and the new number of undo and redo actions
-     *      available.
      *  @param {Function} [initOptions.mergeUndoActionHandler]
      *      A function that will be called while adding a new undo action onto
      *      the undo stack, and that can try to merge the operations of the new
@@ -131,38 +166,29 @@ define('io.ox/office/editframework/model/undomanager', [
      */
     function UndoManager(docModel, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the application instance
-            app = docModel.getApp(),
+        // the application instance
+        var app = docModel.getApp();
 
-            // whether the application manages undo/redo operations on the server
-            remoteUndo = Utils.getBooleanOption(initOptions, 'remoteUndo', false),
+        // callback function that implements merging two actions to one action
+        var mergeUndoActionHandler = Utils.getFunctionOption(initOptions, 'mergeUndoActionHandler');
 
-            // callback function that implements merging two actions to one action
-            mergeUndoActionHandler = Utils.getFunctionOption(initOptions, 'mergeUndoActionHandler', $.noop),
+        // all undo actions
+        var actions = [];
 
-            // all undo actions
-            actions = [],
+        // index of the next redo action in the 'actions' array
+        var currentAction = 0;
 
-            // index of the next redo action in the 'actions' array
-            currentAction = 0,
+        // number of nested action groups
+        var groupLevel = 0;
 
-            // number of nested action groups
-            groupLevel = 0,
+        // current undo action in grouped mode
+        var groupAction = null;
 
-            // current undo action in grouped mode
-            groupAction = null,
-
-            // whether undo or redo operations are currently processed
-            processing = false,
-
-            // number of undo actions available in the remote undo manager
-            remoteUndoCount = 0,
-
-            // number of redo actions available in the remote undo manager
-            remoteRedoCount = 0;
+        // whether undo or redo operations are currently processed
+        var processing = false;
 
         // base constructor ---------------------------------------------------
 
@@ -178,6 +204,40 @@ define('io.ox/office/editframework/model/undomanager', [
             self.trigger('change:count', self.getUndoCount(), self.getRedoCount());
         }
 
+        /**
+         * Pushes the passed new undo action onto the undo stack. Shortens the
+         * undo stack if the current undo action is not the topmost action on
+         * the stack.
+         *
+         * @param {UndoAction} newAction
+         *  The new undo action to be pushed onto the undo stack.
+         */
+        function pushAction(newAction) {
+
+            // last action on action stack
+            var lastAction = null;
+
+            // truncate main undo stack and push the new action
+            if (currentAction < actions.length) {
+
+                // remove undone actions, push new action without merging
+                actions.splice(currentAction);
+
+            } else if (mergeUndoActionHandler && (actions.length > 0)) {
+
+                // custom callback function wants to merge operations of consecutive undo actions
+                lastAction = _.last(actions);
+                if (mergeUndoActionHandler.call(self, lastAction, newAction) === true) {
+                    lastAction.redoSelectionState = newAction.redoSelectionState;
+                    return;
+                }
+            }
+
+            actions.push(newAction);
+            currentAction = actions.length;
+            triggerChangeCountEvent();
+        }
+
         /**
          * Opens a new undo group. If no undo group is open yet, triggers an
          * 'undogroup:open' event.
@@ -195,13 +255,17 @@ define('io.ox/office/editframework/model/undomanager', [
         /**
          * Closes the most recent undo group. If no undo group is open anymore
          * afterwards, triggers an 'undogroup:close' event.
+         *
+         * @param {Object} options
+         *  Additional options for undo/redo after
          */
-        function closeUndoGroup() {
+        function closeUndoGroup(options) {
 
             // push existing group action to action stack on last group level
             groupLevel -= 1;
             if ((groupLevel === 0) && groupAction) {
                 if (!app.isOperationsBlockActive()) { // the operations were not cancelled
+                    groupAction.options = options;
                     pushAction(groupAction);
                 }
                 groupAction = null;
@@ -214,134 +278,59 @@ define('io.ox/office/editframework/model/undomanager', [
         }
 
         /**
-         * Pushes the passed new undo action onto the undo stack. Shortens the
-         * undo stack if the current undo action is not the topmost action on
-         * the stack.
+         * Invokes the passed callback functions sequentially. Each callback
+         * function may run asynchronous code and return a promise.
          *
-         * @param {UndoAction} newAction
-         *  The new undo action to be pushed onto the undo stack.
-         */
-        function pushAction(newAction) {
-
-            var // last action on action stack
-                lastAction = null;
-
-            // truncate main undo stack and push the new action
-            if (currentAction < actions.length) {
-
-                // remove undone actions, push new action without merging
-                actions.splice(currentAction);
-
-            } else {
-
-                // try to merge with last action, if stack has not been truncated
-                lastAction = _.last(actions);
-
-                // try to merge an 'insertText' operation for a single character with the last action on stack
-                if (_.isObject(lastAction) && (mergeUndoActionHandler.call(self, lastAction, newAction) === true)) {
-                    return;
-                }
-            }
-
-            actions.push(newAction);
-            currentAction = actions.length;
-            triggerChangeCountEvent();
-        }
-
-        /**
-         * Handles update push messages sent from the application after a
-         * remote undo or redo action has been applied. Updates the internal
-         * state according to the passed state of the remote undo manager.
-         */
-        function remoteUpdateHandler(data) {
-
-            var newUndoCount = Utils.getIntegerOption(data, 'undoCount', remoteUndoCount),
-                newRedoCount = Utils.getIntegerOption(data, 'redoCount', remoteRedoCount);
-
-            if ((remoteUndoCount !== newUndoCount) || (remoteRedoCount !== newRedoCount)) {
-                remoteUndoCount = newUndoCount;
-                remoteRedoCount = newRedoCount;
-                triggerChangeCountEvent();
-            }
-        }
-
-        /**
-         * Requests undo or redo actions from the remote undo manager, and
-         * applies the associated operations at the document model.
-         *
-         * @param {String} type
-         *  Either 'undo' or 'redo'.
-         *
-         * @param {Number} [count=1]
-         *  The number of undo/redo actions whose operations will be applied.
+         * @param {Array<Function>} callbacks
+         *  The callback functions to be invoked.
          *
          * @returns {jQuery.Promise}
-         *  A promise that will be resolved or rejected after the undo/redo
-         *  actions have been applied completely.
+         *  A promise that will be resolved after all callbacks have been
+         *  invoked and have finished successfully; ot that will be rejected,
+         *  if any callback function returns a rejected promise, or the boolean
+         *  value false.
          */
-        function requestAction(type/*, count*/) {
-
-            // sends the undo/redo query to the real-time framework
-            function sendRealTimeQuery() {
-                // TODO: pass undo/redo count
-                return app.sendRealTimeQuery(type);
-            }
-
-            // wait for all pending actions, then send the real-time query
-            return app.saveChanges().then(sendRealTimeQuery).then(function (data) {
-                // returns another Promise that will be resolved after all
-                // undo/redo operations have been applied
-                return app.applyUpdateMessageData(data);
-            });
+        function invokeCallbacks(callbacks) {
+            return callbacks.reduce(function (promise, callback) {
+                return promise.then(function () {
+                    var result = callback.call(self);
+                    return (result === false) ? $.Deferred().reject() : result;
+                });
+            }, $.when());
         }
 
         /**
-         * Apply the operations and return a promise.
-         * @param {[]} operations array with operations
+         * Applies the passed operations from an undo action.
+         *
+         * @param {Array<Object>|Array<Function>} operations
+         *  The operations to be applied, either as array of operation objects,
+         *  or as array of callback functions.
+         *
+         * @param {Object} [selectionState]
+         *  The new selection state to be set at the document model.
+         *
          * @returns {jQuery.Promise}
-         *  A promise that will be resolved or rejected after the undo/redo action
-         *  has been applied completely.
+         *  A promise that will be resolved after the operations have been
+         *  applied successfully (or when no callback function has returned a
+         *  rejected promise); otherwise the promise will be rejected.
          */
-        function applyOperations(operations) {
-            var promise = null,
-                undoFunction = _.first(operations);
+        function applyOperations(operations, selectionState) {
 
-            // block keyboard events while processing undo operations
-            if (_.isFunction(docModel.setBlockKeyboardEvent)) {
-                docModel.setBlockKeyboardEvent(true);
-            }
+            // invoke the callback functions, or apply the document operations
+            // (bug 30954: always create a deep copy of the operations)
+            var promise = _.isFunction(operations[0]) ? invokeCallbacks(operations) :
+                docModel.applyOperations(_.copy(operations, true), { async: true });
 
-            if (_.isFunction(undoFunction)) {
-                promise = $.when(undoFunction());
-            } else {
-                // apply all collected operations
-                // bug 30954: always create a deep copy of the operations
-                promise = docModel.applyOperations(_.copy(operations, true), { async: true });
-            }
-
-            // unblock keyboard events again
-            promise.always(function () {
-                if (docModel && _.isFunction(docModel.setBlockKeyboardEvent)) {
-                    docModel.setBlockKeyboardEvent(false);
+            // restore the selection state, after all operations have been applied
+            return promise.done(function () {
+                if (_.isObject(selectionState)) {
+                    docModel.setSelectionState(selectionState);
                 }
             });
-
-            return promise;
         }
 
         // methods ------------------------------------------------------------
 
-        /**
-         * Returns whether the undo stack manages its undo actions locally (the
-         * constructor option 'remoteUndo' was not set).
-         *
-         * @returns {Boolean}
-         *  Whether the undo stack manages its undo actions locally.
-         */
-        this.isLocalUndo = function () {
-            return !remoteUndo;
-        };
-
         /**
          * Returns whether the undo manager is enabled (importing the document
          * has been finished, and the undo manager is currently not processing
@@ -399,18 +388,24 @@ define('io.ox/office/editframework/model/undomanager', [
          * @param {Object} [context]
          *  The context the callback function will be bound to.
          *
+         * @param {Object} [options]
+         *  Additional options that will be stored in the undo action generated
+         *  by this method.
+         *
          * @returns {Any}
          *  The return value of the callback function. In asynchronous mode,
          *  this will be the promise returned by the callback function.
          */
-        this.enterUndoGroup = function (callback, context) {
+        this.enterUndoGroup = function (callback, context, options) {
 
             // open a new undo group
             openUndoGroup();
 
             // invoke the callback function, wait for its result
             var result = callback.call(context);
-            this.waitForAny($.when(result), closeUndoGroup);
+            this.waitForAny($.when(result), function () {
+                closeUndoGroup(options);
+            });
 
             return result;
         };
@@ -421,38 +416,62 @@ define('io.ox/office/editframework/model/undomanager', [
          *
          * @constructor
          *
-         * @param {Object|Object[]|Function} [undoOperations]
+         * @param {Object|Array<Object>|Function} [undoOperations]
          *  One ore more operations that form a logical undo action. When the
          *  undo action is executed, the operations will be applied in the
          *  exact order as passed in this parameter; they will NOT be applied
          *  in reversed order (as would be the case if the operations had been
          *  added in multiple undo actions). The parameter may be a single
-         *  operation object, an array of operation objects, or omitted.
+         *  operation object, an array of operation objects, an arbitrary
+         *  callback function, or omitted. If the callback function returns the
+         *  boolean value false, or a promise that will be rejected, undoing
+         *  this action will be considered to be failed.
          *
-         * @param {Object|Object[]|Function} [redoOperations]
+         * @param {Object|Array<Object>|Function} [redoOperations]
          *  One ore more operations that form a logical redo action. When the
          *  redo action is executed, the operations will be applied in the
          *  exact order as passed in this parameter. The parameter may be a
-         *  single operation object, an array of operation objects, or omitted.
+         *  single operation object, an array of operation objects, an
+         *  arbitrary callback function, or omitted. If the callback function
+         *  returns the boolean value false, or a promise that will be
+         *  rejected, redoing this action will be considered to be failed.
+         *
+         * @param {Object} [undoSelectionState]
+         *  A descriptor of the initial selection state that will be stored in
+         *  the undo action. If specified, the selection state will be restored
+         *  after applying the undo operations of this undo action. See methods
+         *  EditModel.getSelectionState() and EditModel.setSelectionState() for
+         *  details. In grouped undo actions, the selection state of the first
+         *  embedded undo action will be used to restore the selection state.
+         *
+         * @param {Object} [redoSelectionState]
+         *  A descriptor of the final selection state that will be stored in
+         *  the undo action. If specified, the selection state will be restored
+         *  after applying the redo operations of this undo action. See methods
+         *  EditModel.getSelectionState() and EditModel.setSelectionState() for
+         *  details. In grouped undo actions, the selection state of the last
+         *  embedded undo action will be used to restore the selection state.
          *
          * @returns {UndoManager}
          *  A reference to this instance.
          */
-        this.addUndo = function (undoOperations, redoOperations) {
+        this.addUndo = function (undoOperations, redoOperations, undoSelectionState, redoSelectionState) {
 
             // check that undo manager is valid and either undo or redo operations have been passed
-            if (!remoteUndo && this.isUndoEnabled() && (_.isObject(undoOperations) || _.isFunction(undoOperations) || _.isFunction(redoOperations) || _.isObject(redoOperations))) {
+            if (this.isUndoEnabled() && (_.isObject(undoOperations) || _.isObject(redoOperations))) {
 
                 if (groupLevel > 0) {
                     // active group action: insert operations into its operation arrays
                     if (groupAction) {
                         groupAction.appendOperations(undoOperations, redoOperations);
+                        // always use the last selection state (but stick to the first undo selection state)
+                        groupAction.redoSelectionState = redoSelectionState;
                     } else {
-                        groupAction = new UndoAction(undoOperations, redoOperations);
+                        groupAction = new UndoAction(undoOperations, redoOperations, undoSelectionState, redoSelectionState);
                     }
                 } else {
                     // create and insert a new action
-                    pushAction(new UndoAction(undoOperations, redoOperations));
+                    pushAction(new UndoAction(undoOperations, redoOperations, undoSelectionState, redoSelectionState));
                 }
             }
 
@@ -466,11 +485,11 @@ define('io.ox/office/editframework/model/undomanager', [
          *  The number of undo actions available on the stack.
          */
         this.getUndoCount = function () {
-            return remoteUndo ? remoteUndoCount : currentAction;
+            return currentAction;
         };
 
         /**
-         * Applies the undo next undo action.
+         * Applies the undo operations of the next undo action.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved or rejected after the undo action
@@ -478,31 +497,23 @@ define('io.ox/office/editframework/model/undomanager', [
          */
         this.undo = function () {
 
-            var // the resulting Promise
-                promise = null,
-                // collect all undo operations into a single array
-                operations = [];
+            // nothing to do without an undo action on the stack
+            if (currentAction === 0) { return $.when(); }
 
             this.trigger('undo:before');
             processing = true;
 
-            if (remoteUndo) {
-                // request undo from remote undo manager
-                promise = requestAction('undo');
-            } else {
-
-                if (currentAction > 0) {
-                    currentAction -= 1;
-                    operations = actions[currentAction].undoOperations;
-                    promise = applyOperations(operations);
-                }
-
-            }
+            // apply the undo operations of the next undo action
+            currentAction -= 1;
+            var undoAction = actions[currentAction];
+            var operations = undoAction.undoOperations;
+            var promise = applyOperations(operations, undoAction.undoSelectionState);
 
             // notify listeners after all operations have been applied
             this.waitForAny(promise, function () {
                 processing = false;
-                self.trigger('undo:after', operations);
+                // do not pass callback functions to the listeners
+                self.trigger('undo:after', _.isFunction(operations[0]) ? [] : operations, undoAction.options);
                 triggerChangeCountEvent();
             });
 
@@ -516,7 +527,7 @@ define('io.ox/office/editframework/model/undomanager', [
          *  The number of redo actions available on the stack.
          */
         this.getRedoCount = function () {
-            return remoteUndo ? remoteRedoCount : (actions.length - currentAction);
+            return actions.length - currentAction;
         };
 
         /**
@@ -528,32 +539,23 @@ define('io.ox/office/editframework/model/undomanager', [
          */
         this.redo = function () {
 
-            var // the resulting Promise
-                promise = null,
-                // collect all redo operations into a single array
-                operations = [];
+            // nothing to do without an undo action on the stack
+            if (currentAction === actions.length) { return $.when(); }
 
             this.trigger('redo:before');
             processing = true;
 
-            if (remoteUndo) {
-                // request redo from remote undo manager
-                promise = requestAction('redo');
-            } else {
-
-                if (currentAction < actions.length) {
-                    operations = actions[currentAction].redoOperations;
-
-                    promise = applyOperations(operations);
-
-                    currentAction += 1;
-                }
-            }
+            // apply the redo operations of the next undo action
+            var undoAction = actions[currentAction];
+            var operations = undoAction.redoOperations;
+            var promise = applyOperations(operations, undoAction.redoSelectionState);
+            currentAction += 1;
 
             // notify listeners after all operations have been applied
             this.waitForAny(promise, function () {
                 processing = false;
-                self.trigger('redo:after', operations);
+                // do not pass callback functions to the listeners
+                self.trigger('redo:after', _.isFunction(operations[0]) ? [] : operations);
                 triggerChangeCountEvent();
             });
 
@@ -565,11 +567,6 @@ define('io.ox/office/editframework/model/undomanager', [
         // initial notification about undo stack size
         this.waitForImportSuccess(triggerChangeCountEvent);
 
-        // remote undo stack: listen to update push messages from application
-        if (remoteUndo) {
-            this.listenTo(app, 'docs:update', remoteUpdateHandler);
-        }
-
         // destroy class members on destruction
         this.registerDestructor(function () {
             self = initOptions = null;
