@@ -47,8 +47,8 @@ define('io.ox/office/editframework/utils/attributeutils', [
      */
     AttributeUtils.isRegisteredAttribute = function (definitions, name, options) {
 
-        var // whether to include special attributes
-            special = Utils.getBooleanOption(options, 'special', false);
+        // whether to include special attributes
+        var special = Utils.getBooleanOption(options, 'special', false);
 
         return (name in definitions) && (special || (definitions[name].special !== true));
     };
@@ -144,6 +144,71 @@ define('io.ox/office/editframework/utils/attributeutils', [
         }
     };
 
+    /**
+     * Adds or removes an attribute value in the specified attribute map.
+     *
+     * @param {Object} attributes
+     *  A simple map with formatting attributes to be updated (this MUST NOT be
+     *  a structured attribute set with sub objects mapped by family!).
+     *
+     * @param {String} name
+     *  The name of the formatting attribute to be changed.
+     *
+     * @param {Any} value
+     *  The new value of the formatting attribute. If set to the value null,
+     *  the specified attribute will be removed from the map.
+     *
+     * @param {Object} [autoClearDefinition]
+     *  The definition descriptor of the attribute. If specified, and if the
+     *  passed attribute value is equal to the default value according to the
+     *  property 'def' of the definition, the attribute will be removed from
+     *  the attribute map. Additionally, child attributes described in the
+     *  property 'childAttrs' of the attribute definition will be removed if
+     *  they do not match with the current value of the attribute changed
+     *  initially. The array property 'childAttrs' of an attribute definition
+     *  has been assembled from the 'parent' attribute descriptors passed to
+     *  the method ModelAttributesMixin.registerAttributeDefinitions().
+     */
+    AttributeUtils.updateAttribute = function (attributes, name, value, autoClearDefinition) {
+
+        // whether this attribute has changed
+        var changed = false;
+
+        // remove the attribute from the map, if the passed value is null or equal to the default value
+        if (_.isNull(value) || (_.isObject(autoClearDefinition) && _.isEqual(value, autoClearDefinition.def))) {
+            if (name in attributes) {
+                delete attributes[name];
+                changed = true;
+            }
+        } else {
+            if (!_.isEqual(attributes[name], value)) {
+                attributes[name] = _.copy(value, true);
+                changed = true;
+            }
+        }
+
+        // delete child attributes according to current attribute value
+        if (changed && _.isObject(autoClearDefinition) && _.isArray(autoClearDefinition.childAttrs)) {
+
+            // fall-back to the default value of the attribute, if null has been passed
+            if (_.isNull(value)) { value = autoClearDefinition.def; }
+
+            // remove all child attributes from the map that do not match with the current attribute
+            _.each(autoClearDefinition.childAttrs, function (childAttr) {
+
+                // the expected value of the primary attribute changed above
+                var expectedValue = childAttr.value;
+                // whether the current value of the primary attribute matches the expected value
+                var valueMatches = _.isFunction(expectedValue) ? expectedValue(value) : _.isEqual(value, expectedValue);
+
+                // delete secondary attribute if expected value does not match
+                if (!valueMatches) { delete attributes[childAttr.name]; }
+            });
+        }
+
+        return changed;
+    };
+
     /**
      * Returns the attribute set containing all explicit attributes stored in
      * the passed DOM element.
