@@ -19,75 +19,57 @@ define('io.ox/office/editframework/utils/color', [
 
     'use strict';
 
-    var // the gamma correction factors (intended to be similar to MSO)
-        INV_GAMMA = 2.27,
-        GAMMA = 1 / INV_GAMMA,
+    // the gamma correction factors (intended to be similar to MSO)
+    var INV_GAMMA = 2.27;
+    var GAMMA = 1 / INV_GAMMA;
 
-        // threshold luma for dark colors
-        Y_DARK = 0.4,
+    // threshold luma for dark colors
+    var Y_DARK = 0.4;
 
-        // maps the lower-case names of all preset colors to the real mixed-case names and RGB color values
-        PRESET_COLORS = (function () {
-            var map = {};
-            _.each({
-                aliceBlue: 'f0f8ff',         antiqueWhite: 'faebd7',      aqua: '00ffff',                  aquamarine: '7fffd4',
-                azure: 'f0ffff',             beige: 'f5f5dc',             bisque: 'ffe4c4',                black: '000000',
-                blanchedAlmond: 'ffebcd',    blue: '0000ff',              blueViolet: '8a2be2',            brown: 'a52a2a',
-                burlyWood: 'deb887',         cadetBlue: '5f9ea0',         chartreuse: '7fff00',            chocolate: 'd2691e',
-                coral: 'ff7f50',             cornflowerBlue: '6495ed',    cornsilk: 'fff8dc',              crimson: 'dc143c',
-                cyan: '00ffff',              darkBlue: '00008b',          darkCyan: '008b8b',              darkGoldenrod: 'b8860b',
-                darkGray: 'a9a9a9',          darkGreen: '006400',         darkKhaki: 'bdb76b',             darkMagenta: '8b008b',
-                darkOliveGreen: '556b2f',    darkOrange: 'ff8c00',        darkOrchid: '9932cc',            darkRed: '8b0000',
-                darkSalmon: 'e9967a',        darkSeaGreen: '8fbc8f',      darkSlateBlue: '483d8b',         darkSlateGray: '2f4f4f',
-                darkTurquoise: '00ced1',     darkViolet: '9400d3',        deepPink: 'ff1493',              deepSkyBlue: '00bfff',
-                dimGray: '696969',           dodgerBlue: '1e90ff',        firebrick: 'b22222',             floralWhite: 'fffaf0',
-                forestGreen: '228b22',       fuchsia: 'ff00ff',           gainsboro: 'dcdcdc',             ghostWhite: 'f8f8ff',
-                gold: 'ffd700',              goldenrod: 'daa520',         gray: '808080',                  green: '008000',
-                greenYellow: 'adff2f',       honeydew: 'f0fff0',          hotPink: 'ff69b4',               indianRed: 'cd5c5c',
-                indigo: '4b0082',            ivory: 'fffff0',             khaki: 'f0e68c',                 lavender: 'e6e6fa',
-                lavenderBlush: 'fff0f5',     lawnGreen: '7cfc00',         lemonChiffon: 'fffacd',          lightBlue: 'add8e6',
-                lightCoral: 'f08080',        lightCyan: 'e0ffff',         lightGoldenrodYellow: 'fafad2',  lightGray: 'd3d3d3',
-                lightGreen: '90ee90',        lightPink: 'ffb6c1',         lightSalmon: 'ffa07a',           lightSeagreen: '20b2aa',
-                lightSkyBlue: '87cefa',      lightSlateGray: '778899',    lightSteelBlue: 'b0c4de',        lightYellow: 'ffffe0',
-                lime: '00ff00',              limeGreen: '32cd32',         linen: 'faf0e6',                 magenta: 'ff00ff',
-                maroon: '800000',            mediumAquamarine: '66cdaa',  mediumBlue: '0000cd',            mediumOrchid: 'ba55d3',
-                mediumPurple: '9370d8',      mediumSeagreen: '3cb371',    mediumSlateBlue: '7b68ee',       mediumSpringGreen: '00fa9a',
-                mediumTurquoise: '48d1cc',   mediumVioletred: 'c71585',   midnightBlue: '191970',          mintCream: 'f5fffa',
-                mistyRose: 'ffe4e1',         moccasin: 'ffe4b5',          navajoWhite: 'ffdead',           navy: '000080',
-                oldLace: 'fdf5e6',           olive: '808000',             oliveDrab: '6b8e23',             orange: 'ffa500',
-                orangeRed: 'ff4500',         orchid: 'da70d6',            paleGoldenrod: 'eee8aa',         paleGreen: '98fb98',
-                paleTurquoise: 'afeeee',     paleVioletRed: 'd87093',     papayaWhip: 'ffefd5',            peachPuff: 'ffdab9',
-                peru: 'cd853f',              pink: 'ffc0cb',              plum: 'dda0dd',                  powderBlue: 'b0e0e6',
-                purple: '800080',            red: 'ff0000',               rosyBrown: 'bc8f8f',             royalBlue: '4169e1',
-                saddleBrown: '8b4513',       salmon: 'fa8072',            sandyBrown: 'f4a460',            seaGreen: '2e8b57',
-                seaShell: 'fff5ee',          sienna: 'a0522d',            silver: 'c0c0c0',                skyBlue: '87ceeb',
-                slateBlue: '6a5acd',         slateGray: '708090',         snow: 'fffafa',                  springGreen: '00ff7f',
-                steelBlue: '4682b4',         tan: 'd2b48c',               teal: '008080',                  thistle: 'd8bfd8',
-                tomato: 'ff6347',            turquoise: '40e0d0',         violet: 'ee82ee',                wheat: 'f5deb3',
-                white: 'ffffff',             whiteSmoke: 'f5f5f5',        yellow: 'ffff00',                yellowGreen: '9acd32'
-            }, function (value, key) {
-                map[key.toLowerCase()] = { name: key, rgb: value };
-            });
-            return map;
-        }()),
-
-        SYSTEM_COLORS = (function () {
-            var map = {};
-            _.each([
-                'ActiveBorder', 'ActiveCaption', 'AppWorkspace', 'Background',
-                'ButtonFace', 'ButtonHighlight', 'ButtonShadow',
-                'ButtonText', 'CaptionText', 'GrayText', 'Highlight',
-                'HighlightText', 'InactiveBorder', 'InactiveCaption',
-                'InactiveCaptionText', 'InfoBackground', 'InfoText',
-                'Menu', 'MenuText', 'Scrollbar', 'threeDDarkShadow',
-                'ThreeDFace', 'ThreeDHighlight', 'ThreeDLightShadow',
-                'ThreeDShadow', 'Window', 'WindowFrame', 'WindowText'
-            ], function (key) {
-                var name = key.substring(0, 1).toLowerCase() + key.substring(1);
-                map[key.toLowerCase()] = { name: name };
-            });
-            return map;
-        }());
+    // maps the lower-case names of all preset colors to the real mixed-case names and RGB color values
+    var PRESET_COLOR_MAP = (function () {
+        var map = {};
+        _.each({
+            aliceBlue: 'f0f8ff',         antiqueWhite: 'faebd7',      aqua: '00ffff',                  aquamarine: '7fffd4',
+            azure: 'f0ffff',             beige: 'f5f5dc',             bisque: 'ffe4c4',                black: '000000',
+            blanchedAlmond: 'ffebcd',    blue: '0000ff',              blueViolet: '8a2be2',            brown: 'a52a2a',
+            burlyWood: 'deb887',         cadetBlue: '5f9ea0',         chartreuse: '7fff00',            chocolate: 'd2691e',
+            coral: 'ff7f50',             cornflowerBlue: '6495ed',    cornsilk: 'fff8dc',              crimson: 'dc143c',
+            cyan: '00ffff',              darkBlue: '00008b',          darkCyan: '008b8b',              darkGoldenrod: 'b8860b',
+            darkGray: 'a9a9a9',          darkGreen: '006400',         darkKhaki: 'bdb76b',             darkMagenta: '8b008b',
+            darkOliveGreen: '556b2f',    darkOrange: 'ff8c00',        darkOrchid: '9932cc',            darkRed: '8b0000',
+            darkSalmon: 'e9967a',        darkSeaGreen: '8fbc8f',      darkSlateBlue: '483d8b',         darkSlateGray: '2f4f4f',
+            darkTurquoise: '00ced1',     darkViolet: '9400d3',        deepPink: 'ff1493',              deepSkyBlue: '00bfff',
+            dimGray: '696969',           dodgerBlue: '1e90ff',        firebrick: 'b22222',             floralWhite: 'fffaf0',
+            forestGreen: '228b22',       fuchsia: 'ff00ff',           gainsboro: 'dcdcdc',             ghostWhite: 'f8f8ff',
+            gold: 'ffd700',              goldenrod: 'daa520',         gray: '808080',                  green: '008000',
+            greenYellow: 'adff2f',       honeydew: 'f0fff0',          hotPink: 'ff69b4',               indianRed: 'cd5c5c',
+            indigo: '4b0082',            ivory: 'fffff0',             khaki: 'f0e68c',                 lavender: 'e6e6fa',
+            lavenderBlush: 'fff0f5',     lawnGreen: '7cfc00',         lemonChiffon: 'fffacd',          lightBlue: 'add8e6',
+            lightCoral: 'f08080',        lightCyan: 'e0ffff',         lightGoldenrodYellow: 'fafad2',  lightGray: 'd3d3d3',
+            lightGreen: '90ee90',        lightPink: 'ffb6c1',         lightSalmon: 'ffa07a',           lightSeagreen: '20b2aa',
+            lightSkyBlue: '87cefa',      lightSlateGray: '778899',    lightSteelBlue: 'b0c4de',        lightYellow: 'ffffe0',
+            lime: '00ff00',              limeGreen: '32cd32',         linen: 'faf0e6',                 magenta: 'ff00ff',
+            maroon: '800000',            mediumAquamarine: '66cdaa',  mediumBlue: '0000cd',            mediumOrchid: 'ba55d3',
+            mediumPurple: '9370d8',      mediumSeagreen: '3cb371',    mediumSlateBlue: '7b68ee',       mediumSpringGreen: '00fa9a',
+            mediumTurquoise: '48d1cc',   mediumVioletred: 'c71585',   midnightBlue: '191970',          mintCream: 'f5fffa',
+            mistyRose: 'ffe4e1',         moccasin: 'ffe4b5',          navajoWhite: 'ffdead',           navy: '000080',
+            oldLace: 'fdf5e6',           olive: '808000',             oliveDrab: '6b8e23',             orange: 'ffa500',
+            orangeRed: 'ff4500',         orchid: 'da70d6',            paleGoldenrod: 'eee8aa',         paleGreen: '98fb98',
+            paleTurquoise: 'afeeee',     paleVioletRed: 'd87093',     papayaWhip: 'ffefd5',            peachPuff: 'ffdab9',
+            peru: 'cd853f',              pink: 'ffc0cb',              plum: 'dda0dd',                  powderBlue: 'b0e0e6',
+            purple: '800080',            red: 'ff0000',               rosyBrown: 'bc8f8f',             royalBlue: '4169e1',
+            saddleBrown: '8b4513',       salmon: 'fa8072',            sandyBrown: 'f4a460',            seaGreen: '2e8b57',
+            seaShell: 'fff5ee',          sienna: 'a0522d',            silver: 'c0c0c0',                skyBlue: '87ceeb',
+            slateBlue: '6a5acd',         slateGray: '708090',         snow: 'fffafa',                  springGreen: '00ff7f',
+            steelBlue: '4682b4',         tan: 'd2b48c',               teal: '008080',                  thistle: 'd8bfd8',
+            tomato: 'ff6347',            turquoise: '40e0d0',         violet: 'ee82ee',                wheat: 'f5deb3',
+            white: 'ffffff',             whiteSmoke: 'f5f5f5',        yellow: 'ffff00',                yellowGreen: '9acd32'
+        }, function (value, key) {
+            map[key.toLowerCase()] = { name: key, rgb: value };
+        });
+        return map;
+    }());
 
     // private static functions ===============================================
 
@@ -148,51 +130,35 @@ define('io.ox/office/editframework/utils/color', [
     }
 
     /**
-     * draws system color string as fillstyle in a canvas, to get its rgb values
+     * Returns the RGB value of the specified system color.
      *
-     * @param {String} name
-     *  System color name
+     * @param {String} sysColor
+     *  The name of a system color, as used in CSS, and in document operations.
+     *  The character case of the color name will be ignored.
      *
      * @returns {String}
-     *  hex string of rgb
+     *  The RGB value of the system color, as 6-digit string.
      */
     var getSystemRGBColor = (function () {
 
         var canvas = new Canvas();
-        canvas.initialize({ width: 1, height: 1 });
+        canvas.initialize({ width: 3, height: 3 });
 
-        return function (name) {
-            canvas.render(function (ctx) {
-                ctx.setGlobalAlpha(1);
-                ctx.setFillStyle({ style: name });
-                ctx.drawRect(0, 0, 1, 1);
-            });
-            var imgData = canvas.getImageData();
-            return ('00000' + (imgData[0] * 0x10000 + imgData[1] * 0x100 + imgData[2]).toString(16)).substr(-6);
-        };
-    }());
-
-    /**
-     * Converts SystemColor Name to its rgb color value
-     *
-     * @param {String} sysColor
-     *  as name
-     *
-     * @returns {String}
-     * the correct rgb hex string.
-     */
-    function convertSysColorToRGB(sysColor) {
-        var lower = sysColor.toLowerCase();
-        var entry = SYSTEM_COLORS[lower];
-        if (entry) {
-            if (!entry.rgb) {
-                entry.rgb = getSystemRGBColor(entry.name);
-            }
-            return entry.rgb;
+        // store only lower-case color names in the cache
+        function getColorKey(sysColor) {
+            return sysColor.toLowerCase();
         }
-        Utils.warn('System Color "' + sysColor + '" is not defined in Color.SYSTEM_COLORS');
-        return '9E9E9E';
-    }
+
+        // converts color names to RGB strings
+        function getRGBColor(sysColor) {
+            canvas.render(function (context) {
+                context.setFillStyle(sysColor).drawRect(0, 0, 3, 3, 'fill');
+            });
+            return canvas.getPixelColor(1, 1).hex;
+        }
+
+        return _.memoize(getRGBColor, getColorKey);
+    }());
 
     // class AlphaModel ======================================================
 
@@ -217,14 +183,24 @@ define('io.ox/office/editframework/utils/color', [
     // public methods ---------------------------------------------------------
 
     /**
-     * Changes the specified color channel to the specified value.
+     * Changes the specified color channel to the specified value. This method
+     * is intended to be used by subclasses representing different color models
+     * to manipulate the various supported color channels.
      *
      * @param {String} channel
-     *  The name of the color channel.
+     *  The name of the color channel. The supported channel names depend on
+     *  the subclass representing a specific color model. The channel name 'a'
+     *  will manipulate the alpha channel provided by this base class.
      *
      * @param {Number} value
      *  The new value of the color channel.
      *
+     * @param {Number} [cycle]
+     *  If specified, the size of the channel interval (the valid numbers for
+     *  the channel). The channel value passed in the parameter 'value' will be
+     *  adjusted to the channel size by calculating the modulo. If omitted, the
+     *  passed value will be reduced to the interval [0,1].
+     *
      * @returns {AlphaModel}
      *  A reference to this instance.
      */
@@ -235,14 +211,24 @@ define('io.ox/office/editframework/utils/color', [
 
     /**
      * Modulates the specified color channel (multiplies the color channel with
-     * the specified factor).
+     * the specified factor). This method is intended to be used by subclasses
+     * representing different color models to manipulate the various supported
+     * color channels.
      *
      * @param {String} channel
-     *  The name of the color channel.
+     *  The name of the color channel. The supported channel names depend on
+     *  the subclass representing a specific color model. The channel name 'a'
+     *  will manipulate the alpha channel provided by this base class.
      *
      * @param {Number} factor
      *  The modulation factor. MUST be non-negative.
      *
+     * @param {Number} [cycle]
+     *  If specified, the size of the channel interval (the valid numbers for
+     *  the channel). The resulting channel value will be adjusted to the
+     *  channel size by calculating the modulo. If omitted, the resulting value
+     *  will be reduced to the interval [0,1].
+     *
      * @returns {AlphaModel}
      *  A reference to this instance.
      */
@@ -252,14 +238,24 @@ define('io.ox/office/editframework/utils/color', [
 
     /**
      * Shifts the specified color channel (adds the specified value to the
-     * color channel).
+     * color channel). This method is intended to be used by subclasses
+     * representing different color models to manipulate the various supported
+     * color channels.
      *
      * @param {String} channel
-     *  The name of the color channel.
+     *  The name of the color channel. The supported channel names depend on
+     *  the subclass representing a specific color model. The channel name 'a'
+     *  will manipulate the alpha channel provided by this base class.
      *
      * @param {Number} shift
      *  The value to be added to the color channel.
      *
+     * @param {Number} [cycle]
+     *  If specified, the size of the channel interval (the valid numbers for
+     *  the channel). The resulting channel value will be adjusted to the
+     *  channel size by calculating the modulo. If omitted, the resulting value
+     *  will be reduced to the interval [0,1].
+     *
      * @returns {AlphaModel}
      *  A reference to this instance.
      */
@@ -270,7 +266,9 @@ define('io.ox/office/editframework/utils/color', [
     // class RGBModel =========================================================
 
     /**
-     * Representation of a color using the RGB color model.
+     * Representation of a color using the RGB color model. This class adds the
+     * color channels 'r', 'g', and 'b' which can be manipulated by the methods
+     * of the base class AlphaModel.
      *
      * @constructor
      *
@@ -343,6 +341,16 @@ define('io.ox/office/editframework/utils/color', [
         return new RGBModel(this.r, this.g, this.b, this.a);
     };
 
+    /**
+     * Returns the luma (the weighted lightness) of this RGB color.
+     *
+     * @returns {Number}
+     *  The luma of this color, in the interval [0;1].
+     */
+    RGBModel.prototype.getLuma = function () {
+        return 0.2126 * this.r + 0.7152 * this.g + 0.0722 * this.b;
+    };
+
     /**
      * Returns a reference to this instance. Used to ease the conversion from
      * different color models to an RGB color model.
@@ -369,9 +377,9 @@ define('io.ox/office/editframework/utils/color', [
             diff = max - min,
             sum = max + min;
 
-        var h = (diff === 0) ? 0 : (max === this.r) ? Utils.mod((this.g - this.b) / diff * 60, 360) : (max === this.g) ? ((this.b - this.r) / diff * 60 + 120) : ((this.r - this.g) / diff * 60 + 240),
-            s = ((sum === 0) || (sum === 2)) ? 0 : (sum < 1) ? (diff / sum) : (diff / (2 - sum)),
-            l = sum / 2;
+        var h = (diff === 0) ? 0 : (max === this.r) ? Utils.mod((this.g - this.b) / diff * 60, 360) : (max === this.g) ? ((this.b - this.r) / diff * 60 + 120) : ((this.r - this.g) / diff * 60 + 240);
+        var s = ((sum === 0) || (sum === 2)) ? 0 : (sum < 1) ? (diff / sum) : (diff / (2 - sum));
+        var l = sum / 2;
 
         return new HSLModel(h, s, l, this.a);
     };
@@ -422,14 +430,16 @@ define('io.ox/office/editframework/utils/color', [
      *  A reference to this instance.
      */
     RGBModel.prototype.gray = function () {
-        this.r = this.g = this.b = 0.2126 * this.r + 0.7152 * this.g + 0.0722 * this.b;
+        this.r = this.g = this.b = this.getLuma();
         return this;
     };
 
     // class HSLModel =========================================================
 
     /**
-     * Representation of a color using the HSL color model.
+     * Representation of a color using the HSL color model. This class adds the
+     * color channels 'h', 's', and 'l' which can be manipulated by the methods
+     * of the base class AlphaModel.
      *
      * @constructor
      *
@@ -597,7 +607,8 @@ define('io.ox/office/editframework/utils/color', [
      *  semi-transparent color, or as keyword 'transparent'.
      *
      * @property {String} hex
-     *  The hexadecimal RRGGBB value, ignoring the actual opacity of the color.
+     *  The upper-case hexadecimal RRGGBB value, ignoring the actual opacity of
+     *  the color.
      */
     function ColorDescriptor(model) {
 
@@ -607,20 +618,21 @@ define('io.ox/office/editframework/utils/color', [
 
         // alpha channel, and luma
         this.a = model.a;
-        this.y = this.rgb.clone().gray().r;
+        this.y = this.rgb.getLuma();
         this.dark = this.y <= Y_DARK;
 
         // CSS representation (double rounding to workaround rounding errors during RGB/HSL conversion)
-        var r8 = Math.round(Math.round(this.rgb.r * 25500000) / 100000),
-            g8 = Math.round(Math.round(this.rgb.g * 25500000) / 100000),
-            b8 = Math.round(Math.round(this.rgb.b * 25500000) / 100000);
+        var r8 = Math.round(Math.round(this.rgb.r * 25500000) / 100000);
+        var g8 = Math.round(Math.round(this.rgb.g * 25500000) / 100000);
+        var b8 = Math.round(Math.round(this.rgb.b * 25500000) / 100000);
 
         // add plain hexadecimal color representation without alpha channel
-        this.hex = ('00000' + (r8 * 0x10000 + g8 * 0x100 + b8).toString(16)).substr(-6);
+        var hex = ('00000' + (r8 * 0x10000 + g8 * 0x100 + b8).toString(16)).substr(-6);
+        this.hex = hex.toUpperCase();
 
         // add CSS color representation ('transparent' for full transparency, RGB hex
         // code for opaque colors, or 'rgba' function style for transparent colors)
-        this.css = (this.a === 0) ? 'transparent' : (this.a === 1) ? ('#' + this.hex) : 'rgba(' + r8 + ',' + g8 + ',' + b8 + ',' + this.a + ')';
+        this.css = (this.a === 0) ? 'transparent' : (this.a === 1) ? ('#' + hex) : 'rgba(' + r8 + ',' + g8 + ',' + b8 + ',' + this.a + ')';
 
     } // class ColorDescriptor
 
@@ -814,10 +826,10 @@ define('io.ox/office/editframework/utils/color', [
          */
         this.resolve = function (auto, theme) {
 
-            var // the color model containing the resolved color
-                model = null,
-                // whether to apply the color transformations
-                applyTransforms = true;
+            // the color model containing the resolved color
+            var model = null;
+            // whether to apply the color transformations
+            var applyTransforms = true;
 
             function createDefaultModel() {
                 applyTransforms = false;
@@ -835,12 +847,12 @@ define('io.ox/office/editframework/utils/color', [
 
                 // predefined system UI colors without fixed RGB values
                 case 'system':
-                    model = _.isString(value) ? RGBModel.parseHex(convertSysColorToRGB(value)) : createDefaultModel();
+                    model = _.isString(value) ? RGBModel.parseHex(getSystemRGBColor(value)) : createDefaultModel();
                     break;
 
                 // predefined colors with fixed RGB values
                 case 'preset':
-                    var preset = _.isString(value) ? PRESET_COLORS[value.toLowerCase()] : null;
+                    var preset = _.isString(value) ? PRESET_COLOR_MAP[value.toLowerCase()] : null;
                     model = preset ? RGBModel.parseHex(preset.rgb) : createDefaultModel();
                     break;
 
@@ -866,7 +878,7 @@ define('io.ox/office/editframework/utils/color', [
                             Utils.warn('Color.resolve(): scheme color type "style" not implemented');
                             model = createDefaultModel();
                         } else {
-                            model = RGBModel.parseHex(theme.getSchemeColor(value));
+                            model = RGBModel.parseHex(theme.getSchemeColor(value, '000000'));
                         }
                     } else {
                         model = createDefaultModel();
@@ -935,10 +947,10 @@ define('io.ox/office/editframework/utils/color', [
          */
         this.resolveText = function (fillColors, theme) {
 
-            var // the resulting text color
-                textColor = this,
-                // the effective fill color
-                fillColor = null;
+            // the resulting text color
+            var textColor = this;
+            // the effective fill color
+            var fillColor = null;
 
             // resolve explicit colors directly
             if (this.isAuto()) {
@@ -956,6 +968,53 @@ define('io.ox/office/editframework/utils/color', [
             return textColor.resolve('text', theme);
         };
 
+        /**
+         * Returns a color descriptor with details for a color that is a mix of
+         * this color instance, and the passed color instance.
+         *
+         * @param {Color} color
+         *  The other color to be mixed with this color.
+         *
+         * @param {Number} weighting
+         *  Specifies how much of the other color will be mixed into this
+         *  color. Values equal to or less than zero will result in an exact
+         *  copy of THIS color. Values equal to or greater than one will result
+         *  in an exact copy of the OTHER color. Values between zero and one
+         *  result in a mixed color between this and the other color, where
+         *  values close to zero result in colors similar to THIS color, and
+         *  values close to one result in colors similar to the OTHER color.
+         *
+         * @param {String|Color} auto
+         *  Additional information needed to resolve the automatic color. See
+         *  method Color.resolve() for details.
+         *
+         * @param {Theme} [theme]
+         *  A document theme object used to map scheme color names to color
+         *  values. If missing, theme colors will not be resolved correctly.
+         *
+         * @returns {ColorDescriptor}
+         *  A descriptor for the resulting color.
+         */
+        this.resolveMixed = function (color, weighting, auto, theme) {
+
+            // resolve this color and the other color
+            var desc1 = this.resolve(auto, theme);
+            var desc2 = color.resolve(auto, theme);
+
+            // early exit if passed weithing is out of the open interval (0,1)
+            if (weighting <= 0) { return desc1; }
+            if (weighting >= 1) { return desc2; }
+
+            // use the RGBA color model to calculate a mixed color
+            var r = desc1.rgb.r + (desc2.rgb.r - desc1.rgb.r) * weighting;
+            var g = desc1.rgb.g + (desc2.rgb.g - desc1.rgb.g) * weighting;
+            var b = desc1.rgb.b + (desc2.rgb.b - desc1.rgb.b) * weighting;
+            var a = desc1.rgb.a + (desc2.rgb.a - desc1.rgb.a) * weighting;
+
+            var rgb = new RGBModel(r, g, b, a);
+            return new ColorDescriptor(rgb);
+        };
+
         /**
          * Returns the JSON representation of this color, as used in document
          * operations.
@@ -1044,7 +1103,7 @@ define('io.ox/office/editframework/utils/color', [
         if (value === 'transparent') { return createTransparentColor('rgb', '000000'); }
 
         // predefined color names
-        var preset = PRESET_COLORS[value.toLowerCase()];
+        var preset = PRESET_COLOR_MAP[value.toLowerCase()];
         if (preset) { return new Color('preset', preset.name); }
 
         // 6-digit hexadecimal color
