@@ -72,6 +72,14 @@ define('io.ox/office/editframework/utils/editconfig', [
      */
     EditConfig.ENABLED_RESTORE_DOCUMENT = EditConfig.getFlag('documentRestoreEnabled', true);
 
+    /**
+     * A Boolean flag specifying whether the Application should load rescue documents
+     * in read-only mode or not.
+     *
+     * @constant
+     */
+    EditConfig.RESCUE_DOCUMENT_READONLY = EditConfig.getFlag('rescueDocumentReadOnly', true);
+
     // static methods =========================================================
 
     /**
