@@ -33,13 +33,17 @@ define('io.ox/office/editframework/utils/operationcontext', [
      *  The JSON operation object wrapped by this instance.
      *
      * @property {Boolean} external
-     *  The external state flag.
+     *  Whether the operation has been received from the server.
+     *
+     * @property {Boolean} importing
+     *  Whether the operation is part of the initial document import process.
      */
-    function OperationContext(docModel, operation, external) {
+    function OperationContext(docModel, operation, external, importing) {
 
         this.docModel = docModel;
         this.operation = operation;
-        this.external = external;
+        this.external = !!external;
+        this.importing = !!importing;
 
     } // class OperationContext
 
