@@ -52,28 +52,53 @@ define('io.ox/office/editframework/utils/operations', [
         INSERT_FONT_DESCRIPTION: 'insertFontDescription',
 
         /**
-         * Name of the operation that inserts a new style sheet into the style
-         * sheet collection of a specific style family.
+         * Name of the operation that inserts a new style sheet into the
+         * document.
          *
          * @constant
          */
         INSERT_STYLESHEET: 'insertStyleSheet',
 
         /**
-         * Name of the operation that removes a style sheet from the style
-         * sheet collection of a specific style family.
+         * Name of the operation that removes an existing style sheet from the
+         * document.
          *
          * @constant
          */
         DELETE_STYLESHEET: 'deleteStyleSheet',
 
         /**
-         * :)
+         * Name of the operation that changes the properties of an existing
+         * style sheet in the document.
          *
          * @constant
          */
         CHANGE_STYLESHEET: 'changeStyleSheet',
 
+        /**
+         * Name of the operation that inserts a new auto-style into the
+         * document.
+         *
+         * @constant
+         */
+        INSERT_AUTOSTYLE: 'insertAutoStyle',
+
+        /**
+         * Name of the operation that changes the formatting attributes of an
+         * existing auto-style in the document.
+         *
+         * @constant
+         */
+        CHANGE_AUTOSTYLE: 'changeAutoStyle',
+
+        /**
+         * Name of the operation that deletes an existing auto-style from the
+         * document.
+         *
+         * @constant
+         */
+        DELETE_AUTOSTYLE: 'deleteAutoStyle',
+
         /**
          * Name of the operation that does nothing (internal usage).
          *
