@@ -19,27 +19,28 @@ define('io.ox/office/editframework/view/control/bordermodepicker', [
 
     'use strict';
 
-    var // all available entries for the border picker control
-        BORDER_ENTRIES = [
+    // all available entries for the border picker control
+    var BORDER_ENTRIES = [
 
-            { name: 'left',    value: 'left',    icon: 'docs-border-l', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Left border') },
-            { name: 'right',   value: 'right',   icon: 'docs-border-r', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Right border') },
-            { name: 'top',     value: 'top',     icon: 'docs-border-t', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Top border') },
-            { name: 'bottom',  value: 'bottom',  icon: 'docs-border-b', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Bottom border') },
-            { name: 'insidev', value: 'insidev', icon: 'docs-border-v', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Inner vertical borders') },
-            { name: 'insideh', value: 'insideh', icon: 'docs-border-h', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Inner horizontal borders') },
+        { name: 'left',    value: 'left',    icon: 'docs-border-l', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Left border') },
+        { name: 'right',   value: 'right',   icon: 'docs-border-r', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Right border') },
+        { name: 'top',     value: 'top',     icon: 'docs-border-t', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Top border') },
+        { name: 'bottom',  value: 'bottom',  icon: 'docs-border-b', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Bottom border') },
+        { name: 'insidev', value: 'insidev', icon: 'docs-border-v', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Inner vertical borders') },
+        { name: 'insideh', value: 'insideh', icon: 'docs-border-h', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Inner horizontal borders') },
 
-            { name: 'none',               value: { left: false, right: false, insidev: false, top: false, bottom: false, insideh: false }, icon: 'docs-border',        label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'No borders') },
-            { name: 'outer',              value: { left: true,  right: true,  insidev: false, top: true,  bottom: true,  insideh: false }, icon: 'docs-border-tblr',   label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Outer borders') },
-            { name: 'inner',              value: { left: false, right: false, insidev: true,  top: false, bottom: false, insideh: true },  icon: 'docs-border-hv',     label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Inner borders') },
-            { name: 'all',                value: { left: true,  right: true,  insidev: true,  top: true,  bottom: true,  insideh: true },  icon: 'docs-border-tbhlrv', label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'All borders') },
-            { name: 'left-right',         value: { left: true,  right: true,  insidev: false, top: false, bottom: false, insideh: false }, icon: 'docs-border-lr',     label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Left and right borders') },
-            { name: 'left-right-insidev', value: { left: true,  right: true,  insidev: true,  top: false, bottom: false, insideh: false }, icon: 'docs-border-lrv',    label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'All vertical borders') },
-            { name: 'outer-insidev',      value: { left: true,  right: true,  insidev: true,  top: true,  bottom: true,  insideh: false }, icon: 'docs-border-tblrv',  label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Inner vertical and outer borders') },
-            { name: 'top-bottom',         value: { left: false, right: false, insidev: false, top: true,  bottom: true,  insideh: false }, icon: 'docs-border-tb',     label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Top and bottom borders') },
-            { name: 'top-bottom-insideh', value: { left: false, right: false, insidev: false, top: true,  bottom: true,  insideh: true },  icon: 'docs-border-tbh',    label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'All horizontal borders') },
-            { name: 'outer-insideh',      value: { left: true,  right: true,  insidev: false, top: true,  bottom: true,  insideh: true },  icon: 'docs-border-tbhlr',  label: /*#. in paragraphs and tables cells */ gt.pgettext('borders', 'Inner horizontal and outer borders') }
-        ];
+        { name: 'none',               value: Utils.makeSet(['left', 'right', 'insidev', 'top', 'bottom', 'insideh'], false), icon: 'docs-border',        label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'No borders') },
+
+        { name: 'outer',              value: Utils.makeSet(['left', 'right', 'top', 'bottom']),                              icon: 'docs-border-tblr',   label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Outer borders') },
+        { name: 'inner',              value: Utils.makeSet(['insidev', 'insideh']),                                          icon: 'docs-border-hv',     label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Inner borders') },
+        { name: 'all',                value: Utils.makeSet(['left', 'right', 'insidev', 'top', 'bottom', 'insideh']),        icon: 'docs-border-tbhlrv', label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'All borders') },
+        { name: 'left-right',         value: Utils.makeSet(['left', 'right']),                                               icon: 'docs-border-lr',     label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Left and right borders') },
+        { name: 'top-bottom',         value: Utils.makeSet(['top', 'bottom']),                                               icon: 'docs-border-tb',     label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Top and bottom borders') },
+        { name: 'left-right-insidev', value: Utils.makeSet(['left', 'right', 'insidev']),                                    icon: 'docs-border-lrv',    label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'All vertical borders') },
+        { name: 'top-bottom-insideh', value: Utils.makeSet(['top', 'bottom', 'insideh']),                                    icon: 'docs-border-tbh',    label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'All horizontal borders') },
+        { name: 'outer-insidev',      value: Utils.makeSet(['left', 'right', 'top', 'bottom', 'insidev']),                   icon: 'docs-border-tblrv',  label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Inner vertical and outer borders') },
+        { name: 'outer-insideh',      value: Utils.makeSet(['left', 'right', 'top', 'bottom', 'insideh']),                   icon: 'docs-border-tbhlr',  label: /*#. in paragraphs and table cells */ gt.pgettext('borders', 'Inner horizontal and outer borders') }
+    ];
 
     // class BorderModePicker =================================================
 
@@ -204,15 +205,14 @@ define('io.ox/office/editframework/view/control/bordermodepicker', [
         // initialization -----------------------------------------------------
 
         // prepare the sections for the toggle buttons and the complex border buttons
-        self.createMenuSection('single').createMenuSection('compound');
+        self.createMenuSection('single').createMenuSection('none').createMenuSection('compound');
 
         // insert all supported list items
-        _.each(BORDER_ENTRIES, function (entry) {
-            var single = _.isString(entry.value),
-                section = single ? 'single' : 'compound',
-                visible = isInsideHor(entry.value) ? (isInsideVert(entry.value) ? showInsideBothItems : showInsideHorItems) : (isInsideVert(entry.value) ? showInsideVertItems : true);
-            self.createOptionButton(entry.value, { section: section, icon: entry.icon, label: entry.label, dataValue: entry.name, visible: visible });
-        });
+        BORDER_ENTRIES.forEach(function (entry) {
+            var section = _.isString(entry.value) ? 'single' : (entry.name === 'none') ? 'none' : 'compound';
+            var visible = isInsideHor(entry.value) ? (isInsideVert(entry.value) ? showInsideBothItems : showInsideHorItems) : (isInsideVert(entry.value) ? showInsideVertItems : true);
+            this.createOptionButton(entry.value, { section: section, icon: entry.icon, label: entry.label, dataValue: entry.name, visible: visible });
+        }, this);
 
         // register custom update handler to select the correct border icon
         this.registerUpdateHandler(updateHandler);
