@@ -52,19 +52,19 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
      */
     var getBorderStyleBitmapUrl = (function () {
 
-        var // the canvas element used to generate the bitmaps
-            canvas = new Canvas(),
+        // the canvas element used to generate the bitmaps
+        var canvas = new Canvas();
 
-            // maps unique bitmap keys values to the data URLs
-            bitmapUrls = {};
+        // maps unique bitmap keys values to the data URLs
+        var bitmapUrls = {};
 
         // the getBorderStyleBitmapUrl() method to be returned from the local scope
         function getBorderStyleBitmapUrl(width, height, borderStyle) {
 
-            var // number of lines
-                lineCount = borderStyle.count || 1,
-                // unique key of the generated bitmap
-                bitmapKey = width + ',' + height + ',' + borderStyle.style + ',' + borderStyle.width + ',' + borderStyle.color + ',' + lineCount;
+            // number of lines
+            var lineCount = borderStyle.count || 1;
+            // unique key of the generated bitmap
+            var bitmapKey = width + ',' + height + ',' + borderStyle.style + ',' + borderStyle.width + ',' + borderStyle.color + ',' + lineCount;
 
             // return data URL of a bitmap already created
             if (bitmapKey in bitmapUrls) {
@@ -78,14 +78,14 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
             if (borderStyle.style !== 'none') {
                 canvas.render(function (context) {
 
-                    var // the path with all line segments (of double lines)
-                        path = context.createPath(),
-                        // effective line width
-                        lineWidth = Math.max(1, borderStyle.width),
-                        // dash pattern
-                        pattern = Border.getBorderPattern(borderStyle.style, lineWidth),
-                        // Y offset of the first line
-                        y = Math.floor(height / 2) - lineWidth * (lineCount - 1) - (lineWidth % 2) / 2;
+                    // the path with all line segments (of double lines)
+                    var path = context.createPath();
+                    // effective line width
+                    var lineWidth = Math.max(1, borderStyle.width);
+                    // dash pattern
+                    var pattern = Border.getBorderPattern(borderStyle.style, lineWidth);
+                    // Y offset of the first line
+                    var y = Math.floor(height / 2) - lineWidth * (lineCount - 1) - (lineWidth % 2) / 2;
 
                     context.setLineStyle({ style: borderStyle.color, width: lineWidth, pattern: pattern });
                     if (borderStyle.width < 1) { context.setGlobalAlpha(0.4); }
@@ -93,7 +93,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
                         path.pushLine(0, y, width, y);
                         y += 2 * lineWidth;
                     });
-                    context.drawPath(path);
+                    context.drawPath(path, 'stroke');
                 });
             }
 
@@ -113,7 +113,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
      *
      * @extends RadioList
      *
-     * @param {Array} listEntries
+     * @param {Array<Object>} listEntries
      *  An array of descriptors for the entries of the drop-down list. Each
      *  descriptor is an object with the following properties:
      *  - {Any} value
@@ -138,8 +138,8 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
      */
     function BorderStylePicker(listEntries, initOptions) {
 
-        var // maps control values to border style descriptors
-            borderStyles = {};
+        // maps control values to border style descriptors
+        var borderStyles = {};
 
         // base constructor ---------------------------------------------------
 
@@ -184,7 +184,7 @@ define('io.ox/office/editframework/view/control/borderstylepicker', [
         this.getMenu().on('create:item', createItemHandler);
 
         // create the bitmaps for the icons, and insert the entries into the drop-down list
-        _.each(listEntries, function (entry) {
+        listEntries.forEach(function (entry) {
             borderStyles[entry.value] = _.extend({ color: '#333333' }, entry.icon);
             this.createOptionButton(entry.value, { label: entry.label });
         }, this);
