@@ -14,9 +14,8 @@
 define('io.ox/office/editframework/view/control/borderwidthpicker', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/control/combofield',
-    'io.ox/office/editframework/view/editlabels',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, ComboField, EditLabels, gt) {
+], function (Utils, ComboField, gt) {
 
     'use strict';
 
@@ -52,14 +51,11 @@ define('io.ox/office/editframework/view/control/borderwidthpicker', [
 
         [0.5, 1, 1.5, 2, 2.5, 3, 4, 6].forEach(function (size) {
             this.createListEntry(size, {
-                label: gt.format(
-                    //#. A single list entry of a GUI border width picker.
-                    //#. Example result: "5 points"
-                    //#. %1$d is the width of the border line.
-                    //#, c-format
-                    gt.npgettext('borders', '%1$d point', '%1$d points', size),
-                    _.noI18n(size)
-                ),
+                //#. A single list entry of a GUI border width picker.
+                //#. Example result: "5 points"
+                //#. %1$d is the width of the border line.
+                //#, c-format
+                label: gt.npgettext('borders', '%1$d point', '%1$d points', size, _.noI18n(size)),
                 style: 'text-align:center;'
             });
         }, this);
