@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH
+  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  * @author Jonas Regier <jonas.regier@open-xchange.com>
@@ -15,10 +15,11 @@
 define('io.ox/office/editframework/view/control/colorpicker', [
     'io.ox/office/tk/utils',
     'io.ox/office/tk/control/radiolist',
-    'io.ox/office/editframework/utils/color',
     'io.ox/office/tk/control/colorslider',
+    'io.ox/office/baseframework/app/appobjectmixin',
+    'io.ox/office/editframework/utils/color',
     'gettext!io.ox/office/editframework/main'
-], function (Utils, RadioList, Color, ColorSlider, gt) {
+], function (Utils, RadioList, ColorSlider, AppObjectMixin, Color, gt) {
 
     'use strict';
 
@@ -108,6 +109,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
      * @constructor
      *
      * @extends RadioList
+     * @extends AppObjectMixin
      *
      * @param {EditView} docView
      *  The document view instance containing this control.
@@ -118,9 +120,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
      *  the button for the automatic color will not be created at all.
      *
      * @param {Object} [initOptions]
-     *  Optional parameters. Supports all options of the RadioList base class,
-     *  and the following options:
-     *  @param.
+     *  Optional parameters. Supports all options of the RadioList base class.
      */
     function ColorPicker(docView, colorType, initOptions) {
 
@@ -154,16 +154,20 @@ define('io.ox/office/editframework/view/control/colorpicker', [
             // reference to all scheme color rows in the DOM
             schemeColorRows = null;
 
-        // base constructor ---------------------------------------------------
+        // base constructors --------------------------------------------------
 
         RadioList.call(this, Utils.extendOptions({
             itemDesign: 'grid',
             gridColumns: (Utils.SMALL_DEVICE) ? 6 : 10,
             updateCaptionMode: 'none',
             itemMatcher: sameColors,
-            dropDownVersion: { label: Utils.getStringOption(initOptions, 'tooltip') }
+            dropDownVersion: { label: Utils.getStringOption(initOptions, 'tooltip') },
+            isRootAnchoredMenu: Utils.SMALL_DEVICE
+
         }, initOptions));
 
+        AppObjectMixin.call(this, docView.getApp());
+
         // private methods ----------------------------------------------------
 
         /**
@@ -179,7 +183,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
          */
         function createItemHandler(event, buttonNode, jsonColor) {
             var
-                className = (Utils.SMALL_DEVICE) ? 'color-button-mobile' : 'color-button',
+                className = Utils.SMALL_DEVICE ? 'color-button-mobile' : 'color-button',
                 boxNode = $('<span class="' + className + '">');
             setBackgroundColor(boxNode, jsonColor);
             buttonNode.prepend(boxNode);
@@ -195,7 +199,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
         /**
          * Get the corresponding scheme color row to a given color object.
          */
-        function getColorRowNumber (color) {
+        function getColorRowNumber(color) {
             var colorRow = defaultHandlePosition;
             var temp;
             for (var n = 0; n < 10; n++) {
@@ -392,8 +396,6 @@ define('io.ox/office/editframework/view/control/colorpicker', [
          */
         function initializeColorTable() {
 
-            self.clearMenu({ except: '.title' });
-
             function addAutoColor() {
                 // add automatic color
                 if (_.isString(colorType)) {
@@ -403,10 +405,11 @@ define('io.ox/office/editframework/view/control/colorpicker', [
             }
 
             function addSchemeColors() {
+
                 // different creation method on small devices
-                var method = (Utils.SMALL_DEVICE) ? fillSchemeColorRowMobile : fillSchemeColorRow,
+                var method = Utils.SMALL_DEVICE ? fillSchemeColorRowMobile : fillSchemeColorRow;
                 // different length due to a different orientation on small devices
-                    length = (Utils.SMALL_DEVICE) ? SCHEME_COLOR_DEFINITIONS.length : SCHEME_COLOR_DEFINITIONS[0].transformations.length;
+                var length = Utils.SMALL_DEVICE ? SCHEME_COLOR_DEFINITIONS.length : SCHEME_COLOR_DEFINITIONS[0].transformations.length;
 
                 // add scheme colors
                 if (docModel.hasSchemeColors()) {
@@ -415,29 +418,33 @@ define('io.ox/office/editframework/view/control/colorpicker', [
                 }
             }
 
-            function addPreColors() {
+            function addStandardColors() {
                 // add predefined colors
                 self.createMenuSection('standard', { label: gt('Standard Colors') });
                 _.each(BUILTIN_COLOR_DEFINITIONS, function (definition) {
                     self.createOptionButton(definition.color, { section: 'standard', tooltip: definition.label, dataValue: definition.name });
                 });
             }
+
+            // clear the menu, but do not remove the title node
+            self.clearMenu('>:not(.title)');
+
             // section order according to the device type
             if (Utils.SMALL_DEVICE) {
                 addAutoColor();
-                addPreColors();
+                addStandardColors();
                 addSchemeColors();
             } else {
                 addAutoColor();
                 addSchemeColors();
-                addPreColors();
+                addStandardColors();
             }
         }
 
         /**
          *  unhides a color row for a given color and hides the last color.
          */
-        function showActiveSchemeColorRow (colorNumber, lastColor) {
+        function showActiveSchemeColorRow(colorNumber, lastColor) {
             // hides the last selected row in the mobile color picker
             schemeColorRows.eq(lastColor)[0].style.display = 'none';
             // show the row from the given color number
@@ -508,9 +515,7 @@ define('io.ox/office/editframework/view/control/colorpicker', [
         }
 
         // refresh color buttons in the drop-down menu after theme has changed
-        this.listenTo(docView.getApp().getImportPromise(), 'done', function () {
-            self.listenTo(docModel.getThemeCollection(), 'triggered', initializeColorTableDebounced);
-        });
+        this.listenTo(docModel.getThemeCollection(), 'triggered', initializeColorTableDebounced);
 
         // destroy all members on destruction
         this.registerDestructor(function () {
