@@ -44,6 +44,12 @@ define('io.ox/office/editframework/view/control/languagepicker', [
         'sv_SE'
     ];
 
+    // the locale of the user interface, with dash instead of underscore
+    var UI_LOCALE = LocaleData.LOCALE.replace('_', '-');
+
+    // special list item value for the entry 'None' (no language selected)
+    var NONE_VALUE = 'none';
+
     // a promise that will resolve when the locales with dictionaries have been received
     var definitionsPromise = (function () {
 
@@ -90,56 +96,27 @@ define('io.ox/office/editframework/view/control/languagepicker', [
             self = this,
             showListIcons = Utils.getBooleanOption(initOptions, 'showListIcons', true),
             showAllLanguages = Utils.getBooleanOption(initOptions, 'showAllLanguages', true),
-            mostRecentlyUsedNumber = showAllLanguages ? 4 : 0,
-            mostRecentlyBlackList = showAllLanguages ? ['none'] : [],
-            mostRecentlyUsedSettingsKey = 'languagepicker/mostrecentlyused',
-            localeDefinitions,
-            uiLocale = Config.LOCALE.replace('_', '-');
+            localeDefinitions;
 
         // base constructor ---------------------------------------------------
 
         RadioList.call(this, Utils.extendOptions(initOptions, {
             tooltip: gt('Text language'),
             sortItems: true,
-            mostRecentlyUsedNumber: mostRecentlyUsedNumber,
-            mostRecentlyBlackList: mostRecentlyBlackList,
-            mostRecentlyUsedSettingsKey: mostRecentlyUsedSettingsKey
+            // show most recently used languages in an own section
+            mruSize: showAllLanguages ? 4 : 0,
+            mruSettingsKey: 'languagepicker/mostrecentlyused',
+            mruBlackList: showAllLanguages ? [NONE_VALUE] : []
         }));
 
         // private methods ----------------------------------------------------
 
-        /**
-         * Add languages to the Language Picker if the initOptions.showAllLanguages is true;
-         */
-        function addLanguagePickerLanguages() {
-            self.getMenu().createMostRecentlyUsedSection();
-            createNoneLanguageButton();
-
-            addLanguages();
-        }
-
-        /**
-         * Add languages to the Language Picker if the initOptions.showAllLanguages is false;
-         */
-        function addReduceLanguagePickeLanguages() {
-            var mostRecentlyLanguages = Settings.get(mostRecentlyUsedSettingsKey, []);
-
-            function isMostRecentlyLanguage(value) {
-                return _.find(mostRecentlyLanguages, function (item) {
-                    return item.value === value;
-                });
-            }
-
-            addLanguages(function (value) {
-                return isMostRecentlyLanguage(value) || self.getValue() === value || uiLocale === value;
-            });
-            createNoneLanguageButton();
-        }
-
         function createNoneLanguageButton() {
-            self.createOptionButton('none', {
-                label: /*#. None is a "special" text language used in the languagepicker or means "Do not check spelling". Please do not remove the square brackets. */ gt('[None]'),
-                section: '[None]'
+            self.createOptionButton(NONE_VALUE, {
+                section: '[None]',
+                //#. A special entry used in a language selector control that means "No language selected" (e.g. no spell checking).
+                label: gt.pgettext('language', 'None'),
+                labelStyle: 'font-style:italic;'
             });
         }
 
@@ -149,23 +126,41 @@ define('io.ox/office/editframework/view/control/languagepicker', [
          *  if the filter return true the language will be added to the list.
          */
         function addLanguages(languageFilter) {
-            var filter = _.isFunction(languageFilter) ? languageFilter : _.constant(true);
 
             localeDefinitions.forEach(function (definition) {
 
-                if (filter(definition.value)) {
+                if (!languageFilter || languageFilter(definition.value)) {
                     var options = { label: definition.label };
                     if (showListIcons) {
                         options.icon = 'docs-dict-available';
                         if (!definition.supported) {
-                            options.iconStyle = 'visibility: hidden';
+                            options.iconStyle = 'visibility:hidden;';
                         }
                     }
-
                     self.createOptionButton(definition.value, options);
                 }
             });
+        }
 
+        /**
+         * Add languages to the Language Picker if the initOptions.showAllLanguages is true;
+         */
+        function addLanguagePickerLanguages() {
+            createNoneLanguageButton();
+            addLanguages();
+        }
+
+        /**
+         * Add languages to the Language Picker if the initOptions.showAllLanguages is false;
+         */
+        function addReduceLanguagePickerLanguages() {
+
+            // prepare a flag set with all languages to be shown
+            var languageSet = Utils.makeSet(self.getMenu().getMRUListEntries());
+            languageSet[UI_LOCALE] = languageSet[self.getValue()] = true;
+
+            addLanguages(function (language) { return language in languageSet; });
+            createNoneLanguageButton();
         }
 
         // initialization -----------------------------------------------------
@@ -177,7 +172,7 @@ define('io.ox/office/editframework/view/control/languagepicker', [
             if (Utils.getBooleanOption(initOptions, 'showAllLanguages', true)) {
                 addLanguagePickerLanguages();
             } else {
-                addReduceLanguagePickeLanguages();
+                addReduceLanguagePickerLanguages();
             }
         });
 
