@@ -191,10 +191,10 @@ define('io.ox/office/editframework/view/control/stylesheetpicker', [
             // bug 33737, 33747: restore browser focus
             self.getMenu().guardFocusedListItem(function () {
 
-                //Bug 39578 indices are temporary wrong because new button is always at the end and sorting is debounced
+                // Bug 39578: indices are temporary wrong because new button is always at the end and sorting is debounced
                 // collecting old index
-                //Bug 40403 double quotes dont work for attribute-selector
-                var btnSelector = 'a[data-value="' + styleId.replace(/\"/g, '\\"') + '"]';
+                // Bug 40403 double quotes must be escaped in attribute selector
+                var btnSelector = 'a[data-value="' + Utils.escapeHTML(styleId) + '"]';
                 var menuNode = self.getMenu().getNode();
                 var oldCellNode = menuNode.find(btnSelector).parent();
                 var oldIndex = oldCellNode.index();
