@@ -57,43 +57,43 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
      */
     function TableSizePicker(initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // minimum size allowed to choose
-            MIN_SIZE = { width: 1, height: 1 },
-            // maximum size allowed to choose (defaulting to 15 columns and rows)
-            MAX_SIZE = { width: Utils.getIntegerOption(initOptions, 'maxCols', 15, 1), height: Utils.getIntegerOption(initOptions, 'maxRows', 15, 1) },
-            // minimum size visible even if selected size is smaller
-            MIN_VIEW_SIZE = { width: Math.min(MAX_SIZE.width, 6), height: Math.min(MAX_SIZE.height, 4) },
+        // minimum size allowed to choose
+        var MIN_SIZE = { width: 1, height: 1 };
+        // maximum size allowed to choose (defaulting to 15 columns and rows)
+        var MAX_SIZE = { width: Utils.getIntegerOption(initOptions, 'maxCols', 15, 1), height: Utils.getIntegerOption(initOptions, 'maxRows', 15, 1) };
+        // minimum size visible even if selected size is smaller
+        var MIN_VIEW_SIZE = { width: Math.min(MAX_SIZE.width, 6), height: Math.min(MAX_SIZE.height, 4) };
 
-            // maximum grid size, according to options, and screen size
-            maxGridSize = _.clone(MAX_SIZE),
+        // maximum grid size, according to options, and screen size
+        var maxGridSize = _.clone(MAX_SIZE);
 
-            // current grid size
-            gridSize = _.clone(MIN_SIZE),
+        // current grid size
+        var gridSize = _.clone(MIN_SIZE);
 
-            // the drop-down menu instance (must be created after Button base constructor!)
-            menu = null,
+        // the drop-down menu instance (must be created after Button base constructor!)
+        var menu = null;
 
-            // the drop-down button
-            menuButton = $(Forms.createButtonMarkup(Utils.extendOptions({ attributes: { 'aria-haspopup': true } }, initOptions))),
+        // the drop-down button
+        var menuButton = $(Forms.createButtonMarkup(Utils.extendOptions({ attributes: { 'aria-haspopup': true } }, initOptions)));
 
-            // the button control to be inserted into the drop-down menu
-            // since 'aria-label' would override 'aria-describedby' and title is used as native tooltip, so nothing is set
-            gridButtonNode = $(Forms.createButtonMarkup({ attributes: { role: 'menuitem' } })),
+        // the button control to be inserted into the drop-down menu
+        // since 'aria-label' would override 'aria-describedby' and title is used as native tooltip, so nothing is set
+        var gridButtonNode = $(Forms.createButtonMarkup({ attributes: { role: 'menuitem' } }));
 
-            // canvas element for rendering the grid lines
-            canvas = new Canvas(),
+        // canvas element for rendering the grid lines
+        var canvas = new Canvas();
 
-            // the tooltip node showing the current grid size
-            sizeToolTip = null,
+        // the tooltip node showing the current grid size
+        var sizeToolTip = null;
 
-            // whether to grow to the left or right or to the top or bottom
-            growTop = false, growLeft = false,
+        // whether to grow to the left or right or to the top or bottom
+        var growTop = false, growLeft = false;
 
-            // current position of mouse pointer (page coordinates)
-            mousePos = null;
+        // current position of mouse pointer (page coordinates)
+        var mousePos = null;
 
         // base constructors --------------------------------------------------
 
@@ -175,11 +175,11 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
             if (mousePos) {
                 (function () {
 
-                    var // position/size of the grid
-                        gridPosition = Utils.getNodePositionInPage(canvas.getNode()),
-                        // mouse position relative to grid origin
-                        mouseRelX = growLeft ? (gridPosition.left + gridPosition.width - mousePos.x) : (mousePos.x - gridPosition.left),
-                        mouseRelY = growTop ? (gridPosition.top + gridPosition.height - mousePos.y) : (mousePos.y - gridPosition.top);
+                    // position/size of the grid
+                    var gridPosition = Utils.getNodePositionInPage(canvas.getNode());
+                    // mouse position relative to grid origin
+                    var mouseRelX = growLeft ? (gridPosition.left + gridPosition.width - mousePos.x) : (mousePos.x - gridPosition.left);
+                    var mouseRelY = growTop ? (gridPosition.top + gridPosition.height - mousePos.y) : (mousePos.y - gridPosition.top);
 
                     // enlarge grid if the last column/row is covered more than 80% of its width/height
                     gridSize = { width: Math.floor(mouseRelX / CELL_WIDTH + 1.2), height: Math.floor(mouseRelY / CELL_HEIGHT + 1.2) };
@@ -199,15 +199,15 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
             // render the grid
             canvas.render(function (context, width, height) {
 
-                var // the pixel size of the highlighted area
-                    highlightWidth = gridSize.width * CELL_WIDTH + 1,
-                    highlightHeight = gridSize.height * CELL_HEIGHT + 1,
-                    // a path object containing all line segments of the grid
-                    path = context.createPath();
+                // the pixel size of the highlighted area
+                var highlightWidth = gridSize.width * CELL_WIDTH + 1;
+                var highlightHeight = gridSize.height * CELL_HEIGHT + 1;
+                // a path object containing all line segments of the grid
+                var path = context.createPath();
 
                 // render the filled area
-                context.setLineStyle(null).setFillStyle({ style: '#c8c8c8' });
-                context.drawRect(growLeft ? (width - highlightWidth) : 0, growTop ? (height - highlightHeight) : 0, highlightWidth, highlightHeight);
+                context.setFillStyle('#c8c8c8');
+                context.drawRect(growLeft ? (width - highlightWidth) : 0, growTop ? (height - highlightHeight) : 0, highlightWidth, highlightHeight, 'fill');
 
                 // render the lines
                 for (var x = 0; x <= width; x += CELL_WIDTH) { path.pushLine(x, 0, x, height); }
@@ -215,23 +215,27 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
                 context.setLineStyle({ style: 'black', width: 1 });
                 context.setGlobalAlpha(0.1);
                 context.translate(0.5, 0.5);
-                context.drawPath(path);
+                context.drawPath(path, 'stroke');
             });
 
             // update the tooltip
-            sizeToolTip.setText(_.noI18n(gt('Table size') + _.noI18n(' ') + gt.format(
-                //#. Tooltip for an 'Insert table' toolbar control
-                //#. %1$d is the number of columns currently selected with the mouse
+            sizeToolTip.setText(
+                //#. Tooltip for an 'Insert table' toolbar control that shows the size of a table that
+                //#. will be inserted into a document, while moving with the mouse over a preview grid.
+                //#. %1$s is the placeholder for the translated text 'M column(s)'
+                //#. %2$s is the placeholder for the translated text 'N row(s)'
                 //#, c-format
-                gt.ngettext('%1$d column', '%1$d columns', gridSize.width),
-                _.noI18n(gridSize.width)
-            ) + ' \xd7 ' + gt.format(
-                //#. Tooltip for an 'Insert table' toolbar control
-                //#. %1$d is the number of rows currently selected with the mouse
-                //#, c-format
-                gt.ngettext('%1$d row', '%1$d rows', gridSize.height),
-                _.noI18n(gridSize.height)
-            )));
+                gt('Table size %1$s \xd7 %2$s',
+                    //#. Tooltip for an 'Insert table' toolbar control
+                    //#. %1$d is the number of columns currently selected with the mouse
+                    //#, c-format
+                    gt.ngettext('%1$d column', '%1$d columns', gridSize.width, _.noI18n(gridSize.width)),
+                    //#. Tooltip for an 'Insert table' toolbar control
+                    //#. %1$d is the number of rows currently selected with the mouse
+                    //#, c-format
+                    gt.ngettext('%1$d row', '%1$d rows', gridSize.height, _.noI18n(gridSize.height))
+                )
+            );
 
             // return precalculated position and alignment to the anchor
             return { anchorBorder: growTop ? 'top' : 'bottom', anchorAlign: growLeft ? 'trailing' : 'leading' };
@@ -242,8 +246,8 @@ define('io.ox/office/editframework/view/control/tablesizepicker', [
          * tooltip according to the growing direction of the pop-up node.
          */
         function toolTipPrepareLayoutHandler() {
-            var anchorBorder = growTop ? 'top bottom' : 'bottom top',
-                anchorAlign = growLeft ? 'trailing' : 'leading';
+            var anchorBorder = growTop ? 'top bottom' : 'bottom top';
+            var anchorAlign = growLeft ? 'trailing' : 'leading';
             if (Utils.TOUCHDEVICE) {
                 anchorBorder = (growLeft ? 'left' : 'right') + ' ' + anchorBorder;
                 anchorAlign = (growTop ? 'trailing' : 'leading') + ' ' + anchorAlign;
