@@ -44,7 +44,7 @@ define('io.ox/office/editframework/view/control/userbadge', [
     function UserBadge(docView, clientData, initOptions) {
 
         var // the link containing the user name
-            userNameNode = (clientData.guest || DriveUtils.isGuest()) ? $('<div class="user-name disabled">') : $('<a class="user-name halo-link">'),
+            userNameNode = (clientData.guest || DriveUtils.isGuest() || !DriveUtils.isContactsEnabled()) ? $('<div class="user-name disabled">') : $('<a class="user-name halo-link">'),
 
             // the status node at the right border
             userStatusNode = $('<div class="user-status">'),
