@@ -99,7 +99,7 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
          *  The trimmed URL from the input field.
          */
         function getUrl() {
-            return Utils.trimString(urlInputNode.val());
+            return Utils.removeWhiteSpacesString(urlInputNode.val());
         }
 
         function updateUrlField() {
@@ -151,8 +151,8 @@ define('io.ox/office/editframework/view/dialog/hyperlinkdialog', [
         // Bug 43868: ios auto correction should be of for input fields
         // TODO: use Forms.createInputMarkup() to create inputs here, it alrady has this fix
         if (Utils.IOS) {
-            urlInputNode.attr({ autocorrect : 'off', autocapitalize : 'none' });
-            displayInputNode.attr({ autocorrect : 'off', autocapitalize : 'none' });
+            urlInputNode.attr({ autocorrect: 'off', autocapitalize: 'none' });
+            displayInputNode.attr({ autocorrect: 'off', autocapitalize: 'none' });
         }
 
         // add the input controls to the dialog body
