@@ -49,6 +49,7 @@ define('io.ox/office/editframework/view/dialog/saveasfiledialog', [
      *      can be: FolderPicker, FlatFolderPicker & FilePicker
      */
     var SaveAsFileDialog = Dialogs.ModalDriveDialog.extend({ constructor: function (initOptions) {
+      //Utils.info('+++ SaveAsFileDialog :: initOptions.exportAsPdf : ', initOptions.exportAsPdf);
 
         // self reference
         var self = this;
@@ -71,6 +72,9 @@ define('io.ox/office/editframework/view/dialog/saveasfiledialog', [
         }
         driveUtil.getNode().css('height', '250px');
 
+        // whether to export as PDF
+        var exportAsPdf = Utils.getBooleanOption(initOptions, 'exportAsPdf', false);
+
         // base constructor ---------------------------------------------------
 
         Dialogs.ModalDriveDialog.call(this, Utils.extendOptions({
@@ -88,8 +92,13 @@ define('io.ox/office/editframework/view/dialog/saveasfiledialog', [
          * activated.
          */
         function updateOkButton() {
-            var state = allowEmpty || (inputNode.val().length > 0);
-            var selectedFile = self.getSelectedFile();
+            var inputValue    = inputNode.val();
+            var state         = allowEmpty || ($.trim(inputValue) !== '');
+            var selectedFile  = self.getSelectedFile();
+
+            if (exportAsPdf) {
+                state         = state && (/\.pdf\s*$/).test(inputValue);
+            }
             state = state && selectedFile && selectedFile.folder_id;
             self.enableOkButton(state);
         }
