@@ -74,6 +74,13 @@ define('io.ox/office/editframework/view/editlabels', [
         //#. menu title: number format settings for table cells
         gt.pgettext('menu-title', 'Number format');
 
+    /**
+     * @constant
+     */
+    EditLabels.SLIDE_HEADER_LABEL =
+        //#. menu title: settings for a single presentation slide
+        gt.pgettext('menu-title', 'Slide');
+
     /**
      * @constant
      */
