@@ -13,7 +13,6 @@
 
 define('io.ox/office/editframework/view/editview', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/keycodes',
     'io.ox/office/baseframework/app/extensionregistry',
     'io.ox/office/baseframework/view/baseview',
     'io.ox/office/baseframework/view/baselabels',
@@ -31,7 +30,7 @@ define('io.ox/office/editframework/view/editview', [
     'io.ox/office/editframework/view/popup/userslayermenu',
     'gettext!io.ox/office/editframework/main',
     'less!io.ox/office/editframework/view/editstyle'
-], function (Utils, KeyCodes, ExtensionRegistry, BaseView, BaseLabels, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, gt) {
+], function (Utils, ExtensionRegistry, BaseView, BaseLabels, Config, ToolBarTabCollection, TopPane, EditToolPane, SearchPane, OperationsPane, ClipboardPane, Labels, Controls, Dialogs, MobileSearchGroup, UsersLayerMenu, gt) {
 
     'use strict';
 
@@ -78,13 +77,13 @@ define('io.ox/office/editframework/view/editview', [
      *      The current search settings. See the description of the method
      *      EditView.getSearchSettings() for details about the properties
      *      contained in this object.
-     *  The function may return the promise of a Deferred object, if the search
-     *  action involves asynchronous operations. The view will be locked until
-     *  the promise has been resolved or rejected. The promise may be rejected
-     *  with an error code string which may result in an alert message box
-     *  shown in the user interface. Alternatively, the function may return an
-     *  explicit error code string synchronously (without using a promise). The
-     *  function will be called in the context of this view instance.
+     *  The function may return a promise, if the search action involves
+     *  asynchronous operations. The view will be locked until the promise has
+     *  been resolved or rejected. The promise may be rejected with an error
+     *  code string which may result in an alert message box shown in the user
+     *  interface. Alternatively, the function may return an explicit error
+     *  code string synchronously (without using a promise). The function will
+     *  be called in the context of this view instance.
      *
      * @param {Object} [initOptions]
      *  Optional parameters. Supports all options that are supported by the
@@ -306,15 +305,20 @@ define('io.ox/office/editframework/view/editview', [
                 btnPrint           = new Controls.Button({ icon: 'fa-print', tooltip: gt('Print as PDF'), classes: 'link-style', dropDownVersion: { label: gt('Print as PDF') } }),
 
                 btnSendMail        = null,
-                operationSendMail  = 'document/sendmail',
+                btnSendMailKey     = 'document/sendmail',
 
-               // no configuration at all, automatically always defaults to the file-attachment build-in.
-               //sendMailAttachmentConfig = { attachMode: 'attachment' },
-                sendMailInlineHTMLConfig = { attachMode: 'inline-html' },
+              // no configuration at all, automatically always defaults to the file-attachment build-in.
+              //sendMailAttachmentConfig    = { attachMode: 'attachment' },
+                sendMailPDFAttachmentConfig = { attachMode: 'pdf-attachment' },
+                sendMailInlineHTMLConfig    = { attachMode: 'inline-html' },
+
+                canConvertToPDFAttachment   = app.canConvertTo('pdf-mail-attachment'),
+                canConvertToInlineHTML      = app.canConvertTo('inline-html-document'),
 
                 btnReload          = new Controls.Button({ icon: 'fa-repeat', label: gt('Reload'), tooltip: gt('Reload document'), classes: 'link-style' }),
                 btnAcquireEdit     = new Controls.AcquireEditButton(self, { classes: 'link-style' }),
-                enablePageSettings = Utils.getBooleanOption(initOptions, 'enablePageSettings', false);
+                enablePageSettings = Utils.getBooleanOption(initOptions, 'enablePageSettings', false),
+                btnShare           = new Controls.ShareButton(self, gt('Share'));
 
             /**
              *  provide different appearances of "send mail" button(s) in dependency
@@ -322,36 +326,45 @@ define('io.ox/office/editframework/view/editview', [
              *  own do provide functionality for converting the current document's
              *  (entire) content.
              */
-            if (app.canConvertTo('inline-html-document')) {
+            if (canConvertToPDFAttachment || canConvertToInlineHTML) {
 
                 btnSendMail        = new Controls.CompoundButton(self, {
-                    visibleKey:      'app/bundled',
+                    visibleKey:      'document/sendmail/menu',
                     icon:            'fa-envelope-o',
                     classes:         'link-style',
                     tooltip:         BaseLabels.SEND_AS_MAIL_LABEL,
                     dropDownVersion: { label: BaseLabels.SEND_AS_MAIL_LABEL }
                 })
-                .addGroup(operationSendMail, new Controls.Button({ label: BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL }))
-                .addGroup((operationSendMail + '/inline-html'), new Controls.Button({ value: sendMailInlineHTMLConfig, label: BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL }));
+                .addGroup('document/sendmail', new Controls.Button({ label: BaseLabels.ATTACH_AS_FILE_TO_MAIL_LABEL }));
 
-                operationSendMail  = null;
+                if (canConvertToPDFAttachment) {
+                    btnSendMail
+                        .addGroup('document/sendmail/pdf-attachment', new Controls.Button({ value: sendMailPDFAttachmentConfig, label: BaseLabels.ATTACH_AS_PDF_TO_MAIL_LABEL }));
+                }
+                if (canConvertToInlineHTML) {
+                    btnSendMail
+                        .addGroup('document/sendmail/inline-html', new Controls.Button({ value: sendMailInlineHTMLConfig, label: BaseLabels.SEND_CONTENT_AS_NEW_MAIL_LABEL }));
+                }
+
+                btnSendMailKey = 'document/sendmail/menu';
 
             } else { // defaults to the file-attachment build-in.
 
                 btnSendMail        = new Controls.Button({
-                //  value:           sendMailAttachmentConfig,
                     icon:            'fa-envelope-o',
                     classes:         'link-style',
                     tooltip:         BaseLabels.SEND_AS_MAIL_LABEL,
                     dropDownVersion: { label: BaseLabels.SEND_AS_MAIL_LABEL }
                 });
+
+                btnSendMailKey = 'document/sendmail';
             }
 
             // -----------------------------------------------------
             // TABS
             //      prepare all tabs (for normal or combined panes)
             // -----------------------------------------------------
-            self.createToolBarTab('file', { label: Labels.FILE_HEADER_LABEL, priority: 99 });
+            self.createToolBarTab('file', { label: Labels.FILE_HEADER_LABEL, priority: 10 });
 
             // -----------------------------------------------------
             // TOOLBARS
@@ -377,7 +390,8 @@ define('io.ox/office/editframework/view/editview', [
                 var fileNameField       = new Controls.FileNameField(self),
                     cBoxAutosave        = new Controls.CheckBox({ label: gt('AutoSave') }),
                     btnSaveAs           = new Controls.Button({ label: gt('Save as'), value: 'file' }),
-                    btnSaveAsTemplate   = new Controls.Button({ label: gt('Save as template'), value: 'template' });
+                    btnSaveAsTemplate   = new Controls.Button({ label: gt('Save as template'), value: 'template' }),
+                    btnExportAsPdf      = new Controls.Button({ label: gt('Export as PDF'), value: 'pdf' });        // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
 
                 renameToolbar
                     .addGroup('document/rename', fileNameField);
@@ -387,6 +401,8 @@ define('io.ox/office/editframework/view/editview', [
                         .addGroup('document/saveas/dialog', btnSaveAs)
                         .addGroup('document/saveas/dialog', btnSaveAsTemplate)
                         .addSeparator()
+                        .addGroup('document/exportaspdf/dialog', btnExportAsPdf)                                    // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
+                        .addSeparator()
                         .addGroup('document/autosave', cBoxAutosave)
                     );
 
@@ -418,13 +434,12 @@ define('io.ox/office/editframework/view/editview', [
                 .addGap()
                 .addGroup('document/print', btnPrint)
                 .addGap()
-                /**
-                 *  provide different appearance of "send mail" button(s) in dependency of an application's ([app]'s) send mail operations/methods.
-                 */
-                .addGroup(operationSendMail, btnSendMail);
+                // provide different appearance of "send mail" button(s) in dependency of an application's ([app]'s) send mail operations/methods.
+                .addGroup(btnSendMailKey, btnSendMail)
+                .addGroup('document/share', btnShare);
 
             actionToolbar
-                .addGroup('document/acquireedit', btnAcquireEdit, { visibleKey: 'document/acquireedit' })
+                .addGroup('document/acquireeditOrPending', btnAcquireEdit, { visibleKey: 'document/acquireedit' })
                 .addGroup('document/reload', btnReload, { visibleKey: 'document/reload' });
 
             // call initialization handler passed by sub class
@@ -454,6 +469,7 @@ define('io.ox/office/editframework/view/editview', [
                 .addSectionLabel(_.noI18n('Debug'))
                 .addGroup('debug/operationspane', new Controls.CheckBox({ label: _.noI18n('Show operations panel') }))
                 .addGroup('debug/clipboardpane',  new Controls.CheckBox({ label: _.noI18n('Show clipboard panel') }))
+                .addGroup('debug/console',        new Controls.CheckBox({ label: _.noI18n('Show overlay log console') }))
                 .addGroup('debug/highlight',      new Controls.CheckBox({ label: _.noI18n('Highlight DOM elements') }));
 
             // create the drop-down list for the debug actions
@@ -572,7 +588,7 @@ define('io.ox/office/editframework/view/editview', [
         /**
          * Returns the search group.
          *
-         * @returns {SearchPane or MobileSearchGroup}
+         * @returns {SearchPane|MobileSearchGroup}
          *  The search pane of this application.
          */
         this.getSearchGroup = function () {
@@ -599,6 +615,32 @@ define('io.ox/office/editframework/view/editview', [
             return toolPane;
         };
 
+        /**
+         * Registers a label text and optional icon for a specific user defined
+         * application state.
+         *
+         * @param {String} state
+         *  The identifier of an application state.
+         *
+         * @param {String} label
+         *  The label text to be shown while the application state is active.
+         *
+         * @param {Object} [options]
+         *  Optional parameters:
+         *  @param {String} [options.icon]
+         *      The CSS class of an icon to be shown in front of the label.
+         *  @param {Boolean} [options.busy=false]
+         *      If set to true, a rotating busy icon will be shown in front of
+         *      the label. This option overrides the option 'icon'.
+         *
+         * @returns {EditView}
+         *  A reference to this instance.
+         */
+        this.registerStatusCaption = function (state, label, options) {
+            topPane.getAppStatusLabel().registerCaption(state, label, options);
+            return this;
+        };
+
         /**
          * Creates a new editable container node for clipboard functionality,
          * and inserts it into the hidden container node of the application.
@@ -676,8 +718,8 @@ define('io.ox/office/editframework/view/editview', [
          * class ModalQueryDialog). The dialog will be closed automatically, if
          * the application loses edit rights.
          *
-         * @param {String} title
-         *  The title text for the dialog.
+         * @param {String|Null} title
+         *  The title text for the dialog; or null for a dialog without title.
          *
          * @param {String} message
          *  The message text shown in the dialog body.
@@ -794,6 +836,20 @@ define('io.ox/office/editframework/view/editview', [
                     title: title,
                     value: newFileName
                 });
+            } else if (type === 'pdf') {  // DOCS-122 :: misinterpreted story - [https://jira.open-xchange.com/browse/DOCS-122] :: but hereby saved for good.
+
+            //  newFileName = oldFileName + '.pdf';
+                newFileName = oldFileName;
+                var
+                    len     = newFileName.length,
+                    idx     = newFileName.lastIndexOf('.');
+
+                newFileName = newFileName.substring(0, ((idx >= 0) ? idx : len)) + '.pdf';
+                title = gt('Export as PDF');
+
+                // create the dialog
+                dialog = new Dialogs.SaveAsFileDialog({ title: title, value: newFileName, preselect: app.getFileParameters().folder_id, exportAsPdf: true });
+
             } else {
 
                 //#. %1$s is the name of the original file used to create a new copy
