@@ -38,45 +38,45 @@ define('io.ox/office/editframework/view/operationspane', [
      */
     function OperationsPane(docView) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the application instance
-            app = docView.getApp(),
+        // the application instance
+        var app = docView.getApp();
 
-            // the document model instance
-            docModel = docView.getDocModel(),
+        // the document model instance
+        var docModel = docView.getDocModel();
 
-            // a tool-tip for details about attribute sets shown in this pane
-            attrsToolTip = new AttributesToolTip(docView),
+        // a tool-tip for details about attribute sets shown in this pane
+        var attrsToolTip = new AttributesToolTip(docView);
 
-            // the <table> element of the operations log
-            opTableNode = null,
+        // the <table> element of the operations log
+        var opTableNode = null;
 
-            // the <table> element of the debug info table
-            infoTableNode = null,
+        // the <table> element of the debug info table
+        var infoTableNode = null;
 
-            // number of operations already logged
-            operationsCount = 0,
+        // number of operations already logged
+        var operationsCount = 0;
 
-            // operations not yet logged
-            pendingOperations = [],
+        // operations not yet logged
+        var pendingOperations = [];
 
-            // background loop logging all pending operations
-            logOperationsTimer = null,
+        // background loop logging all pending operations
+        var logOperationsTimer = null;
 
-            // output elements for the debug info table (faster than DOM look-ups)
-            infoNodeMap = {};
+        // output elements for the debug info table (faster than DOM look-ups)
+        var infoNodeMap = {};
 
         // base constructor ---------------------------------------------------
 
         Pane.call(this, docView, {
             position: 'bottom',
             classes: 'operations-pane noI18n',
-            size: 250,
+            size: 300,
             resizable: true,
             minSize: 100,
-            maxSize: 400
+            maxSize: 500
         });
 
         // private methods ----------------------------------------------------
@@ -93,7 +93,7 @@ define('io.ox/office/editframework/view/operationspane', [
          * Direct callback for logOperations(): called every time when
          * logOperations() is called.
          */
-        function registerOperations(event, operations, external, shallow) {
+        function registerOperations(event, operations, external) {
             RTConnection.log('registerOperations entered');
 
             // append the new operations to the pending operations queue
@@ -103,104 +103,119 @@ define('io.ox/office/editframework/view/operationspane', [
                     if (app.isPrepareLosingEditRights()) {
                         RTConnection.log('registerOperations while preparelosingeditrights: ' + JSON.stringify(operation));
                     }
-                    return { operation: operation, external: external, shallow: shallow };
+                    return { operation: operation, external: external };
                 }));
             }
+
+            // update the OSN in the info section
+            self.setDebugInfoText('application', 'osn', docModel.getOperationStateNumber());
+        }
+
+        function generateOperationsMarkup(operations) {
+
+            // the number of operations applied successfully by the document model
+            var successCount = docModel.getOperationsCount();
+            // bug 29601: number of operations to be skipped (that have been optimized away)
+            var skipCount = 0;
+
+            return operations.reduce(function (markup, entry) {
+
+                var operation = _.clone(entry.operation);
+                var name = operation.name || '';
+                var osn = ('osn' in operation) ? operation.osn : '';
+                var opl = ('opl' in operation) ? operation.opl : '';
+
+                // bug 29601: skip operations, that were 'optimized' in 'sendActions' in the
+                // optimizeOperationHandler. Otherwise the debug pane will be irritating, because
+                // 'merged operations' are followed by the operations, that will not be sent to
+                // the server, because they were removed by the 'optimizeOperationHandler'.
+                if (!entry.external) {
+                    if (_.isNumber(opl) && (opl > 1)) {
+                        skipCount = opl - 1;
+                    } else if (skipCount > 0) {
+                        skipCount -= 1;
+                        return markup;
+                    }
+                }
+
+                delete operation.name;
+                delete operation.osn;
+                delete operation.opl;
+                operationsCount += 1;
+
+                var source = entry.external ? 'External' : 'Internal';
+                var classes = source.toLowerCase() + ((successCount < operationsCount) ? ' error' : '');
+                if (entry.removed) { classes += ' removed'; }
+
+                markup += '<tr class="' + classes + '">';
+                markup += '<td>' + operationsCount + '</td>';
+                markup += '<td title="' + source + ' operation">' + source[0] + '</td>';
+                markup += '<td style="text-align:right;">' + osn + '</td>';
+                markup += '<td style="text-align:right;">' + opl + '</td>';
+                markup += '<td>' + Utils.escapeHTML(name) + '</td>';
+                markup += '<td title="' + Forms.createLoggingTooltipMarkup(operation) + '">' + Utils.escapeHTML(Utils.stringifyForDebug(operation)) + '</td>';
+                markup += '</tr>';
+                return markup;
+            }, '');
         }
 
         /**
-         * Deferred callback for logOperations(): called once after current
-         * script execution ends.
+         * Starts the background loop that logs collected pending operations.
          */
-        function printSomeOperations() {
-
-            // check if the background loop is already running
-            if (logOperationsTimer) { return; }
+        function startLogger() {
 
             // create a new background loop that processes all pending operations
             logOperationsTimer = self.repeatDelayed(function () {
 
-                // abort the background loop, if all operations have been logged
-                if (pendingOperations.length === 0) { return Utils.BREAK; }
+                // the entire HTML mark-up to be appended to the operations log
+                var markup = '';
 
-                var // the operations to insert into the table
-                    operations = pendingOperations.splice(0, 20),
-                    // the number of operations applied successfully by the document model
-                    successCount = docModel.getOperationsCount(),
-                    // checking the operation length, so that operations removed from the
-                    // 'optimizeOperationHandler' will not be displayed in the debug pane.
-                    oplCounter = 1,
-                    // the entire HTML mark-up to be appended to the operations log
-                    markup = '';
-
-                // log the next operations chunk
-                operations.forEach(function (entry) {
-
-                    var operation = _.clone(entry.operation),
-                        name = operation.name || '',
-                        osn = ('osn' in operation) ? operation.osn : '',
-                        opl = ('opl' in operation) ? operation.opl : '',
-                        // skip operations, that were 'optimized' in 'sendActions' in the
-                        // optimizeOperationHandler. Otherwise the debug pane will be irritating, because
-                        // 'merged operations' are followed by the operations, that will not be sent to
-                        // the server, because they were removed by the 'optimizeOperationHandler'.
-                        skipOperation = false;
-
-                    // bug 29601: check if this operation was merged by the 'optimizeOperationHandler' (only for internal operations)
-                    if (!entry.external) {
-                        if (_.isNumber(opl) && (opl > 1)) {
-                            oplCounter = opl;
-                        } else if (oplCounter > 1) {
-                            oplCounter -= 1;
-                            skipOperation = true;
-                        }
-                    }
-
-                    if (skipOperation) { return; }
-
-                    delete operation.name;
-                    delete operation.osn;
-                    delete operation.opl;
-                    operationsCount += 1;
-
-                    var source = entry.shallow ? 'Shallow' : entry.external ? 'External' : 'Internal';
-                    var classes = source.toLowerCase() + ((successCount < operationsCount) ? ' error' : '');
-
-                    markup += '<tr class="' + classes + '">';
-                    markup += '<td>' + operationsCount + '</td>';
-                    markup += '<td title="' + source + ' operation">' + source[0] + '</td>';
-                    markup += '<td style="text-align:right;">' + osn + '</td>';
-                    markup += '<td style="text-align:right;">' + opl + '</td>';
-                    markup += '<td>' + Utils.escapeHTML(name) + '</td>';
-                    markup += '<td title="' + Forms.createLoggingTooltipMarkup(operation) + '">' + Utils.escapeHTML(Utils.stringifyForDebug(operation)) + '</td>';
-                    markup += '</tr>';
-                });
+                // generate HTML mark-up for at most 200ms
+                var t0 = _.now();
+                while ((pendingOperations.length > 0) && (_.now() - t0 < 200)) {
+                    markup += generateOperationsMarkup(pendingOperations.splice(0, 20));
+                }
 
                 // append the mark-up, and scroll down to the last log entry
-                opTableNode.append(markup);
-                scrollDownOperationsNode();
-
-                // update the OSN (using no synchronous and no own debounced function for performance reasons)
-                self.setDebugInfoText('application', 'osn', docModel.getOperationStateNumber());
-
-            }, 50, 'OperationsPane: logOperationsTimer');
-
-            // forget reference to the timer, when all operations have been logged
-            logOperationsTimer.always(function () { logOperationsTimer = null; });
+                if (markup.length > 0) {
+                    opTableNode.append(markup);
+                    scrollDownOperationsNode();
+                }
+            }, 1000);
         }
 
         /**
-         * Marking the last 'number' operations in the operations table with orange background color. This
-         * means, that they were not executed, not send to the server and they do not influence the osn for
-         * the following operations.
-         * This scenario happens for example, if a paste process is cancelled and an existing selection was
-         * already removed before the pasting started.
+         * Stops the background loop that logs collected pending operations.
+         */
+        function abortLogger() {
+            logOperationsTimer.abort();
+            logOperationsTimer = null;
+        }
+
+        /**
+         * Marks the last operations in the operations table with orange
+         * background color. This means, that they were not executed, not send
+         * to the server and they do not influence the OSN for the following
+         * operations. This scenario happens for example, if a paste process is
+         * cancelled and an existing selection was already removed before the
+         * pasting started.
          *
          * @param {Number} number
-         *  The number of operations that need to be marked with orange background color.
+         *  The number of operations that need to be marked with orange
+         *  background color.
          */
-        function markLastOperationsAsRemoved(number) {
-            if (_.isNumber(number)) { opTableNode.find('tr').slice(-1 * number).css('background-color', 'orange'); }
+        function operationsRemovedHandler(number) {
+
+            // mark operations not yet logged
+            var pendingCount = pendingOperations.length;
+            for (var index = Math.max(0, pendingCount - number); index < pendingCount; index += 1) {
+                pendingOperations[index].removed = true;
+            }
+
+            // mark operations already logged
+            if (pendingCount < number) {
+                opTableNode.find('tr').slice(number - pendingCount).addClass('removed');
+            }
         }
 
         // public methods -----------------------------------------------------
@@ -242,8 +257,8 @@ define('io.ox/office/editframework/view/operationspane', [
          *  A reference to this instance.
          */
         this.addDebugInfoNode = function (header, label, tooltip) {
-            var infoNode = $('<td>'),
-                rowNode = $('<tr><td title="' + Utils.escapeHTML(tooltip) + '">' + label + '</td></tr>').append(infoNode);
+            var infoNode = $('<td>');
+            var rowNode = $('<tr><td title="' + Utils.escapeHTML(tooltip) + '">' + label + '</td></tr>').append(infoNode);
             infoNodeMap[header].last().after(rowNode);
             infoNodeMap[header] = infoNodeMap[header].add(rowNode);
             infoNodeMap[header + ':' + label] = infoNode;
@@ -369,18 +384,17 @@ define('io.ox/office/editframework/view/operationspane', [
         // log operations after importing the document
         this.waitForImport(function () {
 
-            // create the debounced logOperations() method
-            var logOperations = this.createDebouncedMethod(registerOperations, printSomeOperations, { infoString: 'OperationsPane: printSomeOperations' });
+            // mark some operations in the pane as removed
+            this.listenTo(app, 'operations:remove', operationsRemovedHandler);
 
-            // reconnect the 'operations:after' event to the debounced method
-            this.stopListeningTo(docModel, 'operations:after', registerOperations);
-            this.listenTo(docModel, 'operations:after', logOperations);
+            // start logging with visible operations pane, pause logging in hidden operations pane
+            this.on({ 'pane:show': startLogger, 'pane:hide': abortLogger });
 
-            // marking some operations in the pane as removed
-            this.listenTo(app, 'operations:remove', markLastOperationsAsRemoved);
+            // start logging of initial import operations after a delay
+            this.executeDelayed(function () {
+                if (!logOperationsTimer && self.isVisible()) { startLogger(); }
+            }, 3000);
 
-            // trigger deferred logging by calling 'logOperations' once without new operations
-            logOperations({}, []);
         }, this);
 
         // destroy all class members on destruction
