@@ -116,6 +116,8 @@ define('io.ox/office/editframework/view/popup/userslayermenu', [
         this.on('menu:userclose', function () { autoShow = false; });
 
         // auto show/hide collaborator list depending on user event
+        // Listening to 'docs:users', not 'docs:users:selection', so that
+        // no update happens, if only the selection has changed (46610)
         this.listenTo(app, 'docs:users', function (activeClients) {
 
             // redraw user badges
@@ -135,7 +137,11 @@ define('io.ox/office/editframework/view/popup/userslayermenu', [
         });
 
         // bug 36482: repaint when application state changes, e.g. offline mode
-        this.listenTo(app, 'docs:state', fillMenuDebounced);
+        // -> but not, if 'ready' changes to 'sending' or vice versa or if only 'recalc' is sent
+        this.listenTo(app, 'docs:state', function (newState, oldState) {
+            var noBadgeGroupUpdate = ((newState === 'ready' || newState === 'recalc') && (!oldState || oldState === 'sending')) || (newState === 'sending' && oldState === 'ready');
+            if (!noBadgeGroupUpdate) { fillMenuDebounced(); }
+        });
 
         // bug 35534: restore collaborators pop-up
         this.listenTo(app.getWindow(), 'show', function () {
