@@ -19,6 +19,25 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
 
     'use strict';
 
+    // class TabDescriptor ====================================================
+
+    /**
+     * Stores all settings for a single toolbar tab.
+     *
+     * @constructor
+     */
+    function TabDescriptor(tabId, initOptions) {
+
+        this.tabId = tabId;
+        this.visibleKey = Utils.getStringOption(initOptions, 'visibleKey', null);
+        this.labelKey = Utils.getStringOption(initOptions, 'labelKey', null);
+        this.priority = Utils.getIntegerOption(initOptions, 'priority', 0);
+        this.sticky = Utils.getBooleanOption(initOptions, 'sticky', false);
+        this.visible = true;
+        this.label = null;
+
+    } // class TabDescriptor
+
     // class ToolBarTabCollection =============================================
 
     /**
@@ -76,17 +95,17 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
      */
     function ToolBarTabCollection(docView) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // all existing tool bar tabs
-            tabs = [],
+        // descriptors for all existing tool bar tabs
+        var tabDescs = [];
 
-            // identifier of the active tab
-            activeTabId = null,
+        // identifier of the active tab
+        var activeTabId = null;
 
-            // identifier of the last active tab, while no tab is active (bug 39071)
-            lastTabId = null;
+        // identifier of the last active tab, while no tab is active (bug 39071)
+        var lastTabId = null;
 
         // base constructors --------------------------------------------------
 
@@ -97,15 +116,18 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
 
         /**
          * Returns the descriptor of the active tab.
+         *
+         * @returns {TabDescriptor|Null}
+         *  The descriptor of the active tab.
          */
         function getActiveTab() {
-            return _.findWhere(tabs, { tabId: activeTabId });
+            return _.findWhere(tabDescs, { tabId: activeTabId }) || null;
         }
 
         /**
          * Activates the first visible tab.
          *
-         * @param {Array} [filteredTabs]
+         * @param {Array<TabDescriptor>} [filteredTabs]
          *  If specified, activates the first visible tab in the passed array.
          *  Otherwise, searches for a visible tab in all available tabs.
          *
@@ -114,10 +136,10 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
          */
         function activateFirstTab(filteredTabs) {
 
-            var // filter by visible tabs
-                visibleTabs = _.where(filteredTabs || tabs, { visible: true }),
-                // the active tab
-                activeTab = getActiveTab();
+            // filter by visible tabs
+            var visibleTabs = _.where(filteredTabs || tabDescs, { visible: true });
+            // the active tab
+            var activeTab = getActiveTab();
 
             // filter by priority of the active tab
             if (activeTab && activeTab.visible) {
@@ -142,33 +164,33 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
          */
         function controllerChangeHandler() {
 
-            var // the application controller
-                controller = docView.getApp().getController(),
-                // all tabs currently visible
-                visibleTabs = _.where(tabs, { visible: true }),
-                // all tabs currently hidden
-                hiddenTabs = _.where(tabs, { visible: false }),
-                // the active tab
-                activeTab = getActiveTab();
+            // the application controller
+            var controller = docView.getApp().getController();
+            // all tabs currently visible
+            var visibleTabs = _.where(tabDescs, { visible: true });
+            // all tabs currently hidden
+            var hiddenTabs = _.where(tabDescs, { visible: false });
+            // the active tab
+            var activeTab = getActiveTab();
 
             // process all tabs
-            _.each(tabs, function (tab) {
+            tabDescs.forEach(function (tabDesc) {
 
-                var // tabs without visibility key are always visible
-                    visible = _.isString(tab.visibleKey) ? controller.isItemEnabled(tab.visibleKey) : true,
-                    // get dynamic label text
-                    label = _.isString(tab.labelKey) ? controller.getItemValue(tab.labelKey) : true;
+                // tabs without visibility key are always visible
+                var visible = !tabDesc.visibleKey || controller.isItemEnabled(tabDesc.visibleKey);
+                // get dynamic label text
+                var label = !tabDesc.labelKey || controller.getItemValue(tabDesc.labelKey);
 
                 // show or hide the tabs, if the state has changed
-                if (tab.visible !== visible) {
-                    tab.visible = visible;
-                    self.trigger(visible ? 'tab:show' : 'tab:hide', tab.tabId);
+                if (tabDesc.visible !== visible) {
+                    tabDesc.visible = visible;
+                    self.trigger(visible ? 'tab:show' : 'tab:hide', tabDesc.tabId);
                 }
 
                 // change the button text, if the item is contained in the event data
-                if (_.isString(label) && (tab.label !== label)) {
-                    tab.label = label;
-                    self.trigger('tab:label', tab.tabId, label);
+                if (_.isString(label) && (tabDesc.label !== label)) {
+                    tabDesc.label = label;
+                    self.trigger('tab:label', tabDesc.tabId, label);
                 }
             });
 
@@ -224,24 +246,16 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
          */
         this.createTab = function (tabId, options) {
 
-            var // the tab descriptor
-                tab = {
-                    tabId: tabId,
-                    visibleKey: Utils.getStringOption(options, 'visibleKey'),
-                    labelKey: Utils.getStringOption(options, 'labelKey'),
-                    priority: Utils.getIntegerOption(options, 'priority', 0),
-                    sticky: Utils.getBooleanOption(options, 'sticky', false),
-                    visible: true,
-                    label: null
-                };
+            // the tab descriptor
+            var tabDesc = new TabDescriptor(tabId, options);
 
             // insert new tab and notify listeners
-            tabs.push(tab);
+            tabDescs.push(tabDesc);
             this.trigger('tab:create', tabId, options);
 
             // initially hide all tabs with existing visibility key
-            if (_.isString(tab.visibleKey)) {
-                tab.visible = false;
+            if (tabDesc.visibleKey) {
+                tabDesc.visible = false;
                 this.trigger('tab:hide', tabId);
             }
 
@@ -318,7 +332,7 @@ define('io.ox/office/editframework/view/toolbartabcollection', [
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
-            self = docView = tabs = null;
+            self = docView = tabDescs = null;
         });
 
     } // class ToolBarTabCollection
