@@ -78,7 +78,7 @@ define('io.ox/office/portal/action/recentsactions', [
                 });
 
                 // build the titel for the tooltip
-                escapedTitle = _.noI18n(escapedFileName) + '<br> <span class ="tooltip-filepath">' + escapedFilePathinToolTip + '</span>';
+                escapedTitle = _.noI18n(escapedFileName) + '<div class ="tooltip-filepath">' + escapedFilePathinToolTip + '</div>';
                 // iPad title problem: long tap on element -> ios popup appears -> html markup is visible
                 if (Utils.COMPACT_DEVICE) {
                     escapedTitle = escapedFileName;
