@@ -17,14 +17,11 @@ define('io.ox/office/portal/action/templateactions', [
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
     'io.ox/core/extPatterns/actions',
-    'io.ox/office/portal/portalutils',
-    'io.ox/office/tk/utils',
-    'io.ox/office/tk/io',
-    'io.ox/office/tk/keycodes',
     'io.ox/office/tk/utils/driveutils',
+    'io.ox/office/portal/portalutils',
     'io.ox/office/portal/view/contextmenu',
     'gettext!io.ox/office/portal/main'
-], function (Ext, Links, CoreActions, PortalUtils, Utils, IO, KeyCodes, DriveUtils, ContextMenu, gt) {
+], function (Ext, Links, CoreActions, DriveUtils, Utils, ContextMenu, gt) {
 
     'use strict';
 
@@ -36,14 +33,16 @@ define('io.ox/office/portal/action/templateactions', [
      */
     var loadImageInQueue = (function () {
         var queue = [];
+        var loadedURLs = {};
         var max = 2;
 
-        function err(error) {
+        function err(/*error*/) {
             var img = $(this);
-            Utils.error(new Date().toLocaleTimeString(), 'error loading preview for "' + img.attr('name') + '"', error);
+            //Utils.error(new Date().toLocaleTimeString(), 'error loading preview for "' + img.attr('name') + '"', error);
             img.data('state', 'done');
             img.off('load', loaded);
             img.off('error', err);
+            loadedURLs[img.attr('src')] = true;
             checkQueue();
         }
 
@@ -53,7 +52,7 @@ define('io.ox/office/portal/action/templateactions', [
             img.off('error', err);
             img.data('src', null);
             img.data('state', 'done');
-
+            loadedURLs[img.attr('src')] = true;
             checkQueue();
         }
 
@@ -96,11 +95,15 @@ define('io.ox/office/portal/action/templateactions', [
         }
 
         return function loadImageInQueueInner(img, src) {
-            img.data('src', src);
-            img.data('state', 'inQueue');
-            queue.push(img);
+            if (loadedURLs[src]) {
+                img.attr('src', src);
+            } else {
+                img.data('src', src);
+                img.data('state', 'inQueue');
+                queue.push(img);
 
-            checkQueue();
+                checkQueue();
+            }
         };
     }());
 
@@ -128,7 +131,6 @@ define('io.ox/office/portal/action/templateactions', [
          *  The url string for the template.
          */
         var createTemplateURL = function (data, options) {
-
             // Thumbnails have a different size for presentation and text/spreadsheet.
             // In presentation the standard is 16:9 (180px : 100px). When the ratio is higher, the thumbnail
             // width is 180px but the hight is smaller. When the ratio is smaller, the thumbnail
@@ -141,7 +143,7 @@ define('io.ox/office/portal/action/templateactions', [
             }
 
             var // whether the template files are local or global
-                isGlobal = PortalUtils.getBooleanOption(options, 'isGlobal', true),
+                isGlobal = Utils.getBooleanOption(options, 'isGlobal', true),
                 // the constructed url
                 url = isGlobal ? ox.abs + ox.apiRoot + '/oxodocumentfilter?action=templatepreview&id=' + data.id +
                     '&folder=' + data.folder_id + '&format=preview_image&delivery=view&scaleType=contains' :
@@ -185,12 +187,11 @@ define('io.ox/office/portal/action/templateactions', [
                     fullFileName = baton.data['com.openexchange.file.sanitizedFilename'] || baton.data.filename,
                     // set classes according to the current app portal to get the right css layout
                     templateItemClass = 'template-item ' + itemClass + ' ' + appBaseName,
-                    templatePreviewClass = getTemplatePreviewClass(appBaseName),
                     // the element which should be highlighted, it has to be different in presentation or text/spreadsheet
                     highLightElement = null;
 
                 var // the template container
-                    templateItem = $('<a>').addClass(templateItemClass)
+                    templateItem = $('<a class="' + templateItemClass + '">')
                     .attr({
                         'data-toggle': 'tooltip',
                         'data-animation': 'false',
@@ -198,10 +199,30 @@ define('io.ox/office/portal/action/templateactions', [
                         title: _.noI18n(fullFileName),
                         tabindex: 0
                     }),
-                    templatePreview = $('<div>').addClass(templatePreviewClass),
-                    showName = _.noI18n(PortalUtils.removeFileExtension(fullFileName)),
-                    templatePreviewIMG = $('<img class = "templateIMG" name = "' + showName + '"</img>'),
-                    templateName = $('<p>').addClass('template-name').text(showName);
+                    templatePreview = $('<div class="template-preview">'),
+                    showName = _.noI18n(Utils.removeFileExtension(fullFileName)),
+                    templatePreviewIMG = $('<img class = "templateIMG" name = "' + showName + '"/>'),
+                    templateName = $('<p>').addClass('template-name').text(showName),
+                    icon = Utils.createDocumentIcon(fullFileName);
+
+                //----------------------------------------------
+                templatePreview.addClass('new-blank');
+                templateItem.addClass('template-blank');
+                templatePreview.append(icon);
+                templatePreviewIMG.css('visibility', 'hidden');
+                // showed delayed to prevent flickering icons when the images are loaded very fast (e.g. from cache)
+                icon.hide().delay(200).fadeIn(100);
+
+                templatePreviewIMG.on('load', function () {
+                    templatePreview.removeClass('new-blank');
+                    templateItem.removeClass('template-blank');
+                    templatePreviewIMG.css('visibility', 'visible');
+                    icon.remove();
+                });
+                templatePreviewIMG.on('error', function () {
+                    templatePreviewIMG.remove();
+                });
+                //----------------------------------------------
 
                 loadImageInQueue(templatePreviewIMG, createTemplateURL(baton.data, options));
 
@@ -222,13 +243,13 @@ define('io.ox/office/portal/action/templateactions', [
                     if (!ContextMenu.isOpen()) {
 
                         // provide feedback to the user which element will be opened
-                        PortalUtils.markElement(highLightElement);
+                        Utils.markElement(highLightElement);
 
                         CoreActions.invoke(templateExtension + '/action/open', this, baton.data);
                     }
                 });
 
-                templateItem.on('keydown', { grid: true }, PortalUtils.keydownHandler);
+                templateItem.on('keydown', { grid: true }, Utils.keydownHandler);
 
                 // handle context menu
                 templateItem.on('contextmenu', function (e) {
@@ -243,7 +264,7 @@ define('io.ox/office/portal/action/templateactions', [
                 // iOS: check if there is a long tap to invoke a 'contextmenu' event
                 if (Utils.IOS) {
                     templateItem.on('touchstart', function (event) {
-                        PortalUtils.iosContextEventHandler(event, templateItem);
+                        Utils.iosContextEventHandler(event, templateItem);
                     });
                 }
 
@@ -274,7 +295,7 @@ define('io.ox/office/portal/action/templateactions', [
             // global flag that a context menu is open
             ContextMenu.setOpen(true);
             // mark the selected element
-            PortalUtils.markElement(highLight);
+            Utils.markElement(highLight);
 
             // create the context menu
             var cmenu = new ContextMenu(event);
@@ -309,7 +330,7 @@ define('io.ox/office/portal/action/templateactions', [
 
                 editTemplateButton.on('click', function () {
                     cmenu.hide();  //hide the context menu after a button was clicked
-                    CoreActions.invoke(PortalUtils.getAppBaseName(baton.data.filename) + '-edit-template', self, baton.data);
+                    CoreActions.invoke(Utils.getAppBaseName(baton.data.filename) + '-edit-template', self, baton.data);
                 });
 
                 return editTemplateButton;
@@ -336,7 +357,7 @@ define('io.ox/office/portal/action/templateactions', [
                     evt.preventDefault(); // ?? TODO
                     cmenu.hide();  //hide the context menu after a button was clicked
 
-                    PortalUtils.showInDrive(baton.data, true);
+                    Utils.showInDrive(baton.data, true);
                 });
                 return showTemplateInDriveButton;
             }
@@ -346,7 +367,7 @@ define('io.ox/office/portal/action/templateactions', [
 
             // remove the highlight and destory the context menu
             cmenu.on('popup:hide', function () {
-                PortalUtils.removeMark(highLight);
+                Utils.removeMark(highLight);
 
                 // After a click event the context menu is closed by the basemenu globalClickHandler().
                 // When a context menu is open, clicking on an element should not invoke it's attached action, but just close the context menu.
@@ -385,7 +406,7 @@ define('io.ox/office/portal/action/templateactions', [
                 var // appBaseName for the currently used portal
                     appBaseName = baton.appBaseName,
                     // set classes according to the current app portal to get the right css layout
-                    templateClass = 'new-blank ' + getTemplatePreviewClass(appBaseName),
+                    templateClass = 'new-blank template-preview',
                     templateItemClass = 'template-item template-blank ' + appBaseName;
 
                 var // the template container
@@ -411,13 +432,13 @@ define('io.ox/office/portal/action/templateactions', [
                     if (!ContextMenu.isOpen()) {
 
                         // provide feedback to the user which element will be opened
-                        PortalUtils.markElement(templatePreview);
+                        Utils.markElement(templatePreview);
 
                         CoreActions.invoke(invokeId, this, baton);
                     }
                 });
 
-                templateItem.on('keydown', PortalUtils.keydownHandler);
+                templateItem.on('keydown', Utils.keydownHandler);
 
                 // prevent native context menu for the getBlank template and the focus change on click due to mousedown
                 templateItem.on('mousedown contextmenu', function (e) {
@@ -429,7 +450,7 @@ define('io.ox/office/portal/action/templateactions', [
                 // for the newBlank template
                 if (Utils.IOS) {
                     templateItem.on('touchstart', function (event) {
-                        PortalUtils.iosContextEventHandler(event, templateItem);
+                        Utils.iosContextEventHandler(event, templateItem);
                     });
                 }
 
@@ -438,12 +459,6 @@ define('io.ox/office/portal/action/templateactions', [
 
         };
 
-        // helper function to get the right class name according to the used app portal
-        // for the 'blank' and 'normal' template
-        function getTemplatePreviewClass(appBaseName) {
-            return (appBaseName === 'presentation') ? 'template-preview-presentation' : 'template-preview';
-        }
-
         // create extension points
         this.text = Ext.point(templateExtension + '/text');
         this.textuser = Ext.point(templateExtension + '/text/templateuser');
@@ -458,24 +473,24 @@ define('io.ox/office/portal/action/templateactions', [
         // action to create a blank text document
         new Links.Action(templateExtension + '/action/new/text', {
             action: function () {
-                PortalUtils.trackEvent({ moduleName: 'io.ox/office/text', target: 'templates', action: 'newblank' });
-                return ox.launch('io.ox/office/text/main', PortalUtils.getNewLaunchOptions());
+                Utils.trackEvent({ moduleName: 'io.ox/office/text', target: 'templates', action: 'newblank' });
+                return ox.launch('io.ox/office/text/main', Utils.getNewLaunchOptions());
             }
         });
 
         // action to create a blank spreadsheet document
         new Links.Action(templateExtension + '/action/new/spreadsheet', {
             action: function () {
-                PortalUtils.trackEvent({ moduleName: 'io.ox/office/spreadsheet', target: 'templates', action: 'newblank' });
-                return ox.launch('io.ox/office/spreadsheet/main', PortalUtils.getNewLaunchOptions());
+                Utils.trackEvent({ moduleName: 'io.ox/office/spreadsheet', target: 'templates', action: 'newblank' });
+                return ox.launch('io.ox/office/spreadsheet/main', Utils.getNewLaunchOptions());
             }
         });
 
         // action to create a blank presentation document
         new Links.Action(templateExtension + '/action/new/presentation', {
             action: function () {
-                PortalUtils.trackEvent({ moduleName: 'io.ox/office/presentation', target: 'templates', action: 'newblank' });
-                return ox.launch('io.ox/office/presentation/main', PortalUtils.getNewLaunchOptions());
+                Utils.trackEvent({ moduleName: 'io.ox/office/presentation', target: 'templates', action: 'newblank' });
+                return ox.launch('io.ox/office/presentation/main', Utils.getNewLaunchOptions());
             }
         });
 
@@ -485,13 +500,13 @@ define('io.ox/office/portal/action/templateactions', [
                 var loadDeferred = baton.data.loadDeferred;
 
                 if (loadDeferred && loadDeferred.state() === 'pending') {
-                    PortalUtils.warn('cant run convert document, because old call is still pending');
+                    Utils.warn('cant run convert document, because old call is still pending');
                     return;
                 }
 
-                var appModuleName = PortalUtils.getModuleNameForFile(baton.data.filename);
+                var appModuleName = Utils.getModuleNameForFile(baton.data.filename);
                 loadDeferred = ox.launch(appModuleName + '/main', { action: 'convert', template: true, target_folder_id: DriveUtils.getStandardDocumentsFolderId(), templateFile: baton.data, target_filename: gt('unnamed') });
-                PortalUtils.trackEvent({ moduleName: appModuleName, target: 'templates', action: 'newfromtemplate' });
+                Utils.trackEvent({ moduleName: appModuleName, target: 'templates', action: 'newfromtemplate' });
                 baton.data.loadDeferred = loadDeferred;
                 return loadDeferred;
             }
