@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
  */
@@ -95,6 +95,8 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                 require(['io.ox/files/filepicker', 'io.ox/office/baseframework/app/extensionregistry']).done(function (FilePicker, ExtensionRegistry) {
                     var preselectKey = 'recentOpenDocPath' + appBaseName;
                     var preselect = Settings.get(preselectKey) || DriveUtils.getStandardDocumentsFolderId();
+                    var extensions = ExtensionRegistry.getEditableExtensions();
+                    var filter = extensions.map(function (ext) { return '.' + ext; }).join(',');
 
                     var dialog = new FilePicker({
                         // filter files of disabled applications (capabilities)
@@ -112,7 +114,7 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
                         width: Dialogs.getBestDialogWidth(800),
                         //uploadFolder: DriveUtils.getStandardDocumentsFolderId(),
                         hideTrashfolder: true,
-                        acceptLocalFileType: ExtensionRegistry.getEditableTypes()
+                        acceptLocalFileType: filter
                     });
                     dialog.done(function (selectedFiles) {
                         var selectedFile = selectedFiles[0];
@@ -128,19 +130,18 @@ define('io.ox/office/portal/action/toolbaractionsimpl', [
 
                             }
 
-                            var actionModuleName = PortalUtils.getModuleNameForFile(selectedFile.filename);
-
                             if (loadDeferred && loadDeferred.state() === 'pending') {
                                 Utils.warn('cant run load document, because old call is still pending');
                                 return;
                             }
 
+                            var actionModuleName = PortalUtils.getModuleNameForFile(selectedFile.filename);
                             PortalUtils.trackEvent({ moduleName: appBaseName, actionModuleName: actionModuleName, target: 'toolbar', action: 'open' });
-                            if (ExtensionRegistry.isNative(selectedFile.filename)) {
-                                loadDeferred = ox.launch(actionModuleName + '/main', { action: 'load', file: selectedFile });
-                            } else {
-                                loadDeferred = ox.launch(actionModuleName + '/main', { action: 'convert', target_folder_id: selectedFile.folder_id, templateFile: selectedFile, preserveFileName: true });
-                            }
+
+                            var launchOptions = ExtensionRegistry.isNative(selectedFile.filename) ?
+                                { action: 'load', file: selectedFile } :
+                                { action: 'convert', target_folder_id: selectedFile.folder_id, templateFile: selectedFile, preserveFileName: true };
+                            loadDeferred = ox.launch(actionModuleName + '/main', launchOptions);
                             Settings.set(preselectKey, selectedFile.folder_id).save();
                         }
                     });
