@@ -25,10 +25,11 @@ define('io.ox/office/portal/collection/documentcollection', [
 
             var self = this;
 
-            // populate the collection with recent documents
-            _.each(recentsArray, function (recentDocument) {
-                self.add(new DocumentModel(recentDocument), { merge: true });
-            });
+            // populate the collection with recent documents and
+            // invokes an 'update' event that re-renders the view
+            // TODO refactor: to risky to remove it before release, but
+            // merge=true should not be needed here, it's the default for 'set'
+            self.set(recentsArray, { merge: true });
 
         }
 
