@@ -31,9 +31,9 @@ define('io.ox/office/portal/collection/templatecollection', [
 
             var self = this;
 
-            _.each(templateList, function (template) {
-                self.add(new TemplateModel(template), { merge: true });
-            });
+            // populate the collection with template objects and
+            // invokes an 'update' event that re-renders the view
+            self.set(templateList);
 
         },
 
