@@ -40,7 +40,7 @@ define('io.ox/office/portal/mainhelper', [
 
     // methods ----------------------------------------------------------------
 
-    MainHelper.createLauncher = function (appBaseName, appTitle, appOptions) {
+    MainHelper.createLauncher = function (appBaseName, appTitle) {
 
         var // the module name of the portal application
             PORTAL_MODULE_NAME = Utils.getPortalModuleName(appBaseName),
@@ -48,8 +48,10 @@ define('io.ox/office/portal/mainhelper', [
             EDIT_MODULE_NAME = Utils.getEditorModuleName(appBaseName),
             // the application instance
             app = ox.ui.createApp({ name: PORTAL_MODULE_NAME, title: appTitle, trackingId: 'io.ox/' + appBaseName + '-portal', appBaseName: appBaseName }),
-            // RequireJS path of the application welcome tour
-            appTourPath = Utils.getStringOption(appOptions, 'appTourPath', '');
+            // the document collection for the recent documents list
+            documentCollection = new DocumentCollection(),
+            // the template collection for the listed templates
+            templateCollection = new TemplateCollection();
 
         // load fileActions for the current App to use necessary action links for recent list/template context menus
         FileActions.create(appBaseName);
@@ -63,20 +65,16 @@ define('io.ox/office/portal/mainhelper', [
                 chromeless: true
             });
 
+            var rootNode = portalWindow.nodes.main,
+                windowBodyNode = portalWindow.nodes.body,
+                recentsNode = $('<div>').addClass('office-portal-recents').append($('<h2>').text(gt('Recent Documents'))),
+                recentsList = $('<div>').addClass('office-portal-recents-list f6-target'),
+                templatesNode = $('<div>').addClass('office-portal-templates').append($('<h2>').text(gt('New from Template'))),
+                templateTypeWrapper = $('<div>').addClass('template-type-wrapper col-xs-12');
+
             // the bootstrap of the OX Documents app
             function initOXDocuments() {
-
-                // prepare app skeleton. Maybe this could be the AppView in the future.
-                var rootNode = portalWindow.nodes.main,
-                    windowBodyNode = portalWindow.nodes.body,
-                    recentsNode = $('<div>').addClass('office-portal-recents').append($('<h2>').text(gt('Recent Documents'))),
-                    recentsList = $('<div>').addClass('office-portal-recents-list f6-target'),
-                    templatesNode = $('<div>').addClass('office-portal-templates').append($('<h2>').text(gt('New from Template'))),
-                    // the document collection for the recent documents list
-                    documentCollection = new DocumentCollection(),
-                    // the template collection for the listed templates
-                    templateCollection = new TemplateCollection();
-
+                // TODO: refactor later: there are two 'on' listener for portalWindow in this class, merge them
                 portalWindow.setTitle(appTitle);
                 portalWindow.on('show', function () {
                     portalWindow.setTitle(appTitle);
@@ -85,30 +83,43 @@ define('io.ox/office/portal/mainhelper', [
                 // prefetch application source code
                 IO.prefetchModuleSource(EDIT_MODULE_NAME);
 
-                rootNode.empty().append(recentsNode.append(recentsList), templatesNode);
-
                 // create application views
                 new ToolbarView({ el: windowBodyNode, model: app });
-                var documentView = new DocumentView({ collection: documentCollection, el: recentsList, model: app }),
-                    templateView = new TemplateView({ collection: templateCollection, el: templatesNode, model: app });
+                new DocumentView({ collection: documentCollection, el: recentsList, model: app });
+                new TemplateView({ collection: templateCollection, el: templateTypeWrapper, model: app });
+
+                // append main nodes to the rootNode
+                rootNode.empty().append(recentsNode.append(recentsList), templatesNode.append(templateTypeWrapper));
+
+                // get data for the portal the first time and show it
+                updatePortal();
+            }
+
+            function updatePortal() {
+
+                // Remove the highlight class 'permanentHover' for all templates.
+                // The highlight is set (e.g.) when the user opens a document from a template.
+                // Therefore it must be removed later.
+                portalWindow.nodes.main.find('.permanentHover').removeClass('permanentHover');
 
                 if (DriveUtils.isGuest()) {
                     // guests & anonymous users
                     documentCollection.setData([]);
                     templateCollection.setData([]);
                 } else {
+
                     // try to get recent files and templates
-                    portalWindow.busy();
                     IO.sendRequest(IO.FILTER_MODULE_NAME, { action: 'gettemplateandrecentlist', type: appBaseName })
-                    .always(function () {
-                        portalWindow.idle();
-                    }).done(function (data) {
-                        // populate the document and template collection with data from server
+                    .done(function (data) {
+
+                        // must be reset, because the order from the list is important and
+                        // when no element is removed/added, but the order is, there would be no repaint
+                        // (minor issue, reset also repaints, so we repaint two times (reset, setData) for the recent list)
+                        documentCollection.reset();
+
+                        // set data for the collection, what cause a 'update' that renders also the view
                         documentCollection.setData(data.recents || []);
                         templateCollection.setData(data.templates || []);
-                        // render views with fresh data
-                        documentView.render(appBaseName);
-                        templateView.render(appBaseName);
 
                         // to init the bootstrap tooltips in portal
                         $('[data-toggle="tooltip"]').tooltip();
@@ -137,8 +148,10 @@ define('io.ox/office/portal/mainhelper', [
 
             // refreshes Documents app only on visibility
             function refresh() {
+
+                 //TODO for later - maybe we should refresh all portals not only the visible, but check if 'documentsToShow' in 'showOptimalCount' is called without an NAN error on global refresh
                 if (!portalWindow.state.visible) { return; }
-                initOXDocuments();
+                updatePortal();
             }
 
             // save settings to the app object
@@ -155,18 +168,24 @@ define('io.ox/office/portal/mainhelper', [
             // Reinit app on portal window show. This is needed for this use case:
             // User opens a document from the recents list -> loses app focus,
             // and close the document -> gained focus to this app without an app 'resume' event).
-            portalWindow.on('show', initOXDocuments);
+            portalWindow.on('show', updatePortal);
 
             // refresh Documents portal on OX global refresh event
             ox.on('refresh^', refresh);
 
+            // after the tooltip is inserted in the DOM, set the max-width for the tooltip, according to the rootNote width
+            rootNode.on('inserted.bs.tooltip', function () {
+                // '-90' to give some margin
+                rootNode.find('.tooltip-inner').css('maxWidth', rootNode.outerWidth() - 90 + 'px');
+            });
+
             // init OX Documents in folder support addition success.
             Commons.addFolderSupport(app, null, 'infostore', options.folder).always(initOXDocuments).fail(appFail);
         });
 
         // register as application tour (will create an entry in the settings menu to start the tour)
-        if (appTourPath && !_.device('smartphone')) {
-            GuidedTour.registerAppTour(PORTAL_MODULE_NAME, appTourPath);
+        if (!_.device('smartphone')) {
+            GuidedTour.registerAppTour(PORTAL_MODULE_NAME, PORTAL_MODULE_NAME + '/fulltour');
         }
 
         return { getApp: app.getInstance };
