@@ -17,11 +17,9 @@ define('io.ox/office/portal/model/templatemodel', function () {
 
     var templateModel = Backbone.Model.extend({
 
-        defaults: function () {
-        },
+        defaults: _.noop,
 
-        initialize: function () {
-        }
+        initialize: _.noop
 
     });
 
