@@ -15,10 +15,9 @@ define('io.ox/office/portal/portaltour', [
     'io.ox/office/tk/config',
     'io.ox/office/tk/utils/driveutils',
     'io.ox/office/baseframework/app/guidedtour',
-    'io.ox/office/baseframework/app/baseapplication',
     'io.ox/office/portal/portalutils',
     'gettext!io.ox/office/portal/main'
-], function (Config, DriveUtils, GuidedTour, BaseApplication, PortalUtils, gt) {
+], function (Config, DriveUtils, GuidedTour, PortalUtils, gt) {
 
     'use strict';
 
@@ -39,23 +38,23 @@ define('io.ox/office/portal/portaltour', [
      */
     function PortalTour(appBaseName) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // type identifier of the Portal application
-            PORTAL_APP_TYPE = PortalUtils.getPortalModuleName(appBaseName),
+        // type identifier of the Portal application
+        var PORTAL_APP_TYPE = PortalUtils.getPortalModuleName(appBaseName);
 
-            // type identifier of the Portal application
-            EDITOR_APP_TYPE = PortalUtils.getEditorModuleName(appBaseName),
+        // type identifier of the associated editor application
+        var EDITOR_APP_TYPE = PortalUtils.getEditorModuleName(appBaseName);
 
-            // CSS selector for the 'My Files/Documents' folder in Drive
-            DOCUMENTRS_FOLDER_SELECTOR = '.folder-tree .folder[data-id="' + PortalUtils.getNewLaunchOptions().folderId + '"] .folder-node',
+        // CSS selector for the 'My Files/Documents' folder in Drive
+        var DOCUMENTRS_FOLDER_SELECTOR = '.folder-tree .folder[data-id="' + PortalUtils.getNewLaunchOptions().target_folder_id + '"] .folder-node';
 
-            // the editor application (may exist but be inactive, e.g. when using Back button)
-            editApp = null,
+        // the editor application (may exist but be inactive, e.g. when using Back button)
+        var editApp = null;
 
-            // the launch options used to show the existing editor application
-            editLaunchOptions = null;
+        // the launch options used to show the existing editor application
+        var editLaunchOptions = null;
 
         // base constructor ---------------------------------------------------
 
@@ -211,6 +210,8 @@ define('io.ox/office/portal/portaltour', [
                 .content(gt.pgettext('tour', 'Changes are saved automatically whenever you work on your document.'))
                 // invoke the callback function that will insert some contents into the document
                 .once('before:show', callback)
+                // wait for the application window node, and the 'data-doc-loaded' marker that will be set after import
+                .waitFor(this.EDITOR_TOP_PANE_SELECTOR + ' .app-status-label i')
                 // highlight the 'All changes saved' status label
                 .referTo(this.EDITOR_TOP_PANE_SELECTOR + ' .app-status-label', { position: 'bottom', hotspot: 'i' });
         };
