@@ -6,7 +6,7 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Edy Haryono <edy.haryono@open-xchange.com>
  */
@@ -64,14 +64,15 @@ define('io.ox/office/portal/portalutils', [
     /**
      * Returns the application module name for the given filename.
      *
-     * @param {String} filename
+     * @param {String} fileName
      *  Filename as string
      *
-     * @returns {String | Null}
+     * @returns {String|Null}
      *  Application module name string if it exists, otherwise null.
      */
-    PortalUtils.getModuleNameForFile = function (filename) {
-        return ExtensionRegistry.getEditModule(filename);
+    PortalUtils.getModuleNameForFile = function (fileName) {
+        var editModule = ExtensionRegistry.getEditModule(fileName);
+        return (editModule && ExtensionRegistry.isEditable(fileName, editModule)) ? editModule : null;
     };
 
     /**
@@ -103,7 +104,6 @@ define('io.ox/office/portal/portalutils', [
         }
 
         return $('<i>').addClass(iconClasses);
-
     };
 
     /**
@@ -121,21 +121,21 @@ define('io.ox/office/portal/portalutils', [
 
         if (!_.isNumber(timestamp)) { return gt('unknown'); }
 
-        var now = DateUtils.getLocalDate(),
-            timeStampDate = DateUtils.getLocalDate(timestamp);
+        var now = new Date();
+        var date = new Date(timestamp);
 
         function getTimeString() {
-            return DateUtils.format(timeStampDate, DateUtils.getTimeFormat());
+            return DateUtils.format(date, DateUtils.getTimeFormat());
         }
 
         function getDateString() {
             // get locale country default date format
             var formatString = DateUtils.getDateFormat();
             // hide year if the document is modified in this year
-            if (timeStampDate.getYear() === now.getYear()) {
+            if (date.getYear() === now.getYear()) {
                 formatString = DateUtils.getNoYearFormat();
             }
-            return DateUtils.format(timeStampDate, formatString);
+            return DateUtils.format(date, formatString);
         }
 
         function isToday(date) {
@@ -145,7 +145,7 @@ define('io.ox/office/portal/portalutils', [
         }
 
         // show only time if the document is last modifed today
-        return isToday(timeStampDate) ? getTimeString() : getDateString();
+        return isToday(date) ? getTimeString() : getDateString();
 
     };
 
