@@ -17,8 +17,6 @@ define('io.ox/office/portal/presentation/main', [
 
     'use strict';
 
-    return MainHelper.createLauncher('presentation', _.noI18n('Presentation'), {
-        appTourPath: 'io.ox/office/portal/presentation/fulltour'
-    });
+    return MainHelper.createLauncher('presentation', _.noI18n('Presentation'));
 
 });
