@@ -12,10 +12,9 @@
  */
 
 define('io.ox/office/portal/spreadsheet/fulltour', [
-    'io.ox/office/portal/portalutils',
     'io.ox/office/portal/portaltour',
     'gettext!io.ox/office/portal/main'
-], function (PortalUtils, PortalTour, gt) {
+], function (PortalTour, gt) {
 
     'use strict';
 
@@ -28,13 +27,13 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
      *
      * @extends PortalTour
      */
-    function SpreadsheetFullTour(options) {
+    var SpreadsheetFullTour = PortalTour.extend({ constructor: function (options) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // whether to show the short version of the spreadsheet tour
-            shortTour = options && options.auto && PortalTour.isAnyPortalTourShown();
+        // whether to show the short version of the spreadsheet tour
+        var shortTour = options && options.auto && PortalTour.isAnyPortalTourShown();
 
         // base constructor ---------------------------------------------------
 
@@ -48,10 +47,10 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
          * local function parameter separator.
          */
         function getLocalizedFormula(formula) {
-            var grammarConfig = self.getApp().getModel().getGrammarConfig('ui');
+            var formulaGrammar = self.getApp().getModel().getFormulaGrammar('ui');
             return formula
-                .replace(/SUM/g, grammarConfig.getFunctionName('SUM'))
-                .replace(/,/g, grammarConfig.SEP);
+                .replace(/SUM/g, formulaGrammar.getFunctionName('SUM'))
+                .replace(/,/g, formulaGrammar.SEP);
         }
 
         // initialization -----------------------------------------------------
@@ -85,7 +84,7 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
 
             // insert document contents, show the 'Saving changes' label
             this.autoSaveStep(function () {
-                this.executeItem('cell/active/value', 'Lorem ipsum dolor sit amet.');
+                this.executeItem('cell/active/parse', 'Lorem ipsum dolor sit amet.');
             });
 
             // describe the 'File' toolbar
@@ -100,7 +99,7 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
             .content(gt.pgettext('tour', 'You can use all the regular spreadsheet formulas by typing them into a cell.'))
             .on('before:show', function () {
                 this.getDocView().cancelCellEditMode();
-                this.executeItem('cell/active/value', getLocalizedFormula('\'=SUM'));
+                this.executeItem('cell/active/parse', getLocalizedFormula('\'=SUM'));
             })
             .waitForAndReferTo(this.EDITOR_APP_PANE_SELECTOR + ' .selection-layer .active-cell', { position: 'bottom', hotspot: true });
 
@@ -123,7 +122,7 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
                 // need to launch explicitly, in case this step is reached by using the Back button in a short tour
                 self.launchEditorApp().done(function () {
                     this.getDocView().cancelCellEditMode();
-                    this.executeItem('cell/active/value', getLocalizedFormula('=SUM(1, 2, 3)'));
+                    this.executeItem('cell/active/parse', getLocalizedFormula('=SUM(1, 2, 3)'));
                 }.bind(this));
             })
             .waitForAndReferToGroup(this.EDITOR_WINDOW_SELECTOR + ' .status-pane', 'view/formula', { position: 'top', hotspot: true });
@@ -137,10 +136,10 @@ define('io.ox/office/portal/spreadsheet/fulltour', [
         // final tour step describing how to restart the tour, return to correct application with the Back button
         this.restartTourStep().on('back', (shortTour ? this.launchEditorApp : this.launchDriveApp).bind(this));
 
-    } // class SpreadsheetFullTour
+    } }); // class SpreadsheetFullTour
 
     // exports ================================================================
 
-    return PortalTour.extend({ constructor: SpreadsheetFullTour });
+    return SpreadsheetFullTour;
 
 });
