@@ -17,8 +17,6 @@ define('io.ox/office/portal/spreadsheet/main', [
 
     'use strict';
 
-    return MainHelper.createLauncher('spreadsheet', _.noI18n('Spreadsheet'), {
-        appTourPath: 'io.ox/office/portal/spreadsheet/fulltour'
-    });
+    return MainHelper.createLauncher('spreadsheet', _.noI18n('Spreadsheet'));
 
 });
