@@ -12,10 +12,9 @@
  */
 
 define('io.ox/office/portal/text/fulltour', [
-    'io.ox/office/portal/portalutils',
     'io.ox/office/portal/portaltour',
     'gettext!io.ox/office/portal/main'
-], function (PortalUtils, PortalTour, gt) {
+], function (PortalTour, gt) {
 
     'use strict';
 
@@ -28,7 +27,7 @@ define('io.ox/office/portal/text/fulltour', [
      *
      * @extends PortalTour
      */
-    function TextFullTour() {
+    var TextFullTour = PortalTour.extend({ constructor: function () {
 
         // base constructor ---------------------------------------------------
 
@@ -73,10 +72,10 @@ define('io.ox/office/portal/text/fulltour', [
         // final tour step describing how to restart the tour, return to Drive application with the Back button
         this.restartTourStep().on('back', this.launchDriveApp.bind(this));
 
-    } // class TextFullTour
+    } }); // class TextFullTour
 
     // exports ================================================================
 
-    return PortalTour.extend({ constructor: TextFullTour });
+    return TextFullTour;
 
 });
