@@ -17,8 +17,6 @@ define('io.ox/office/portal/text/main', [
 
     'use strict';
 
-    return MainHelper.createLauncher('text', _.noI18n('Text'), {
-        appTourPath: 'io.ox/office/portal/text/fulltour'
-    });
+    return MainHelper.createLauncher('text', _.noI18n('Text'));
 
 });
