@@ -25,6 +25,24 @@ define('io.ox/office/portal/view/templateview', [
 
         className: 'office-portal-template',
 
+        initialize: function () {
+
+            var // the document view object
+                self = this;
+
+            // observer for the collection (when the collection is updated)
+            this.listenTo(this.collection, 'update', function () {
+                // re-render the recent list for the current app
+                self.render(self.model.get('appBaseName'));
+            });
+
+            // observer for the collection (when only a model in the collection has been changed)
+            this.listenTo(this.collection, 'change', function () {
+                // re-render the recent list for the current app
+                self.render(self.model.get('appBaseName'));
+            });
+        },
+
         /**
          * Renders templates section of supported applications and 'My Templates' section
          *
@@ -39,12 +57,12 @@ define('io.ox/office/portal/view/templateview', [
             if ((_.browser.Android) && (appBaseName === 'text') && !PortalUtils.CHROME_ON_ANDROID) { return; }
 
             var self = this,
-                templateTypeWrapper = $('<div>').addClass('template-type-wrapper col-xs-12'),
                 templateWrapper = $('<div>').addClass('template-list f6-target');
 
-            templateTypeWrapper.append(templateWrapper);
+            // empty the template list
+            self.$el.empty();
 
-            self.$el.append(templateTypeWrapper);
+            self.$el.append(templateWrapper);
 
             // draw create with blank template
             TemplateActions[appBaseName].invoke('draw', templateWrapper, Ext.Baton({ app: self.model, appBaseName: appBaseName }));
@@ -59,7 +77,10 @@ define('io.ox/office/portal/view/templateview', [
 
                 _.each(this.collection.getTemplates(appBaseName, templateSource), function (template) {
                     // render
-                    TemplateActions[appBaseName + type].invoke('draw', templateWrapper, Ext.Baton({ data: template.attributes }));
+                    // Important: 'template.attributes' is cloned here, because it's changed when a document is opened otherwise (passed by reference).
+                    // That would introduce a 'version' attribute in the baton that prevent displaying the most recent template thumbnail.
+                    // (e.g. modify a template -> thumbnail is not updated)
+                    TemplateActions[appBaseName + type].invoke('draw', templateWrapper, Ext.Baton({ data: _.clone(template.attributes) }));
                 });
             }, this);
 
