@@ -16,8 +16,9 @@ define('io.ox/office/presentation/app/application', [
     'io.ox/office/editframework/app/editapplication',
     'io.ox/office/presentation/model/model',
     'io.ox/office/presentation/view/view',
-    'io.ox/office/presentation/app/controller'
-], function (EditApplication, PresentationModel, PresentationView, PresentationController) {
+    'io.ox/office/presentation/app/controller',
+    'io.ox/office/tk/utils'
+], function (EditApplication, PresentationModel, PresentationView, PresentationController, Utils) {
 
     'use strict';
 
@@ -41,9 +42,12 @@ define('io.ox/office/presentation/app/application', [
         // base constructor ---------------------------------------------------
 
         EditApplication.call(this, PresentationModel, PresentationView, PresentationController, launchOptions, {
+            prepareFlushHandler: prepareFlushDocument,
+            prepareRenameHandler: prepareRenameHandler,
             postProcessHandler: postProcessDocument,
             optimizeOperationsHandler: optimizeOperations,
             sendActionsDelay: 1000,
+            isMultiSelectionApp: true,
             localStorageApp: false
         });
 
@@ -75,6 +79,60 @@ define('io.ox/office/presentation/app/application', [
             return self.getModel().updateDocumentFormatting();
         }
 
+        /**
+         * Preprocessing before the document will be flushed for downloading,
+         * printing, sending as mail, or closing.
+         */
+        function prepareFlushDocument() {
+            sendChangedViewAttributes();
+            return self.getModel().getPreFlushDocumentPromise();
+        }
+
+        /**
+         * Preparations before the rename requests will be sent to the
+         * backend. Must call sendChangedViewAttributes to make sure that
+         * view settings are not sent while closing the document.
+         */
+        function prepareRenameHandler() {
+            sendChangedViewAttributes();
+        }
+
+        /**
+         * Send changed view attributes from the slide pane with an operation,
+         * so that the attributes are stored in the document. Only send changed
+         * view attributes when the user has edit rights, has modified the
+         * document locally, is not on mobile or tablets.
+         */
+        function sendChangedViewAttributes() {
+
+            // don't save it on tablets/mobile, because the slide pane is not resizable there
+            if (Utils.COMPACT_DEVICE) {
+                return self;
+            }
+
+            // only send changed attributes when user has edit rights
+            if (!self.getModel().getEditMode()) {
+                return self;
+            }
+
+            // whether the document is modified
+            var modified = self.isLocallyModified();
+
+            // if file was not modified, check if the slide pane width has been changed compared to the document
+            if (!modified) {
+                if (self.getModel().getSlidePaneWidthInDocAttributes() !== self.getModel().getSlidePaneWidth()) {
+                    modified = true;
+                }
+            }
+            // if the file was not modified, nothing to do
+            if (!modified) {
+                return self;
+            }
+            // send the slidePaneWidth with an operation
+            self.getModel().setSlidePaneWidthInDocAttributes();
+
+        }
+
         // initialization -----------------------------------------------------
 
         // destroy all class members
@@ -84,16 +142,6 @@ define('io.ox/office/presentation/app/application', [
 
     } }); // class PresentationApplication
 
-    // static methods ---------------------------------------------------------
-
-    /**
-     * Replacement for the generic method EditApplication.createLauncher()
-     * without parameters, to launch presentation applications.
-     */
-    PresentationApplication.createLauncher = function () {
-        return EditApplication.createLauncher('io.ox/office/presentation', PresentationApplication, { icon: 'fa-film' });
-    };
-
     // exports ================================================================
 
     return PresentationApplication;
