@@ -15,19 +15,17 @@
 define('io.ox/office/presentation/app/controller', [
     'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/color',
-    'io.ox/office/editframework/utils/border',
+    'io.ox/office/editframework/utils/hyperlinkutils',
     'io.ox/office/editframework/utils/mixedborder',
-    'io.ox/office/editframework/utils/lineheight',
     'io.ox/office/editframework/app/editcontroller',
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
-    'io.ox/office/drawinglayer/view/imageutil',
     'io.ox/office/presentation/format/paragraphstyles',
     'io.ox/office/textframework/utils/config',
     'io.ox/office/textframework/components/hyperlink/hyperlink',
     'io.ox/office/textframework/utils/position',
     'io.ox/office/textframework/format/tablestyles'
-], function (Utils, Color, Border, MixedBorder, LineHeight, EditController, DrawingUtils, DrawingLabels, Image, ParagraphStyles, Config, Hyperlink, Position, TableStyles) {
+], function (Utils, Color, HyperlinkUtils, MixedBorder, EditController, DrawingUtils, DrawingLabels, ParagraphStyles, Config, Hyperlink, Position, TableStyles) {
 
     'use strict';
 
@@ -101,7 +99,7 @@ define('io.ox/office/presentation/app/controller', [
 
             'document/editable/text': {
                 parent: 'document/editable',
-                enable: function () { return docModel.isTextSelected(); }
+                enable: function () { return docModel.isTextSelected() || docModel.getSelection().isAnyTextFrameDrawingSelection(); }
             },
 
             'document/editable/text/notextframe': {
@@ -126,9 +124,10 @@ define('io.ox/office/presentation/app/controller', [
                 shortcut: { keyCode: 'F4', shift: true }
             },
             'document/setCursorIntoTextframe': {
-                set: function () {
-                    docModel.getSelection().setSelectionIntoTextframe();
-                },
+                set: function () { docModel.getSelection().setSelectionIntoTextframe({ complete: true }); }
+            },
+            'document/switchCursorIntoTextframe': {
+                set: function () { docModel.getSelection().toggleTextFrameAndTextSelection({ complete: true }); },
                 shortcut: { keyCode: 'F2' }
             },
 
@@ -266,12 +265,42 @@ define('io.ox/office/presentation/app/controller', [
             // slides
 
             'slide/insertslide': {
+                parent: 'document/editable',
                 enable: function () { return !docModel.isMasterView(); },
-                set: function () { docModel.insertSlide(); }
+                set: function () { docModel.insertSlide(); },
+                shortcut: { keyCode: 'M', ctrl: true }
+            },
+            'slide/insertlayoutslide': {
+                parent: 'document/editable',
+                enable: function () { return docModel.isMasterView(); },
+                set: function () { docModel.insertLayoutSlide(); }
             },
             'slide/deleteslide': {
-                enable: function () { return !docModel.isMasterView() && !docModel.isOnlySlideInView(); },
-                set: function () { docModel.deleteSlide(); }
+                parent: 'document/editable',
+                enable: function () { return docModel.isSlideSelectionDeletable(docModel.getSlidePaneSelection()); },
+                set: function () { docModel.deleteMultipleSlides(docModel.getSlidePaneSelection()); }
+            },
+            'slide/hideslide': {
+                parent: 'document/editable',
+                enable: function () { return !docModel.isMasterView() && !docModel.isHiddenSlide() && !docModel.isEmptySlideView(); },
+                set: function () { docModel.setHiddenSlide(true); }
+            },
+            'slide/unhideslide': {
+                parent: 'document/editable',
+                enable: function () { return !docModel.isMasterView() &&  docModel.isHiddenSlide() && !docModel.isEmptySlideView(); },
+                set: function () { docModel.setHiddenSlide(false); }
+            },
+            'slide/move': {
+                parent: 'document/editable',
+                set: function (value) { docModel.moveMultipleSlides(value.indexStart, value.indexEnd); }
+            },
+            'slide/moveslideupwards': {
+                enable: function () { return !docModel.isFirstSlideActive(); },
+                set: function (selection) { docModel.moveSlectedSlidesOneStep({ downwards: false }, selection); }
+            },
+            'slide/moveslidedownwards': {
+                enable: function () { return !docModel.isLastSlideActive(); },
+                set: function (selection) { docModel.moveSlectedSlidesOneStep({ downwards: true }, selection); }
             },
 
             // characters
@@ -295,9 +324,9 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (fontName) { docModel.setAttribute('character', 'fontName', fontName); }
             },
             'character/fontsize': {
-                parent: ['character/attributes', 'insert/comment/supported/odf'],
-                get: function (attributes) { return attributes.fontSize; },
-                set: function (fontSize) { docModel.setAttribute('character', 'fontSize', fontSize); }
+                parent: ['character/attributes', 'insert/comment/supported/odf', 'drawing/fontscale'],
+                get: function (attributes) { return attributes.fontSize ? Math.round(attributes.fontSize * this.getParentValue(2)) : attributes.fontSize; },
+                set: function (fontSize) { docModel.setAttribute('character', 'fontSize', Math.round(fontSize / this.getParentValue(2))); }
             },
             'character/bold': {
                 parent: 'character/attributes',
@@ -355,6 +384,11 @@ define('io.ox/office/presentation/app/controller', [
                 set: function () { return docModel.removeHyperlink(); }
             },
 
+            'character/hyperlink/valid': {
+                parent: 'character/attributes',
+                enable: function (attrs) { return attrs.url && HyperlinkUtils.hasSupportedProtocol(attrs.url) && HyperlinkUtils.isValidURL(attrs.url); }
+            },
+
             'character/reset': {
                 parent: 'document/editable/text',
                 set: function () { docModel.resetAttributes(); },
@@ -532,7 +566,7 @@ define('io.ox/office/presentation/app/controller', [
                 set: function () {
                     var selection = docModel.getSelection();
                     if (docModel.isDrawingSelected()) {
-                        return docModel.deleteSelected();
+                        return docModel.deleteSelected({ deleteKey: true });
 
                     } else if (selection.isAdditionalTextframeSelection()) {
                         var start = Position.getOxoPosition(docModel.getCurrentRootNode(), selection.getSelectedTextFrameDrawing(), 0),
@@ -549,6 +583,34 @@ define('io.ox/office/presentation/app/controller', [
                 get: function () { return DrawingLabels.getDrawingTypeLabel(docModel.getSelection().getClosestSelectedDrawingType()); }
             },
 
+            'drawing/anydrawing': {
+                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); }
+            },
+
+            'drawing/textframeautofit': {
+                parent: ['drawing/anydrawing'],
+                get: function () { return docModel.isAutoResizableTextFrame(); },
+                set: function (autoResizeHeight) { docModel.handleTextFrameAutoFit(autoResizeHeight, autoResizeHeight ? false : undefined); }
+            },
+
+            'drawing/textframeautotextheight': {
+                parent: ['drawing/anydrawing'],
+                get: function () { return docModel.isAutoTextHeightTextFrame() && !docModel.isAutoResizableTextFrame(); },
+                set: function (autoResizeText) { docModel.handleTextFrameAutoFit(autoResizeText ? false : undefined, autoResizeText); }
+            },
+
+            'drawing/lockratio': {
+                enable: function () { return docModel.getSelection().isAnyDrawingSelection() || (docModel.getSelection().isMultiSelectionSupported() && docModel.getSelection().isMultiSelection()); },
+                get: function () { return docModel.isLockedRatioDrawing(); },
+                set: function (state) { docModel.handleDrawingLockRatio(state); }
+            },
+
+            'drawing/verticalalignment': {
+                enable: docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }),
+                get: function () { return docModel.getVerticalAlignmentMode(); },
+                set: function (mode) { docModel.setVerticalAlignmentMode(mode); }
+            },
+
             // drawing fill formatting
 
             'drawing/fill/attributes': {
@@ -581,11 +643,48 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (color) { docModel.setDrawingBorderColor(color); }
             },
 
+            'drawing/fontscale': {
+                parent: 'document/editable',
+                get: function () { return parseFloat(docModel.getSelection().getClosestSelectedDrawing().find('>.textframecontent').attr('font-scale') || 1); },
+                enable: function () { return docModel.getSelection().getClosestSelectedDrawing().length > 0; }
+            },
+
+            // group and ungroup of drawings
+
+            'drawing/group': {
+                enable: function () { return docModel.getSelection().isGroupableSelection(); },
+                set: function () { docModel.groupDrawings(); }
+            },
+
+            'drawing/ungroup': {
+                enable: function () { return docModel.getSelection().isUngroupableSelection(); },
+                set: function () { docModel.ungroupDrawings(); }
+            },
+
+            'drawing/order': {
+                enable: function () { return docModel.getSelection().isAnyDrawingSelection(); },
+                set: function (value) { docModel.changeDrawingOrder(value); }
+            },
+
+            // drawing/s alignment
+
+            'drawing/align': {
+                enable: function () { return docModel.getSelection().isAnyDrawingSelection(); },
+                set: function (position) { docModel.changeAlignment(position); }
+            },
+
             // text frames
 
             'textframe/insert': {
-                parent: ['document/editable/text', 'insert/textframe/supported', 'insert/comment/odf/supported'],
-                set: function () { docModel.insertTextFrame(); }
+                parent: ['document/editable', 'insert/comment/odf/supported'],
+                get: function () { return docModel.isInsertTextFrameActive(); },
+                set: function (value, inputOptions) {
+                    if (Utils.getStringOption(inputOptions, 'sourceType') === 'keyboard') {
+                        return docModel.insertTextFrameWithDefaultBox();
+                    } else {
+                        return docModel.insertTextFramePreparation();
+                    }
+                }
             },
 
             // comments
@@ -629,16 +728,65 @@ define('io.ox/office/presentation/app/controller', [
             // images
 
             'image/insert/dialog': {
-                parent: ['document/editable/text', 'insert/textframe/supported', 'insert/comment/odf/supported'],
+                parent: ['insert/textframe/supported', 'insert/comment/odf/supported'],
                 set: function (dialogType) { return docModel.showInsertImageDialog(dialogType); }
             },
 
-            // debug
-            'debug/textframeautofit': {
-                enable: function () { return docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }); },
-                get: function () { return docModel.isAutoResizableTextFrame(); },
-                set: function (state) { docModel.handleTextFrameAutoFit(state); }
+            'shape/insert': {
+                parent: ['document/editable'],
+                get: function () { return docModel.isInsertShapeActive(); },
+                set: function (presetShape, inputOptions) {
+                    if (Utils.getStringOption(inputOptions, 'sourceType') === 'keyboard') {
+                        return docModel.insertShapeWithDefaultBox(presetShape);
+                    } else {
+                        return docModel.insertShapePreparation(presetShape);
+                    }
+                }
             },
+
+            // insert a new slide, either blank or with a specifically chosen layout
+
+            'layoutslidepicker/insertslide': {
+                parent: ['document/editable'],
+                enable: function () {
+                    return (
+                        !docModel.isMasterView() &&
+                        (docModel.getMasterSlideCount() >= 1)
+                    );
+                },
+                // - the `data-value` value of option buttons will be passed along with all
+                //   form control events as payload - in this case acting as `slideId`.
+                // - visa verse `get` will be able to preselect the corresponding layout slide
+                //   of any currently selected standard slide from the former one's return value.
+                get: function () {
+                    return docModel.getLayoutSlideId(docModel.getActiveSlideId());
+                },
+                set: function (slideId) {
+                  //Utils.info('+++ slide/insertslide +++ slideId : ', slideId);
+                    var UNDEFINED_VALUE;
+
+                    if (slideId === 'blank_slide') {
+                        slideId = UNDEFINED_VALUE;
+                    }
+                    docModel.insertSlide(slideId);
+                }
+            },
+
+            // change respectively reset the currently selected slide's layout
+
+            'layoutslidepicker/changelayout': {
+                parent: ['layoutslidepicker/insertslide'],
+                enable: function () { return !docModel.isEmptySlideView(); },
+                get: function () {
+                    return docModel.getLayoutSlideId(docModel.getActiveSlideId());
+                },
+                set: function (slideId) {
+                  //Utils.info('+++ slide/changelayout +++ slideId : ', slideId);
+
+                    docModel.changeLayout(slideId);
+                }
+            },
+
             'debug/recordoperations': {
                 get: function () { return docModel.isRecordingOperations(); },
                 set: function (state) { docModel.setRecordingOperations(state); }
@@ -654,41 +802,36 @@ define('io.ox/office/presentation/app/controller', [
                 get: function () { return docModel.isDraftMode(); },
                 set: function (state) { docModel.toggleDraftMode(state); }
             },
-            'debug/verticalalignment': {
-                enable: docModel.getSelection().isAnyTextFrameSelection({ allDrawingTypesAllowed: true }),
-                get: function () { return docModel.getVerticalAlignmentMode(); },
-                set: function (mode) { docModel.setVerticalAlignmentMode(mode); }
-            },
             'debug/insertslide': {
                 enable: function () { return !docModel.isMasterView(); },
                 set: function () { docModel.insertSlide(); }
             },
-            'debug/deleteslide': {
-                enable: function () { return !docModel.isMasterView() && !docModel.isOnlySlideInView(); },
-                set: function () { docModel.deleteSlide(); }
-            },
             'debug/followmastershapes': {
+                enable: function () { return !docModel.isMasterSlideId(docModel.getActiveSlideId()); },
                 get: function () { return docModel.isFollowMasterShapeSlide(); },
                 set: function () { docModel.setFollowMasterShape(!docModel.isFollowMasterShapeSlide()); }
             },
+            'debug/hiddenslide': {
+                enable: function () { return !docModel.isMasterView(); },
+                get: function () { return docModel.isHiddenSlide(); },
+                set: function () { docModel.setHiddenSlide(!docModel.isHiddenSlide()); }
+            },
             'debug/resetbackground': {
                 enable: function () { return docModel.isSlideWithBackground(); },
                 set: function () { docModel.resetBackground(); }
             },
             'debug/slideattributes': {
-                get: function () { return docModel.getSlideAttributes(); }
+                get: function () { return docModel.getAllFamilySlideAttributes(); }
             },
             'debug/setbackgroundcolor': {
                 parent: ['debug/slideattributes'],
-                get: function (attrs) { return attrs && attrs.fill && attrs.fill.color; },
+                get: function (attrs) { return attrs && attrs.fill && attrs.fill.color ? attrs.fill.color : undefined; },
                 set: function (color) { docModel.setBackgroundColor(color); }
             },
             'debug/setbackgroundimage': {
                 parent: ['debug/slideattributes'],
                 get: function (attrs) { return attrs && attrs.fill && attrs.fill.color; },
-                set: function (dialogType) {
-                    return docModel.showInsertImageDialogForSlideBackground(dialogType);
-                }
+                set: function (dialogType) { return docModel.showInsertImageDialogForSlideBackground(dialogType); }
             },
             'debug/normalslideview': {
                 enable: function () { return docModel.isMasterView(); },
@@ -706,6 +849,23 @@ define('io.ox/office/presentation/app/controller', [
                 enable: function () { return !docModel.isLastSlideActive(); },
                 set: function () { docModel.changeToNeighbourSlide({ next: true }); }
             },
+            'debug/moveslideupwards': {
+                enable: function () { return !docModel.isFirstSlideActive(); },
+                set: function (id) { docModel.moveSlectedSlidesOneStep({ downwards: false }, id); }
+            },
+            'debug/moveslidedownwards': {
+                enable: function () { return !docModel.isLastSlideActive(); },
+                set: function (id) { docModel.moveSlectedSlidesOneStep({ downwards: true }, id); }
+            },
+            'debug/changeLayoutSlide': {
+                enable: function () { return !docModel.isMasterView(); },
+                get: function () { return docModel.getLayoutSlideId(docModel.getActiveSlideId()); },
+                set: function (id) { docModel.changeLayout(id); }
+            },
+            'debug/useFastLoad': {
+                get: function () { return app.getUserSettingsValue('useFastLoad', true); },
+                set: function (state) { app.setUserSettingsValue('useFastLoad', state); }
+            },
 
             // fields
             updateField: {
@@ -720,19 +880,33 @@ define('io.ox/office/presentation/app/controller', [
                 parent: 'document/editable',
                 set: function () { docModel.getFieldManager().removeField(); }
             },
-
+            'document/insertfooter': {
+                parent: 'document/editable/text',
+                set: function () { docModel.getFieldManager().openFooterDialog(); }
+            },
             'document/insertfield': {
                 parent: 'document/editable/text',
-                set: function (value) { docModel.getFieldManager().dispatchInsertField(value, 'default'); }
+                set: function (value) { docModel.getFieldManager().dispatchInsertField(value); }
+            },
+            insertSlideNumber: {
+                parent: 'document/editable',
+                set: function () { docModel.getFieldManager().dispatchInsertField('slidenum'); }
+            },
+            insertDateTime: {
+                parent: 'document/editable',
+                set: function () { docModel.getFieldManager().dispatchInsertField('datetime'); }
             },
-
             'document/formatfield': {
                 parent: 'document/editable',
                 get: function () { return docModel.getFieldManager().getSelectedFieldFormat(); },
                 set: function (value) { docModel.getFieldManager().updateFieldFormatting(value); }
             },
 
-            // slide Pane
+            // slide pane
+            slidePaneSetSize: {
+                set: function (width) { docModel.setLocalViewSlidePaneWidth(width); }
+            },
+
             slidePaneShowFirstSlide: {
                 set: function () {  docModel.setActiveSlideId(docModel.getIdOfFirstSlideOfActiveView()); }
             },
@@ -753,6 +927,10 @@ define('io.ox/office/presentation/app/controller', [
                 set: function (id) { docModel.setActiveSlideId(id); }
             },
 
+            slidePaneSetLastSlideActive: {
+                set: function () { docModel.changeToLastSlideInView(); }
+            },
+
             // android-entry for selection which cant be deleted by softkeyboard
             'document/editable/selection': {
                 parent: 'document/editable',
