@@ -131,7 +131,11 @@ define('io.ox/office/presentation/format/paragraphstyles', [
 
             bulletSize: { def: { type: 'followText', size: 0 } },
 
-            defaultTabSize: { def: 0 }
+            defaultTabSize: { def: 0 },
+
+            spacingBefore: { def: 0 },
+
+            spacingAfter: { def: 0 }
         },
 
         // parent families with parent element resolver functions
@@ -280,11 +284,16 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 },
                 // active paragraph tab stops
                 activeParaTabStops = null,
-                // zoom factor in floating point notation
-                zoomFactor = docModel.getApp().getView().getZoomFactor() / 100,
                 // if paraTabStops has left and right oriented tabs, mixedTabs is set by the right-tab. if it is set it overwrites behavior of text-aligment and para-margin
                 mixedTab = getMixedTab(paraTabStops);
 
+            if (docModel.getApp().isInQuit()) {
+                return;
+            }
+
+           // zoom factor in floating point notation
+            var zoomFactor = docModel.getApp().getView().getZoomFactor() / 100;
+
             if (paragraph.length) {
                 // Calculate top position and height of first paragraph child. Our paragraph
                 // have always at least one child element.
@@ -495,7 +504,7 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 return;
             }
 
-            var pageAttrs = docModel.getDefaultAttributes('page').page;
+            var pageAttrs = docModel.getDefaultAttributes('page');
             var maxParaWidth = pageAttrs.width - pageAttrs.marginLeft - pageAttrs.marginRight;
             var indentRight = paraAttributes.paragraph.indentRight;
             var currentParaWidth = mixedTab.pos + indentRight;
@@ -619,6 +628,15 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 return -space;
             }
 
+            function calcSpacingHmm(space) {
+                var lineHeight = characterStyles.calculateLineHeight(space, mergedAttributes.character);
+                if (lineHeight.type === 'px') {
+                    return Utils.convertLengthToHmm(lineHeight.val, 'px');
+                } else {
+                    return Utils.convertLengthToHmm((lineHeight.val / 100) * mergedAttributes.character.fontSize, 'pt');
+                }
+            }
+
             // Always update character formatting of all child nodes which may
             // depend on paragraph settings, e.g. automatic text color which
             // depends on the paragraph fill color. Also visit all helper nodes
@@ -772,6 +790,13 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 bottomMargin = 0;
             }
 
+            if (paragraphAttributes.spacingBefore && prevParagraph.length) {
+                topMargin += calcSpacingHmm(paragraphAttributes.spacingBefore);
+            }
+            if (paragraphAttributes.spacingAfter && nextParagraph.length) {
+                bottomMargin += calcSpacingHmm(paragraphAttributes.spacingAfter);
+            }
+
             _.extend(collectedAttrs, {
                 marginTop: (topMargin / 100) + 'mm',
                 marginBottom: (bottomMargin / 100) + 'mm'
@@ -820,18 +845,16 @@ define('io.ox/office/presentation/format/paragraphstyles', [
          */
         function getMergedPlaceHolderAttributes(layoutId, masterId, placeHolderType, placeHolderIndex, paraLevel) {
 
-            var // the slide styles object
-                slideStyles =  docModel.getSlideStyles(),
-                // the drawing styles object
+            var // the drawing styles object
                 drawingStyles = docModel.getDrawingStyles(),
                 // the layout drawing attributes
                 layoutDrawingAttrs = layoutId ? drawingStyles.getPlaceHolderAttributes(layoutId, placeHolderType, placeHolderIndex) : null,
                 // the layout slide attributes
-                layoutSlideAttrs = layoutId ? slideStyles.getListStylesAttributes(layoutId, placeHolderType) : null,
+                layoutSlideAttrs = layoutId ? docModel.getListStylesAttributesOfSlide(layoutId, placeHolderType) : null,
                 // the master drawing attributes
                 masterDrawingAttrs = masterId ? drawingStyles.getPlaceHolderAttributes(masterId, placeHolderType, placeHolderIndex) : null,
                 // the master slide attributes
-                masterSlideAttrs = masterId ? slideStyles.getListStylesAttributes(masterId, placeHolderType) : null,
+                masterSlideAttrs = masterId ? docModel.getListStylesAttributesOfSlide(masterId, placeHolderType) : null,
                 // the attributes of layout and master slide
                 attributes = null;
 
@@ -856,6 +879,36 @@ define('io.ox/office/presentation/format/paragraphstyles', [
             return attributes;
         }
 
+        /**
+         * Getting the merged place holder attributes for non place holder drawings.
+         *
+         * @param {jQuery|Node} drawing
+         *  The drawing containing the paragraph with the specified level.
+         *
+         * @param {String} paraLevel
+         *  The paragraph level.
+         *
+         * @returns {Object}
+         *  An object containing the merged attributes for a specified paragraph level. Merged are the
+         *  default list attributes and the list attributes that are assigned to the drawing node.
+         */
+        function getMergedNonPlaceHolderAttributes(drawing, paraLevel) {
+
+            var // the default attributes for a specified level
+                defaultAttrs = docModel.getDefaultTextListStylesForLevel(paraLevel),
+                // the hard list style attributes at the drawing (45279)
+                explicitDrawingAttrs = docModel.getDrawingStyles().getDrawingListStyleAttributes(drawing);
+                // explicitDrawingAttrs = AttributeUtils.getExplicitAttributes(drawing);
+
+            defaultAttrs = docModel.extendAttributes({}, defaultAttrs);
+
+            if (explicitDrawingAttrs && explicitDrawingAttrs[paraLevel]) {
+                defaultAttrs = docModel.extendAttributes(defaultAttrs, explicitDrawingAttrs[paraLevel]);
+            }
+
+            return defaultAttrs;
+        }
+
         /**
          * Getting all available list level attributes specified for a given set of layout slide id, master slide
          * id, place holder type and place holder index.
@@ -885,18 +938,16 @@ define('io.ox/office/presentation/format/paragraphstyles', [
          */
         function getAllAvailableListStyleAttributes(layoutId, masterId, placeHolderType, placeHolderIndex, options) {
 
-            var // the slide styles object
-                slideStyles =  docModel.getSlideStyles(),
-                // the drawing styles object
+            var // the drawing styles object
                 drawingStyles = docModel.getDrawingStyles(),
                 // the layout drawing attributes
                 layoutDrawingAttrs = layoutId ? drawingStyles.getPlaceHolderAttributes(layoutId, placeHolderType, placeHolderIndex) : null,
                 // the layout slide attributes
-                layoutSlideAttrs = layoutId ? slideStyles.getListStylesAttributes(layoutId, placeHolderType) : null,
+                layoutSlideAttrs = layoutId ? docModel.getListStylesAttributesOfSlide(layoutId, placeHolderType) : null,
                 // the master drawing attributes
                 masterDrawingAttrs = masterId ? drawingStyles.getPlaceHolderAttributes(masterId, placeHolderType, placeHolderIndex) : null,
                 // the master slide attributes
-                masterSlideAttrs = masterId ? slideStyles.getListStylesAttributes(masterId, placeHolderType) : null,
+                masterSlideAttrs = masterId ? docModel.getListStylesAttributesOfSlide(masterId, placeHolderType) : null,
                 // the attributes of layout or master slide
                 attributes = null,
                 // whether only the names shall be returned, not the definition of the list level styles
@@ -1017,9 +1068,10 @@ define('io.ox/office/presentation/format/paragraphstyles', [
                 }
             } else {
 
-                // using the default text list styles, that are saved in the list handler mixin
+                // using the default text list styles
                 // -> these values will be used for shapes or text frames
-                placeHolderAttributes = docModel.getDefaultTextListStylesForLevel(paraLevel);
+                // -> additionally there can be list styles hard defined at the drawing (45279)
+                placeHolderAttributes = getMergedNonPlaceHolderAttributes(drawing, paraLevel);
             }
 
             // merging the new place holder attributes into the specified attribute set
