@@ -6,16 +6,21 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Sven Jacobi <sven.jacobi@open-xchange.com>
  */
 
-define('io.ox/office/presentation/main', ['io.ox/office/presentation/app/application'], function (PresentationApplication) {
+define('io.ox/office/presentation/main', [
+    'io.ox/office/baseframework/app/applicationlauncher'
+], function (ApplicationLauncher) {
 
     'use strict';
 
     // entry point for the OX AppSuite front-end to launch a new OX Presentation instance
-    return PresentationApplication.createLauncher();
+    return ApplicationLauncher.createLauncher('io.ox/office/presentation', {
+        icon: 'fa-film',
+        trackingId: 'io.ox/presentation-editor'
+    });
 
 });
