@@ -25,6 +25,9 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
      * A mix-in class for the document model providing the handler functions
      * that keep lists up-to-date.
      *
+     * Triggers the follwing events:
+     * - 'listformatting:done': The debounced list formatting is done.
+     *
      * @constructor
      *
      * @param {Application} app
@@ -43,10 +46,19 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
 
         // private methods ----------------------------------------------------
 
-        // direct callback: called every time when implParagraphChanged() has been called
-        // Option 'singleParagraph': If set to true, only the one specified paragraph is updated. Otherwise
-        // all paragraphs in the drawing that contains the specified paragraph are updated. 'singleParagraph'
-        // is useful, if a bullet type is modified or some character attributes in a paragraph are modified.
+        /**
+         * Direct callback for 'updateListsDebounced'. This is triggered every time, when a list update
+         * is required. It allows registration of paragraphs, for that a list update must be done. Typically
+         * this paragraph and all its neighbors need to be updated. Using the option 'singleParagraph' it
+         * can be forced, that the neighbors will not be updated.
+         *
+         * @param {Object} options
+         *  Optional parameters:
+         *  @param {Boolean} [options.singleParagraph=false]
+         *   If set to true, only the one specified paragraph is updated. Otherwise
+         *   all paragraphs in the drawing that contains the specified paragraph are updated. 'singleParagraph'
+         *   is useful, if a bullet type is modified or some character attributes in a paragraph are modified.
+         */
         function registerListUpdate(paragraph, options) {
 
             // whether only the specified paragraph needs to be updated
@@ -58,12 +70,25 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
             }
         }
 
-        // deferred callback
+        /**
+         * The deferred callback for the list update.
+         *
+         * @returns {jQuery.Promise}
+         *  A promise that is resolved, when all paragraphs are updated. Asynchronous updating of
+         *  lists happens only during loading the document.
+         */
         function updateList() {
-            var allParagraps = onlySingleParagraph ? paragraphs : paragraphs.parent().children(DOM.PARAGRAPH_NODE_SELECTOR);
-            updateLists(null, allParagraps);
+
+            var // the collector for the paragraphs that need to be updated
+                allParagraps = onlySingleParagraph ? paragraphs : paragraphs.parent().children(DOM.PARAGRAPH_NODE_SELECTOR),
+                // a promise that is resolved, when all paragraphs are updated.
+                // This happens only asynchronous, when the document is loaded
+                updateListPromise = updateLists(null, allParagraps);
+
             paragraphs = $();
             onlySingleParagraph = false;
+
+            return updateListPromise;
         }
 
         /**
@@ -87,22 +112,14 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
          */
         function updateLists(options, paragraphs) {
 
-            var // an array collecting all numbers for numbered list items
-                listItemCounter = [],
-                // paragraph index in a list
-                listParagraphIndex = [],
+            var // a collector for all numbers for numbered list items
+                listItemCounter = {},
+                // check, if for the current level a start value is already defined
+                isStartValueOnLevelSet = {},
                 // list of all paragraphs in the document
                 paragraphNodes = null,
                 // the deferred, whose promise will be returned
-                def = null,
-                // Performance: If only paragraphs with numbered lists were splitted in the registration phase,
-                // it is sufficient to update all paragraphs starting from the one paragraph that was marked
-                // with 'splitInNumberedList'.
-                splitInNumberedList = false, // TODO updateListsDebouncedOptions.splitInNumberedList,
-                // whether the splitted paragraph in the numbered list was found
-                splittedNumberedListFound = false,
-                // whether DOM manipulations can be suppressed. This is the case for numbered
-                suppressDomManipulation = false;
+                def = null;
 
             function updateListInParagraph(para) {
 
@@ -117,7 +134,9 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                     // whether tab stops need to be recalculated at the paragraph
                     updateParaTabstops = false,
                     // during loading the document, the counter has to be resetted for every first paragraph in text frame
-                    resetListItemCounter = !paragraphs && $(para).prevAll(DOM.PARAGRAPH_NODE_SELECTOR).length === 0,
+                    // -> Important: There can be paragraphs from several drawings in 'paragraphs', if a layout slide was modified(!)
+                    resetListItemCounter = $(para).prevAll(DOM.PARAGRAPH_NODE_SELECTOR).length === 0,
+                    // resetListItemCounter = !paragraphs && $(para).prevAll(DOM.PARAGRAPH_NODE_SELECTOR).length === 0,
                     // for some characters and fonts it is necessary to replace the values by more reliable values
                     replacementChar = null,
                     // the character and font name that are used for displaying
@@ -141,67 +160,85 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                     // the character attributes of the text span following the list label node
                     followingTextAttributes = null,
                     // the list span inside the list label node
-                    listSpans = null;
+                    listSpans = null,
+                    // whether the paragraph is empty
+                    isEmptyParagraph = false;
 
                 // helper function to count the number for the list items in numbered lists
+                // (only used for numbered list paragraphs)
                 function countListLevel() {
 
-                    if (!listItemCounter[listCounterId] || resetListItemCounter) {
+                    if (resetListItemCounter) {  // resetting for each new drawing
+                        listItemCounter = {};
+                        isStartValueOnLevelSet = {};
+                    }
+
+                    if (!listItemCounter[listCounterId]) {
                         listItemCounter[listCounterId] = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
-                        listParagraphIndex[listCounterId] = 0;
                     }
 
                     if (!noListLabel) {
-                        listItemCounter[listCounterId][listLevel]++;
-                        listParagraphIndex[listCounterId]++;
-                    }
-
-                    if (paraAttributes.listStartValue >= 0) {
-                        listItemCounter[listCounterId][listLevel] = paraAttributes.listStartValue;
-                    }
-
-                    // TODO: reset sub-levels depending on their 'levelRestartValue' attribute
-                    subLevelIdx = listLevel + 1;
-
-                    for (; subLevelIdx < 10; subLevelIdx++) {
-                        listItemCounter[listCounterId][subLevelIdx] = 0;
-                    }
-
-                    // fix level counts of non-existing upper levels
-                    subLevelIdx = listLevel - 1;
-
-                    for (; subLevelIdx >= 0; subLevelIdx--) {
-                        if (listItemCounter[listCounterId][subLevelIdx] === 0) {
-                            listItemCounter[listCounterId][subLevelIdx] = 1;
+                        if (_.isNumber(paraAttributes.bullet.startAt)) {
+                            if (isStartValueOnLevelSet[listLevel]) {
+                                if (!isEmptyParagraph) { listItemCounter[listCounterId][listLevel]++; } // there is already a start value defined
+                            } else {
+                                listItemCounter[listCounterId][listLevel] = paraAttributes.bullet.startAt;  // this is the first paragraph with start value
+                                isStartValueOnLevelSet[listLevel] = true;  // a new start value for this level is set
+                            }
+                        } else {
+                            if (!isEmptyParagraph) { listItemCounter[listCounterId][listLevel]++; }
+                            isStartValueOnLevelSet[listLevel] = false;  // no current start value for this level
                         }
                     }
 
+                    // reset all sub-levels depending on their 'levelRestartValue' attribute
+                    subLevelIdx = listLevel + 1;
+
+                    _.each(_.keys(listItemCounter), function (counterId) {
+
+                        var index = subLevelIdx;
+                        for (; index < 10; index++) {
+                            listItemCounter[counterId][index] = 0;
+                            isStartValueOnLevelSet[index] = false;  // no current start value for all sub levels
+                        }
+
+                        // restart at the same level for all other list IDs
+                        if (counterId !== listCounterId) {
+                            listItemCounter[counterId][listLevel] = 0;
+                        }
+                    });
+
                 }
 
-                // Updating paragraphs, that are no longer part of lists (for example after 'Backspace')
-                if ($(para).data('removeLabel')) {
-                    $(para).removeData('removeLabel');
+                // handling the count list level for paragraphs, that are not numbered lists. This
+                // can be bullet lists or no lists at all -> at that level and lower, all lists are
+                // restarted.
+                function restartCountListLevel(level) {
+
+                    _.each(_.keys(listItemCounter), function (counterId) {
+
+                        var index = level;
+                        for (; index < 10; index++) {
+                            listItemCounter[counterId][index] = 0;
+                            isStartValueOnLevelSet[index] = false;
+                        }
+                    });
                 }
 
-                if ($(para).data('updateList')) {
-                    $(para).removeData('updateList');
+                // updating the paragraph
+                oldLabel = $(para).children(DOM.LIST_LABEL_NODE_SELECTOR);
+                updateParaTabstops = oldLabel.length > 0;
+                oldLabel.remove();
+
+                // After removing the label, it can be checked, if the paragraph is empty
+                // -> DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS might already be set by the 'selectionChangeHandler'
+                isEmptyParagraph = $(para).hasClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS) || DOM.isEmptyParagraph(para);
+                if (isEmptyParagraph) {
+                    $(para).addClass(DOM.PARAGRAPH_NODE_LIST_EMPTY_CLASS); // -> adding a class to the paragraph to mark it as empty
                 }
 
-                if ($(para).data('splitInNumberedList')) {  // might be set at more than one paragraph
-                    splittedNumberedListFound = true;
-                    $(para).removeData('splitInNumberedList');
-                }
-
-                // Performance III: No DOM manipulation, if the split happened in a numbered list and the marked
-                // paragraph (marked with 'splitInNumberedList') was not found yet. Only for following paragraphs
-                // the DOM manipulations are necessary. But the number counting is necessary for all paragraphs.
-                suppressDomManipulation = (splitInNumberedList && !splittedNumberedListFound);
-
-                if (!suppressDomManipulation) {
-                    oldLabel = $(para).children(DOM.LIST_LABEL_NODE_SELECTOR);
-                    updateParaTabstops = oldLabel.length > 0;
-                    oldLabel.remove();
-                }
+                // resetting counter for non numbering lists
+                if (paraAttributes.bullet.type !== 'numbering') { restartCountListLevel(_.isNumber(listLevel) ? listLevel : 0); }
 
                 if (_.isNumber(listLevel) && listLevel >= 0) {
 
@@ -219,12 +256,6 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
 
                         if (paraAttributes.bullet.type === 'numbering') { countListLevel(); }
 
-                        // Performance III: After updating the listItemCounter and listParagraphIndex, the following
-                        // DOM manipulations can be ignored, if 'suppressDomManipulation' is set to true. This is the
-                        // case for numbered lists in which the added paragraph marked with 'splitInNumberedList' was
-                        // not found yet.
-                        if (suppressDomManipulation) { return; }
-
                         updateParaTabstops = true;
 
                         if (paraAttributes.bullet.type === 'character') {
@@ -244,11 +275,12 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
 
                         } else if (paraAttributes.bullet.type === 'numbering') {
                             numType = paraAttributes.bullet.numType || 'arabicPeriod';
-                            textChar = self.createNumberedListItem(listItemCounter[listCounterId][listLevel], numType);
+                            textChar = self.createNumberedListItem(isEmptyParagraph ? (listItemCounter[listCounterId][listLevel] + 1) : listItemCounter[listCounterId][listLevel], numType);
                             displayFontName = paraAttributes.bulletFont.name ? paraAttributes.bulletFont.name : null;
                         }
 
                         numberingElement = DOM.createListLabelNode(noListLabel ? '' : textChar);
+
                         span = DOM.findFirstPortionSpan(para);
                         followingTextAttributes = self.getCharacterStyles().getElementAttributes(span).character;
                         listSpans = numberingElement.children('span');
@@ -263,22 +295,22 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                             .addClass('drawing')
                             .data('url', imageUrl)
                             .append($('<div>').addClass('content')
-                                .append($('<img>', { src: absUrl }).css('width', imageWidth + 'pt'))
+                                .append($('<img>', { src: absUrl }).css('width', Utils.convertToEM(imageWidth, 'pt')))
                             );
 
                             self.getCharacterStyles().updateElementLineHeight(image, paraAttributes.lineHeight, followingTextAttributes);
-                            $(image).css('height', followingTextAttributes.fontSize + 'pt');
-                            $(image).css('width', followingTextAttributes.fontSize + 'pt');
+                            $(image).css('height', Utils.convertToEM(followingTextAttributes.fontSize, 'pt'));
+                            $(image).css('width', Utils.convertToEM(followingTextAttributes.fontSize, 'pt'));
                             numberingElement.prepend(image);
 
                         } else if (!noListLabel) {
 
                             if (paraAttributes.bulletSize.type === 'followText') {
-                                listSpans.css('font-size', followingTextAttributes.fontSize + 'pt');
+                                listSpans.css('font-size', Utils.convertToEM(followingTextAttributes.fontSize, 'pt'));
                             } else if (paraAttributes.bulletSize.type === 'percent') {
-                                listSpans.css('font-size', Utils.round((paraAttributes.bulletSize.size / 100) * followingTextAttributes.fontSize, 1) + 'pt');
+                                listSpans.css('font-size', Utils.convertToEM(Utils.round((paraAttributes.bulletSize.size / 100) * followingTextAttributes.fontSize, 1), 'pt'));
                             } else {
-                                listSpans.css('font-size', paraAttributes.bulletSize.size + 'pt'); // TODO: Is the size given in 'pt' ?
+                                listSpans.css('font-size', Utils.convertToEM(paraAttributes.bulletSize.size, 'pt')); // TODO: Is the size given in 'pt' ?
                             }
 
                             if (paraAttributes.bulletFont.followText) {
@@ -312,6 +344,7 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                         }
 
                         $(para).prepend(numberingElement);
+
                     }
                 }
 
@@ -320,8 +353,8 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                 }
             }
 
-            // receiving list of all document paragraphs
-            paragraphNodes = paragraphs ? paragraphs : self.getCurrentRootNode().find(DOM.PARAGRAPH_NODE_SELECTOR);
+            // receiving list of all document paragraphs (excluding slides)
+            paragraphNodes = paragraphs ? paragraphs : self.getCurrentRootNode().find(DOM.PARAGRAPH_NODE_SELECTOR).not('.slide');
 
             if (Utils.getBooleanOption(options, 'async', false)) {
                 def = self.iterateArraySliced(paragraphNodes, updateListInParagraph, { delay: 'immediate', infoString: 'Text: updateListInParagraph' });
@@ -330,7 +363,10 @@ define('io.ox/office/presentation/model/updatelistsmixin', [
                 def = $.when();
             }
 
-            return def.promise();
+            return def.promise().always(function () {
+                // informing the listeners, that the list formatting is done
+                self.trigger('listformatting:done');
+            });
         }
 
         // public methods -----------------------------------------------------
