@@ -27,10 +27,12 @@ define('io.ox/office/presentation/utils/operations', [
      */
     var PresentationOperations = _.extend(TextOperations, {
 
-        SLIDE_INSERT: 'insertSlide', // TODO: Shift this into presentation
+        SLIDE_INSERT: 'insertSlide',
         MASTER_SLIDE_INSERT: 'insertMasterSlide',
-        LAYOUT_SLIDE_INSERT: 'insertLayoutSlide'
-
+        LAYOUT_SLIDE_INSERT: 'insertLayoutSlide',
+        LAYOUT_SLIDE_MOVE: 'moveLayoutSlide',
+        LAYOUT_CHANGE: 'changeLayout',
+        SLIDE_MOVE: 'moveSlide'
     });
 
     // exports ================================================================
