@@ -20,17 +20,11 @@ define('io.ox/office/settings/contexttemplatemodel', function () {
         /**
          * returns all template folder-ids in one array
          */
-        this.getAll = function () {
-            return data;
-        };
+        this.getAll = _.constant(data);
 
-        this.add = function () {
+        this.add = _.noop;
 
-        };
-
-        this.remove = function () {
-
-        };
+        this.remove = _.noop;
     }
 
     return Model;
