@@ -6,19 +6,19 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
- * © 2016 OX Software GmbH
+  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Stefan Eckert <stefan.eckert@open-xchange.com>
  */
 
 define('io.ox/office/settings/templatefolders', [
     'io.ox/office/tk/dialogs',
-    'io.ox/mail/detail/links',
     'io.ox/core/notifications',
     'io.ox/office/tk/utils',
     'io.ox/office/tk/utils/driveutils',
-    'io.ox/office/settings/view/settingslabels'
-], function (Dialogs, DeepLinks, Notifications, Utils, DriveUtils, Labels) {
+    'io.ox/office/settings/view/settingslabels',
+    'io.ox/mail/detail/links' /* this line is important for deep links usage (works with jq delegation) */
+], function (Dialogs, Notifications, Utils, DriveUtils, Labels) {
 
     'use strict';
 
@@ -67,7 +67,7 @@ define('io.ox/office/settings/templatefolders', [
             function remove(path, li) {
                 var id = _.last(path).id;
                 if (!templateModel.remove(id)) {
-                    if (ox.debug) { console.warn('folder not in list', id); }
+                    Utils.warn('folder not in list', id);
                 } else {
                     li.remove();
                 }
@@ -190,13 +190,13 @@ define('io.ox/office/settings/templatefolders', [
                 });
                 dialog.show().always(function () {
                     busy = false;
-                }).done(function (folder_id) {
+                }).done(function () {
                     var folder_id = dialog.getSelectedFolderId();
                     if (folder_id && folder_id !== myFiles) {
                         path(folder_id, function (path) {
                             var id = _.last(path).id;
                             if (!templateModel.add(id)) {
-                                if (ox.debug) { console.warn('folder already in list', id); }
+                                Utils.warn('folder already in list', id);
                                 return;
                             }
                             if (oldId) {
@@ -213,7 +213,7 @@ define('io.ox/office/settings/templatefolders', [
                  * standard button for opening FolderPicker
                  * if selected folder is new, it will be added to account & to gui
                  */
-                settings.appendButton(Utils.getStringOption(options, 'newFolder', Labels.ADD_NEW_TEMPLATE_FOLDER), clickAdd);
+                settings.appendButton(Utils.getStringOption(options, 'newFolder', Labels.ADD_NEW_TEMPLATE_FOLDER), clickAdd).attr('data-action', 'newtempfolder');
             }
 
             settings.append($('<div style="display: block; height: 20px">'));
