@@ -30,7 +30,7 @@ define('io.ox/office/settings/units', [
         },
         in: {
             label: Labels.INCH_LABEL,
-            step: 0.1
+            step: 0.05
         }
     };
 
@@ -54,13 +54,13 @@ define('io.ox/office/settings/units', [
         this.refresh = function (settings) {
             settings.appendTitle(Labels.MEASUREMENTS);
 
-            var folders = $('<ul class="list-unstyled publications list-group widget-list"></ul>');
+            var folders = $('<ul class="list-unstyled publications list-group widget-list">');
 
             settings.append(folders);
 
             var standardUnit = getStandardUnit();
 
-            var select = $('<select id="units/standard" class="form-control">');
+            var select = $('<select id="io-ox-office-standard-units" class="form-control">');
             _.each(ALL_UNITS, function (data, unit) {
                 var option = $('<option>').text(data.label).val(unit);
                 if (unit === standardUnit) {
@@ -73,20 +73,11 @@ define('io.ox/office/settings/units', [
                 setStandardUnit(this.value);
             });
 
-            var form = $('<div class="form-group clearfix">');
-            var label = $('<label class="control-label col-sm-4" for="units/standard">');
-            label.text(Labels.MEASUREMENTS_LABEL);
-
-            var div = $('<div class="col-sm-4">');
-
-            div.append(select);
-            form.append(label);
-            form.append(div);
-
-            settings.append(form);
-
-            settings.append($('<div style="display: block; height: 20px">'));
+            var label = $('<label class="control-label col-sm-4" for="io-ox-office-standard-units">').text(Labels.MEASUREMENTS_LABEL);
+            var div = $('<div class="col-sm-4">').append(select);
+            var form = $('<div class="form-group clearfix">').append(label, div);
 
+            settings.append(form, '<div style="display:block;height:20px;">');
         };
 
     } // class Units
