@@ -13,14 +13,13 @@
 
 define('io.ox/office/spreadsheet/app/controller', [
     'io.ox/office/tk/utils',
-    'io.ox/office/editframework/utils/border',
     'io.ox/office/editframework/utils/mixedborder',
     'io.ox/office/editframework/app/editcontroller',
     'io.ox/office/spreadsheet/utils/config',
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/paneutils',
     'io.ox/office/spreadsheet/app/drawingcontroller'
-], function (Utils, Border, MixedBorder, EditController, Config, SheetUtils, PaneUtils, DrawingControllerMixin) {
+], function (Utils, MixedBorder, EditController, Config, SheetUtils, PaneUtils, DrawingControllerMixin) {
 
     'use strict';
 
@@ -101,7 +100,7 @@ define('io.ox/office/spreadsheet/app/controller', [
             'view/subtotals/type': {
                 parent: 'app/valid',
                 enable: function () {
-                    var subtotals = docView.getSubtotals();
+                    var subtotals = docView.getSubtotalResult();
                     return (subtotals.cells > 1) && (this.getValue() in subtotals);
                 },
                 get: function () { return app.getUserSettingsValue('subtotalType', 'sum'); },
@@ -117,7 +116,7 @@ define('io.ox/office/spreadsheet/app/controller', [
             'view/formula': {
                 parent: 'view/cell/editmode/off',
                 enable: function () { return docView.isSingleCellSelection() && !docView.hasDrawingSelection() && _.isString(this.getValue()); },
-                get: function () { return docView.getActiveCellEntry().formula; }
+                get: function () { var formula = docView.getActiveCellFormula(); return formula ? ('=' + formula) : null; }
             },
 
             'view/sheet/more': {
@@ -168,42 +167,55 @@ define('io.ox/office/spreadsheet/app/controller', [
                 set: function () { docView.incZoom(); }
             },
 
+            // document operations --------------------------------------------
+
+            'document/formula/recalcall': {
+                parent: 'document/editable',
+                set: function () { return docModel.getDependencyManager().recalcFormulas({ all: true }); }
+            },
+
             // sheet operations -----------------------------------------------
 
             'sheet/attributes': {
                 parent: 'document/editable',
-                get: function () { return docView.getSheetAttributes().sheet; }
+                get: function () { return docView.getSheetAttributeSet(true).sheet; }
             },
 
             'sheet/visible': {
                 parent: 'sheet/attributes',
                 enable: function () { return docView.getVisibleSheetCount() > 1; },
                 get: function (attributes) { return attributes.visible; },
-                set: function (visible) { docView.setSheetAttributes({ sheet: { visible: visible } }); }
+                set: function (visible) { return docView.changeSheet({ sheet: { visible: visible } }); }
+            },
+
+            'sheet/unhide': {
+                parent: 'document/editable',
+                enable: function () { return docView.getHiddenSheetCount() > 0; },
+                set: function () { return docView.showUnhideSheetsDialog(); }
             },
 
             'sheet/showall': {
                 parent: 'document/editable',
                 enable: function () { return docView.getHiddenSheetCount() > 0; },
-                set: function () { docView.showAllSheets(); }
+                set: function () { return docView.showAllSheets(); }
             },
 
             'sheet/insert': {
                 parent: 'document/editable',
                 enable: function () { return docModel.getSheetCount() < Config.MAX_SHEET_COUNT; },
-                set: function () { docView.insertSheet(); }
+                set: function () { return docView.insertSheet(); }
             },
 
             'sheet/delete': {
                 parent: 'document/editable',
                 enable: function () { return docView.getVisibleSheetCount() > 1; },
-                set: function () { docView.deleteSheet(); }
+                set: function () { return docView.deleteSheet(); }
             },
 
             'sheet/name': {
                 parent: 'document/editable',
                 get: function () { return docView.getSheetName(); },
-                set: function (sheetName) { docView.renameSheet(sheetName); }
+                set: function (sheetName) { return docView.renameSheet(sheetName); }
             },
 
             'sheet/rename/dialog': {
@@ -216,18 +228,17 @@ define('io.ox/office/spreadsheet/app/controller', [
                 set: function () { return docView.showCopySheetDialog(); }
             },
 
+            'sheet/move': {
+                parent: 'document/editable',
+                set: function (data) { return docView.moveSheet(data.from, data.to); }
+            },
+
             'sheet/reorder/dialog': {
                 parent: 'document/editable',
                 enable: function () { return docView.getVisibleSheetCount() > 1; },
                 set: function () { return docView.showReorderSheetsDialog(); }
             },
 
-            'sheet/formulas/refresh': {
-                parent: 'view/cell/editmode/off',
-                set: function () { return docView.getCellCollection().refreshAllFormulaCells(); },
-                shortcut: { keyCode: 'F9', shift: true, ctrlOrMeta: true }
-            },
-
             // Parent item for various sheet-level operations in the active sheet, enabled if:
             // - document is in edit mode,
             // - in-place cell edit mode is not active,
@@ -276,17 +287,17 @@ define('io.ox/office/spreadsheet/app/controller', [
             },
 
             'name/insert/dialog': {
-                parent: 'document/editable/cell',
+                parent: 'sheet/operation/unlocked/cell',
                 set: function () { return docView.showInsertNameDialog(); }
             },
 
             'name/edit/dialog': {
-                parent: 'document/editable/cell',
+                parent: 'sheet/operation/unlocked/cell',
                 set: function (label) { return docView.showChangeNameDialog(label); }
             },
 
             'name/delete': {
-                parent: 'document/editable/cell',
+                parent: 'sheet/operation/unlocked/cell',
                 set: function (label) { return docView.deleteName(label); }
             },
 
@@ -415,15 +426,21 @@ define('io.ox/office/spreadsheet/app/controller', [
 
             // cell operations on active cell ---------------------------------
 
-            // inserts some text into the active cell
-            'cell/active/value': {
+            // inserts ready-to-use cell contents into the active cell
+            'cell/active/contents': {
                 parent: 'sheet/operation/cell', // can be used in locked sheets
-                set: function (value) { return docView.setCellContents(value, null, { parse: true }); }
+                set: function (contents) { return docView.setCellContents(contents); }
+            },
+
+            // inserts some text (to be parsed) into the active cell
+            'cell/active/parse': {
+                parent: 'sheet/operation/cell', // can be used in locked sheets
+                set: function (value) { return docView.parseCellContents(value); }
             },
 
             'function/insert/dialog': {
                 parent: 'sheet/operation/cell', // can be used in locked sheets
-                set: function () { return docView.insertFunction(); }
+                set: function () { return docView.showInsertFunctionDialog(); }
             },
 
             'cell/painter': {
@@ -434,14 +451,19 @@ define('io.ox/office/spreadsheet/app/controller', [
 
             // cell operations on selection -----------------------------------
 
+            'cell/fill': {
+                parent: 'sheet/operation/cell', // can be used in locked sheets
+                set: function (contents) { return docView.fillRangeContents(contents); }
+            },
+
             'cell/clear/values': {
                 parent: 'sheet/operation/cell', // can be used in locked sheets
-                set: function () { return docView.fillCellRanges(null); }
+                set: function () { return docView.fillRangeContents({ v: null, f: null }); }
             },
 
             'cell/clear/all': {
                 parent: 'sheet/operation/cell', // can be used in locked sheets
-                set: function () { return docView.clearCellRanges(); }
+                set: function () { return docView.clearRangeContents(); }
             },
 
             'cell/merge': {
@@ -453,7 +475,7 @@ define('io.ox/office/spreadsheet/app/controller', [
 
             'cell/autofill': {
                 parent: 'sheet/operation/cell', // can be used in locked sheets
-                set: function (fillData) { return docView.autoFill(fillData.border, fillData.count); }
+                set: function (fillData) { return docView.autoFill(fillData.border, fillData.count, { invertType: fillData.invertType }); }
             },
 
             'cell/autoformula': {
@@ -466,8 +488,8 @@ define('io.ox/office/spreadsheet/app/controller', [
 
             'cell/sort': {
                 parent: 'sheet/operation/unlocked/cell',
-                // TODO: sorting real tables has been disabled, until GUI and OOXML filter support sorting tables
-                enable: function () { return !docView.isRealTableSelected(); },
+                // Only one single range can be sorted by now
+                enable: function () { return !(docView.getSelectedRanges().length > 1); },
                 get: function () { return docView.getSortState(); },
                 set: function (sortObj) { return docView.sortCellRange(sortObj); }
             },
@@ -482,19 +504,19 @@ define('io.ox/office/spreadsheet/app/controller', [
 
             'cell/attributes': {
                 parent: 'document/editable/cell',
-                get: function () { return docView.getCellAttributes(); },
-                set: function (attributes) { return docView.fillCellRanges(undefined, attributes); }
+                get: function () { return docView.getActiveAttributeSet(); },
+                set: function (attributes) { return docView.fillRangeContents({ a: attributes }); }
             },
 
             'cell/stylesheet': {
                 parent: ['cell/attributes', 'view/cell/editmode/off'],
                 get: function (attributes) { return attributes.styleId; },
-                set: function (styleId) { return docView.fillCellRanges(undefined, { styleId: styleId }); }
+                set: function (styleId) { return docView.fillRangeContents({ a: { styleId: styleId } }); }
             },
 
-            'cell/reset': {
+            'cell/attributes/clear': {
                 parent: ['cell/attributes', 'view/cell/editmode/off'],
-                set: function () { return docView.clearAttributes(); }
+                set: function () { return docView.fillRangeContents({ s: '' }); }
             },
 
             // cell attributes (family 'cell') ----------------------------
@@ -596,8 +618,8 @@ define('io.ox/office/spreadsheet/app/controller', [
             'cell/numberformat/code': {
                 parent: 'cell/numberformat/category',
                 enable: function (category) { return !/^(standard|custom)$/.test(category); },
-                get: function () { return docView.getNumberFormatCode(); },
-                set: function (formatCode) { return docView.setNumberFormatCode(formatCode); }
+                get: function () { return docView.getNumberFormat(); },
+                set: function (format) { return docView.setNumberFormat(format); }
             },
 
             // cell attributes (family 'character') ---------------------------
@@ -655,15 +677,13 @@ define('io.ox/office/spreadsheet/app/controller', [
 
             'character/format': {
                 parent: 'app/valid'
-            },
-
-            'document/ooxml': {
-                enable: function () { return app.isOOXML(); }
             }
         });
 
         // update GUI after changed selection, and after receiving view updates
-        this.listenTo(docView, 'change:sheet:viewattributes change:layoutdata celledit:enter celledit:change celledit:leave', function () { self.update(); });
+        this.listenTo(docView, 'change:sheet:viewattributes update:selection:data celledit:enter celledit:change celledit:leave', function () {
+            self.update();
+        });
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
