@@ -17,11 +17,10 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
     'io.ox/office/drawinglayer/utils/drawingutils',
     'io.ox/office/drawinglayer/view/drawinglabels',
     'io.ox/office/spreadsheet/utils/operations',
-    'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/model/formula/tokenarray',
     'io.ox/office/spreadsheet/view/chartcreator',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, Color, DrawingUtils, DrawingLabels, Operations, SheetUtils, TokenArray, ChartCreator, gt) {
+], function (Utils, Color, DrawingUtils, DrawingLabels, Operations, TokenArray, ChartCreator, gt) {
 
     'use strict';
 
@@ -134,18 +133,61 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
         }
 
         /**
-         * Generates and applies a drawing operation.
+         * Generates and applies a document operation for a chart object with correct undo operation.
          *
          * @returns {jQuery.Promise}
          *  A promise that will be resolved after the drawing operations have
          *  been applied successfully, or that will be rejected on any error.
          */
-        function createAndApplyDrawingOperation(opName, properties, callback) {
+        function createAndApplyChartOperation(chartModel, opName, properties, callback) {
             return docView.getSheetModel().createAndApplyOperations(function (generator) {
+
                 var position = getDrawingPosition();
-                if (callback) { callback(generator, position); }
-                generator.generateDrawingOperation(opName, position, properties);
-            });
+                var promise = callback ? $.when(callback(generator, position)) : $.when();
+
+                return promise.done(function () {
+                    generateChartOperation(generator, chartModel, opName, position, properties);
+                });
+            }, { storeSelection: true });
+        }
+
+        /**
+         * Generates a document operation for a chart object with correct undo operation.
+         */
+        function generateChartOperation(generator, chartModel, opName, position, properties) {
+            var undoProperties = null;
+            switch (opName) {
+                case Operations.SET_CHART_LEGEND_ATTRIBUTES:
+                    var legendModel = chartModel.getLegendModel(properties.axis);
+                    undoProperties = { attrs: legendModel.getUndoAttributeSet(properties.attrs) };
+                    break;
+
+                case Operations.SET_CHART_TITLE_ATTRIBUTES:
+                    var titleModel = chartModel.getTitleModel(properties.axis);
+                    undoProperties = { axis: properties.axis, attrs: titleModel.getUndoAttributeSet(properties.attrs) };
+                    break;
+
+                case Operations.SET_CHART_AXIS_ATTRIBUTES:
+                    var axisModel = chartModel.getAxisModel(properties.axis);
+                    undoProperties = { axis: properties.axis, attrs: axisModel.getUndoAttributeSet(properties.attrs) };
+                    break;
+
+                case Operations.SET_CHART_GRIDLINE_ATTRIBUTES:
+                    var gridModel = chartModel.getAxisModel(properties.axis).getGrid();
+                    undoProperties = { axis: properties.axis, attrs: gridModel.getUndoAttributeSet(properties.attrs) };
+                    break;
+
+                case Operations.SET_DRAWING_ATTRIBUTES:
+                    undoProperties = { attrs: chartModel.getUndoAttributeSet(properties.attrs) };
+                    break;
+
+                default:
+                    Utils.error('generateChartOperation(): unknown operation "' + opName + '"');
+                    return;
+            }
+
+            generator.generateDrawingOperation(opName, position, undoProperties, { undo: true });
+            generator.generateDrawingOperation(opName, position, properties);
         }
 
         /**
@@ -166,6 +208,9 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          * Changes the attributes of the specified title in the selected chart
          * object.
          *
+         * @param {ChartModel} chartModel
+         *  The chart model to be manipulated.
+         *
          * @param {String} titleId
          *  The identifier of the title object. Must be one of 'main', 'x',
          *  'y', or 'z'.
@@ -177,14 +222,17 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          *  A promise that will be resolved after the operation has been
          *  applied successfully, or that will be rejected on any error.
          */
-        function setChartTitleAttributes(titleId, attrs) {
-            return createAndApplyDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES, { axis: titleId, attrs: attrs });
+        function setChartTitleAttributes(chartModel, titleId, attrs) {
+            return createAndApplyChartOperation(chartModel, Operations.SET_CHART_TITLE_ATTRIBUTES, { axis: titleId, attrs: attrs });
         }
 
         /**
          * Changes the text of the specified title in the selected chart
          * object.
          *
+         * @param {ChartModel} chartModel
+         *  The chart model to be manipulated.
+         *
          * @param {String} titleId
          *  The identifier of the title object. Must be one of 'main', 'x',
          *  'y', or 'z'.
@@ -197,8 +245,8 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          *  A promise that will be resolved after the operation has been
          *  applied successfully, or that will be rejected on any error.
          */
-        function setChartTitle(titleId, title) {
-            return setChartTitleAttributes(titleId, { text: { link: [title] }, character: ChartCreator.getHeadChar() });
+        function setChartTitle(chartModel, titleId, title) {
+            return setChartTitleAttributes(chartModel, titleId, { text: { link: [title] }, character: ChartCreator.getHeadChar() });
         }
 
         function selectNewChartSource() {
@@ -215,10 +263,10 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
                 var sheet = docView.getActiveSheet();
 
                 if (!chartSourceToken) {
-                    chartSourceToken = new TokenArray(docView.getSheetModel());
+                    chartSourceToken = new TokenArray(docView.getSheetModel(), 'chart');
                 }
 
-                chartSourceToken.clear().appendRange(range, { sheet: sheet, abs: true });
+                chartSourceToken.clearTokens().appendRange(range, { sheet: sheet, abs: true });
 
                 var chart = getDrawingModel('chart');
 
@@ -244,32 +292,52 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
          */
         function changeChartType(id) {
 
-            var chart = getDrawingModel('chart');
+            var chartModel = getDrawingModel('chart');
             var data = DrawingLabels.CHART_TYPE_STYLES[id];
-            var oldData = chart.getMergedAttributes().chart;
+            var oldData = chartModel.getMergedAttributeSet(true).chart;
 
-            if (data.type !== oldData.type && (data.type.indexOf('bubble') === 0 || oldData.type.indexOf('bubble') === 0)) {
-                //special behavior for bubble charts!!!
-                var possSources = chart.getDataSourceInfo();
+            var oldNoAx = oldData.type.indexOf('pie') === 0 || oldData.type.indexOf('donut') === 0;
+            var noAx = data.type.indexOf('pie') === 0 || data.type.indexOf('donut') === 0;
+
+            var oldBubble = oldData.type.indexOf('bubble') === 0;
+            var bubble = data.type.indexOf('bubble') === 0;
+
+            if (oldNoAx !== noAx || oldBubble !== bubble) {
+                // special behavior for bubble & pie charts!!!
+                // fix for Bug 46917
+                var possSources = chartModel.getDataSourceInfo();
                 if (possSources.warn) {
                     return yellChartDirection(possSources.warn);
                 }
-                return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chart, possSources.axis, data);
+                return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chartModel, possSources.axis, data);
             }
 
-            return createAndApplyDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, { attrs: { chart: data } }, function (generator, position) {
+            return createAndApplyChartOperation(chartModel, Operations.SET_DRAWING_ATTRIBUTES, { attrs: { chart: data } }, function (generator, position) {
                 if ((data.type === 'pie2d' || data.type === 'donut2d')) {
-                    var noShape = { line: ChartCreator.getNoneShape(), label: false };
-                    generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES,     position, { attrs: noShape, axis: 'x' });
-                    generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES,     position, { attrs: noShape, axis: 'y' });
-                    generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { attrs: noShape, axis: 'x' });
-                    generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { attrs: noShape, axis: 'y' });
-                    generator.generateDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES,    position, { attrs: { text: { link: [] } }, axis: 'x' });
-                    generator.generateDrawingOperation(Operations.SET_CHART_TITLE_ATTRIBUTES,    position, { attrs: { text: { link: [] } }, axis: 'y' });
+                    var noShape = { line: ChartCreator.getNoneShape(), axis: { label: false } };
+                    generateChartOperation(generator, chartModel, Operations.SET_CHART_AXIS_ATTRIBUTES,     position, { attrs: noShape, axis: 'x' });
+                    generateChartOperation(generator, chartModel, Operations.SET_CHART_AXIS_ATTRIBUTES,     position, { attrs: noShape, axis: 'y' });
+                    generateChartOperation(generator, chartModel, Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { attrs: noShape, axis: 'x' });
+                    generateChartOperation(generator, chartModel, Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { attrs: noShape, axis: 'y' });
+                    generateChartOperation(generator, chartModel, Operations.SET_CHART_TITLE_ATTRIBUTES,    position, { attrs: { text: { link: [] }, character: null }, axis: 'x' });
+                    generateChartOperation(generator, chartModel, Operations.SET_CHART_TITLE_ATTRIBUTES,    position, { attrs: { text: { link: [] }, character: null }, axis: 'y' });
                 }
             });
         }
 
+        function isFirstRowColEnabled(chartModel, rowCol) {
+            if (!chartModel) { return null; }
+
+            var possSources = chartModel.getDataSourceInfo();
+            if (possSources.warn) { return null; }
+            if (possSources.axis) { rowCol = Math.abs(rowCol - 1); }
+            if (rowCol === 1) {
+                return chartModel.isTitleLabel() || chartModel.getFirstPointsCount() > 1;
+            } else {
+                return chartModel.isNamesLabel() || chartModel.getSeriesCount() > 1;
+            }
+        }
+
         function isFirstRowCol(chartModel, rowCol) {
             if (!chartModel) { return null; }
 
@@ -298,6 +366,14 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
         }
 
+        function exchange(chartModel) {
+            var possSources = chartModel.getDataSourceInfo();
+            if (possSources.warn) {
+                return yellChartDirection(possSources.warn);
+            }
+            return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chartModel, 1 - possSources.axis, undefined, chartModel.isNamesLabel(), chartModel.isTitleLabel());
+        }
+
         function addAxisDef(axisId, defs) {
 
             var // the base path of axis items
@@ -312,11 +388,11 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             }
 
             function setAxisAttributes(chartModel, attrs) {
-                return createAndApplyDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, { axis: getCorrectAxisId(chartModel), attrs: attrs });
+                return createAndApplyChartOperation(chartModel, Operations.SET_CHART_AXIS_ATTRIBUTES, { axis: getCorrectAxisId(chartModel), attrs: attrs });
             }
 
             function setGridLineAttributes(chartModel, attrs) {
-                return createAndApplyDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, { axis: getCorrectAxisId(chartModel), attrs: attrs });
+                return createAndApplyChartOperation(chartModel, Operations.SET_CHART_GRIDLINE_ATTRIBUTES, { axis: getCorrectAxisId(chartModel), attrs: attrs });
             }
 
             // *** axis items ***
@@ -330,7 +406,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             // parent item providing access to the attributes of a chart axis model
             defs[keyPath + 'attributes'] = {
                 parent: [keyPath + 'model', 'drawing/chart'],
-                get: function (axisModel) { return axisModel ? axisModel.getMergedAttributes() : null; },
+                get: function (axisModel) { return axisModel ? axisModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) { return setAxisAttributes(this.getParentValue(1), attributes); }
             };
 
@@ -359,7 +435,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             // parent item providing access to the attributes of a chart axis grid model
             defs[keyPath + 'grid/attributes'] = {
                 parent: [keyPath + 'grid/model', 'drawing/chart'],
-                get: function (gridModel) { return gridModel ? gridModel.getMergedAttributes() : null; },
+                get: function (gridModel) { return gridModel ? gridModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) { return setGridLineAttributes(this.getParentValue(1), attributes); }
             };
 
@@ -381,22 +457,31 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             // parent item providing access to the attributes of a chart axis title model
             defs[keyPath + 'title/attributes'] = {
                 parent: [keyPath + 'title/model', 'drawing/chart'],
-                get: function (titleModel) { return titleModel ? titleModel.getMergedAttributes() : null; },
-                set: function (attributes) { return setChartTitleAttributes(getCorrectAxisId(this.getParentValue(1)), attributes); }
+                get: function (titleModel) { return titleModel ? titleModel.getMergedAttributeSet(true) : null; },
+                set: function (attributes) {
+                    var chartModel = this.getParentValue(1);
+                    return setChartTitleAttributes(chartModel, getCorrectAxisId(chartModel), attributes);
+                }
             };
 
             // return or modify the text contents of a chart axis title
             defs[keyPath + 'title/text'] = {
                 parent: [keyPath + 'title/attributes', 'drawing/chart'],
                 get: function (attributes) { return getChartTitle(attributes); },
-                set: function (title) { return setChartTitle(getCorrectAxisId(this.getParentValue(1)), title); }
+                set: function (title) {
+                    var chartModel = this.getParentValue(1);
+                    return setChartTitle(chartModel, getCorrectAxisId(chartModel), title);
+                }
             };
 
             // remove the main title from a chart (disabled if title does not exist)
             defs[keyPath + 'title/delete'] = {
                 parent: [keyPath + 'title/text', 'drawing/chart'],
                 enable: function () { return this.getValue().length > 0; },
-                set: function () { return setChartTitle(getCorrectAxisId(this.getParentValue(1)), ''); }
+                set: function () {
+                    var chartModel = this.getParentValue(1);
+                    return setChartTitle(chartModel, getCorrectAxisId(chartModel), '');
+                }
             };
         }
 
@@ -470,24 +555,20 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
                 enable: function (chartModel) { return chartModel.getSeriesCount() > 0; },
                 set: function () {
                     var chart = getDrawingModel('chart');
-                    var possSources = chart.getDataSourceInfo();
-                    if (possSources.warn) {
-                        return yellChartDirection(possSources.warn);
-                    }
-                    return ChartCreator.updateSeries(app, possSources.range, possSources.sheet, chart, 1 - possSources.axis);
+                    return exchange(chart);
                 }
             };
 
             defs['drawing/chartfirstcol'] = {
                 parent: 'drawing/chart',
-                enable: function (chartModel) { return chartModel.getSeriesCount() > 0; },
+                enable: function (chartModel) { return isFirstRowColEnabled(chartModel, 0); },
                 get: function (chartModel) { return isFirstRowCol(chartModel, 0); },
                 set: function (state) { return setFirstRowCol(getDrawingModel('chart'), 0, state); }
             };
 
             defs['drawing/chartfirstrow'] = {
                 parent: 'drawing/chart',
-                enable: function (chartModel) { return chartModel.getSeriesCount() > 0; },
+                enable: function (chartModel) { return isFirstRowColEnabled(chartModel, 1); },
                 get: function (chartModel) { return isFirstRowCol(chartModel, 1); },
                 set: function (state) { return setFirstRowCol(getDrawingModel('chart'), 1, state); }
             };
@@ -501,7 +582,7 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             // parent item providing access to the attributes of a chart model
             defs['drawing/chart/attributes'] = {
                 parent: 'drawing/chart',
-                get: function (chartModel) { return chartModel ? chartModel.getMergedAttributes() : null; },
+                get: function (chartModel) { return chartModel ? chartModel.getMergedAttributeSet(true) : null; },
                 set: function (attributes) { this.getParentValue().setAttributes(attributes); }
             };
 
@@ -515,12 +596,12 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
             defs['drawing/chartdatalabel'] = {
                 parent: ['drawing/chart', 'drawing/chart/attributes'],
                 get: function (chartModel, attributes) { return attributes ? attributes.chart.dataLabel : false; },
-                set: function (state) { return createAndApplyDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, { attrs: { chart: { dataLabel: state } } }); }
+                set: function (state) { return createAndApplyChartOperation(this.getParentValue(), Operations.SET_DRAWING_ATTRIBUTES, { attrs: { chart: { dataLabel: state } } }); }
             };
 
             defs['drawing/chartmarkeronly'] = {
                 parent: ['drawing/chart'],
-                enable: function (chartModel) { var data = chartModel ? chartModel.getMergedAttributes().chart : {}; return data.type === 'line2d' || data.type === 'scatter2d'; },
+                enable: function (chartModel) { var data = chartModel ? chartModel.getMergedAttributeSet(true).chart : {}; return data.type === 'line2d' || data.type === 'scatter2d'; },
                 get: function (chartModel) { return chartModel ? chartModel.isMarkerOnly() : false; },
                 set: function (state) { this.getParentValue().setMarkerOnly(state); }
             };
@@ -545,8 +626,8 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             defs['drawing/chartlegend/pos'] = {
                 parent: 'drawing/chart',
-                get: function (chartModel) { return chartModel ? chartModel.getLegendModel().getMergedAttributes().legend.pos : null; },
-                set: function (pos) { return createAndApplyDrawingOperation(Operations.SET_CHART_LEGEND_ATTRIBUTES, { attrs: { legend: { pos: pos } } }); }
+                get: function (chartModel) { return chartModel ? chartModel.getLegendModel().getMergedAttributeSet(true).legend.pos : null; },
+                set: function (pos) { return createAndApplyChartOperation(this.getParentValue(), Operations.SET_CHART_LEGEND_ATTRIBUTES, { attrs: { legend: { pos: pos } } }); }
             };
 
             defs['drawing/chart/axes/enabled'] = {
@@ -565,54 +646,54 @@ define('io.ox/office/spreadsheet/app/drawingcontroller', [
 
             // parent item providing access to the attributes of the main title model of a chart
             defs['drawing/chart/title/attributes'] = {
-                parent: 'drawing/chart/title/model',
-                get: function (titleModel) { return titleModel ? titleModel.getMergedAttributes() : null; },
-                set: function (attributes) { return setChartTitleAttributes('main', attributes); }
+                parent: ['drawing/chart/title/model', 'drawing/chart'],
+                get: function (titleModel) { return titleModel ? titleModel.getMergedAttributeSet(true) : null; },
+                set: function (attributes) { return setChartTitleAttributes(this.getParentValue(1), 'main', attributes); }
             };
 
             // return or modify the text contents of the main title of a chart
             defs['drawing/chart/title/text'] = {
-                parent: 'drawing/chart/title/attributes',
+                parent: ['drawing/chart/title/attributes', 'drawing/chart'],
                 get: function (attributes) { return getChartTitle(attributes); },
-                set: function (title) { return setChartTitle('main', title); }
+                set: function (title) { return setChartTitle(this.getParentValue(1), 'main', title); }
             };
 
             // remove the main title from a chart (disabled if title does not exist)
             defs['drawing/chart/title/delete'] = {
-                parent: 'drawing/chart/title/text',
+                parent: ['drawing/chart/title/text', 'drawing/chart'],
                 enable: function () { return this.getValue().length > 0; },
-                set: function () { return setChartTitle('main', ''); }
+                set: function () { return setChartTitle(this.getParentValue(1), 'main', ''); }
             };
 
             // IMAGE
 
             defs['drawing/border/style'] = {
                 parent: 'drawing/image',
-                get: function (imageModel) { return DrawingUtils.getPresetBorder(imageModel ? imageModel.getMergedAttributes().line : null); },
+                get: function (imageModel) { return DrawingUtils.getPresetBorder(imageModel ? imageModel.getMergedAttributeSet(true).line : null); },
                 set: function (preset) {
-                    var attributes = this.getParentValue().getMergedAttributes(),
+                    var attributes = this.getParentValue().getMergedAttributeSet(true),
                         options = { line: DrawingUtils.resolvePresetBorder(preset) };
 
                     if (attributes.line.color.type === 'auto') {
                         options.line.color = { type: 'rgb', value: '000000' };
                     }
 
-                    return docView.setDrawingAttributes(options);
+                    return docView.changeDrawings(options);
                 }
             };
 
             defs['drawing/border/color'] = {
                 parent: 'drawing/image',
-                get: function (imageModel) { return imageModel ? imageModel.getMergedAttributes().line.color : Color.AUTO; },
+                get: function (imageModel) { return imageModel ? imageModel.getMergedAttributeSet(true).line.color : Color.AUTO; },
                 set: function (color) {
-                    var attributes = this.getParentValue().getMergedAttributes(),
+                    var attributes = this.getParentValue().getMergedAttributeSet(true),
                         options = { line: { color: color } };
 
                     if (attributes.line.type !== 'solid') {
                         options.line.type = 'solid';
                     }
 
-                    return docView.setDrawingAttributes(options);
+                    return docView.changeDrawings(options);
                 }
             };
 
