@@ -6,18 +6,20 @@
  *
  * http://creativecommons.org/licenses/by-nc-sa/2.5/
  *
-  * © 2016 OX Software GmbH, Germany. info@open-xchange.com
+ * © 2016 OX Software GmbH, Germany. info@open-xchange.com
  *
  * @author Daniel Rentz <daniel.rentz@open-xchange.com>
  */
 
 define('io.ox/office/spreadsheet/main', [
-    'io.ox/office/spreadsheet/app/application'
-], function (SpreadsheetApplication) {
+    'io.ox/office/baseframework/app/applicationlauncher'
+], function (ApplicationLauncher) {
 
     'use strict';
 
-    // entry point for the OX AppSuite front-end to launch a new OX Spreadsheet instance
-    return SpreadsheetApplication.createLauncher();
+    return ApplicationLauncher.createLauncher('io.ox/office/spreadsheet', {
+        icon: 'fa-table',
+        trackingId: 'io.ox/spreadsheet-editor'
+    });
 
 });
