@@ -13,45 +13,36 @@
 
 define('io.ox/office/spreadsheet/model/drawing/axismodel', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/config',
     'io.ox/office/drawinglayer/view/chartstyleutil',
     'io.ox/office/editframework/model/attributedmodel',
-    'io.ox/office/spreadsheet/model/drawing/gridlinemodel',
-    'io.ox/office/spreadsheet/model/drawing/axistitlemodel'
-], function (Utils, Config, ChartStyleUtil, AttributedModel, GridlineModel, AxisTitleModel) {
+    'io.ox/office/spreadsheet/utils/operations',
+    'io.ox/office/spreadsheet/model/drawing/titlemodel',
+    'io.ox/office/spreadsheet/model/drawing/gridlinemodel'
+], function (Utils, ChartStyleUtil, AttributedModel, Operations, TitleModel, GridlineModel) {
 
     'use strict';
 
     // class AxisModel ========================================================
 
-    var PERCENTFORMAT = {
-        exp: -2,
-        format: '0%',
-        labelLength: 4
-    };
-
-    ///////////////////////////////////////////////////////////////////////////
-
     /**
-     * visualization model for chart axes,
-     * it defines colors and textual colors
+     * Representation of a simgle axis in a chart drawing object.
      *
      * @constructor
      *
      * @extends AttributedModel
      */
-    function AxisModel(chartModel, type, otherType) {
-        var self = this;
-        var title = null;
-        var zeroLine = null;
-        var grid = null;
-        var format = null;
-        var labelLen = 0;
+    var AxisModel = AttributedModel.extend({ constructor: function (chartModel, axisId, otherType) {
 
-        var dataAxis = chartModel.getModelData()['axis' + type.toUpperCase()];
+        var self = this;
+        var titleModel = null;
+        var gridModel = null;
+        var zeroLine = null;
+        var format = null;
+
+        var dataAxis = chartModel.getModelData()['axis' + axisId.toUpperCase()];
         if (dataAxis) {
-            grid = new GridlineModel(chartModel, {}, dataAxis);
-            title = new AxisTitleModel(chartModel);
+            titleModel = new TitleModel(chartModel, axisId);
+            gridModel = new GridlineModel(chartModel, axisId, {}, dataAxis);
 
             var otherAxis = chartModel.getModelData()['axis' + otherType.toUpperCase()];
             if (otherAxis.stripLines) {
@@ -66,103 +57,29 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
 
         AttributedModel.call(this, chartModel.getDocModel(), null, { families: 'axis line character' });
 
-        // methods ------------------------------------------------------------
+        // private methods ----------------------------------------------------
 
-        this.refreshInfo = function () {
-            labelLen = 0;
-            if (format) {
-                labelLen = format.labelLength;
-            }
-            refreshMinMax();
-
-            if (!dataAxis) { return; }
-
-            var attrs = this.getMergedAttributes();
-
-            ChartStyleUtil.handleLineProps(chartModel, attrs.line, dataAxis, 'line');
-            ChartStyleUtil.handleLineProps(chartModel, attrs.line, dataAxis, 'tick');
-
-            if (attrs.axis.label) {
-                ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, dataAxis, 'label');
-            } else {
-                dataAxis.labelFontColor = 'transparent';
-                dataAxis.labelFontSize = 1;
-            }
-
-            dataAxis.labelAutoFit = false;
-            dataAxis.labelAngle = 0;
-
-            var drawingType = chartModel.getAxisIdForDrawing(type);
-            if (drawingType === 'x') {
-                if (labelLen > 10) {
-                    dataAxis.labelAngle = -20;
-                }
-            } else {
-                if (labelLen > 10) {
-                    dataAxis.labelAutoFit = true;
-                }
-            }
-
-            if (zeroLine) {
-                zeroLine.color = dataAxis.lineColor;
-                zeroLine.thickness = dataAxis.lineThickness;
-            }
-
-            var overwriteLabels = false;
-            var stripLines = dataAxis.stripLines;
-            _.each(stripLines, function (stripLine) {
-                if (!stripLine.zero) {
-                    if (attrs.axis.label) {
-                        ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, stripLine, 'label');
-                    } else {
-                        stripLine.labelFontColor = 'transparent';
-                        stripLine.labelFontSize = 1;
-                    }
-                    overwriteLabels = true;
-                }
-            });
-            if (overwriteLabels) {
-                dataAxis.labelFontColor = 'transparent';
-            }
-
-            grid.refreshInfo();
-
-            var titleAtt = title.getMergedAttributes();
-            dataAxis.title = titleAtt.text.link[0];
-            if (dataAxis.title) {
-                ChartStyleUtil.handleCharacterProps(chartModel, titleAtt.character, dataAxis, 'title');
-            }
-
-        };
-
-        this.setFormat = function (newFormat) {
-            format = newFormat;
-        };
-
-        this.getGrid = function () {
-            return grid;
-        };
-
-        this.getTitle = function () {
-            return title;
-        };
-
-        this.registerDestructor(function () {
-            if (grid) {
-                grid.destroy();
-            }
-            if (title) {
-                title.destroy();
-            }
-            grid = title = null;
-        });
+        function isHorizontal() {
+            return chartModel.getAxisIdForDrawing(axisId) === 'x';
+        }
 
         function refreshMinMax() {
             var data = chartModel.getModelData();
             if (!data.series.length) {
                 return;
             }
-            if (type === 'x') {
+
+            if (isHorizontal()) {
+                if (format && format.format) {
+                    dataAxis.labelAutoFit = false;
+                } else {
+                    dataAxis.labelAutoFit = true;
+                }
+            } else {
+                dataAxis.labelAutoFit = true;
+            }
+
+            if (axisId === 'x') {
                 refreshAxisX(data);
             } else {
                 refreshAxisY(data);
@@ -187,31 +104,30 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         function distance(a, b) {
             return Math.abs(a - b);
         }
+
         function updateInterval(number) {
             var normalized = Utils.normalizeNumber(number);
 
-            var dist1 = distance(normalized.mant, 1);
-            var dist2 = distance(normalized.mant, 2);
-            var dist5 = distance(normalized.mant, 5);
+            var distances = [];
+            distances.push({ value: 1, dist: distance(normalized.mant, 1) });
+            distances.push({ value: 2, dist: distance(normalized.mant, 2) });
+            distances.push({ value: 5, dist: distance(normalized.mant, 5) });
+            distances.push({ value: 10, dist: distance(normalized.mant, 10) });
 
             var newMant = null;
-            if (dist1 < dist2) {
-                if (dist1 < dist5) {
-                    newMant = 1;
-                } else {
-                    newMant = 5;
+            var minDist = 999999;
+
+            distances.forEach(function (d) {
+                if (d.dist < minDist) {
+                    minDist = d.dist;
+                    newMant = d.value;
                 }
-            } else {
-                if (dist2 < dist5) {
-                    newMant = 2;
-                } else {
-                    newMant = 5;
-                }
-            }
+            });
+
             return newMant * Math.pow(10, normalized.exp);
         }
 
-        function updateMinMax(minValue, maxValue, precision, intervalCount, xAxis) {
+        function updateMinMax(minValue, maxValue, precision, intervalCount, xAxis, allLabels) {
             if (minValue < maxValue) {
                 var interval = (maxValue - minValue) / intervalCount;
                 interval = round(interval, precision - 1);
@@ -223,7 +139,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     dataAxis.maximum = maxValue;
                     dataAxis.interval = null;
                 } else {
-                    var intCount = parseFloat((maxValue - minValue) / interval);
+                    var intCount = 1 + ((maxValue - minValue) / interval);
 
                     if (Math.abs(maxValue) < Math.abs(minValue)) {
                         maxValue = Utils.roundUp(maxValue, interval);
@@ -233,11 +149,14 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                         maxValue = minValue + (interval * intCount);
                     }
                 }
-                setMinMax(minValue, maxValue, interval, undefined, xAxis);
+                setMinMax(minValue, maxValue, interval, xAxis, allLabels);
             }
         }
 
-        function setMinMax(min, max, interval, interlaced, xAxis) {
+        function setMinMax(min, max, interval, xAxis, allLabels) {
+
+            if (min < 0 && format && format.format && format.format.category === 'date') { min = 0; }
+
             dataAxis.minimum = min;
             dataAxis.maximum = max;
             dataAxis.interval = interval;
@@ -261,7 +180,6 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             var formatter = chartModel.getDocModel().getNumberFormatter();
             var steps = (dataAxis.maximum - dataAxis.minimum) / dataAxis.interval;
             var lastLine = null;
-            labelLen = 0;
             var line = null;
 
             for (i = 0; i <= steps; i += 1) {
@@ -277,22 +195,24 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                         value: 0,
                         color: 'transparent',
                         label: '',
-                        labelBackgroundColor: 'transparent'
+                        labelBackgroundColor: 'transparent',
+                        labelPlacement: 'outside'
                     };
                     stripLines[index] = line;
                 }
                 line.labelFontColor = 'transparent';
                 line.label = '';
                 line.value = value;
+                line.labelPlacement = 'outside';
 
-                if (!interlaced || (index % 2)) {
+                if (allLabels || dataAxis.labelAutoFit || (index % 2)) {
                     var realValue = value * Math.pow(10, format.exp);
                     if (format && format.format) {
-                        line.label = formatter.formatValue(realValue, format.format);
+                        line.label = formatter.formatValue(format.format, realValue);
                     } else {
                         line.label = formatter.formatStandardNumber(realValue, 8);
                     }
-                    if (lastLine && lastLine.label === line.label) {
+                    if (!line.label || (lastLine && lastLine.label === line.label)) {
                         line.label = '';
                         lastLine = null;
                     } else {
@@ -307,7 +227,6 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                         }
                     }
                 }
-                labelLen = Math.max(labelLen, line.label.length);
                 index++;
             }
             for (; index < stripLines.length; index++) {
@@ -318,19 +237,20 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         }
 
         function refreshAxisX(data) {
-            var area = chartModel.getMergedAttributes().chart.type.indexOf('area') === 0;
+            var area = chartModel.getMergedAttributeSet(true).chart.type.indexOf('area') === 0;
             if (!data.linearX && (chartModel.isXYType() || area)) {
                 var minValue = Number.POSITIVE_INFINITY;
                 var maxValue = Number.NEGATIVE_INFINITY;
 
                 _.each(data.series, function (dd) {
                     _.each(dd.dataPoints, function (dataPoint) {
-                        var value = dataPoint[type];
+                        var value = dataPoint[axisId];
                         minValue = Math.min(minValue, value);
                         maxValue = Math.max(maxValue, value);
                     });
                 });
 
+                // TODO: disable this block to reproduce Bug 46447
                 if (chartModel.isXYType()) {
                     var intervalCount = Utils.minMax(data.series.length, 2, 8);
                     var diff = maxValue - minValue;
@@ -347,9 +267,9 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     minValue -= 0.5;
                 }
 
-                updateMinMax(minValue, maxValue, 2, 4, true);
+                updateMinMax(minValue, maxValue, 2, 4, true, area);
             } else {
-                setMinMax(null, null, null, null, true);
+                setMinMax(null, null, null, true);
             }
         }
 
@@ -361,13 +281,13 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
         }
 
         function refreshAxisY(data) {
-            var chartAttrs = chartModel.getMergedAttributes().chart;
+            var chartAttrs = chartModel.getMergedAttributeSet(true).chart;
             var stacking = chartAttrs.stacking;
 
             var givenMin = null;
             var givenMax = null;
 
-            var axisInfo = self.getMergedAttributes();
+            var axisInfo = self.getMergedAttributeSet(true);
             if (axisInfo) {
                 if (axisInfo.min !== 'auto') {
                     givenMin = axisInfo.min;
@@ -387,7 +307,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                     _.each(data.series, function (dd) {
                         var jValue = dd.dataPoints[j];
                         if (!jValue) { return; }
-                        var useValue = jValue[type];
+                        var useValue = jValue[axisId];
                         value += useValue;
                     });
                     minValue = Math.min(minValue, value);
@@ -396,7 +316,7 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             } else {
                 _.each(data.series, function (dd) {
                     _.each(dd.dataPoints, function (dataPoint) {
-                        var value = dataPoint[type];
+                        var value = dataPoint[axisId];
                         minValue = Math.min(minValue, value);
                         maxValue = Math.max(maxValue, value);
                     });
@@ -411,7 +331,10 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
                 minValue -= diff / 8;
             } else if (stacking === 'percentStacked') {
                 ignoreMax = true;
-                format = PERCENTFORMAT;
+                format = {
+                    exp: -2,
+                    format: chartModel.getDocModel().getNumberFormatter().getParsedFormat('0%', { grammarId: 'ui' })
+                };
                 //Trial & error...
                 if (maxValue >= 0 && minValue >= 0) {
                     // scenario 1
@@ -467,10 +390,110 @@ define('io.ox/office/spreadsheet/model/drawing/axismodel', [
             updateMinMax(minValue, maxValue, precision, 8, ignoreMax);
         }
 
-    } // class AxisModel
+        // public methods -----------------------------------------------------
+
+        this.refreshInfo = function () {
+            refreshMinMax();
+
+            if (!dataAxis) { return; }
+
+            var attrs = this.getMergedAttributeSet(true);
+
+            ChartStyleUtil.handleLineProps(chartModel, attrs.line, dataAxis, 'line');
+            ChartStyleUtil.handleLineProps(chartModel, attrs.line, dataAxis, 'tick');
+
+            if (attrs.axis.label) {
+                ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, dataAxis, 'label');
+            } else {
+                dataAxis.labelFontColor = 'transparent';
+                dataAxis.labelFontSize = 1;
+            }
+
+            if (zeroLine) {
+                zeroLine.color = dataAxis.lineColor;
+                zeroLine.thickness = dataAxis.lineThickness;
+            }
+
+            var overwriteLabels = false;
+            var stripLines = dataAxis.stripLines;
+            _.each(stripLines, function (stripLine) {
+                if (!stripLine.zero) {
+                    if (attrs.axis.label) {
+                        ChartStyleUtil.handleCharacterProps(chartModel, attrs.character, stripLine, 'label');
+                    } else {
+                        stripLine.labelFontColor = 'transparent';
+                        stripLine.labelFontSize = 1;
+                    }
+                    overwriteLabels = true;
+                }
+            });
+            if (overwriteLabels) {
+                dataAxis.labelFontColor = 'transparent';
+            }
+
+            gridModel.refreshInfo();
+
+            var titleAtt = titleModel.getMergedAttributeSet(true);
+            dataAxis.title = titleAtt.text.link[0];
+            if (dataAxis.title) {
+                ChartStyleUtil.handleCharacterProps(chartModel, titleAtt.character, dataAxis, 'title');
+            }
+        };
+
+        this.setFormat = function (newFormat) {
+            format = newFormat;
+        };
+
+        this.getGrid = function () {
+            return gridModel;
+        };
+
+        this.getTitle = function () {
+            return titleModel;
+        };
+
+        // operation generators -----------------------------------------------
+
+        /**
+         * Generates the undo operations needed to restore this chart axis.
+         *
+         * @param {SheetOperationsGenerator} generator
+         *  The operations generator to be filled with the undo operations.
+         *
+         * @param {Array<Number>} position
+         *  The position of the parent chart object in the sheet, as expected
+         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *
+         * @returns {AxisModel}
+         *  A reference to this instance.
+         */
+        this.generateRestoreOperations = function (generator, position) {
+
+            // restore this axis
+            if (this.hasExplicitAttributes()) {
+                var properties = { axis: axisId, attrs: this.getExplicitAttributeSet(true) };
+                generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, properties, { undo: true });
+            }
+
+            // restore the axis title, and the grid line settings
+            if (titleModel) { titleModel.generateRestoreOperations(generator, position); }
+            if (gridModel) { gridModel.generateRestoreOperations(generator, position); }
+
+            return this;
+        };
+
+        // initialization -----------------------------------------------------
+
+        this.registerDestructor(function () {
+            if (gridModel) { gridModel.destroy(); }
+            if (titleModel) { titleModel.destroy(); }
+            chartModel = gridModel = titleModel = null;
+        });
+
+    } }); // class AxisModel
 
     // exports ================================================================
 
-    return AttributedModel.extend({ constructor: AxisModel });
+    return AxisModel;
 
 });
