@@ -13,14 +13,16 @@
 
 define('io.ox/office/spreadsheet/model/drawing/legendmodel', [
     'io.ox/office/drawinglayer/view/chartstyleutil',
-    'io.ox/office/editframework/model/attributedmodel'
-], function (ChartStyleUtil, AttributedModel) {
+    'io.ox/office/editframework/model/attributedmodel',
+    'io.ox/office/spreadsheet/utils/operations'
+], function (ChartStyleUtil, AttributedModel, Operations) {
 
     'use strict';
 
     // class LegendModel ======================================================
 
     /**
+     * Representation of a legend in a chart drawing object.
      *
      * @constructor
      *
@@ -34,11 +36,11 @@ define('io.ox/office/spreadsheet/model/drawing/legendmodel', [
 
         AttributedModel.call(this, chartModel.getDocModel(), attrs, { families: 'legend character' });
 
-        // methods ------------------------------------------------------------
+        // public methods -----------------------------------------------------
 
         this.refreshInfo = function () {
-            var att = self.getMergedAttributes();
-            var legendPos = att.legend.pos;
+            var attributeSet = self.getMergedAttributeSet(true);
+            var legendPos = attributeSet.legend.pos;
             switch (legendPos) {
                 case 'bottom':
                 case 'top':
@@ -51,16 +53,39 @@ define('io.ox/office/spreadsheet/model/drawing/legendmodel', [
                     dataLegend.horizontalAlign = legendPos;
                     break;
                 case 'topRight':
-                    dataLegend.verticalAlign = 'top';
+                    dataLegend.verticalAlign = 'center';
                     dataLegend.horizontalAlign = 'right';
                     break;
             }
 
             if (legendPos !== 'off') {
-                ChartStyleUtil.handleCharacterProps(chartModel, att.character, dataLegend);
+                ChartStyleUtil.handleCharacterProps(chartModel, attributeSet.character, dataLegend);
             }
         };
 
+        // operation generators -----------------------------------------------
+
+        /**
+         * Generates the undo operations needed to restore this chart legend.
+         *
+         * @param {SheetOperationsGenerator} generator
+         *  The operations generator to be filled with the undo operations.
+         *
+         * @param {Array<Number>} position
+         *  The position of the parent chart object in the sheet, as expected
+         *  by the method SheetOperationsGenerator.generateDrawingOperation().
+         *
+         * @returns {LegendModel}
+         *  A reference to this instance.
+         */
+        this.generateRestoreOperations = function (generator, position) {
+            if (this.hasExplicitAttributes()) {
+                var properties = { attrs: this.getExplicitAttributeSet(true) };
+                generator.generateDrawingOperation(Operations.SET_CHART_LEGEND_ATTRIBUTES, position, properties, { undo: true });
+            }
+            return this;
+        };
+
     } // class LegendModel
 
     // exports ================================================================
