@@ -140,7 +140,7 @@ define('io.ox/office/spreadsheet/model/drawing/manualcolorchart', [
         }
 
         function getColor(index, type, count) {
-            var attributes = chartModel.getMergedAttributes();
+            var attributes = chartModel.getMergedAttributeSet(true);
 
             var colors = attributes.chart.chartColors;
 
@@ -163,7 +163,7 @@ define('io.ox/office/spreadsheet/model/drawing/manualcolorchart', [
         }
 
         function getStyleSet(dataSeries, color) {
-            var attributes = chartModel.getMergedAttributes();
+            var attributes = chartModel.getMergedAttributeSet(true);
 
             var result = color;
             var styleId = null;
@@ -194,7 +194,7 @@ define('io.ox/office/spreadsheet/model/drawing/manualcolorchart', [
 
         function getVaryColor() {
             if (self.isVaryColorEnabled()) {
-                var attributes = chartModel.getMergedAttributes();
+                var attributes = chartModel.getMergedAttributeSet(true);
                 return attributes.chart.varyColors;
             }
             return false;
@@ -231,7 +231,7 @@ define('io.ox/office/spreadsheet/model/drawing/manualcolorchart', [
 
         this.handleColor = function (shape, dataSeries, index, targetKey, count) {
             var vary = getVaryColor();
-            var attributes = chartModel.getMergedAttributes();
+            var attributes = chartModel.getMergedAttributeSet(true);
 
             _.each(dataSeries.dataPoints, function (dataPoint) {
                 dataPoint[targetKey] = null;
