@@ -17,8 +17,9 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
     'io.ox/office/editframework/utils/border',
     'io.ox/office/drawinglayer/model/drawingstylecollection',
     'io.ox/office/spreadsheet/model/cellstylecollection',
-    'io.ox/office/spreadsheet/model/tablestylecollection'
-], function (Utils, Color, Border, DrawingStyleCollection, CellStyleCollection, TableStyleCollection) {
+    'io.ox/office/spreadsheet/model/tablestylecollection',
+    'io.ox/office/spreadsheet/model/cellautostylecollection'
+], function (Utils, Color, Border, DrawingStyleCollection, CellStyleCollection, TableStyleCollection, CellAutoStyleCollection) {
 
     'use strict';
 
@@ -36,6 +37,12 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         rows: { def: 1048576 },
 
+        /**
+         * Specifies whether all formulas in the document shall be relaculated
+         * once after import.
+         */
+        calcOnLoad: { def: false },
+
         // view attributes
 
         /**
@@ -50,44 +57,43 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
 
         /**
          * Name of the font family used to render the cell contents. Bound to
-         * the apply flag 'font' of a cell style sheet.
+         * the apply flag 'font'.
          */
         fontName: { def: 'Arial', apply: 'font' },
 
         /**
          * Size of the font used to render the cell contents, in points. Bound
-         * to the apply flag 'font' of a cell style sheet.
+         * to the apply flag 'font'.
          */
         fontSize: { def: 11, apply: 'font' },
 
         /**
          * Specifies whether to render the cell contents with bold characters.
-         * Bound to the apply flag 'font' of a cell style sheet.
+         * Bound to the apply flag 'font'.
          */
         bold: { def: false, apply: 'font' },
 
         /**
          * Specifies whether to render the cell contents with italic
-         * characters. Bound to the apply flag 'font' of a cell style sheet.
+         * characters. Bound to the apply flag 'font'.
          */
         italic: { def: false, apply: 'font' },
 
         /**
          * Specifies whether to underline the cell contents. Bound to the apply
-         * flag 'font' of a cell style sheet.
+         * flag 'font'.
          */
         underline: { def: false, apply: 'font' },
 
         /**
          * Specifies whether to strike the cell contents. Supported values are
-         * 'none', 'single', and 'double'. Bound to the apply flag 'font' of a
-         * cell style sheet.
+         * 'none', 'single', and 'double'. Bound to the apply flag 'font'.
          */
         strike: { def: 'none', apply: 'font' },
 
         /**
          * Text color used to render the cell contents, underlines, and strike
-         * lines. Bound to the apply flag 'font' of a cell style sheet.
+         * lines. Bound to the apply flag 'font'.
          */
         color: { def: Color.AUTO, apply: 'font' }
     };
@@ -98,147 +104,138 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
 
         /**
          * Horizontal alignment of the text contents in the cell. Bound to the
-         * apply flag 'align' of a cell style sheet.
+         * apply flag 'align'.
          */
         alignHor: { def: 'auto', apply: 'align' },
 
         /**
          * Vertical alignment of the text contents in the cell. Bound to the
-         * apply flag 'align' of a cell style sheet.
+         * apply flag 'align'.
          */
         alignVert: { def: 'bottom', apply: 'align' },
 
         /**
          * Specifies whether to break long text automatically into multiple
          * text lines. Has no effect on non-text cell results. Bound to the
-         * apply flag 'align' of a cell style sheet.
+         * apply flag 'align'.
          */
         wrapText: { def: false, apply: 'align' },
 
         /**
-         * The number format code, and/or identifier of a predefined number
-         * format, as object with the string property 'code', and index
-         * property 'id'. Bound to the apply flag 'number' of a cell style
-         * sheet.
+         * The identifier of a number format code (used in OOXML together with
+         * the operation 'insertNumberFormat'). Bound to the apply flag
+         * 'number'.
          */
-        numberFormat: { def: { id: 0 }, apply: 'number' },
+        formatId: { def: 0, apply: 'number' },
 
         /**
-         * The fill color for the cell area. Bound to the apply flag 'fill' of
-         * a cell style sheet.
+         * An explicit number format code, used in ODF, and in contexts where
+         * the number format has not been created with the operation
+         * 'insertNumberFormat' (e.g. in conditional formatting rules). Bound
+         * to the apply flag 'number'.
+         */
+        formatCode: { def: 'General', apply: 'number' },
+
+        /**
+         * The fill color for the cell area. Bound to the apply flag 'fill'.
          */
         fillColor: { def: Color.AUTO, apply: 'fill' },
 
         /**
          * The style of the left border of the cell. Bound to the apply flag
-         * 'border' of a cell style sheet.
+         * 'border'.
          */
         borderLeft: { def: Border.NONE, apply: 'border' },
 
         /**
          * The style of the right border of the cell. Bound to the apply flag
-         * 'border' of a cell style sheet.
+         * 'border'.
          */
         borderRight: { def: Border.NONE, apply: 'border' },
 
         /**
          * The style of the top border of the cell. Bound to the apply flag
-         * 'border' of a cell style sheet.
+         * 'border'.
          */
         borderTop: { def: Border.NONE, apply: 'border' },
 
         /**
          * The style of the bottom border of the cell. Bound to the apply flag
-         * 'border' of a cell style sheet.
+         * 'border'.
          */
         borderBottom: { def: Border.NONE, apply: 'border' },
 
         /**
          * The style of the diagonal border of the cell from top-left corner to
-         * bottom-right corner. Bound to the apply flag 'border' of a cell
-         * style sheet.
+         * bottom-right corner. Bound to the apply flag 'border'.
          */
         borderDown: { def: Border.NONE, apply: 'border' },
 
         /**
          * The style of the diagonal border of the cell from bottom-left corner
-         * to top-right corner. Bound to the apply flag 'border' of a cell
-         * style sheet.
+         * to top-right corner. Bound to the apply flag 'border'.
          */
         borderUp: { def: Border.NONE, apply: 'border' },
 
-        /**
-         * The style of the inner horizontal borders of an entire cell range.
-         * Will be copied to the attributes 'topBorder' and/or 'bottomBorder'
-         * according to the position of a cell in the range to be formatted.
-         * Cannot be inserted into a cell style sheet.
-         */
-        borderInsideHor: { def: Border.NONE, scope: 'element' },
-
-        /**
-         * The style of the inner vertical borders of an entire cell range.
-         * Will be copied to the attributes 'leftBorder' and/or 'rightBorder'
-         * according to the position of a cell in the range to be formatted.
-         * Cannot be inserted into a cell style sheet.
-         */
-        borderInsideVert: { def: Border.NONE, scope: 'element' },
-
         /**
          * Specifies whether the cell is unlocked. Locked cells in locked
          * sheets cannot be modified. Has no effect in unlocked sheets. Bound
-         * to the apply flag 'protect' of a cell style sheet.
+         * to the apply flag 'protect'.
          */
         unlocked: { def: false, apply: 'protect' },
 
         /**
          * Specifies whether the formula expression of a formula cell will be
          * hidden in the user interface of a locked sheet. Has no effect in
-         * unlocked sheets. Bound to the apply flag 'protect' of a cell style
-         * sheet.
+         * unlocked sheets. Bound to the apply flag 'protect'.
          */
         hidden: { def: false, apply: 'protect' }
     };
 
     // definitions for apply group flags --------------------------------------
 
+    // used in OOXML only!
     var APPLY_ATTRIBUTE_DEFINITIONS = {
 
         /**
-         * If part of a cell style sheet, specifies whether the font attributes
-         * of the style will overwrite explicit attributes of the target cell.
+         * Specifies whether the font attributes of the style sheet will reset
+         * explicit attributes of the target cell; or whether font attributes
+         * of a cell have been changed manually.
          */
         font: { def: true },
 
         /**
-         * If part of a cell style sheet, specifies whether the fill color of
-         * the style will overwrite the explicit fill color of the target cell.
+         * Specifies whether the fill attributes of the style sheet will reset
+         * explicit attributes of the target cell; or whether fill attributes
+         * of a cell have been changed manually.
          */
         fill: { def: true },
 
         /**
-         * If part of a cell style sheet, specifies whether the border
-         * attributes of the style will overwrite the border attributes of the
-         * target cell.
+         * Specifies whether the border attributes of the style sheet will
+         * reset explicit attributes of the target cell; or whether border
+         * attributes of a cell have been changed manually.
          */
         border: { def: true },
 
         /**
-         * If part of a cell style sheet, specifies whether the alignment
-         * attributes of the style will overwrite the alignment attributes of
-         * the target cell.
+         * Specifies whether the alignment attributes of the style sheet will
+         * reset explicit attributes of the target cell; or whether alignment
+         * attributes of a cell have been changed manually.
          */
         align: { def: true },
 
         /**
-         * If part of a cell style sheet, specifies whether the number format
-         * of the style will overwrite the number format of the target cell.
+         * Specifies whether the number format of the style sheet will reset
+         * explicit attributes of the target cell; or whether the number format
+         * of a cell has been changed manually.
          */
         number: { def: true },
 
         /**
-         * If part of a cell style sheet, specifies whether the protection
-         * flags of the style will overwrite the protection flags of the target
-         * cell.
+         * Specifies whether the protection flags of the style sheet will reset
+         * explicit attributes of the target cell; or whether protection flags
+         * of a cell have been changed manually.
          */
         protect: { def: true }
     };
@@ -250,12 +247,12 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         /**
          * Specifies whether the column is visible in the GUI.
          */
-        visible: { def: true },
+        visible: { def: true, resize: true },
 
         /**
          * The width of the column, in 1/100 mm.
          */
-        width: { def: 2000 },
+        width: { def: 2000, resize: true },
 
         /**
          * Specifies whether the width of the column has been set or changed in
@@ -271,12 +268,12 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         /**
          * Specifies whether the row is visible in the GUI.
          */
-        visible: { def: true },
+        visible: { def: true, resize: true },
 
         /**
          * The height of the row, in 1/100 mm.
          */
-        height: { def: 500 },
+        height: { def: 500, resize: true },
 
         /**
          * Specifies whether the height of the row has been set or changed in
@@ -297,7 +294,7 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          * (auto-filter, or filtered table range). The row will be hidden
          * although the attribute 'visible' is true. Used by ODF only!
          */
-        filtered: { def: false }
+        filtered: { def: false, resize: true }
     };
 
     // definitions for sheet attributes ---------------------------------------
@@ -587,6 +584,23 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         value2: { def: '' },
 
+        /**
+         * A data structure that describes the start point, the end point, and
+         * an arbitrary number of additional points inbetween a color scale
+         * rule.
+         */
+        colorScale: { def: [] },
+
+        /**
+         * A data structure that describes a data bar rule.
+         */
+        dataBar: { def: {} },
+
+        /**
+         * A data structure that describes an icon set rule.
+         */
+        iconSet: { def: {} },
+
         /**
          * The sheet-global priority of this rule among all formatting rules in
          * the sheet. The lower this value, the higher the priority. Rules with
@@ -598,7 +612,15 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          * Specifies whether to stop evaluating other formatting rules matching
          * a specific cell, if the conditions of this rule has matched.
          */
-        stop: { def: false }
+        stop: { def: false },
+
+        /**
+         * An incomplete formatting attribute set containing cell attributes,
+         * character attributes, and the identifier of a style sheet. If the
+         * conditions of the rule are matching, these attributes will be used
+         * to render in the respective cell, above its own attributes.
+         */
+        attrs: { def: {} }
     };
 
     // additional definitions for drawing attributes --------------------------
@@ -677,18 +699,31 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
         // the style sheet collection for cells, columns, and rows
         var cellStyles = null;
 
+        // the auto-style collection for cells, columns, and rows
+        var cellAutoStyles = null;
+
         // public methods -----------------------------------------------------
 
         /**
          * Returns the cell style collection of this document.
          *
-         * @returns {StyleCollection}
+         * @returns {CellStyleCollection}
          *  The cell style collection of this document.
          */
         this.getCellStyles = function () {
             return cellStyles;
         };
 
+        /**
+         * Returns the cell auto-style collection of this document.
+         *
+         * @returns {AutoStyleCollection}
+         *  The cell auto-style collection of this document.
+         */
+        this.getCellAutoStyles = function () {
+            return cellAutoStyles;
+        };
+
         /**
          * Returns the default column width for all undefined columns in a
          * sheet, according to the font settings in the current default cell
@@ -702,10 +737,14 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         this.getDefaultColWidthHmm = function (baseWidth) {
 
-            var charAttributes = cellStyles.getDefaultStyleAttributeSet().character,
-                maxDigitWidth = this.getFontCollection().getDigitWidths(charAttributes).maxWidth,
-                colWidth = maxDigitWidth * baseWidth + 5;
+            // attributes of the default cell style (NOT the default auto-style!)
+            var charAttributes = cellStyles.getDefaultStyleAttributeSet().character;
 
+            // the maximum pixel width of any of the digits of the default font
+            var maxDigitWidth = this.getFontCollection().getDigitWidths(charAttributes).maxWidth;
+
+            // the resulting column width, calculated from baseWidth and the actual digit width
+            var colWidth = maxDigitWidth * baseWidth + 5;
             return Utils.convertLengthToHmm(colWidth, 'px');
         };
 
@@ -724,8 +763,8 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
          */
         this.getRowHeightHmm = function (charAttributes) {
 
-            var // the normal line height according to the font settings
-                lineHeight = this.getFontCollection().getNormalLineHeight(charAttributes);
+            // the normal line height according to the font settings
+            var lineHeight = this.getFontCollection().getNormalLineHeight(charAttributes);
 
             // use at least 125% of the font size, to compensate for browsers
             // reporting very small line heights (especially Chrome)
@@ -786,9 +825,11 @@ define('io.ox/office/spreadsheet/model/modelattributesmixin', [
             .addStyleCollection(new TableStyleCollection(this))
             .addStyleCollection(new DrawingStyleCollection(this));
 
+        this.addAutoStyleCollection(cellAutoStyles = new CellAutoStyleCollection(this));
+
         // destroy class members on destruction
         this.registerDestructor(function () {
-            cellStyles = null;
+            cellStyles = cellAutoStyles = null;
         });
 
     } // class ModelAttributesMixin
