@@ -27,8 +27,12 @@ define('io.ox/office/spreadsheet/model/viewsettingsmixin', [
      * Triggers the following events:
      * - 'change:viewattributes'
      *      After at least one view attribute has been changed. Event handlers
-     *      receive an incomplete attribute map containing all changed view
-     *      attributes with their new values.
+     *      receive the following parameters:
+     *      (1) {jQuery.Event} event
+     *          The jQuery event object.
+     *      (2) {Object} changedAttributes
+     *          An incomplete attribute map containing all changed view
+     *          attributes with their new values.
      *
      * @constructor
      *
@@ -53,11 +57,11 @@ define('io.ox/office/spreadsheet/model/viewsettingsmixin', [
      */
     function ViewSettingsMixin(definitions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the current view attributes of this object
-            viewAttributes = Utils.mapProperties(definitions, function (definition) { return definition.def; });
+        // the current view attributes of this object
+        var viewAttributes = Utils.mapProperties(definitions, function (definition) { return definition.def; });
 
         // public methods -----------------------------------------------------
 
@@ -100,8 +104,8 @@ define('io.ox/office/spreadsheet/model/viewsettingsmixin', [
          */
         this.setViewAttributes = function (attributes) {
 
-            var // all changed attributes, for listeners
-                changedAttributes = {};
+            // all changed attributes, for listeners
+            var changedAttributes = {};
 
             _.each(attributes, function (value, name) {
                 if (name in definitions) {
