@@ -17,26 +17,26 @@ define('io.ox/office/spreadsheet/utils/address', [
 
     'use strict';
 
-    var // maximum number of columns that will ever be allowed in a sheet (A to ZZZZ)
-        MAX_COL_COUNT = 475254,
+    // maximum number of columns that will ever be allowed in a sheet (A to ZZZZ)
+    var MAX_COL_COUNT = 475254;
 
-        // maximum number of rows that will ever be allowed in a sheet (1 to 99,999,999)
-        MAX_ROW_COUNT = 99999999,
+    // maximum number of rows that will ever be allowed in a sheet (1 to 99,999,999)
+    var MAX_ROW_COUNT = 99999999;
 
-        // regular expression pattern matching a valid column name (A to ZZZZ)
-        COL_PATTERN = '[A-Z]{1,4}',
+    // regular expression pattern matching a valid column name (A to ZZZZ)
+    var COL_PATTERN = '[A-Z]{1,4}';
 
-        // regular expression pattern matching a row name (1 to 99,999,999)
-        ROW_PATTERN = '0*[1-9][0-9]{0,7}',
+    // regular expression pattern matching a row name (1 to 99,999,999)
+    var ROW_PATTERN = '0*[1-9][0-9]{0,7}';
 
-        // regular expression object matching a column name only
-        RE_COL_NAME = new RegExp('^' + COL_PATTERN + '$', 'i'),
+    // regular expression object matching a column name only
+    var RE_COL_NAME = new RegExp('^' + COL_PATTERN + '$', 'i');
 
-        // regular expression object matching a row name only
-        RE_ROW_NAME = new RegExp('^' + ROW_PATTERN + '$'),
+    // regular expression object matching a row name only
+    var RE_ROW_NAME = new RegExp('^' + ROW_PATTERN + '$');
 
-        // regular expression object matching a cell name
-        RE_CELL_NAME = new RegExp('^(' + COL_PATTERN + ')(' + ROW_PATTERN + ')$', 'i');
+    // regular expression object matching a cell name
+    var RE_CELL_NAME = new RegExp('^(' + COL_PATTERN + ')(' + ROW_PATTERN + ')$', 'i');
 
     // class Address ==========================================================
 
@@ -154,11 +154,15 @@ define('io.ox/office/spreadsheet/utils/address', [
      * @param {String} str
      *  The string representation of a column (case-insensitive).
      *
+     * @param {Number} [max]
+     *  If specified, the zero-based index of the largest allowed column index.
+     *  If the parsed column index is greater, this method will return -1.
+     *
      * @returns {Number}
      *  The zero-based column index, if the passed string is valid, otherwise
      *  the value -1.
      */
-    Address.parseCol = function (str) {
+    Address.parseCol = function (str, max) {
         var col = -1;
         if (RE_COL_NAME.test(str)) {
             str = str.toUpperCase();
@@ -166,7 +170,7 @@ define('io.ox/office/spreadsheet/utils/address', [
                 col = (col + 1) * 26 + str.charCodeAt(ichar) - 65;
             }
         }
-        return (col < MAX_COL_COUNT) ? col : -1;
+        return ((typeof max === 'number') ? (col <= max) : (col < MAX_COL_COUNT)) ? col : -1;
     };
 
     /**
@@ -175,13 +179,17 @@ define('io.ox/office/spreadsheet/utils/address', [
      * @param {String} str
      *  The string representation of a row (one-based).
      *
+     * @param {Number} [max]
+     *  If specified, the zero-based index of the largest allowed row index. If
+     *  the parsed row index is greater, this method will return -1.
+     *
      * @returns {Number}
      *  The zero-based row index, if the passed string is valid, otherwise the
      *  value -1.
      */
-    Address.parseRow = function (str) {
+    Address.parseRow = function (str, max) {
         var row = RE_ROW_NAME.test(str) ? (parseInt(str, 10) - 1) : -1;
-        return (row < MAX_ROW_COUNT) ? row : -1;
+        return ((typeof max === 'number') ? (row <= max) : (row < MAX_ROW_COUNT)) ? row : -1;
     };
 
     /**
@@ -190,13 +198,19 @@ define('io.ox/office/spreadsheet/utils/address', [
      * @param {String} str
      *  The string representation of a cell address, in A1 notation.
      *
+     * @param {Address} [max]
+     *  If specified, the largest allowed cell address. If the column index, or
+     *  the row index in the parsed cell address is greater, this method will
+     *  return null.
+     *
      * @returns {Address|Null}
      *  The cell address, if the passed string is valid, otherwise null.
      */
-    Address.parse = function (str) {
+    Address.parse = function (str, max) {
         var matches = RE_CELL_NAME.exec(str);
         if (!matches) { return null; }
-        var col = Address.parseCol(matches[1]), row = Address.parseRow(matches[2]);
+        var col = Address.parseCol(matches[1], max ? max[0] : null);
+        var row = Address.parseRow(matches[2], max ? max[1] : null);
         return ((col >= 0) && (row >= 0)) ? new Address(col, row) : null;
     };
 
@@ -222,8 +236,42 @@ define('io.ox/office/spreadsheet/utils/address', [
         return Utils.comparePairs(address1[1], address1[0], address2[1], address2[0]);
     };
 
+    /**
+     * Compares the passed cell addresses. Defines a natural order for sorting
+     * with the following behavior (let A and B be cell addresses): If the
+     * column index of A is less than the column index of B; or if both column
+     * indexes are equal, and the row index of A is less than the row index of
+     * B, then A is considered less than B (vertically ordered cell addresses).
+     *
+     * @param {Address} address1
+     *  The first cell address to be compared to the second cell address.
+     *
+     * @param {Address} address2
+     *  The second cell address to be compared to the first cell address.
+     *
+     * @returns {Number}
+     *  - A negative number, if address1 is less than address2.
+     *  - A positive number, if address1 is greater than address2.
+     *  - Zero, if both cell addresses are equal.
+     */
+    Address.compareVert = function (address1, address2) {
+        return Utils.comparePairs(address1[0], address1[1], address2[0], address2[1]);
+    };
+
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this cell address that can be used for
+     * example as key in an associative map. This method is faster than the
+     * method Address.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this cell address.
+     */
+    Address.prototype.key = function () {
+        return Address.key(this[0], this[1]);
+    };
+
     /**
      * Creates a clone of this cell address.
      *
@@ -278,6 +326,24 @@ define('io.ox/office/spreadsheet/utils/address', [
         return Address.compare(this, address);
     };
 
+    /**
+     * Compares this cell address with the passed cell address. See static
+     * method Address.compareVert() for details.
+     *
+     * @param {Address} address
+     *  The other cell address to be compared to this cell address.
+     *
+     * @returns {Number}
+     *  - A negative number, if this cell address is less than the passed cell
+     *      address.
+     *  - A positive number, if this cell address is greater than the passed
+     *      cell address.
+     *  - Zero, if both cell addresses are equal.
+     */
+    Address.prototype.compareVertTo = function (address) {
+        return Address.compareVert(this, address);
+    };
+
     /**
      * Returns the column or row index of this cell address.
      *
@@ -291,6 +357,16 @@ define('io.ox/office/spreadsheet/utils/address', [
         return this[columns ? 0 : 1];
     };
 
+    /**
+     * Returns a copy of this cell address with switched column and row index.
+     *
+     * @returns {Address}
+     *  A copy of this cell address with switched column and row index.
+     */
+    Address.prototype.mirror = function () {
+        return new Address(this[1], this[0]);
+    };
+
     /**
      * Sets a new column or row index for this cell address.
      *
@@ -308,6 +384,22 @@ define('io.ox/office/spreadsheet/utils/address', [
         return this;
     };
 
+    /**
+     * Sets contents of this cell address to the contents of the passed cell
+     * address.
+     *
+     * @param {Address} address
+     *  The cell address to be copied into this cell address.
+     *
+     * @returns {Address}
+     *  A reference to this instance.
+     */
+    Address.prototype.assign = function (address) {
+        this[0] = address[0];
+        this[1] = address[1];
+        return this;
+    };
+
     /**
      * Modifies the column or row index of this cell address relatively.
      *
@@ -326,18 +418,6 @@ define('io.ox/office/spreadsheet/utils/address', [
         return this;
     };
 
-    /**
-     * Returns a unique string key for this cell address that can be used for
-     * example as key in an associative map. This method is faster than the
-     * method Address.toString().
-     *
-     * @returns {String}
-     *  A unique string key for this cell address.
-     */
-    Address.prototype.key = function () {
-        return Address.key(this[0], this[1]);
-    };
-
     /**
      * Returns the string representation of this cell address, in upper-case A1
      * notation.
