@@ -12,7 +12,7 @@
  */
 
 define('io.ox/office/spreadsheet/utils/addressarray', [
-    'io.ox/office/tk/object/arraytemplate',
+    'io.ox/office/tk/utils/arraytemplate',
     'io.ox/office/spreadsheet/utils/address'
 ], function (ArrayTemplate, Address) {
 
@@ -32,6 +32,18 @@ define('io.ox/office/spreadsheet/utils/addressarray', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this array of cell addresses that can be
+     * used for example as key in an associative map. This method is faster
+     * than the method AddressArray.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this instance.
+     */
+    AddressArray.prototype.key = function () {
+        return this.map(function (address) { return address.key(); }).join(' ');
+    };
+
     /**
      * Returns a shallow copy of this cell address array that does not contain
      * any duplicate cell addresses.
