@@ -13,16 +13,17 @@
 
 define('io.ox/office/spreadsheet/utils/interval', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/spreadsheet/utils/address'
-], function (Utils, Address) {
+], function (Utils, IteratorUtils, Address) {
 
     'use strict';
 
-    var // regular expression object matching a column interval
-        RE_COL_INTERVAL_NAME = new RegExp('^(' + Address.COL_PATTERN + '):(' + Address.COL_PATTERN + ')$', 'i'),
+    // regular expression object matching a column interval
+    var RE_COL_INTERVAL_NAME = new RegExp('^(' + Address.COL_PATTERN + '):(' + Address.COL_PATTERN + ')$', 'i');
 
-        // regular expression object matching a row interval
-        RE_ROW_INTERVAL_NAME = new RegExp('^(' + Address.ROW_PATTERN + '):(' + Address.ROW_PATTERN + ')$');
+    // regular expression object matching a row interval
+    var RE_ROW_INTERVAL_NAME = new RegExp('^(' + Address.ROW_PATTERN + '):(' + Address.ROW_PATTERN + ')$');
 
     // class Interval =========================================================
 
@@ -79,13 +80,19 @@ define('io.ox/office/spreadsheet/utils/interval', [
      * @param {String} str
      *  The string representation of a column interval, e.g. 'A:D'.
      *
+     * @param {Number} [max]
+     *  If specified, the zero-based index of the largest allowed column index.
+     *  If any of the parsed column indexes is greater, this method will return
+     *  null.
+     *
      * @returns {Interval|Null}
      *  The index interval, if the passed string is valid, otherwise null.
      */
-    Interval.parseAsCols = function (str) {
+    Interval.parseAsCols = function (str, max) {
         var matches = RE_COL_INTERVAL_NAME.exec(str);
         if (!matches) { return null; }
-        var index1 = Address.parseCol(matches[1]), index2 = Address.parseCol(matches[2]);
+        var index1 = Address.parseCol(matches[1], max);
+        var index2 = Address.parseCol(matches[2], max);
         return (Math.min(index1, index2) >= 0) ? Interval.create(index1, index2) : null;
     };
 
@@ -97,13 +104,18 @@ define('io.ox/office/spreadsheet/utils/interval', [
      * @param {String} str
      *  The string representation of a row interval, e.g. '1:4'.
      *
+     * @param {Number} [max]
+     *  If specified, the zero-based index of the largest allowed row index. If
+     *  any of the parsed row indexes is greater, this method will return null.
+     *
      * @returns {Interval|Null}
      *  The index interval, if the passed string is valid, otherwise null.
      */
-    Interval.parseAsRows = function (str) {
+    Interval.parseAsRows = function (str, max) {
         var matches = RE_ROW_INTERVAL_NAME.exec(str);
         if (!matches) { return null; }
-        var index1 = Address.parseRow(matches[1]), index2 = Address.parseRow(matches[2]);
+        var index1 = Address.parseRow(matches[1], max);
+        var index2 = Address.parseRow(matches[2], max);
         return (Math.min(index1, index2) >= 0) ? Interval.create(index1, index2) : null;
     };
 
@@ -119,11 +131,16 @@ define('io.ox/office/spreadsheet/utils/interval', [
      *  Whether the passed string represents a column interval (true), or a row
      *  interval (false).
      *
+     * @param {Number} [max]
+     *  If specified, the zero-based index of the largest allowed column/row
+     *  index. If any of the parsed indexes is greater, this method will return
+     *  null.
+     *
      * @returns {Interval|Null}
      *  The index interval, if the passed string is valid, otherwise null.
      */
-    Interval.parseAs = function (str, columns) {
-        return columns ? Interval.parseAsCols(str) : Interval.parseAsRows(str);
+    Interval.parseAs = function (str, columns, max) {
+        return columns ? Interval.parseAsCols(str, max) : Interval.parseAsRows(str, max);
     };
 
     /**
@@ -150,6 +167,18 @@ define('io.ox/office/spreadsheet/utils/interval', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this index interval that can be used for
+     * example as key in an associative map. This method is faster than the
+     * method Interval.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this index interval.
+     */
+    Interval.prototype.key = function () {
+        return this.first + ':' + this.last;
+    };
+
     /**
      * Creates a clone of this index interval.
      *
@@ -318,15 +347,28 @@ define('io.ox/office/spreadsheet/utils/interval', [
     };
 
     /**
-     * Returns a unique string key for this index interval that can be used for
-     * example as key in an associative map. This method is faster than the
-     * method Interval.toString().
+     * Creates an iterator that visits the single indexes of this interval.
      *
-     * @returns {String}
-     *  A unique string key for this index interval.
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.reverse=false]
+     *      If set to true, the indexes in this interval will be visited in
+     *      reversed order.
+     *
+     * @returns {Object}
+     *  An iterator object that implements the standard EcmaScript iterator
+     *  protocol, i.e. it provides the method next() that returns a result
+     *  object with the following properties:
+     *  - {Boolean} done
+     *      If set to true, the interval has been visited completely. No more
+     *      indexes are available; this result object does not contain any
+     *      other properties!
+     *  - {Number} value
+     *      The current index. This property will be omitted, if the iterator
+     *      is done (see property 'done').
      */
-    Interval.prototype.key = function () {
-        return this.first + ':' + this.last;
+    Interval.prototype.iterator = function (options) {
+        return IteratorUtils.createIntervalIterator(this.first, this.last, options);
     };
 
     /**
