@@ -12,9 +12,10 @@
  */
 
 define('io.ox/office/spreadsheet/utils/intervalarray', [
-    'io.ox/office/tk/object/arraytemplate',
+    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/arraytemplate',
     'io.ox/office/spreadsheet/utils/interval'
-], function (ArrayTemplate, Interval) {
+], function (IteratorUtils, ArrayTemplate, Interval) {
 
     'use strict';
 
@@ -74,6 +75,18 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this array of index intervals that can
+     * be used for example as key in an associative map. This method is faster
+     * than the method IntervalArray.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this instance.
+     */
+    IntervalArray.prototype.key = function () {
+        return this.map(function (interval) { return interval.key(); }).join(' ');
+    };
+
     /**
      * Returns the number of column/row indexes covered by all index intervals
      * in this array.
@@ -235,6 +248,81 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
         return result;
     };
 
+    /**
+     * Works similar to merging the index interval array (see method
+     * IntervalArray.merge()) but divides the intervals that overlap each other
+     * into smaller adjoining parts, so that the resulting intervals do not
+     * cover the boundaries of any of the original intervals.
+     *
+     * Example: The interval array [A:D,C:F] will be partitioned to the
+     * intervals A:B (leading part of first interval), C:D (common parts of
+     * both intervals), and E:F (trailing part of second interval).
+     *
+     * @returns {IntervalArray}
+     *  A sorted array of index intervals that do not overlap, that exactly
+     *  cover the intervals in this array, and that are partitioned in a way
+     *  that the resulting intervals do not cover any boundary of an original
+     *  interval. Each interval object in the resulting array will contain an
+     *  additional property 'coveredBy' that is an IntervalArray containing the
+     *  original intervals of this instance covering that particular result
+     *  interval.
+     */
+    IntervalArray.prototype.partition = function () {
+
+        // sort the intervals in this array by start index
+        var sourceIntervals = this.clone().sort();
+        // the source intervals to be processed for the next partial interval (updated during iteration)
+        var coveringIntervals = new IntervalArray();
+        // the resulting partition
+        var resultIntervals = new IntervalArray();
+
+        // creates a new partial interval and inserts it into the result array
+        // (this function must be defined outside thw while-loop)
+        function createPartialInterval() {
+
+            // the start index of the new partial interval to be created
+            var first = sourceIntervals.empty() ? Number.POSITIVE_INFINITY : sourceIntervals.first().first;
+            if (!coveringIntervals.empty()) { first = resultIntervals.last().last + 1; }
+
+            // remove all original intervals already processed in the preceding iteration that cannot be
+            // part of the partition anymore, and find the minimum end index of all remaining source intervals
+            var last = Number.POSITIVE_INFINITY;
+            coveringIntervals.forEachReverse(function (leadingInterval, index) {
+                if (first <= leadingInterval.last) {
+                    last = Math.min(last, leadingInterval.last);
+                } else {
+                    coveringIntervals.splice(index, 1);
+                }
+            });
+
+            // add all source intervals with the current start position to the intermediate array
+            while (!sourceIntervals.empty() && (first === sourceIntervals.first().first)) {
+                var sourceInterval = sourceIntervals.shift();
+                last = Math.min(last, sourceInterval.last);
+                coveringIntervals.push(sourceInterval);
+            }
+
+            // restrict the new partial interval to the start of the next source interval not processed here
+            if (!sourceIntervals.empty()) {
+                last = Math.min(last, sourceIntervals.first().first - 1);
+            }
+
+            // add the resulting partial interval to the result
+            if (!coveringIntervals.empty()) {
+                var partInterval = new Interval(first, last);
+                resultIntervals.push(partInterval);
+                partInterval.coveredBy = coveringIntervals.clone();
+            }
+        }
+
+        // process the source intervals
+        while (!sourceIntervals.empty() || !coveringIntervals.empty()) {
+            createPartialInterval();
+        }
+
+        return resultIntervals;
+    };
+
     /**
      * Returns the index intervals covered by this array, and the passed array
      * of index intervals. More precisely, returns the existing intersection
@@ -316,7 +404,7 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
         });
 
         // ensure to return a clone
-        return (result === this) ? this.clone() : result;
+        return (result === this) ? this.clone(true) : result;
     };
 
     /**
@@ -334,6 +422,58 @@ define('io.ox/office/spreadsheet/utils/intervalarray', [
         return this;
     };
 
+    /**
+     * Creates an iterator that visits the single indexes of the intervals in
+     * this array.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.reverse=false]
+     *      If set to true, the intervals in this array, and the indexes in all
+     *      intervals, will be visited in reversed order.
+     *  @param {Number} [options.begin]
+     *      If specified, only the intervals with an index greater than or
+     *      equal to this value (in reversed mode: with an index less than or
+     *      equal to this value) will be visited. If omitted, all intervals
+     *      from the beginning (in reverse mode: from the end) of this array
+     *      will be visited.
+     *  @param {Number} [options.end]
+     *      If specified, only the intervals with an index less than this value
+     *      (in reverse mode: with an index greater than this value) will be
+     *      visited (half-open interval!). If omitted, all intervals to the end
+     *      (in reverse mode: to the beginning) of this array will be visited.
+     *
+     * @returns {Object}
+     *  An iterator object that implements the standard EcmaScript iterator
+     *  protocol, i.e. it provides the method next() that returns a result
+     *  object with the following properties:
+     *  - {Number} value
+     *      The resulting index inside the interval currently visited.
+     *  - {Interval} interval
+     *      The original index interval from this interval array containing the
+     *      index currently visited.
+     *  - {Number} index
+     *      The array index (!) of the interval in the property 'interval' of
+     *      this result object.
+     */
+    IntervalArray.prototype.indexIterator = function (options) {
+
+        // creates an interval iterator from the result of the outer array iterator
+        function createIntervalIterator(interval) {
+            return interval.iterator(options);
+        }
+
+        // combines the results of the outer and inner iterators
+        function createIteratorResult(arrayResult, indexResult) {
+            indexResult.interval = arrayResult.value;
+            indexResult.index = arrayResult.index;
+            return indexResult;
+        }
+
+        // the nested iterator, combining an outer array iterator with an inner interval index iterator
+        return IteratorUtils.createNestedIterator(this.iterator(options), createIntervalIterator, createIteratorResult);
+    };
+
     /**
      * Returns the string representation of the index intervals as columns.
      *
