@@ -12,9 +12,8 @@
  */
 
 define('io.ox/office/spreadsheet/utils/operationcontext', [
-    'io.ox/office/tk/utils',
     'io.ox/office/editframework/utils/operationcontext'
-], function (Utils, OperationContext) {
+], function (OperationContext) {
 
     'use strict';
 
@@ -29,10 +28,10 @@ define('io.ox/office/spreadsheet/utils/operationcontext', [
      *
      * @extends OperationContext
      */
-    var SheetOperationContext = OperationContext.extend({ constructor: function (docModel, operation, external) {
+    var SheetOperationContext = OperationContext.extend({ constructor: function (docModel, operation, external, importing) {
 
         // base class constructor
-        OperationContext.call(this, docModel, operation, external);
+        OperationContext.call(this, docModel, operation, external, importing);
 
     } }); // class SheetOperationContext
 
