@@ -27,6 +27,9 @@ define('io.ox/office/spreadsheet/utils/operations', [
      */
     var SpreadsheetOperations = _.extend(EditOperations, {
 
+        INSERT_NUMBER_FORMAT: 'insertNumberFormat',
+        DELETE_NUMBER_FORMAT: 'deleteNumberFormat',
+
         INSERT_SHEET: 'insertSheet',
         DELETE_SHEET: 'deleteSheet',
         CHANGE_SHEET: 'setSheetAttributes',
@@ -34,25 +37,20 @@ define('io.ox/office/spreadsheet/utils/operations', [
         MOVE_SHEET: 'moveSheet',
         COPY_SHEET: 'copySheet',
 
-        INSERT_CELLS: 'insertCells',
-        DELETE_CELLS: 'deleteCells',
+        CHANGE_CELLS: 'changeCells',
+        MOVE_CELLS: 'moveCells',
         MERGE_CELLS: 'mergeCells',
 
-        SET_CELL_CONTENTS: 'setCellContents',
-        FILL_CELL_RANGE: 'fillCellRange',
-        CLEAR_CELL_RANGE: 'clearCellRange',
-        AUTO_FILL: 'autoFill',
-
         INSERT_HYPERLINK: 'insertHyperlink',
         DELETE_HYPERLINK: 'deleteHyperlink',
 
         INSERT_COLUMNS: 'insertColumns',
         DELETE_COLUMNS: 'deleteColumns',
-        CHANGE_COLUMNS: 'setColumnAttributes',
+        CHANGE_COLUMNS: 'changeColumns',
 
         INSERT_ROWS: 'insertRows',
         DELETE_ROWS: 'deleteRows',
-        CHANGE_ROWS: 'setRowAttributes',
+        CHANGE_ROWS: 'changeRows',
 
         INSERT_NAME: 'insertName',
         CHANGE_NAME: 'changeName',
@@ -67,12 +65,9 @@ define('io.ox/office/spreadsheet/utils/operations', [
         CHANGE_VALIDATION: 'changeValidation',
         DELETE_VALIDATION: 'deleteValidation',
 
-        INSERT_COND_FORMAT: 'insertCondFormat',
-        CHANGE_COND_FORMAT: 'changeCondFormat',
-        DELETE_COND_FORMAT: 'deleteCondFormat',
-        INSERT_COND_FORMAT_RULE: 'insertCondFormatRule',
-        CHANGE_COND_FORMAT_RULE: 'changeCondFormatRule',
-        DELETE_COND_FORMAT_RULE: 'deleteCondFormatRule'
+        INSERT_CFRULE: 'insertCFRule',
+        CHANGE_CFRULE: 'changeCFRule',
+        DELETE_CFRULE: 'deleteCFRule'
 
     });
 
