@@ -19,24 +19,30 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
 
     'use strict';
 
-    var // configuration for pane sides (header panes)
-        PANE_SIDE_DATA = {
-            left:   { nextSide: 'right',  panePos1: 'topLeft',    panePos2: 'bottomLeft',  columns: true,  leading: true,  anchorName: 'anchorLeft' },
-            right:  { nextSide: 'left',   panePos1: 'topRight',   panePos2: 'bottomRight', columns: true,  leading: false, anchorName: 'anchorRight' },
-            top:    { nextSide: 'bottom', panePos1: 'topLeft',    panePos2: 'topRight',    columns: false, leading: true,  anchorName: 'anchorTop' },
-            bottom: { nextSide: 'top',    panePos1: 'bottomLeft', panePos2: 'bottomRight', columns: false, leading: false, anchorName: 'anchorBottom' }
-        },
+    // configuration for pane sides (header panes)
+    var PANE_SIDE_DATA = {
+        left:   { nextSide: 'right',  panePos1: 'topLeft',    panePos2: 'bottomLeft',  columns: true,  leading: true,  anchorName: 'anchorLeft' },
+        right:  { nextSide: 'left',   panePos1: 'topRight',   panePos2: 'bottomRight', columns: true,  leading: false, anchorName: 'anchorRight' },
+        top:    { nextSide: 'bottom', panePos1: 'topLeft',    panePos2: 'topRight',    columns: false, leading: true,  anchorName: 'anchorTop' },
+        bottom: { nextSide: 'top',    panePos1: 'bottomLeft', panePos2: 'bottomRight', columns: false, leading: false, anchorName: 'anchorBottom' }
+    };
 
-        // configuration for pane positions (grid panes)
-        PANE_POS_DATA = {
-            topLeft:     { colSide: 'left',  rowSide: 'top',    nextColPos: 'topRight',    nextRowPos: 'bottomLeft' },
-            topRight:    { colSide: 'right', rowSide: 'top',    nextColPos: 'topLeft',     nextRowPos: 'bottomRight' },
-            bottomLeft:  { colSide: 'left',  rowSide: 'bottom', nextColPos: 'bottomRight', nextRowPos: 'topLeft' },
-            bottomRight: { colSide: 'right', rowSide: 'bottom', nextColPos: 'bottomLeft',  nextRowPos: 'topRight' }
-        },
+    // configuration for pane positions (grid panes)
+    var PANE_POS_DATA = {
+        topLeft:     { colSide: 'left',  rowSide: 'top',    nextColPos: 'topRight',    nextRowPos: 'bottomLeft' },
+        topRight:    { colSide: 'right', rowSide: 'top',    nextColPos: 'topLeft',     nextRowPos: 'bottomRight' },
+        bottomLeft:  { colSide: 'left',  rowSide: 'bottom', nextColPos: 'bottomRight', nextRowPos: 'topLeft' },
+        bottomRight: { colSide: 'right', rowSide: 'bottom', nextColPos: 'bottomLeft',  nextRowPos: 'topRight' }
+    };
 
-        // the names of all tracking events but 'tracking:start'
-        TRACKING_EVENT_NAMES = 'tracking:move tracking:repeat tracking:scroll tracking:end tracking:cancel';
+    // used to map pane side identifiers to pane position identifiers
+    var PANE_SIDE_TO_PANE_POS = {
+        left: { top: 'topLeft', bottom: 'bottomLeft' },
+        right: { top: 'topRight', bottom: 'bottomRight' }
+    };
+
+    // the names of all tracking events but 'tracking:start'
+    var TRACKING_EVENT_NAMES = 'tracking:move tracking:repeat tracking:scroll tracking:end tracking:cancel';
 
     // static class PaneUtils =================================================
 
@@ -213,7 +219,7 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      *  The pane position for the passed pane side identifiers.
      */
     PaneUtils.getPanePos = function (colPaneSide, rowPaneSide) {
-        return rowPaneSide + Utils.capitalize(colPaneSide);
+        return PANE_SIDE_TO_PANE_POS[colPaneSide][rowPaneSide];
     };
 
     /**
@@ -233,8 +239,8 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      *  'bottomRight' and target pane side 'top').
      */
     PaneUtils.getNextPanePos = function (panePos, paneSide) {
-        var panePosData = PANE_POS_DATA[panePos],
-            paneSideData = PANE_SIDE_DATA[paneSide];
+        var panePosData = PANE_POS_DATA[panePos];
+        var paneSideData = PANE_SIDE_DATA[paneSide];
         return ((paneSide === panePosData.colSide) || (paneSide === panePosData.rowSide)) ? panePos :
             (paneSideData.columns ? panePosData.nextColPos : panePosData.nextRowPos);
     };
@@ -303,10 +309,10 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      */
     PaneUtils.getBorderForPresetStyle = function (presetStyle) {
 
-        var // the tokens in the passed preset style
-            tokens = presetStyle.split(':'),
-            // resulting border value
-            border = { style: 'none', width: 0 };
+        // the tokens in the passed preset style
+        var tokens = presetStyle.split(':');
+        // resulting border value
+        var border = { style: 'none', width: 0 };
 
         if ((tokens.length === 2) && (tokens[0].length > 0) && (tokens[1].length > 0)) {
             border.style = tokens[0];
@@ -358,12 +364,12 @@ define('io.ox/office/spreadsheet/utils/paneutils', [
      */
     PaneUtils.processTrackingCycle = function (startEvent, trackingHandler, endCallback) {
 
-        var // the event target node
-            targetNode = $(startEvent.target),
-            // event delegation target node
-            delegateNode = $(startEvent.delegateTarget),
-            // whether to keep the target node in the DOM (touch tracking)
-            guardTargetNode = (startEvent.trackingType === 'touch') && Utils.containsNode(delegateNode, targetNode);
+        // the event target node
+        var targetNode = $(startEvent.target);
+        // event delegation target node
+        var delegateNode = $(startEvent.delegateTarget);
+        // whether to keep the target node in the DOM (touch tracking)
+        var guardTargetNode = (startEvent.trackingType === 'touch') && Utils.containsNode(delegateNode, targetNode);
 
         // registers or unregisters the 'DOMNodeRemoved' event handler
         function registerDOMNodeRemovedHandler(add) {
