@@ -13,17 +13,18 @@
 
 define('io.ox/office/spreadsheet/utils/range', [
     'io.ox/office/tk/utils',
+    'io.ox/office/tk/utils/iteratorutils',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/address'
-], function (Utils, Interval, Address) {
+], function (Utils, IteratorUtils, Interval, Address) {
 
     'use strict';
 
-    var // pattern for a single cell address in a range
-        CELL_PATTERN = '(' + Address.COL_PATTERN + ')(' + Address.ROW_PATTERN + ')',
+    // pattern for a single cell address in a range
+    var CELL_PATTERN = '(' + Address.COL_PATTERN + ')(' + Address.ROW_PATTERN + ')';
 
-        // regular expression object matching a range name
-        RE_RANGE_NAME = new RegExp('^' + CELL_PATTERN + ':' + CELL_PATTERN + '$', 'i');
+    // regular expression object matching a range name
+    var RE_RANGE_NAME = new RegExp('^' + CELL_PATTERN + ':' + CELL_PATTERN + '$', 'i');
 
     // class Range ============================================================
 
@@ -165,6 +166,27 @@ define('io.ox/office/spreadsheet/utils/range', [
         return address2 ? Range.create(address1[0], address1[1], address2[0], address2[1]) : new Range(address1.clone());
     };
 
+    /**
+     * Creates a cell range address from the passed cell address, and number of
+     * columns and rows. The passed cell address will be cloned when creating
+     * the new range address.
+     *
+     * @param {Address} address
+     *  The start cell address used to create the new cell range address.
+     *
+     * @param {Number} cols
+     *  The number of columns contained in the resulting cell range address.
+     *
+     * @param {Number} rows
+     *  The number of rows contained in the resulting cell range address.
+     *
+     * @returns {Range}
+     *  The cell range address created from the passed cell address and size.
+     */
+    Range.createFromAddressAndSize = function (address, cols, rows) {
+        return Range.create(address[0], address[1], address[0] + cols - 1, address[1] + rows - 1);
+    };
+
     /**
      * Returns the cell range address for the passed string representation.
      *
@@ -172,17 +194,22 @@ define('io.ox/office/spreadsheet/utils/range', [
      *  The string representation of a cell range address, in A1 notation, with
      *  a colon as separator between start and end address.
      *
+     * @param {Address} [max]
+     *  If specified, the largest allowed cell address. If a column index, or a
+     *  row index in the parsed cell range address is greater, this method will
+     *  return null.
+     *
      * @returns {Range|Null}
      *  The cell range address (with adjusted column and row indexes), if the
      *  passed string is valid, otherwise null.
      */
-    Range.parse = function (str) {
+    Range.parse = function (str, max) {
         var matches = RE_RANGE_NAME.exec(str);
         if (!matches) { return null; }
-        var col1 = Address.parseCol(matches[1]),
-            row1 = Address.parseRow(matches[2]),
-            col2 = Address.parseCol(matches[3]),
-            row2 = Address.parseRow(matches[4]);
+        var col1 = Address.parseCol(matches[1], max ? max[0] : null);
+        var row1 = Address.parseRow(matches[2], max ? max[1] : null);
+        var col2 = Address.parseCol(matches[3], max ? max[0] : null);
+        var row2 = Address.parseRow(matches[4], max ? max[1] : null);
         return (Math.min(col1, row1, col2, row2) >= 0) ? Range.create(col1, row1, col2, row2) : null;
     };
 
@@ -213,6 +240,18 @@ define('io.ox/office/spreadsheet/utils/range', [
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this cell range address that can be used
+     * for example as key in an associative map. This method is faster than the
+     * method Range.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this cell range address.
+     */
+    Range.prototype.key = function () {
+        return this.start.key() + ':' + this.end.key();
+    };
+
     /**
      * Creates a deep clone of this cell range address.
      *
@@ -338,6 +377,20 @@ define('io.ox/office/spreadsheet/utils/range', [
         return this.start[1] === this.end[1];
     };
 
+    /**
+     * Returns whether this cell range address covers a single column or row.
+     *
+     * @param {Boolean} columns
+     *  Whether to check this cell range address for a single column (true), or
+     *  for a single row (false).
+     *
+     * @returns {Boolean}
+     *  Whether this cell range address covers a single column or row.
+     */
+    Range.prototype.singleLine = function (columns) {
+        return columns ? this.singleCol() : this.singleRow();
+    };
+
     /**
      * Returns whether this cell range address covers a single cell (start
      * address and end address are equal).
@@ -377,6 +430,40 @@ define('io.ox/office/spreadsheet/utils/range', [
         return this.end.equals(address);
     };
 
+    /**
+     * Returns the linear row-wise index of the passed address inside this
+     * range. The top-left cell has index 0, the next cell in the first row has
+     * index 1, and so on.
+     *
+     * @param {Address} address
+     *  The address whose linear index will be returned. MUST be located inside
+     *  this range.
+     *
+     * @returns {Number}
+     *  The zero-based linear index of the passed address. The result is
+     *  undefined, if the address is not located inside this range.
+     */
+    Range.prototype.indexAt = function (address) {
+        return (address[1] - this.start[1]) * this.cols() + (address[0] - this.start[0]);
+    };
+
+    /**
+     * Returns the address representing the passed linear row-wise index inside
+     * this range. The top-left cell has index 0, the next cell in the first
+     * row has index 1, and so on.
+     *
+     * @param {Number} index
+     *  The zero-based linear index. The result is undefined, if the index is
+     *  not located inside this range.
+     *
+     * @returns {Address}
+     *  The address representing the passed linear index.
+     */
+    Range.prototype.addressAt = function (index) {
+        var cols = this.cols();
+        return new Address(this.start[0] + Math.floor(index % cols), this.start[1] + Math.floor(index / cols));
+    };
+
     /**
      * Returns whether this cell range address contains the specified column
      * index.
@@ -437,6 +524,22 @@ define('io.ox/office/spreadsheet/utils/range', [
         return this.containsCol(address[0]) && this.containsRow(address[1]);
     };
 
+    /**
+     * Returns whether the specified cell is a border cell of this cell range
+     * address (a cell located in the leading or trailing column, or in the top
+     * or bottom row).
+     *
+     * @param {Address} address
+     *  The cell address to be checked.
+     *
+     * @returns {Boolean}
+     *  Whether the specified cell is a border cell of this cell range address.
+     */
+    Range.prototype.isBorderAddress = function (address) {
+        return this.containsAddress(address) &&
+            ((this.start[0] === address[0]) || (this.end[0] === address[0]) || (this.start[1] === address[1]) || (this.end[1] === address[1]));
+    };
+
     /**
      * Returns whether this cell range address contains the passed cell range
      * address completely.
@@ -501,25 +604,135 @@ define('io.ox/office/spreadsheet/utils/range', [
     };
 
     /**
-     * Returns the range address of the top row in this cell range address.
+     * Returns the address of the specified columns in this cell range address.
+     *
+     * @param {Number} index
+     *  The relative column index (the value zero will return the address of
+     *  the leading column in this range).
+     *
+     * @param {Number} [count=1]
+     *  The number of columns covered by the resulting range.
      *
      * @returns {Range}
-     *  The range address of the top row in this cell range address.
+     *  The address of the specified columns in this cell range address.
      */
-    Range.prototype.header = function () {
+    Range.prototype.colRange = function (index, count) {
+        var col = this.start[0] + index;
+        return Range.create(col, this.start[1], col + (count || 1) - 1, this.end[1]);
+    };
+
+    /**
+     * Returns the address of the specified rows in this cell range address.
+     *
+     * @param {Number} index
+     *  The relative row index (the value zero will return the address of the
+     *  top row in this range).
+     *
+     * @param {Number} [count=1]
+     *  The number of rows covered by the resulting range.
+     *
+     * @returns {Range}
+     *  The address of the specified rows in this cell range address.
+     */
+    Range.prototype.rowRange = function (index, count) {
+        var row = this.start[1] + index;
+        return Range.create(this.start[0], row, this.end[0], row + (count || 1) - 1);
+    };
+
+    /**
+     * Returns the address of the specified columns or rows in this cell range
+     * address.
+     *
+     * @param {Number} index
+     *  The relative column/row index (the value zero will return the address
+     *  of the leading column or top row in this range).
+     *
+     * @param {Boolean} columns
+     *  Whether to return a column range (true), or a row range (false) of this
+     *  cell range address.
+     *
+     * @param {Number} [count=1]
+     *  The number of columns or rows covered by the resulting range.
+     *
+     * @returns {Range}
+     *  The address of the specified columns/rows in this cell range address.
+     */
+    Range.prototype.lineRange = function (columns, index, count) {
+        return columns ? this.colRange(index, count) : this.rowRange(index, count);
+    };
+
+    /**
+     * Returns the address of the leading column in this cell range address.
+     *
+     * @returns {Range}
+     *  The address of the leading column in this cell range address.
+     */
+    Range.prototype.leadingCol = function () {
+        return Range.create(this.start[0], this.start[1], this.start[0], this.end[1]);
+    };
+
+    /**
+     * Returns the address of the trailing column in this cell range address.
+     *
+     * @returns {Range}
+     *  The address of the trailing column in this cell range address.
+     */
+    Range.prototype.trailingCol = function () {
+        return Range.create(this.end[0], this.start[1], this.end[0], this.end[1]);
+    };
+
+    /**
+     * Returns the address of the top row in this cell range address.
+     *
+     * @returns {Range}
+     *  The address of the top row in this cell range address.
+     */
+    Range.prototype.headerRow = function () {
         return Range.create(this.start[0], this.start[1], this.end[0], this.start[1]);
     };
 
     /**
-     * Returns the range address of the bottom row in this cell range address.
+     * Returns the address of the bottom row in this cell range address.
      *
      * @returns {Range}
-     *  The range address of the bottom row in this cell range address.
+     *  The address of the bottom row in this cell range address.
      */
-    Range.prototype.footer = function () {
+    Range.prototype.footerRow = function () {
         return Range.create(this.start[0], this.end[1], this.end[0], this.end[1]);
     };
 
+    /**
+     * Returns a copy of this cell range address with switched column and row
+     * indexes.
+     *
+     * @returns {Range}
+     *  A copy of this cell range address with switched column and row indexes.
+     */
+    Range.prototype.mirror = function () {
+        return new Range(this.start.mirror(), this.end.mirror());
+    };
+
+    /**
+     * Returns the address of the bounding cell range of this cell range, and
+     * the passed cell address (the smallest range that contains this range,
+     * and the cell address).
+     *
+     * @param {Address} address
+     *  The cell address to create the bounding range from.
+     *
+     * @returns {Range}
+     *  The address of the bounding cell range of this cell range, and the
+     *  passed cell address.
+     */
+    Range.prototype.expand = function (address) {
+        return Range.create(
+            Math.min(this.start[0], address[0]),
+            Math.min(this.start[1], address[1]),
+            Math.max(this.end[0], address[0]),
+            Math.max(this.end[1], address[1])
+        );
+    };
+
     /**
      * Returns the address of the bounding cell range of this cell range, and
      * the passed cell range address (the smallest range that contains both
@@ -530,7 +743,7 @@ define('io.ox/office/spreadsheet/utils/range', [
      *
      * @returns {Range}
      *  The address of the bounding cell range of this cell range, and the
-     *  passed cell range address
+     *  passed cell range address.
      */
     Range.prototype.boundary = function (range) {
         return Range.create(
@@ -645,15 +858,64 @@ define('io.ox/office/spreadsheet/utils/range', [
     };
 
     /**
-     * Returns a unique string key for this cell range address that can be used
-     * for example as key in an associative map. This method is faster than the
-     * method Range.toString().
+     * Modifies the column or row index of the start cell, AND the end cell of
+     * this cell range address.
      *
-     * @returns {String}
-     *  A unique string key for this cell range address.
+     * @param {Number} distance
+     *  The distance to move the column or row indexes of this cell range.
+     *  Negative values will decrease the indexes.
+     *
+     * @param {Boolean} columns
+     *  Whether to change the column indexes (true), or the row indexes
+     *  (false).
+     *
+     * @returns {Range}
+     *  A reference to this instance.
      */
-    Range.prototype.key = function () {
-        return this.start.key() + ':' + this.end.key();
+    Range.prototype.moveBoth = function (distance, columns) {
+        this.start.move(distance, columns);
+        this.end.move(distance, columns);
+        return this;
+    };
+
+    /**
+     * Creates an iterator that visits the cell addresses in this cell range
+     * row-by-row, or column-by-column.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.reverse=false]
+     *      If set to true, the addresses in this range will be generated in
+     *      reversed order, from bottom-right to top-left cell.
+     *  @param {Boolean} [options.columns=false]
+     *      If set to true, the addresses in this range will be generated in
+     *      vertical order.
+     *
+     * @returns {Object}
+     *  An iterator object that implements the standard EcmaScript iterator
+     *  protocol, i.e. it provides the method next() that returns a result
+     *  object with the following properties:
+     *  - {Boolean} done
+     *      If set to true, the cell range has been visited completely. No more
+     *      addresses are available; this result object does not contain any
+     *      other properties!
+     *  - {Address} value
+     *      The current cell address. This property will be omitted, if the
+     *      iterator is done (see property 'done').
+     */
+    Range.prototype.iterator = function (options) {
+
+        var columns = Utils.getBooleanOption(options, 'columns', false);
+        var iterator1 = this.interval(columns).iterator(options);
+        var interval2 = this.interval(!columns);
+
+        var createIterator = interval2.iterator.bind(interval2, options);
+
+        var createResult = columns ?
+            function (result1, result2) { return { value: new Address(result1.value, result2.value) }; } :
+            function (result1, result2) { return { value: new Address(result2.value, result1.value) }; };
+
+        return IteratorUtils.createNestedIterator(iterator1, createIterator, createResult);
     };
 
     /**
