@@ -64,11 +64,11 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  The row index of the other border in the cell range.
      *
      * @param {Number} sheet1
-     *  The zero-based index of the first sheet of this cell range address.
+     *  The zero-based index of the first sheet of the new cell range address.
      *
      * @param {Number} [sheet2]
-     *  The zero-based index of the second sheet of this cell range address. If
-     *  omitted, the new range will refer to a single sheet.
+     *  The zero-based index of the second sheet of the new cell range address.
+     *  If omitted, the new range will refer to a single sheet.
      *
      * @returns {Range3D}
      *  The cell range address with adjusted column and row indexes.
@@ -89,11 +89,11 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  A simple cell address without sheet indexes.
      *
      * @param {Number} sheet1
-     *  The zero-based index of the first sheet of this cell range address.
+     *  The zero-based index of the first sheet of the new cell range address.
      *
      * @param {Number} [sheet2]
-     *  The zero-based index of the second sheet of this cell range address. If
-     *  omitted, the new range will refer to a single sheet.
+     *  The zero-based index of the second sheet of the new cell range address.
+     *  If omitted, the new range will refer to a single sheet.
      *
      * @returns {Range3D}
      *  The cell range address created from the passed parameters.
@@ -102,6 +102,32 @@ define('io.ox/office/spreadsheet/utils/range3d', [
         return Range3D.create(address[0], address[1], address[0], address[1], sheet1, sheet2);
     };
 
+    /**
+     * Creates a cell range address with sheet indexes from the passed cell
+     * addresses. The columns, rows, and sheets in the resulting cell range
+     * address will be ordered automatically. The passed cell addresses will be
+     * deeply cloned when creating the new range address.
+     *
+     * @param {Address} address1
+     *  The first cell address used to create the new cell range address.
+     *
+     * @param {Address} address2
+     *  The second cell address used to create the new cell range address.
+     *
+     * @param {Number} sheet1
+     *  The zero-based index of the first sheet of the new cell range address.
+     *
+     * @param {Number} [sheet2]
+     *  The zero-based index of the second sheet of the new cell range address.
+     *  If omitted, the new range will refer to a single sheet.
+     *
+     * @returns {Range3D}
+     *  The cell range address created from the passed cell addresses.
+     */
+    Range3D.createFromAddresses = function (address1, address2, sheet1, sheet2) {
+        return Range3D.create(address1[0], address1[1], address2[0], address2[1], sheet1, sheet2);
+    };
+
     /**
      * Creates a cell range address with sheet indexes from the passed simple
      * cell range address. The sheet indexes in the resulting cell range
@@ -113,11 +139,11 @@ define('io.ox/office/spreadsheet/utils/range3d', [
      *  A simple cell range address without sheet indexes.
      *
      * @param {Number} sheet1
-     *  The zero-based index of the first sheet of this cell range address.
+     *  The zero-based index of the first sheet of the new cell range address.
      *
      * @param {Number} [sheet2]
-     *  The zero-based index of the second sheet of this cell range address. If
-     *  omitted, the new range will refer to a single sheet.
+     *  The zero-based index of the second sheet of the new cell range address.
+     *  If omitted, the new range will refer to a single sheet.
      *
      * @returns {Range3D}
      *  The cell range address created from the passed parameters.
@@ -126,8 +152,45 @@ define('io.ox/office/spreadsheet/utils/range3d', [
         return Range3D.create(range.start[0], range.start[1], range.end[0], range.end[1], sheet1, sheet2);
     };
 
+    /**
+     * Creates a cell range address with sheet indexes from the passed column
+     * and row interval. The sheet indexes in the resulting cell range address
+     * will be ordered automatically.
+     *
+     * @param {Interval} colInterval
+     *  The column interval of the new cell range address.
+     *
+     * @param {Interval} rowInterval
+     *  The row interval of the new cell range address.
+     *
+     * @param {Number} sheet1
+     *  The zero-based index of the first sheet of the new cell range address.
+     *
+     * @param {Number} [sheet2]
+     *  The zero-based index of the second sheet of the new cell range address.
+     *  If omitted, the new range will refer to a single sheet.
+     *
+     * @returns {Range3D}
+     *  The cell range address created from the passed index intervals.
+     */
+    Range3D.createFromIntervals = function (colInterval, rowInterval, sheet1, sheet2) {
+        return Range3D.create(colInterval.first, rowInterval.first, colInterval.last, rowInterval.last, sheet1, sheet2);
+    };
+
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this cell range address that can be used
+     * for example as key in an associative map. This method is faster than the
+     * method Range3D.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this cell range address.
+     */
+    Range3D.prototype.key = function () {
+        return this.sheet1 + ':' + this.sheet2 + '!' + Range.prototype.key.call(this);
+    };
+
     /**
      * Creates a deep clone of this cell range address. Overrides the method
      * clone() of the base class Range.
