@@ -12,10 +12,10 @@
  */
 
 define('io.ox/office/spreadsheet/utils/range3darray', [
-    'io.ox/office/tk/utils',
-    'io.ox/office/tk/object/arraytemplate',
-    'io.ox/office/spreadsheet/utils/range3d'
-], function (Utils, ArrayTemplate, Range3D) {
+    'io.ox/office/tk/utils/arraytemplate',
+    'io.ox/office/spreadsheet/utils/range3d',
+    'io.ox/office/spreadsheet/utils/intervalarray'
+], function (ArrayTemplate, Range3D, IntervalArray) {
 
     'use strict';
 
@@ -59,8 +59,55 @@ define('io.ox/office/spreadsheet/utils/range3darray', [
         return Range3DArray.map(ranges, function (range) { return Range3D.createFromRange(range, sheet1, sheet2); });
     };
 
+    /**
+     * Creates an array of cell range addresses with sheet indexes from the
+     * passed column and row intervals, by combining each column interval with
+     * each row interval. The sheet indexes in the resulting cell range address
+     * will be ordered automatically.
+     *
+     * @param {IntervalArray|Interval} colIntervals
+     *  The column intervals of the new cell range addresses. This method also
+     *  accepts a single index interval as parameter.
+     *
+     * @param {IntervalArray|Interval} rowIntervals
+     *  The row intervals of the new cell range addresses. This method also
+     *  accepts a single index interval as parameter.
+     *
+     * @param {Number} sheet1
+     *  The zero-based index of the first sheet of the created cell range
+     *  addresses.
+     *
+     * @param {Number} [sheet2]
+     *  The zero-based index of the second sheet of the created cell range
+     *  addresses. If omitted, the new ranges will refer to a single sheet.
+     *
+     * @returns {Range3DArray}
+     *  The array of cell range addresses created from the passed intervals.
+     */
+    Range3DArray.createFromIntervals = function (colIntervals, rowIntervals, sheet1, sheet2) {
+        var result = new Range3DArray();
+        IntervalArray.forEach(rowIntervals, function (rowInterval) {
+            IntervalArray.forEach(colIntervals, function (colInterval) {
+                result.push(Range3D.createFromIntervals(colInterval, rowInterval, sheet1, sheet2));
+            });
+        });
+        return result;
+    };
+
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this array of cell range addresses that
+     * can be used for example as key in an associative map. This method is
+     * faster than the method Range3DArray.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this instance.
+     */
+    Range3DArray.prototype.key = function () {
+        return this.map(function (range) { return range.key(); }).join(' ');
+    };
+
     /**
      * Returns the number of cells covered by all cell range address.
      *
@@ -136,6 +183,31 @@ define('io.ox/office/spreadsheet/utils/range3darray', [
         return result;
     };
 
+    /**
+     * Returns a shallow copy of this cell range address array that does not
+     * contain any duplicate cell range addresses.
+     *
+     * @returns {Range3DArray}
+     *  A copy of this cell range address array without any duplicates. The
+     *  array will contain the same ranges as contained in this array (no deep
+     *  clones of the ranges).
+     */
+    Range3DArray.prototype.unify = function () {
+
+        // nothing to do for empty array, or single range; but return a cloned array
+        if (this.length <= 1) { return this.clone(); }
+
+        // a map with the unique keys of all result ranges (prevents to search for duplicates in the result)
+        var map = {};
+
+        // remove all ranges from the result that are already contained in the map
+        return this.reject(function (range) {
+            var key = range.key();
+            if (map[key]) { return true; }
+            map[key] = true;
+        });
+    };
+
     /**
      * Returns the cell range addresses covered by this array, and the passed
      * array of cell range addresses. More precisely, returns the existing
@@ -161,84 +233,6 @@ define('io.ox/office/spreadsheet/utils/range3darray', [
         return result;
     };
 
-    /**
-     * Returns a shortened array of cell range addresses containing at most as
-     * many cells as specified. If a cell range address in this array does not
-     * fit completely due to the remaining number of allowed cells, it will be
-     * shortened to the appropriate number of leading sheets and/or upper rows
-     * of the range. If the range cannot be shortened exactly to entire sheets,
-     * it will be split into two or more ranges (the latter range being the
-     * leading part of an inner sheet, and optionally the leading part of an
-     * inner row). Overlapping cell range addresses will NOT be merged.
-     *
-     * Example: Shortening the single range Sheet1:Sheet3!A1:C3 to 26 cells
-     * (all cells but the very last cell Sheet3!C3) results in the ranges
-     * Sheet1:Sheet2!A1:C3,Sheet3!A1:C2,Sheet3!A3:B3.
-     *
-     * @param {Number} maxCells
-     *  The maximum number of cells allowed in the resulting array.
-     *
-     * @returns {Range3DArray}
-     *  The shortened array of cell range addresses.
-     */
-    Range3DArray.prototype.shortenTo = function (maxCells) {
-
-        // the resulting cell ranges
-        var result = new Range3DArray();
-
-        Utils.iterateArray(this, function (range) {
-
-            // no more cells left (e.g., previous range has occupied the last cell)
-            if (maxCells <= 0) { return Utils.BREAK; }
-
-            var // number of cells in the current range
-                cells = range.cells();
-
-            // push entirely fitting range, continue with next range
-            if (cells <= maxCells) {
-                result.push(range);
-                maxCells -= cells;
-                return;
-            }
-
-            // shorten the range to entire sheets
-            var sheets = Math.floor(maxCells / range.cols() / range.rows());
-            if (sheets > 0) {
-                range = range.clone();
-                range.sheet2 = range.sheet1 + sheets - 1;
-                result.push(range);
-                maxCells -= sheets * range.cols() * range.rows();
-            }
-
-            // adjust the range to refer to the split sheet only
-            range = range.clone();
-            range.sheet1 = range.sheet2 = range.sheet1 + sheets;
-
-            // shorten the remaining range to entire rows
-            var rows = Math.floor(maxCells / range.cols());
-            if (rows > 0) {
-                range.end[1] = range.start[1] + rows - 1;
-                result.push(range);
-                maxCells -= range.cols() * rows;
-            }
-
-            // adjust the range to refer to the split row only
-            range = range.clone();
-            range.start[1] = range.end[1] = range.start[1] + rows;
-
-            // add remaining part of the last row
-            if (maxCells > 0) {
-                range.end[0] = range.start[0] + maxCells - 1;
-                result.push(range);
-            }
-
-            // last range has been pushed partly, stop iteration
-            return Utils.BREAK;
-        });
-
-        return result;
-    };
-
     // exports ================================================================
 
     return Range3DArray;
