@@ -13,120 +13,137 @@
 
 define('io.ox/office/spreadsheet/utils/rangearray', [
     'io.ox/office/tk/utils',
-    'io.ox/office/tk/object/arraytemplate',
-    'io.ox/office/spreadsheet/utils/address',
+    'io.ox/office/tk/utils/iteratorutils',
+    'io.ox/office/tk/utils/arraytemplate',
     'io.ox/office/spreadsheet/utils/interval',
     'io.ox/office/spreadsheet/utils/range',
     'io.ox/office/spreadsheet/utils/intervalarray'
-], function (Utils, ArrayTemplate, Address, Interval, Range, IntervalArray) {
+], function (Utils, IteratorUtils, ArrayTemplate, Interval, Range, IntervalArray) {
 
     'use strict';
 
     // private static functions ===============================================
 
     /**
-     * Divides the passed cell range addresses into a sorted array of row band
-     * objects. Each row band contains the row interval, and a merged array of
-     * column intervals representing the parts of the original ranges covered
-     * by the respective row band (see method IntervalArray.merge() for details
-     * about merged index intervals).
-     *
-     * @param {RangeArray} ranges
-     *  An array of cell range addresses.
-     *
-     * @returns {IntervalArray}
-     *  An array of row intervals representing all passed cell range addresses.
-     *  Each row interval object contains the additional property 'intervals'
-     *  representing the parts of the original ranges covered by the row band.
+     * Creates a new band interval instance.
      */
-    function getRowBandsFromRanges(ranges) {
+    function createBandInterval(first, last, ranges) {
+        var interval = new Interval(first, last);
+        if (ranges) { interval.ranges = ranges; }
+        return interval;
+    }
 
-        var // the cell ranges mapped by row interval (used for the resulting row bands)
-            rowBands = new IntervalArray(),
-            // the start array index in bandRanges used to search for matching row intervals
-            startIndex = 0;
+    /**
+     * Divides the cell range addresses into a sorted array of column or row
+     * intervals representing the boundaries of all cell ranges. See public
+     * methods RangeArray.getColBands() and RangeArray.getRowBands() for more
+     * details.
+     */
+    function createBandIntervals(ranges, columns, options) {
 
-        // creates a new row band instance
-        function createRowBand(row1, row2, ranges) {
-            var rowBand = new Interval(row1, row2);
-            rowBand.ranges = ranges;
-            return rowBand;
-        }
+        // whether to add the sorted original ranges to the resulting interval bands
+        var addRanges = Utils.getBooleanOption(options, 'ranges', false);
+        // whether to add the merged range intervals inside the bands to the resulting interval bands
+        var addIntervals = Utils.getBooleanOption(options, 'intervals', false);
+        // whether to add the original ranges intermediately (needed for ranges, or for intervals)
+        var createRanges = addRanges || addIntervals;
+        // the resulting interval bands
+        var bandIntervals = new IntervalArray();
+        // the start array index in 'bandIntervals' used to search for matching intervals
+        var startIndex = 0;
 
-        // work on a clone sorted by start row index
-        ranges = ranges.clone().sort(function (range1, range2) { return range1.start[1] - range2.start[1]; });
+        // work on a clone sorted by start column/row index
+        ranges = ranges.clone().sortBy(function (range) { return range.getStart(columns); });
 
         // build the array of row bands
         ranges.forEach(function (range) {
 
-            var // the start and end row index of the range
-                row1 = range.start[1],
-                row2 = range.end[1];
+            // the start and end band index of the range
+            var first = range.getStart(columns);
+            var last = range.getEnd(columns);
 
             // update the row bands containing the range
-            for (var bandIndex = startIndex; bandIndex < rowBands.length; bandIndex += 1) {
+            for (var bandIndex = startIndex; bandIndex < bandIntervals.length; bandIndex += 1) {
 
-                // the current row band
-                var rowBand = rowBands[bandIndex];
+                // the current band interval
+                var bandInterval = bandIntervals[bandIndex];
 
                 // row band is above the range, ignore it in the next iterations
-                if (rowBand.last < row1) {
+                if (bandInterval.last < first) {
                     startIndex = bandIndex + 1;
                     continue;
                 }
 
-                // row band needs to be split (range starts inside the row band)
-                if (rowBand.first < row1) {
-                    rowBands.splice(bandIndex, 0, createRowBand(rowBand.first, row1 - 1, rowBand.ranges.clone()));
-                    rowBand.first = row1;
+                // band interval needs to be split (range starts inside the band)
+                if (bandInterval.first < first) {
+                    bandIntervals.splice(bandIndex, 0, createBandInterval(bandInterval.first, first - 1, createRanges ? bandInterval.ranges.clone() : null));
+                    bandInterval.first = first;
                     startIndex = bandIndex + 1;
                     // next iteration of the for loop will process the current row band again
                     continue;
                 }
 
-                // row band needs to be split (range ends inside the row band)
-                if (row2 < rowBand.last) {
-                    rowBands.splice(bandIndex + 1, 0, createRowBand(row2 + 1, rowBand.last, rowBand.ranges.clone()));
-                    rowBand.last = row2;
+                // band interval needs to be split (range ends inside the band)
+                if (last < bandInterval.last) {
+                    bandIntervals.splice(bandIndex + 1, 0, createBandInterval(last + 1, bandInterval.last, createRanges ? bandInterval.ranges.clone() : null));
+                    bandInterval.last = last;
                 }
 
-                // now, current row band contains the range completely
-                rowBand.ranges.push(range);
+                // now, current band interval contains the range completely
+                if (createRanges) { bandInterval.ranges.push(range); }
+
                 // continue with next range, if end of range found
-                if (row2 === rowBand.last) { return; }
-                // adjust start row index in case a new row band needs to be appended
-                row1 = rowBand.last + 1;
+                if (last === bandInterval.last) { return; }
+
+                // adjust start index in case a new band interval needs to be appended
+                first = bandInterval.last + 1;
             }
 
-            // no row band found, create and append a new row band
-            rowBands.push(createRowBand(row1, row2, new RangeArray(range)));
+            // no band interval found, create and append a new band interval
+            bandIntervals.push(createBandInterval(first, last, createRanges ? new RangeArray(range) : null));
         });
 
-        // create the column intervals for all row bands
-        rowBands.forEach(function (rowBand) {
-            rowBand.intervals = rowBand.ranges.colIntervals().merge();
-            delete rowBand.ranges;
+        // sort the ranges in each band (option 'ranges'), create the merged intervals (option 'intervals')
+        bandIntervals.forEach(function (bandInterval) {
+            // create the merged intervals from the original ranges
+            if (addIntervals) { bandInterval.intervals = bandInterval.ranges.intervals(!columns).merge(); }
+            // sort the original ranges, or remove them completely
+            if (addRanges) { bandInterval.ranges.sortBy(function (range) { return range.getStart(!columns); }); } else { delete bandInterval.ranges; }
         });
-        return rowBands;
+
+        // further merge adjoining band intervals with equal merged inner intervals originating from different
+        // ranges (only required, if these ranges will not be returned)
+        if (!addRanges && addIntervals) {
+            bandIntervals.forEachReverse(function (bandInterval, index) {
+                var nextInterval = bandIntervals[index + 1];
+                if (nextInterval && (bandInterval.last + 1 === nextInterval.first) && bandInterval.intervals.equals(nextInterval.intervals)) {
+                    bandInterval.last = nextInterval.last;
+                    bandIntervals.splice(index + 1, 1);
+                }
+            });
+        }
+
+        return bandIntervals;
     }
 
     /**
-     * Converts the passed array of row bands to an array cell range addresses.
+     * Converts the passed array of row bands to an array cell range addresses,
+     * as returned by the public method RangeArray.merge().
      *
      * @param {IntervalArray} rowBands
-     *  An array of row bands, as returned for example by the static function
-     *  getRowBandsFromRanges(). Each array element must contain an additional
+     *  An array of row bands, as returned for example by the method
+     *  RangeArray.getRowBands(). Each array element must contain an additional
      *  property 'intervals' containing the column intervals of the row band.
      *
      * @returns {RangeArray}
      *  The array of cell range addresses resulting from the passed row bands.
      */
-    function getRangesFromRowBands(rowBands) {
+    function mergeRangesFromRowBands(rowBands) {
 
-        var // resulting array of cell range addresses
-            resultRanges = new RangeArray(),
-            // current ranges whose last row ends in the current row band
-            bandRanges = [];
+        // resulting array of cell range addresses
+        var resultRanges = new RangeArray();
+        // current ranges whose last row ends in the current row band
+        var bandRanges = [];
 
         // appends the passed ranges to the result array
         function appendResultRanges(ranges) {
@@ -142,10 +159,10 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
         // build ranges from the row bands and their column intervals
         rowBands.forEach(function (rowBand, bandIndex) {
 
-            var // the preceding row band
-                prevRowBand = rowBands[bandIndex - 1],
-                // array index into the bandRanges array
-                bandRangeIndex = 0;
+            // the preceding row band
+            var prevRowBand = rowBands[bandIndex - 1];
+            // array index into the bandRanges array
+            var bandRangeIndex = 0;
 
             // try to extend ranges from the previous row band with ranges from the current row band
             if (prevRowBand && (prevRowBand.last + 1 === rowBand.first)) {
@@ -325,11 +342,23 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
         });
 
         // convert the row bands to an array of cell ranges
-        return getRangesFromRowBands(rowBands);
+        return mergeRangesFromRowBands(rowBands);
     };
 
     // public methods ---------------------------------------------------------
 
+    /**
+     * Returns a unique string key for this array of cell range addresses that
+     * can be used for example as key in an associative map. This method is
+     * faster than the method RangeArray.toString().
+     *
+     * @returns {String}
+     *  A unique string key for this instance.
+     */
+    RangeArray.prototype.key = function () {
+        return this.map(function (range) { return range.key(); }).join(' ');
+    };
+
     /**
      * Returns the number of cells covered by all cell range address.
      *
@@ -606,18 +635,106 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      * contain any duplicate cell range addresses.
      *
      * @returns {RangeArray}
-     *  A copy of this cell range address array without any duplicates.
+     *  A copy of this cell range address array without any duplicates. The
+     *  array will contain the same ranges as contained in this array (no deep
+     *  clones of the ranges).
      */
     RangeArray.prototype.unify = function () {
-        var result = new RangeArray(), map = {};
-        this.forEach(function (range) {
+
+        // nothing to do for empty array, or single range; but return a cloned array
+        if (this.length <= 1) { return this.clone(); }
+
+        // a map with the unique keys of all result ranges (prevents to search for duplicates in the result)
+        var map = {};
+
+        // remove all ranges from the result that are already contained in the map
+        return this.reject(function (range) {
             var key = range.key();
-            if (!map[key]) {
-                result.push(range);
-                map[key] = true;
-            }
+            if (map[key]) { return true; }
+            map[key] = true;
         });
-        return result;
+    };
+
+    /**
+     * Returns a new array with only the cell range addresses in this array
+     * that are not completely covered by other cell ranges in this array.
+     *
+     * @returns {RangeArray}
+     *  A new array with only the cell range addresses in this array that are
+     *  not completely covered by other cell ranges in this array. The array
+     *  will contain the same ranges as contained in this array (no deep clones
+     *  of the ranges).
+     */
+    RangeArray.prototype.filterCovered = function () {
+
+        // nothing to do for empty array, or single range; but return a cloned array
+        if (this.length <= 1) { return this.clone(); }
+
+        // RangeArray.unify() is fast and may help to reduce the following O(n^2) loop
+        var result = this.unify();
+
+        // remove all ranges from the result that are covered by any other range in the array
+        // (duplicate ranges have been removed above, therefore they cannot remove each other)
+        return result.reject(function (range1, index1) {
+            // remove range1 from the result, if it is covered by another range in the array
+            return result.some(function (range2, index2) {
+                return (index1 !== index2) && range2.contains(range1);
+            });
+        });
+    };
+
+    /**
+     * Divides the cell range addresses into a sorted array of column intervals
+     * representing the left and right boundaries of all cell ranges.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.ranges=false]
+     *      If set to true, the elements in the returned array will contain the
+     *      additional property 'ranges' (instane of class RangeArray) with the
+     *      addresses of the original cell ranges covering the respective
+     *      column band, sorted by start row index.
+     *  @param {Boolean} [options.intervals=false]
+     *      If set to true, the elements in the returned array will contain the
+     *      additional property 'intervals' (instance of class IntervalArray)
+     *      containing the merged row intervals of the ranges covered by the
+     *      respective column band.
+     *
+     * @returns {IntervalArray}
+     *  An array of column intervals representing all cell range addresses.
+     *  Each array element contains the additional property 'ranges' if the
+     *  option 'ranges' has been set (see above), and the additional property
+     *  'intervals', if the option 'intervals' has been set (see above).
+     */
+    RangeArray.prototype.getColBands = function (options) {
+        return createBandIntervals(this, true, options);
+    };
+
+    /**
+     * Divides the cell range addresses into a sorted array of row intervals
+     * representing the upper and lower boundaries of all cell ranges.
+     *
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.ranges=false]
+     *      If set to true, the elements in the returned array will contain the
+     *      additional property 'ranges' (instane of class RangeArray) with the
+     *      addresses of the original cell ranges covering the respective row
+     *      band, sorted by start column index.
+     *  @param {Boolean} [options.intervals=false]
+     *      If set to true, the elements in the returned array will contain the
+     *      additional property 'intervals' (instance of class IntervalArray)
+     *      containing the merged column intervals of the ranges covered by the
+     *      respective row band.
+     *
+     * @returns {IntervalArray}
+     *  An array of row intervals representing all cell range addresses. Each
+     *  array element contains the additional property 'ranges' if the option
+     *  'ranges' has been set (see above), and the additional property
+     *  'intervals', if the option 'intervals' has been set (see above).
+     */
+    RangeArray.prototype.getRowBands = function (options) {
+        return createBandIntervals(this, false, options);
     };
 
     /**
@@ -625,13 +742,108 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
      * address in the result overlaps with or adjoins exactly to another cell
      * range address.
      *
+     * Example: The range array [A1:D4,C3:F6] will be merged to the ranges
+     * A1:D2 (upper part of first range), A3:F4 (lower part of first range, and
+     * upper part of second range), and C5:F6 (lower part of second range).
+     *
      * @returns {RangeArray}
-     *  An array of merged cell range addresses exactly covering the cell range
-     *  addresses in this array.
+     *  An array of merged cell range addresses that do not overlap, and that
+     *  exactly cover the cell range addresses in this array.
      */
     RangeArray.prototype.merge = function () {
+
         // at most one range: return directly instead of running the complex row band code
-        return (this.length <= 1) ? this.clone(true) : getRangesFromRowBands(getRowBandsFromRanges(this));
+        if (this.length <= 1) { return this.clone(true); }
+
+        // calculate the row bands of the own ranges, add the merged column intervals
+        var rowBands = this.getRowBands({ intervals: true });
+
+        // return the merged ranges calculated from the row bands
+        return mergeRangesFromRowBands(rowBands);
+    };
+
+    /**
+     * Works similar to merging the range array (see method RangeArray.merge())
+     * but divides the passed ranges into smaller parts, so that the resulting
+     * ranges do not cover the boundaries of any of the original ranges.
+     *
+     * Example: The range array [A1:D4,C3:F6] will be partitioned to the ranges
+     * A1:D2 (upper part of first range above the upper boundary of the second
+     * range), A3:B4 (lower-left part of first range that does not cover the
+     * second range), C3:D4 (common parts of both ranges), E3:F4 (upper-right
+     * part of second range), and C5:F6 (lower part of second range).
+     *
+     * @returns {RangeArray}
+     *  An array of cell range addresses that do not overlap, that exactly
+     *  cover the cell range addresses in this array, and that are partitioned
+     *  in a way that the resulting ranges do not cover any boundary of an
+     *  original range. Each range object in the resulting array will contain
+     *  an additional property 'coveredBy' that is a RangeArray containing the
+     *  original ranges of this instance covering that particular result range.
+     */
+    RangeArray.prototype.partition = function () {
+
+        // partition the first range according to the second range
+        function addPartitionRanges(ranges, range1, range2) {
+
+            // ranges do not overlap: nothing to partition
+            if (!range1.overlaps(range2)) {
+                ranges.push(range1.clone());
+                return;
+            }
+
+            // shortcuts to the start/end addresses
+            var start1 = range1.start;
+            var start2 = range2.start;
+            var end1 = range1.end;
+            var end2 = range2.end;
+
+            // row indexes of the inner rows covered by both ranges
+            var row1 = Math.max(start1[1], start2[1]);
+            var row2 = Math.min(end1[1], end2[1]);
+
+            // put the upper part of the first range, if it starts above the second range
+            if (start1[1] < start2[1]) {
+                ranges.push(Range.create(start1[0], start1[1], end1[0], start2[1] - 1));
+            }
+
+            // put the left part of the first range, if it starts left of the second range
+            if (start1[0] < start2[0]) {
+                ranges.push(Range.create(start1[0], row1, start2[0] - 1, row2));
+            }
+
+            // put the common part of both ranges
+            ranges.push(range1.intersect(range2));
+
+            // put the right part of the first range, if it ends right of the second range
+            if (end1[0] > end2[0]) {
+                ranges.push(Range.create(end2[0] + 1, row1, end1[0], row2));
+            }
+
+            // put the lower part of the first range, if it ends below the second range
+            if (end1[1] > end2[1]) {
+                ranges.push(Range.create(start1[0], end2[1] + 1, end1[0], end1[1]));
+            }
+        }
+
+        // process each range in this array, split the ranges that already exist in the result
+        var resultRanges = new RangeArray();
+        this.forEach(function (newRange) {
+
+            // partition all collected result ranges, without adding the new range yet
+            var nextRanges = new RangeArray();
+            resultRanges.forEach(function (resultRange) { addPartitionRanges(nextRanges, resultRange, newRange); });
+
+            // add the uncovered parts of the new range to the result
+            resultRanges = nextRanges.append(new RangeArray(newRange).difference(nextRanges));
+        });
+
+        // add the original ranges for each result range
+        resultRanges.forEach(function (resultRange) {
+            resultRange.coveredBy = this.filter(function (origRange) { return origRange.contains(resultRange); });
+        }, this);
+
+        return resultRanges;
     };
 
     /**
@@ -690,7 +902,7 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
 
                 // check if the ranges cover each other at all
                 if (!range1.overlaps(range2)) {
-                    result.push(range1);
+                    result.push(range1.clone());
                     return;
                 }
 
@@ -724,72 +936,63 @@ define('io.ox/office/spreadsheet/utils/rangearray', [
             return result.length === 0;
         });
 
-        // ensure to return a clone
-        return (result === this) ? this.clone() : result;
+        // ensure to return a deep clone
+        return (result === this) ? this.clone(true) : result;
     };
 
     /**
-     * Returns a shortened array of cell range addresses containing at most as
-     * many cells as specified. If a cell range address in this array does not
-     * fit completely due to the remaining number of allowed cells, it will be
-     * shortened to the appropriate number of upper rows of the range. If the
-     * range cannot be shortened exactly to entire rows, it will be split into
-     * two ranges (the latter range being the leading part of an inner row).
-     * Overlapping cell range addresses will NOT be merged.
+     * Creates an iterator that visits the single addresses of the cell ranges
+     * in this array.
      *
-     * Example: Shortening the ranges A1:C3,D1:F3 to 14 cells results in the
-     * ranges A1:C3,D1:F1,D2:E2.
+     * @param {Object} [options]
+     *  Optional parameters:
+     *  @param {Boolean} [options.reverse=false]
+     *      If set to true, the ranges in this array, and the addresses in all
+     *      ranges, will be visited in reversed order.
+     *  @param {Boolean} [options.columns=false]
+     *      If set to true, the addresses in the cell ranges will be generated
+     *      in vertical order.
+     *  @param {Number} [options.begin]
+     *      If specified, only the ranges with an index greater than or equal
+     *      to this value (in reversed mode: with an index less than or equal
+     *      to this value) will be visited. If omitted, all ranges from the
+     *      beginning (in reverse mode: from the end) of this array will be
+     *      visited.
+     *  @param {Number} [options.end]
+     *      If specified, only the ranges with an index less than this value
+     *      (in reverse mode: with an index greater than this value) will be
+     *      visited (half-open interval!). If omitted, all ranges to the end
+     *      (in reverse mode: to the beginning) of this array will be visited.
      *
-     * @param {Number} maxCells
-     *  The maximum number of cells allowed in the resulting array.
-     *
-     * @returns {RangeArray}
-     *  The shortened array of cell range addresses.
+     * @returns {Object}
+     *  An iterator object that implements the standard EcmaScript iterator
+     *  protocol, i.e. it provides the method next() that returns a result
+     *  object with the following properties:
+     *  - {Address} value
+     *      The resulting address inside the cell range currently visited.
+     *  - {Range} range
+     *      The original cell range from this range array containing the cell
+     *      address currently visited.
+     *  - {Number} index
+     *      The array index of the cell range in the property 'range' of this
+     *      result object.
      */
-    RangeArray.prototype.shortenTo = function (maxCells) {
+    RangeArray.prototype.addressIterator = function (options) {
 
-        // the resulting cell ranges
-        var result = new RangeArray();
+        // creates an address iterator from the result of the outer array iterator
+        function createAddressIterator(range) {
+            return range.iterator(options);
+        }
 
-        Utils.iterateArray(this, function (range) {
+        // combines the results of the outer and inner iterators
+        function createIteratorResult(arrayResult, addressResult) {
+            addressResult.range = arrayResult.value;
+            addressResult.index = arrayResult.index;
+            return addressResult;
+        }
 
-            // no more cells left (e.g., previous range has occupied the last cell)
-            if (maxCells <= 0) { return Utils.BREAK; }
-
-            var // number of cells in the current range
-                cells = range.cells();
-
-            // push entirely fitting range, continue with next range
-            if (cells <= maxCells) {
-                result.push(range);
-                maxCells -= cells;
-                return;
-            }
-
-            // shorten the range to entire rows
-            var rows = Math.floor(maxCells / range.cols());
-            if (rows > 0) {
-                range = range.clone();
-                range.end[1] = range.start[1] + rows - 1;
-                result.push(range);
-                maxCells -= range.cols() * rows;
-            }
-
-            // adjust the range to refer to the split row only
-            range = range.clone();
-            range.start[1] = range.end[1] = range.start[1] + rows;
-
-            // add remaining part of the last row
-            if (maxCells > 0) {
-                range.end[0] = range.start[0] + maxCells - 1;
-                result.push(range);
-            }
-
-            // last range has been pushed partly, stop iteration
-            return Utils.BREAK;
-        });
-
-        return result;
+        // the nested iterator, combining an outer array iterator with an inner address iterator
+        return IteratorUtils.createNestedIterator(this.iterator(options), createAddressIterator, createIteratorResult);
     };
 
     // exports ================================================================
