@@ -17,10 +17,10 @@ define('io.ox/office/spreadsheet/utils/sheetselection', [
 
     'use strict';
 
-    var // convenience shortcuts
-        Address = SheetUtils.Address,
-        Range = SheetUtils.Range,
-        RangeArray = SheetUtils.RangeArray;
+    // convenience shortcuts
+    var Address = SheetUtils.Address;
+    var Range = SheetUtils.Range;
+    var RangeArray = SheetUtils.RangeArray;
 
     // private global functions ===============================================
 
@@ -56,6 +56,23 @@ define('io.ox/office/spreadsheet/utils/sheetselection', [
      * @property {Array<Array<Number>>} drawings
      *  The positions of all selected drawing frames in the sheet, as integer
      *  arrays (without leading sheet index).
+     *
+     * @param {RangeArray|Range} [ranges]
+     *  The addresses of all selected cell ranges, or a single range address.
+     *  If omitted, the new object will be constructed with an empty array of
+     *  range addresses.
+     *
+     * @param {Number} [active=0]
+     *  Element index of the active range in the property 'ranges'.
+     *
+     * @param {Address} [address]
+     *  The address of the active cell in the active range. If omitted, the
+     *  top-left cell of the active range will be used.
+     *
+     * @param {Array<Array<Number>>} [drawings]
+     *  The positions of all selected drawing frames in the sheet, as integer
+     *  arrays (without leading sheet index). If omitted, an empty array will
+     *  be created.
      */
     function SheetSelection(ranges, active, address, drawings) {
 
