@@ -16,9 +16,8 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
     'io.ox/office/spreadsheet/utils/sheetutils',
     'io.ox/office/spreadsheet/utils/operations',
     'io.ox/office/spreadsheet/model/formula/tokenarray',
-    'io.ox/office/drawinglayer/view/chartstyleutil',
     'gettext!io.ox/office/spreadsheet/main'
-], function (Utils, SheetUtils, Operations, TokenArray, ChartStyleUtil, gt) {
+], function (Utils, SheetUtils, Operations, TokenArray, gt) {
 
     'use strict';
 
@@ -36,7 +35,7 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
     var DEFAULT_LINECOLOR = { transformations: [{ type: 'lumMod', value: 15000 }, { type: 'lumOff', value: 85000 }], type: 'scheme', value: 'text1' };
     var STANDARD_SHAPE = { type: 'solid', color: DEFAULT_LINECOLOR, width: 36 };
-    var NONE_SHAPE = { type: 'none' };
+    var NONE_SHAPE = { type: 'none', color: null, width: null };
     var HEAD_CHAR = { fontSize: 16, bold: false };
 
     var INSERT_DEFAULTS = (function () {
@@ -69,16 +68,10 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
     }());
 
     function getFormula(docModel, sheet, from, to) {
-        if (!from) {
-            throw 'no from assigned';
-        }
         var range = new Range(from, to);
-        var tokenArray = new TokenArray(docModel, { temp: true });
+        var tokenArray = new TokenArray(docModel, 'chart');
         tokenArray.appendRange(range, { sheet: sheet, abs: true });
-        var formula = tokenArray.getFormula('op');
-        tokenArray.destroy();
-
-        return formula;
+        return tokenArray.getFormula('op');
     }
 
     function addDataSeries(docModel, generator, options) {
@@ -358,64 +351,65 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
         var bottAddress = new Address(start[0], bottEntry ? bottEntry.index : start[1]);
 
         var ranges = new Range3DArray(
-                Range3D.createFromAddress(bottAddress, sourceSheet),
-                Range3D.createFromAddress(rightAddress, sourceSheet),
-                Range3D.createFromAddress(start, sourceSheet)
-            );
+            Range3D.createFromAddress(bottAddress, sourceSheet),
+            Range3D.createFromAddress(rightAddress, sourceSheet),
+            Range3D.createFromAddress(start, sourceSheet)
+        );
 
-        var promise = docModel.queryCellContents([ranges], { attributes: true });
+        // first array element of the result is an array with the contents of the three cells
+        var res = docModel.getRangeContents(ranges, { attributes: true, display: true });
+        var bottomCell = res[0];
+        var rightCell = res[1];
+        var startCell = res[2];
 
-        promise = promise.then(function (res) {
+        function cellIsLabel(cell) {
+            if (!startCell) { return false; }
+            if (!startCell.display) { return true; } // empty strings (blank cells) or null values (invalid number format)
+            return cell.format.isAnyDateTime() || !_.isNumber(cell.value);
+        }
 
-            var bottom = false;
-            var right = false;
+        var bottom = false;
+        var right = false;
 
-            // first array element of the result is an array with the contents of the three cells
-            var bottomCell = res[0][0];
-            var rightCell = res[0][1];
-            var startCell = res[0][2];
-
-            function cellIsLabel(cell) {
-                if (!startCell.display) { return true; } // empty strings (blank cells) or null values (invalid number format)
-                return cell.format.isAnyDateTime() || !_.isNumber(cell.result);
-            }
-
-            if (cols === 1 || rows === 1) {
-                var firstString = !_.isNumber(startCell.result);
+        if (cols === 1 || rows === 1) {
+            if (axis !== 0 && axis !== 1) {
                 if (cols === 1) {
                     axis = 0;
-                    if (firstString) {
-                        right = true;
-                    }
                 } else {
                     axis = 1;
-                    if (firstString) {
-                        bottom = true;
-                    }
+                }
+            }
+            var firstString = !_.isNumber(startCell.value);
+            if (axis === 1) {
+                if (firstString) {
+                    bottom = true;
                 }
             } else {
-                bottom = cellIsLabel(bottomCell);
-                right = cellIsLabel(rightCell);
-            }
-
-            if (!_.isUndefined(forceTitle)) {
-                if (axis === 0) {
-                    right = forceTitle;
-                } else if (axis === 1) {
-                    bottom = forceTitle;
+                if (firstString) {
+                    right = true;
                 }
             }
-            if (!_.isUndefined(forceNames)) {
-                if (axis === 0) {
-                    bottom = forceNames;
-                } else if (axis === 1) {
-                    right = forceNames;
-                }
-            }
-            return { cells: [bottom, right], axis: axis };
-        });
+        } else {
+            bottom = cellIsLabel(bottomCell);
+            right = cellIsLabel(rightCell);
+        }
 
-        return promise;
+        if (!_.isUndefined(forceTitle)) {
+            if (axis === 0) {
+                right = forceTitle;
+            } else if (axis === 1) {
+                bottom = forceTitle;
+            }
+        }
+        if (!_.isUndefined(forceNames)) {
+            if (axis === 0) {
+                bottom = forceNames;
+            } else if (axis === 1) {
+                right = forceNames;
+            }
+        }
+
+        return $.when({ cells: [bottom, right], axis: axis });
     }
 
     // static class ChartCreator ==============================================
@@ -458,6 +452,10 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
             return docView.insertDrawing('chart', attrs, function (generator, sheet, position) {
 
+                if (!chart.chartStyleId) {
+                    chart.chartStyleId = 2;
+                }
+
                 var seriesCount = generateSeriesOperations(docModel, range, sheet, generator, position, data.cells, data.axis, chart);
 
                 var legendPos;
@@ -484,11 +482,6 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
                         defaults = INSERT_DEFAULTS.normal;
                 }
 
-                if (!chart.chartStyleId) {
-                    chart.chartStyleId = 2;
-                    generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: { chart: { chartStyleId: 2 }, fill: { color: { type: 'scheme', value: 'light1', fallbackValue: 'FFFFFF' } } } });
-                }
-
                 generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, { axis: 'x', attrs: defaults.xAxis });
                 generator.generateDrawingOperation(Operations.SET_CHART_AXIS_ATTRIBUTES, position, { axis: 'y', attrs: defaults.yAxis });
                 generator.generateDrawingOperation(Operations.SET_CHART_GRIDLINE_ATTRIBUTES, position, { axis: 'x', attrs: defaults.xGrid });
@@ -528,7 +521,7 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
     ChartCreator.updateSeries = function (app, sourceRange, sourceSheet, chartModel, axis, chartAttrs, forceTitle, forceNames) {
 
         if (!chartAttrs) {
-            var mergedAttributes = chartModel.getMergedAttributes();
+            var mergedAttributes = chartModel.getMergedAttributeSet(true);
             //CURVED is a workaround, filter has not all the information it needs!
             chartAttrs = {
                 type: mergedAttributes.chart.type,
@@ -555,12 +548,28 @@ define('io.ox/office/spreadsheet/view/chartcreator', [
 
             return chartModel.getSheetModel().createAndApplyOperations(function (generator) {
 
-                var seriesCount = generateSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, data.cells, axis, chartAttrs, lineAttrs);
+                var clonedData = chartModel.getCloneData(),
+                    oldCount = chartModel.getSeriesCount(),
+                    seriesCount = generateSeriesOperations(docModel, sourceRange, sourceSheet, generator, position, data.cells, axis, chartAttrs, lineAttrs);
 
-                _.times(chartModel.getSeriesCount(), function () {
+                _.times(oldCount, function () {
                     generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: seriesCount });
                 });
-            });
+
+                // UNDO ---
+                generator.generateDrawingOperation(Operations.SET_DRAWING_ATTRIBUTES, position, { attrs: clonedData.attrs }, { undo: true });
+
+                _.each(clonedData.series, function (obj, index) {
+                    generator.generateDrawingOperation(Operations.INSERT_CHART_DATASERIES, position, { series: index, attrs: obj }, { undo: true });
+                });
+
+                _.times(seriesCount, function () {
+                    generator.generateDrawingOperation(Operations.DELETE_CHART_DATASERIES, position, { series: clonedData.series.length }, { undo: true });
+                });
+
+                // callback MUST return a promise
+                return $.when();
+            }, { storeSelection: true });
         });
 
         return promise;
