@@ -42,39 +42,39 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
      */
     function ActiveSheetGroup(docView) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the document model
-            docModel = docView.getDocModel(),
+        // the document model
+        var docModel = docView.getDocModel();
 
-            // the context menu with additional sheet actions
-            contextMenu = null,
+        // the context menu with additional sheet actions
+        var contextMenu = null;
 
-            // the scroll button nodes
-            prevButton = $(Forms.createButtonMarkup({ icon: 'fa-angle-left' })).addClass('scroll-button'),
-            nextButton = $(Forms.createButtonMarkup({ icon: 'fa-angle-right' })).addClass('scroll-button'),
+        // the scroll button nodes
+        var prevButton = $(Forms.createButtonMarkup({ icon: 'fa-angle-left' })).addClass('scroll-button');
+        var nextButton = $(Forms.createButtonMarkup({ icon: 'fa-angle-right' })).addClass('scroll-button');
 
-            // keep track of active sheet index (scroll to active after change)
-            activeIndex = -1,
+        // keep track of active sheet index (scroll to active after change)
+        var activeIndex = -1;
 
-            // index of the first and last sheet tab button currently visible
-            firstIndex = 0,
-            lastIndex = 0,
-            scrollable = false,
+        // index of the first and last sheet tab button currently visible
+        var firstIndex = 0;
+        var lastIndex = 0;
+        var scrollable = false;
 
-            // the sheet tab button currently dragged
-            dndButtonNode = null,
+        // the sheet tab button currently dragged
+        var dndButtonNode = null;
 
-            // tracker node shown while dragging a sheet button
-            dndTrackerNode = $('<div id="io-ox-office-spreadsheet-sheet-dnd-tracker"><div class="caret-icon"></div></div>'),
+        // tracker node shown while dragging a sheet button
+        var dndTrackerNode = $('<div id="io-ox-office-spreadsheet-sheet-dnd-tracker"><div class="caret-icon"></div></div>');
 
-            // helper node inside the tracker node containing the sheet name
-            dndSheetNode = $('<span class="sheet-name">').appendTo(dndTrackerNode),
+        // helper node inside the tracker node containing the sheet name
+        var dndSheetNode = $('<span class="sheet-name">').appendTo(dndTrackerNode);
 
-            // index of the sheet tab button is currently dragged, and the target button index
-            dndStartIndex = -1,
-            dndTargetIndex = -1;
+        // index of the sheet tab button is currently dragged, and the target button index
+        var dndStartIndex = -1;
+        var dndTargetIndex = -1;
 
         // base constructors --------------------------------------------------
 
@@ -103,36 +103,25 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
          */
         function renderSheetButtons() {
 
-            var // the root node of this group
-                groupNode = self.getNode(),
-                // the inner width of the group (space available for buttons)
-                groupWidth = groupNode.width(),
-                // all sheet tab buttons
-                sheetButtons = self.getOptionButtons(),
-                // the width of all sheet buttons
-                buttonsWidth = 0,
-                // relative start/end position of all sheet buttons
-                buttonPositions = null,
-                // total width of all buttons, including scroll buttons
-                totalWidth = 0,
-                // remaining width available in the group node for sheet buttons
-                remainingWidth = 0,
-                // maximum index of button that can be shown at the left border (without gap to right border)
-                maxIndex = 0;
+            // the root node of this group
+            var groupNode = self.getNode();
+            // the inner width of the group (space available for buttons)
+            var groupWidth = groupNode.width();
 
-            // do nothing if there are no sheets available (yet)
+            // all sheet tab buttons; do nothing if there are no sheets available (yet)
+            var sheetButtons = self.getOptionButtons();
             if (sheetButtons.length === 0) { return; }
 
             // initialize all sheet buttons, hide scroll buttons
             showAllSheetButtons();
 
             // get total width of all buttons (bug 35869: round down, browsers may report slightly oversized width due to text nodes)
-            buttonsWidth = Math.floor(sheetButtons.last().offset().left + sheetButtons.last().outerWidth() - sheetButtons.first().offset().left);
+            var buttonsWidth = Math.floor(sheetButtons.last().offset().left + sheetButtons.last().outerWidth() - sheetButtons.first().offset().left);
             if (buttonsWidth <= groupWidth) { return; }
 
             // collect position information of all buttons (performance: once for all buttons, before manipulating DOM again)
             var leadingOffset = sheetButtons.first().offset().left;
-            buttonPositions = sheetButtons.map(function () {
+            var buttonPositions = sheetButtons.map(function () {
                 var buttonOffset = $(this).offset().left - leadingOffset;
                 return {
                     offset: buttonOffset,
@@ -141,6 +130,13 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
                 };
             });
 
+            // total width of all buttons, including scroll buttons
+            var totalWidth = 0;
+            // remaining width available in the group node for sheet buttons
+            var remainingWidth = 0;
+            // maximum index of button that can be shown at the left border (without gap to right border)
+            var maxIndex = 0;
+
             // do not show scroll buttons, if there is only one visible sheet
             if (sheetButtons.length > 1) {
 
@@ -233,8 +229,8 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             // do not try to scroll, if all buttons are visible
             if (!scrollable) { return; }
 
-            var // index of the old last visible sheet
-                oldLastIndex = lastIndex;
+            // index of the old last visible sheet
+            var oldLastIndex = lastIndex;
 
             // move to previous sheets until the index of the last sheet has changed
             while ((firstIndex > 0) && (oldLastIndex === lastIndex)) {
@@ -252,10 +248,10 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
             // do not try to scroll, if all buttons are visible
             if (!scrollable) { return; }
 
-            var // all sheet tab buttons
-                sheetButtons = self.getOptionButtons(),
-                // index of the old last visible sheet
-                oldLastIndex = lastIndex;
+            // all sheet tab buttons
+            var sheetButtons = self.getOptionButtons();
+            // index of the old last visible sheet
+            var oldLastIndex = lastIndex;
 
             // move to next sheets until the index of the last sheet has changed
             while ((lastIndex >= 0) && (lastIndex + 1 < sheetButtons.length) && (oldLastIndex === lastIndex)) {
@@ -333,16 +329,16 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
          */
         function dndTrackingMoveHandler(event) {
 
-            var // all sheet tab buttons
-                buttonNodes = self.getOptionButtons(),
-                // all visible sheet tab buttons
-                visibleNodes = Forms.filterVisibleNodes(buttonNodes),
-                // absolute position and size of all visible sheet buttons
-                buttonRects = _.map(visibleNodes.get(), Utils.getNodePositionInPage),
-                // search rectangle of hovered sheet tab button in array of visible button rectangles
-                rectIndex = Utils.findLastIndex(buttonRects, function (data) {
-                    return (data.left + data.width / 2) <= event.pageX;
-                }, { sorted: true }) + 1;
+            // all sheet tab buttons
+            var buttonNodes = self.getOptionButtons();
+            // all visible sheet tab buttons
+            var visibleNodes = Forms.filterVisibleNodes(buttonNodes);
+            // absolute position and size of all visible sheet buttons
+            var buttonRects = _.map(visibleNodes.get(), Utils.getNodePositionInPage);
+            // search rectangle of hovered sheet tab button in array of visible button rectangles
+            var rectIndex = Utils.findLastIndex(buttonRects, function (data) {
+                return (data.left + data.width / 2) <= event.pageX;
+            }, { sorted: true }) + 1;
 
             // calculate new insertion index (add number of leading hidden buttons)
             dndTargetIndex = buttonNodes.index(visibleNodes[0]) + rectIndex;
@@ -353,12 +349,12 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
                 return;
             }
 
-            var // whether to show the tracking position after the last visible button
-                trailing = rectIndex >= buttonRects.length,
-                // position of the sheet tab button following the tracking position
-                buttonRect = buttonRects[rectIndex] || _.last(buttonRects),
-                // exact insertion position (center of the tracker node), in pixels
-                offsetX = buttonRect.left + (trailing ? buttonRect.width : 0);
+            // whether to show the tracking position after the last visible button
+            var trailing = rectIndex >= buttonRects.length;
+            // position of the sheet tab button following the tracking position
+            var buttonRect = buttonRects[rectIndex] || _.last(buttonRects);
+            // exact insertion position (center of the tracker node), in pixels
+            var offsetX = buttonRect.left + (trailing ? buttonRect.width : 0);
 
             // update position of the tracking icon
             dndTrackerNode.show().css({
@@ -396,15 +392,17 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
                 // adjust drop position, if target position follows source position
                 if (dndStartIndex < dndTargetIndex) { dndTargetIndex -= 1; }
 
-                var // the sheet tab button nodes
-                    buttonNodes = self.getOptionButtons(),
-                    // source sheet index for document operation
-                    fromSheet = Utils.getElementAttributeAsInteger(buttonNodes[dndStartIndex], 'data-index', -1),
-                    // target sheet index for document operation
-                    toSheet = Utils.getElementAttributeAsInteger(buttonNodes[dndTargetIndex], 'data-index', -1);
+                // the sheet tab button nodes
+                var buttonNodes = self.getOptionButtons();
+                // source sheet index for document operation
+                var fromSheet = Utils.getElementAttributeAsInteger(buttonNodes[dndStartIndex], 'data-index', -1);
+                // target sheet index for document operation
+                var toSheet = Utils.getElementAttributeAsInteger(buttonNodes[dndTargetIndex], 'data-index', -1);
 
                 // change sheet order in the document
-                docModel.moveSheet(fromSheet, toSheet);
+                if ((fromSheet >= 0) && (toSheet >= 0)) {
+                    docView.executeControllerItem('sheet/move', { from: fromSheet, to: toSheet });
+                }
             }
 
             // remove tracking icon, focus back to document
@@ -488,14 +486,17 @@ define('io.ox/office/spreadsheet/view/control/activesheetgroup', [
         Forms.setToolTip(prevButton, { tooltip: gt('Scroll to the previous sheet') });
         Forms.setToolTip(nextButton, { tooltip: gt('Scroll to the next sheet') });
 
-        // build the list of available sheets once after import
-        this.waitForImportSuccess(fillList);
+        // initialization after import
+        this.waitForImportSuccess(function () {
+            // build the list of available sheets once after import
+            fillList();
+            // rebuild the list of available sheets after it has been changed
+            this.listenTo(docView, 'change:sheets', fillList);
+            this.listenTo(docModel, 'change:sheet:attributes', fillList); // e.g. sheet protection
+        }, this);
 
         // register handler early for fast preview during import
-        this.listenTo(docView, 'change:sheets', fillList);
-
-        // rebuild the list of available sheets after it has been changed
-        this.listenTo(docModel, 'change:sheet:attributes', fillList); // e.g. sheet protection
+        this.listenTo(docView, 'preview:activesheet', fillList);
 
         // cancel button drag&drop when losing edit rights
         this.listenTo(docModel, 'change:editmode', function (event, editMode) {
