@@ -38,14 +38,14 @@ define('io.ox/office/spreadsheet/view/control/activesheetlist', [
      */
     function ActiveSheetList(docView, initOptions) {
 
-        var // self reference
-            self = this,
+        // self reference
+        var self = this;
 
-            // the document model
-            docModel = docView.getDocModel(),
+        // the document model
+        var docModel = docView.getDocModel();
 
-            // whether to show the sheet name as label text
-            showNames = Utils.getBooleanOption(initOptions, 'showNames', false);
+        // whether to show the sheet name as label text
+        var showNames = Utils.getBooleanOption(initOptions, 'showNames', false);
 
         // base constructors --------------------------------------------------
 
@@ -79,14 +79,17 @@ define('io.ox/office/spreadsheet/view/control/activesheetlist', [
 
         // initialization -----------------------------------------------------
 
-        // build the list of available sheets once after import
-        this.waitForImportSuccess(fillList);
+        // initialization after import
+        this.waitForImportSuccess(function () {
+            // build the list of available sheets once after import
+            fillList();
+            // rebuild the list of available sheets after it has been changed
+            this.listenTo(docView, 'change:sheets', fillList);
+            this.listenTo(docModel, 'change:sheet:attributes', fillList); // e.g. sheet protection
+        }, this);
 
         // register handler early for fast preview during import
-        this.listenTo(docView, 'change:sheets', fillList);
-
-        // rebuild the list of available sheets after it has been changed
-        this.listenTo(docModel, 'change:sheet:attributes', fillList); // e.g. sheet protection
+        this.listenTo(docView, 'preview:activesheet', fillList);
 
         // destroy all class members on destruction
         this.registerDestructor(function () {
